
import java.io.*;
import java.util.StringTokenizer;
import java.util.Vector;

// TODO multiline text literals

// TODO remove both mode

public class PreconditionFinder {
	
	// Just for now. Will convert this to prompt for input file later
	static File dir = new File("C:\\Users\\jcmaxwe3\\workspace\\JavaPrologTool\\Prolog");
	
	// File that contains the list of preconditions the user has to resolve by hand
	static PrintStream unhandledPreconditionsFile;
	
	// Vector to store the preconditions
	static Vector<String> preconditions = new Vector<String>();
	
	// Vector to store the rules
	static Vector<Rule> rules = new Vector<Rule>();
	
	// Vector to store the temporary variables
	static Vector<Rule> temporaryVariables = new Vector<Rule>();
	
	// Output file handles
	static PrintStream prelistOut;
	static PrintStream presetOut;
	
	// Output file name for a precondition list
	private static final String PRECONDITION_LIST_FILENAME = "prelist.xml";
	
	// Output file name for a precontition set list
	private static final String PRECONDITION_SET_FILENAME = "preset.xml";
	
	// Constants for command line options
	private static final String MINUS = "-";
	private static final String PRELIST = "prelist";
	private static final String HELP = "h";
	private static final String PRESET = "preset";
	
	// Variable and constants for what mode the precondition finder is in
	private static final int BOTH_MODE = 0;
	private static final int PRELIST_MODE = 1;
	private static final int PRESET_MODE = 2;
	private static int mode = BOTH_MODE;
	
	// Constant for when the rule type is a temporary variable
	private static final String TEMPORARY_VARIABLE_RULE_TYPE = "Temporary Variable";
	
	// Vector to store a list of text patterns to ignore. For example, in the
	// HIPAA production rule model, we configure the PreconditionFinder to 
	// ignore any precondition that contains "add_to_wm"
	static String ignoreList[] = new String[1];
	
	// The location of the configuration file
	private static final String CONFIGURATION_FILE_NAME = "C:\\Users\\jcmaxwe3\\workspace\\JavaPrologTool\\Prolog\\config.ini";
	
	
	public static void main(String args[]) {
		System.out.println("\nASSUMPTION: All condititionals (\":-\") in the " +
			"Prolog file are on a separate line from the preconditions for " + 
			"a rule.");
		if(args.length == 0) {
			System.out.println("usage: java PreconditionFinder -options\n" + 
				"\tuse java PreconditionFinder " + MINUS + HELP + " for help.");
		}
		else {
			handleCommandLineOptions(args);
		}
		
	} // close main
	
	
	/** Handles the command line options.
	 * @param args The list of command line options. */
	private static void handleCommandLineOptions(String args[]) {
		// First, configure the program
		readConfigurationFile();
		
		if(args[0].equals(MINUS + HELP)) {
			System.out.println(getHelpText());
		}
		
		else if(args[0].equals(MINUS + PRELIST)) {
			mode = PRELIST_MODE;
		}
		
		else if(args[0].equals(MINUS + PRESET)) {
			mode = PRESET_MODE;
		}
		
		generatePrelist();
	}
	
	
	/** Handles the control flow when generating a precondition list. */
// TODO: refactor method name
	private static void generatePrelist() {
		// Set up the file we are going to write to
		try {
			switch(mode) {
			case BOTH_MODE:
				prelistOut = new PrintStream(new FileOutputStream("prelist.xml"));
				presetOut = new PrintStream(new FileOutputStream("preset.xml"));
				break;
			case PRELIST_MODE:
				prelistOut = new PrintStream(new FileOutputStream("prelist.xml"));
				break;
			case PRESET_MODE:
				presetOut = new PrintStream(new FileOutputStream("preset.xml"));
				break;
			}
		} catch(IOException e) { e.printStackTrace(); }
		
		// Now set up the file to write to when we can't handle preconditions
		try {
			unhandledPreconditionsFile = new PrintStream(new FileOutputStream("unhandledPreconditions.txt"));
		} catch(IOException e) { e.printStackTrace(); }
		
		// Read the files in the directory
		File files[] = dir.listFiles();
		
		for(int i=0; i<files.length; i++) {
//for(int i=0; i<1; i++) {   // JUST FOR TESTING
			String fileName = files[i].getPath();
//System.out.println("examining:" + fileName);
			// Do not read glossary files
			if(fileName.contains("glossary.pl") || fileName.contains("glossary.pro") || fileName.contains("glossary") || fileName.contains("Glossary"))
				continue;
//if(fileName.contains("aaa")) {
			if(files[i].isFile() && fileName.substring(fileName.length()-3, fileName.length()).equals(".pl")) {
//System.out.println("file found! " + files[i].getPath());
				processFile(files[i]);
			}
//}
		}
		
		// Now print the preconditions
		// Prelist mode print
		if(mode == PRELIST_MODE || mode == BOTH_MODE) {
			prelistOut.println("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
			prelistOut.println("<prelist>");
			for(int i=0; i<preconditions.size(); i++) {
				prelistOut.println("<precondition>" + preconditions.get(i) + "</precondition>");
			}
			prelistOut.println("</prelist>");
		}
		
		// Preset mode print
		if(mode == PRESET_MODE || mode == BOTH_MODE) {
			presetOut.println("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
			presetOut.println("<preset>");
			
			Vector<String> currentPreconditions;
			for(int i=0; i<rules.size(); i++) {
				presetOut.println("<rule>");
				presetOut.println("\t<concept>" + rules.get(i).getType() + "</concept>");
				presetOut.println("\t<head>" + rules.get(i).getHead() + "</head>");
				currentPreconditions = rules.get(i).getPreconditions();
				
				// Expand any temporary variables, if necessary
				currentPreconditions = expandTemporaryVariables(currentPreconditions);
				
				if(currentPreconditions != null) {
					for(int j=0; j<currentPreconditions.size(); j++) {
						presetOut.println("\t<precondition>" + currentPreconditions.get(j) + "</precondition>");
					}
				}
				presetOut.println("</rule>");
				presetOut.println();
			}
			
			presetOut.println("</preset>");
		}
	} // close generatePrelist()
	
	
	/** Handles the control flow for generating a list of precondition sets. */
	private static void generatePreset() {
		// Set up the file we are going to write to
		try {
			prelistOut = new PrintStream(new FileOutputStream("preset.xml"));
		} catch(IOException e) { e.printStackTrace(); }
		
		// Read the files in the directory
		File files[] = dir.listFiles();
		
		for(int i=0; i<files.length; i++) {
		//for(int i=0; i<2; i++) {   // JUST FOR TESTING
			String fileName = files[i].getPath();
			// Do not read glossary files
			if(fileName.contains("glossary.pl") || fileName.contains("glossary.pro"))
				continue;
			if(files[i].isFile() && fileName.substring(fileName.length()-3, fileName.length()).equals(".pl")) {
//System.out.println("file found! " + files[i].getPath());
				processFile(files[i]);
			}
		}
		
	} // close generatePreset()
	
	
	/** Reads the configuration file to set up the PreconditionFinder. */
	private static void readConfigurationFile() {
		// Constants used to read the file
		final String EQUALS = "=";
		final String IGNORE = "ignore";
		
		Vector<String> ignoreThese = new Vector<String>();
		
		try {
			BufferedReader fin = new BufferedReader(new FileReader(CONFIGURATION_FILE_NAME));
			
			String line;
			while ((line = fin.readLine()) != null)   {
				StringTokenizer tokenizer = new StringTokenizer(line,"=",true);
				
				if(tokenizer.nextToken().equals(IGNORE) && tokenizer.nextToken().equals(EQUALS)) {
					String temp = tokenizer.nextToken();
					ignoreThese.add(temp);
//System.out.println("found an ignore: " + temp);
				}
			}
			
			ignoreList = ignoreThese.toArray(ignoreList);
			
//for(int i=0; i<ignoreList.length; i++) {
//System.out.println("ignore list " + i + ":" + ignoreList[i]);	
//}
		} catch(IOException e) { e.printStackTrace(); }
	}
	
	
	/** The money method. This method containes all the logic for processing
	 * the preconditions in a give file.
	 * @param file The file to process. */
	private static void processFile(File file) {
		try {
			BufferedReader fin = new BufferedReader(new FileReader(file));
			Rule currentRule = new Rule();
			
			String line;
			boolean readingPreconditions = false;
			boolean ignoringPreconditions = false;
			boolean shouldStoreRule = false;
			boolean shouldStorePreconditionsInRule = false;
			boolean atEndOfRule = false;
			boolean areAtHead = false;
			while ((line = fin.readLine()) != null)   {
				line = line.trim();
				
//System.out.println("\tExamining:___" + line + "___");
//System.out.println("\treadingPreconditions is now " + readingPreconditions);
				
				// Check to see if we are in preset mode and are at the head of a new rule
				if(mode == PRESET_MODE && !ignoringPreconditions && !readingPreconditions) {
					// Check to see if the head of the rule corresponds to an ontology item
					if(isStartOfRule(line)) {
						currentRule = new Rule();
						shouldStoreRule = true;
						currentRule.setType(determineRuleType(line));
						
						// If the rule has a multiline head, read the multiline
						if(containsUnbalancedParentheses(line)) {
							line = readMultiLine(fin, line, false);
						}
						
						// Remove the neck if necessary
						line = removeNeck(line);
						
						// Add the head to the current rule
						currentRule.setHead(line);
						areAtHead = true;
						
						// Flag that preconditions need to be stored
						shouldStorePreconditionsInRule = true;
						readingPreconditions = true;
//System.out.println("rule read:" + currentRule);
					}
				}

				// Check to see if the IGNORE_PRECONDITIONS attribute is present
				// in the text
				if(line.contains("[IGNORE_PRECONDITIONS]")) {
					ignoringPreconditions = true;
				}

				// Remove comments and text literals from the line
				line = removeComments(line);
				line = removeTextLiterals(line);
				
				// Check for multi-line preconditions
				if(containsUnbalancedParentheses(line)) {
					line = readMultiLine(fin, line, true);
					
					// If the file is not properly formatted, we may not be able to
					// handle the file yet.  Continue processing
					if(line == null)
						continue;
				}
				
				// If the line is empty, continue reading
				if(line.length() == 0)
					continue;
				
				// Do not read preconditions for directives issued to the Prolog
				// inference engine
				else if(line.length() >= 2 && line.substring(0,2).equals(":-")) {
//System.out.println("ignoring directive");
					continue;
				}
				
				// If the line contains a neck, flag that preconditions follow
				// and continue reading
				else if(line.contains(":-")) {
//System.out.println("substring is:___" + line.substring(0,1) + "___");
					readingPreconditions = true;
					continue;
				}
				
				// If we are not reading preconditions, i.e. we are reading
				// facts or multi-line heads, continue reading
				else if(!readingPreconditions) {
//System.out.println("RETURNING, not reading preconditions");
					continue;
				}
				
				// Else we are reading preconditions
				else {
					// Determine if we are at the end of a rule
					// if so, flag to stop reading preconditions and remove the period
					if(line.charAt(line.length() - 1) == '.') {
						readingPreconditions = false;
						atEndOfRule = true;
						if(ignoringPreconditions) {
//System.out.println("IGNORING 1:" + line);
							ignoringPreconditions = false;
							continue;
						}
						line = line.substring(0,line.length() - 1);
//System.out.println("period removed from " + line);
//System.out.println("\treadingPreconditions is now " + readingPreconditions);
					}
					
					// Remove the comma at the end of the rule, if one exists
					if(line.charAt(line.length() - 1) == ',') {
						line = line.substring(0,line.length() - 1);
//System.out.println("comma removed from " + line);
					}
					
					// Now determine if the PreconditionFinder has been configured
					// to ignore this precondition when in prelist mode
					if((shouldIgnorePrecondition(line) || ignoringPreconditions) && mode == PRELIST_MODE) {
//System.out.println("IGNORING 2:" + line);
						continue;
					}
					
					// Now determine if the precondition is one we can't handle
					if(cannotHandlePrecondition(line)) {
						unhandledPreconditionsFile.println(line);
//System.out.println("CANNOT HANDLE:" + line);
						continue;
					}
					
					// Add to preconditions vector if it is not there,
					// and if we are not ignoring preconditions, if we are in prelist mode
					if((mode == PRELIST_MODE || mode == BOTH_MODE) && !preconditions.contains(line)) {
						// But do not add preconditions that are working memory preconditions
						if(!line.startsWith("wm("))
							preconditions.add(line);
					}
					
					// If we are in preset mode and should store the preconditions,
					// add the preconditions to the current rule.
					if((mode == PRESET_MODE || mode == BOTH_MODE) && shouldStorePreconditionsInRule) {
						if(areAtHead) {
							areAtHead = false;
						} else {
							currentRule.addPrecondition(line);
						}
						
//System.out.println("precondition added:" + line);
//System.out.println("shouldStoreRule:" + shouldStoreRule + "atEndOfRule:" + atEndOfRule);
						if(shouldStoreRule && atEndOfRule) {
							shouldStoreRule = false;
							shouldStorePreconditionsInRule = false;
							atEndOfRule = false;
							
							// If the rule is a temporary variable, then store it in
							// the temporary variable vector
							if(TEMPORARY_VARIABLE_RULE_TYPE.equals(currentRule.getType())) {
								temporaryVariables.add(currentRule);
							}
							// Otherwise, store it in the rules vector
							else {
								rules.add(currentRule);
							}
						}
					}
				}
			 } // close while loop
		} catch(IOException e) { e.printStackTrace(); }
		
	}
	
	
	/** Returns a String with the text literals removed from the input String. 
	 * Text literals are replaced with '' 
	 * @param s The String to remove literals from.
	 * @return The String with literals removed. */
	private static String removeTextLiterals(String s) {
		if(!s.contains("'"))
			return s;
		else {
			int startIndex = s.indexOf('\'');
			String textLiteral = "";
			char array[] = s.toCharArray();
			for(int i=startIndex+1; i<array.length; i++) {
				if(array[i] != '\'' ||
					(array[i] == '\'' && i >= 1 && array[i-1] == '\\'))
					textLiteral = textLiteral + array[i];
				else
					break;
			}
			
			String result = s.replace(textLiteral, "");
			
//System.out.println("");
//System.out.println("before removing literal:" + s);
//System.out.println("after removing literal:" + result);

			return result;
		}
	}
	
	
	/** Returns a String with the comments removed from the input String.
	 * @param s The String to remove comments from.
	 * @return The String with comments removed. */
	private static String removeComments(String s) {
		if(!s.contains("%"))
			return s;
		else if(s.charAt(0) == '%')
			return "";
		else {
			return s.substring(0,s.indexOf('%') - 1);
		}
	}
	
	
	/** Determines if the given string is on the list of preconditions to ignore
	 * @param s The string to check.
	 * @return True if the precondition should be ignored, false otherwise. */
	private static boolean shouldIgnorePrecondition(String s) {
		// Do not consider Prolog comparisons
		if(s.contains("\\="))						// TODO: add other prolog comparisons
			return true;
		
		// Do not consider preconditions that start with a variable
		if(Character.isUpperCase(s.charAt(0)))
			return true;
		
		// Do not consider items on the ignore list
		for(int i=0; i<ignoreList.length; i++) {
			if(s.contains(ignoreList[i]))
				return true;
		}
		return false;
	}
	
	
	/** Determines if the given String contains unbalanced parentheses.
	 * @param s The String to check.
	 * @return True if the String contains unbalanced parenetheses, false otherwise. */
	private static boolean containsUnbalancedParentheses(String s) {
		char array[] = s.toCharArray();
		int openParenCount = 0;
		int closeParenCount = 0;
		for(int i=0; i<array.length; i++) {
			if(array[i] == '(')
				openParenCount++;
			if(array[i] == ')')
				closeParenCount++;
		}
		if(openParenCount != closeParenCount)
			return true;
		else return false;
	}
	
	
	/** Recursively handles the case when a single line of prolog code is broken over
	 * multiple lines of the source file. 
	 * @param fin The stream we are reading from.
	 * @param s The portion of the prolog code line that has already been read
	 * @param shouldRemoveTextLiterals Whether or not text literals should be removed from the multiple line statement.
	 * @return The inputted line of prolog code concatonated with the next line 
	 * of the source file.*/
	private static String readMultiLine(BufferedReader fin, String s, boolean shouldRemoveTextLiterals) {
		try {
			String line = fin.readLine();
			if(line == null) {
//System.out.println("s:" + s);
				//throw new Exception("Prolog file not properly formatted: unbalanced parentheses");
System.out.println("Prolog file not properly formatted: unbalanced parentheses");
				return null;
			}
			line = line.trim();
			
			// Remove text literals and comments from the line
			line = removeComments(line);
			if(shouldRemoveTextLiterals) {
				line = removeTextLiterals(line);
			}
			
			s = s + line;
			if(containsUnbalancedParentheses(s))
				s = readMultiLine(fin,s,shouldRemoveTextLiterals);
		} catch(IOException e) { e.printStackTrace(); System.out.println("IOEXCEPTION ENCOUNTERED"); }
		//catch(Exception e2) { e2.printStackTrace(); System.out.println("EXCEPTION ENCOUNTERED"); }
		return s;
	}
	
	
	/** Determines if the PreconditionFinder cannot handle the given precondition
	 * @param s The precondition to check.
	 * @return True if the precondition cannot be handled, false otherwise. */
	private static boolean cannotHandlePrecondition(String s) {
//System.out.println("First char of__" + s + "__is__" + s.charAt(0) + "__");
		
		if(s.contains(";")) {
//System.out.println("");
			
			return true;
		}
		//try {
		if(s.charAt(0) == '(')
			return true;
		else return false;
		//} catch(StringIndexOutOfBoundsException e) { System.out.println("EXCEPTION while processing:__" + s + "__");  return false; }
	}
	
	
	/** Deterimines if the given line is the start of a rule */
	private static boolean isStartOfRule(String line) {
// TODO: need to make this generalizable for other onotlogies
		StringTokenizer tokenizer = new StringTokenizer(line, "(),");
		while(tokenizer.hasMoreTokens()) {
			String token = tokenizer.nextToken();
			if(token.equals("right") || token.equals("obligation") || token.equals("privilege") || token.equals("noRight") ||
					token.equals("power") || token.equals("liability") || token.equals("disability") || token.equals("immunity") || token.equals("implied") || token.startsWith("s16")) {
				return true;
			} else return false;
		}
		return false;  // Default return
	}
	
	
	/** Determines the type of the rule expressed in the given line. */
	private static String determineRuleType(String line) {
// TODO: need to make this generalizable for other onotlogies
		StringTokenizer tokenizer = new StringTokenizer(line, "(),");
		while(tokenizer.hasMoreTokens()) {
			String token = tokenizer.nextToken();
			if(token.equals("right") || token.equals("obligation") || token.equals("privilege") || token.equals("noRight") ||
					token.equals("power") || token.equals("liability") || token.equals("disability") || token.equals("immunity")) {
				return token;
			}
			if(token.equals("implied"))
				return tokenizer.nextToken();
			if(token.startsWith("s16"))
				return TEMPORARY_VARIABLE_RULE_TYPE;
		}
		return null;  // Default return
	}
	
	
	/** Converts all the Prolog variables in the given vector to generic variables, i.e. "_" */
	private static Vector<String> convertToGeneralVariables(Vector<String> v) {
		Vector<String> result = new Vector<String>();
		
		for(int i=0; i<v.size(); i++) {
			String s = v.get(i);
			StringTokenizer tokenizer = new StringTokenizer(s, " (),");
			
			while(tokenizer.hasMoreTokens()) {
				String token = tokenizer.nextToken();
				if(Character.isUpperCase(token.charAt(0))) {
					//String nonVar = token.replace(token.charAt(0),Character.toLowerCase(token.charAt(0))); 
					String genericVar = "_";
					s = s.replace(token,genericVar);
				}
			}
			if(!result.contains(s))
				result.add(s);
		}
		
    	return result;
	}
	
	
	/** Removes the neck from the given line */
	private static String removeNeck(String line) {
		return line.replace(":-","");
	}
	
	
	/** Expands any temporary variables in the list of preconditions. */
	private static Vector<String> expandTemporaryVariables(Vector<String> preconds) {
		if(preconds == null)
			return null;
		
		// The results vector
		Vector<String> v = new Vector<String>();
		
		// For each precondition, determine if it is a temporary variable
		for(int i=0; i<preconds.size(); i++) {
			String s = ((String)preconds.get(i)).trim();
			
			// Scan the temporary variables vector for a match
			boolean matchFound = false;
			for(int j=0; j<temporaryVariables.size(); j++) {
				Rule r = ((Rule)temporaryVariables.get(j));
				String tv = "wm(" + r.getHead().trim() + ")";
				if(s.equals(tv)) {
					matchFound = true;
					for(int k=0; k<r.getPreconditions().size(); k++) {
						v.add(r.getPreconditions().get(k));
					}
					break;
				}
			}
			
			// If no match was found, add the original precondition to the results vector
			if(!matchFound)
				v.add(preconds.get(i));
		}
		
		return v;
	} // close expandTemporaryVariables()
	
	
	/** Returns the text that is displayed when the user employs the "-h" option. */
	private static String getHelpText() {
		return ("Precondition finder is used to generate lists " +
					"of preconditions from a production rule model\n" +
					"\n" +
					"Options:" +
					"\n" +
					MINUS + HELP + "\t\tDisplay this message\n" +
					"\n" +
					MINUS + PRELIST + "\t\tGenerate a list of preconditions to be used by the JavaPrologTool\n" +
					"\n" +
					"-preset\t\tGenerate a list of precondition sets to be used by the JavaPrologTool\n");
	}
	
} // close PreconditionFinder class

// EOF
