% Contains a list of all the HIPAA actors.

:- multifile
	isPerson/1,
	isHealthcareProvider/1.

:- dynamic
        importDefaultCoveredEntities/0,
        inOrganizedHealthcareArrangement/2,
	isAdult/1,
	isAttorney/1,
	isCourt/1,
	isEmancipatedMinor/1,
	isFDAAgent/1,
	isGovernmentAuthority/1,
	isGovernmentEntity/1,
	isGovernmentProgram/1,
	isGroupHealthPlan/1,
	isGuardian/2,
	isHealthcareProvider/1,
	isHealthInsuranceIssuer/1,
	isHealthOversightAgency/1,
	isHIPAAIndividual/1,
	isLawEnforcement/1,
	isLHCP/1,
	isParent/2,
	isPerson/1,
	isPlanSponsor/2,
	isProtectiveServicesAgency/1,
	isPublicHealthAuthority/1,
	isSocialService/1,
	isUnemancipatedMinor/1,
	originator/1,
	performsMultipleCoveredFunctions/1,
	president/1,
	secretary/1.

% TESTING
isHealthcareProvider(healthcareProvider).
actor(representative).
actor(minor).
isEmancipatedMinor(minor).
isUnemancipatedMinor(minor).
actor(court).
isCourt(court).
actor(personAuthorizedByLaw).
actor(parent).
actor(whistleBlower).
actor(attorney).
actor(airForce).
% [IGNORE_PRECONDITIONS]
actor(X) :-
	areBusinessAssociates(X,_).
actor(army).
actor(coastGuard).
actor(correctionalInstitution).
actor(cms).
% [IGNORE_PRECONDITIONS]
actor(X) :-
	isCoveredEntity(X).
actor(departmentOfDefense).
actor(departmentOfState).
actor(departmentOfTransportation).
actor(departmentOfVeteranAffairs).
actor(employer).
actor(fda).
actor(generalPublic).
actor(hhs).
actor(individual).
actor(lhcp).
actor(marines).
actor(navy).
actor(originator).
actor(personalRepresentative).
actor(secretaryOfHHS).
actor(standardSettingOrganization).
actor(state).
actor(workforce).

% [IGNORE_PRECONDITIONS]
actor(X) :-
	secretary(X).
% [IGNORE_PRECONDITIONS]
actor(X) :-
	president(X).

% Some relations involving actors
% [IGNORE_PRECONDITIONS]
isPerson(X) :-
	actor(X).

isHIPAAIndividual(individual).
isAdult(individual).

% [IGNORE_PRECONDITIONS]
isMinor(Minor) :-
	isEmancipatedMinor(Minor).
% [IGNORE_PRECONDITIONS]
isMinor(Minor) :-
	isUnemancipatedMinor(Minor).

isFDAAgent(fda).

% Uncomment this line to include the default covered entities
% importDefaultCoveredEntities.
% [IGNORE_PRECONDITIONS]
importDefaultCoveredEntities :-
	assert(isHealthcareProvider(healthcareProvider)),
	assert(isGroupHealthPlan(groupHealthPlan)),
	assert(isHealthInsuranceIssuer(healthInsuranceIssuer)),
	assert(isHealthcareClearinghouse(healthcareClearinghouse)),
	assert(isHMO(hmo)),
	assert(isGovernmentProgram(medicaid)),
	assert(isGovernmentProgram(medicare)),
	assert(isGovernmentProgram(militaryHealthCareProgram)),
	assert(isGovernmentProgram(veteransHealthCareProgram)),
	assert(isGovernmentProgram(champus)),
	assert(isGovernmentProgram(indianHealthServiceProgram)),
	assert(isGovernmentProgram(federalEmployeesHealthProgram)),
	assert(isGovernmentProgram(stateChildHealthPlan)),
	assert(isGovernmentProgram(stateHighRiskPoolPlan)),
	assert(isHealthPlan(groupHealthPlan)),
	assert(isHealthPlan(healthInsuranceIssuer)),
	assert(isHealthPlan(hmo)),
	assert(isHealthPlan(medicare)),
	assert(isHealthPlan(medicaid)),
	assert(isHealthPlan(medicareSupplementalPolicyIssuer)),
	assert(isHealthPlan(longTermCarePolicyIssuer)),
	assert(isHealthPlan(employeeWelfareBenefitPlan)),
	assert(isHealthPlan(militaryHealthCareProgram)),
	assert(isHealthPlan(veteransHealthCareProgram)),
	assert(isHealthPlan(champus)),
	assert(isHealthPlan(indianHealthServiceProgram)),
	assert(isHealthPlan(federalEmployeesHealthProgram)),
	assert(isHealthPlan(smallHealthPlan)),
	assert(isHealthPlan(stateChildHealthPlan)),
	assert(isHealthPlan(stateHighRiskPoolPlan)).
	
% We are assuming that parents, guardians, and individuals acting in
% loco parentis have not lost their parental priveleges.
% [IGNORE_PRECONDITIONS]
authority(Parent, actOnBehalf(Parent,Child)) :-
	isParent(Parent,Child).
% [IGNORE_PRECONDITIONS]
authority(Guardian, actOnBehalf(Guardian,Child)) :-
	isGuardian(Guardian,Child).
% [IGNORE_PRECONDITIONS]
authority(LocoParentis, actOnBehalf(LocoParentis,Child)) :-
	inLocoParentis(LocoParentis,Child).

% [IGNORE_PRECONDITIONS]
isParentalAuthority(Parent,Minor) :-
	isParent(Parent,Minor).
% [IGNORE_PRECONDITIONS]
isParentalAuthority(Parent,Minor) :-
	isGuardian(Parent,Minor).
% [IGNORE_PRECONDITIONS]
isParentalAuthority(Parent,Minor) :-
	inLocoParentis(Parent,Minor).

% [IGNORE_PRECONDITIONS]
isGovernmentEntity(X) :-
	isGovernmentProgram(X).
isGovernmentEntity(departmentOfDefense).
isGovernmentEntity(departmentOfState).
isGovernmentEntity(departmentOfTransportation).
isGovernmentEntity(departmentOfVeteranAffairs).
isGovernmentEntity(hhs).

% Licenced health care professionals
isLHCP(lhcp).

% The armed forces
isArmedForces(airForce).
isArmedForces(army).
isArmedForces(coastGuard).
isArmedForces(marines).
isArmedForces(navy).

% derived from s164.512(c)(1)
% [IGNORE_PRECONDITIONS]
isGovernmentAuthority(X) :-
	isSocialService(X).
% [IGNORE_PRECONDITIONS]
isGovernmentAuthority(X) :-
	isProtectiveServicesAgency(X).

% [IGNORE_PRECONDITIONS]
isHealthInsuranceIssuerOrHMO(X) :-
	isHealthInsuranceIssuer(X).
% [IGNORE_PRECONDITIONS]
isHealthInsuranceIssuerOrHMO(X) :-
	isHMO(X).

% EOF










