% Contains the glossary of HIPAA terms

:- style_check(-atom).

%-------------------------------------------
% The glossary terms
%-------------------------------------------
glossary(able,'
	able(+X,+Y)
	     Relation signifying that X is able to do Y.').

glossary(abuses,'
	abuses(+X,+Y)
	     Relation signifying that X abuses Y.').

glossary(accepts,'
	accepts(+X,+Y)
	     Relation signifying that X accepts Y.').

glossary(access,'
        access(+X,+Y)
	     Relation signifying that X has access to Y.').

glossary(accessible,'
	accessible(+X,+Y)
	     Relation signifying that X is accessible to Y.').

glossary(accounting,'
	accounting(+X)
	     Object signifying an accounting of X.').

glossary(accountNumber,'
	accountNumber(+X)
	     Object signifying an account number for an account owned by X.').

glossary(activities,'
	activities(+X)
	     Object signifying the activities of X.').

glossary(actsUnderDirectionOf,'
	actsUnderDirectionOf(+X,+Y)
	     Relation signifying that X acts under the direction of Y.').

glossary(address,'
	address(+X)
	     Object signifying the address of X.').

glossary(adequate,'
        adequate(+X)
	     Attribute signifying the legally ambiguous
	     concept that X is adequate.').

glossary(administers,'
        administers(+X,+Y)
	     Relation signifying that X administers Y.').

glossary(administrativeRequest,'
	administrativeRequest(+X,+Y,+Z)
	     Object signifying an administrative request from X to Y for Z.
	     This includes a separate written statement that, on its face,
	     demonstrates that the applicable requirements have been 
	     met (164.514(h)(2)(i)(A))').

glossary(administrativeTasks,'
        administrativeTasks(+X)
	     Object signifying the administrative tasks of X.').

glossary(admits,'
        admits(+X,+Y)
	     Relation signifying that X admits to doing Y.
	-------------------------
	admits(+X,+Y)
	     Relation signifying that X admits Y as a patient.').

glossary(adverselyAffects,'
        adverselyAffects(+X,+Y)
	     Relation signifying that X adversely affects Y.').

glossary(aggregated,'
	aggregated(+X)
	Source: HIPAA Section 164.501
	     Attribute signifying that X is aggregated.
	-------------------------
	     Data aggregation means, with respect to
	     protected health information created or received by a
	     business associate in its capacity as the business
	     associate of a covered entity, the combining of such
	     protected health information by the business associate
	     with the protected health information received by the
	     business associate in its capacity as a business
	     associate of another covered entity, to permit data
	     analyses that relate to the health care operations of
	     the respective covered entities.').

glossary(agrees,'
        agrees(+X,+Y)
	     Relation signifying that X agrees to Y.').

glossary(airForce,'
        airForce
	     Actor signifying the US Air Force.').

glossary(alerts,'
        alerts(+X,+Y,+Z)
	     Relation signifying that X alerts Y about Z.').

glossary(alternative,'
	alternative(+X)
	     Object signifying an alternative to X.').

glossary(alternativeLocations,'
	alternativeLocations
	     Object signifying alternative locations.').

glossary(alternativeMeans,'
	alternativeMeans
	     Object signifying alternative means.').

glossary(amends,'
	amends(+X,+Y)
	     Relation signifying that X amends Y.').

glossary(ansi,'
	ansi
	Source: HIPAA Section 160.103
	     Stands for the American National Standards Institute.').

glossary(appears,'
        appears(+X)
	     Attribute signifying that X appears to be the case.').

glossary(appends,'
	appends(+X,+Y,+Z)
	     Relation signifying that X appends Y to Z.').

glossary(appointmentReminders,'
	appointmentReminders
	     Object signifying appointment reminders.').

glossary(approves,'
        approves(+X,+Y)
	     Relation signifying that X approves Y or approves of Y.').

glossary(areConsistent,'
        areConsistent(+X,+Y)
	     Relation signifying that X and Y are consistent.').

glossary(areFamilyMembers,'
        areFamilyMembers(+X,+Y)
	     Relation signifying that X is a family member of Y.').

glossary(areFriends,'
        areFriends(+X,+Y)
	     Relation signifying that X is a friend of Y.').

glossary(areIntegral,'
        areIntegral(+X,+Y)
	     Relation signifying ambiguous legal terminology in
	     s164.512(d)(2)(iii).').

glossary(army,'
        army
	     Actor signifying the US Army.').

glossary(asNecessary,'
	asNecessary(+X,+Y)
	     Relation signifying that X performs Y as necessary.').

glossary(aspects,'
	aspects(+X)
	     Object signifying the aspects of X.').

glossary(assigns,'
        assigns(+X,+Y,+Z)
	     Relation signifying that X assigns Y to Z.').

glossary(assures,'
	assures(+X,+Y,+Z)
	     Relation signifying that X assures Y about Z. For example, Bob assures
	     Alice he will safeguard her PHI would be expressed as:
	     
	       assures(bob,alice,safeguards(bob, phi(alice))).').

glossary(at,'
	at(+X,+Y)
	     Relation signifying that X occurs at Y time.
	-------------------------
	     Relation signifying that X occurs at Y place.').

glossary(atDirectionOf,'
	atDirectionOf(+X,+Y,+Z)
	     Relation signifying that X performs Z at the direction of Y.').

glossary(attempts,'
        attempts(+X,+Y)
	     Relation signifying that X attempts to do Y.').

glossary(authority,'
	authority(+X,+Y)
	     Relation signifying that X has the authority to do Y.').

glossary(authorized_by_law,'
	authorized_by_law(+X,+Y,+Z)
	     Relation signifying that X is authorized by external 
	     law Z to perform Y.').

glossary(automatically,'
	automatically(+X)
	     Attribute signifying that X occurs automatically.').

glossary(avoids,'
	avoids(+X,+Y)
	     Relation signifying that X avoids Y.').

glossary(basis,'
        basis(+X)
	     Object signifying the basis for X.').

glossary(because,'
        because(+X,+Y)
	     Relation signifying that X occurs because of Y.').

glossary(before,'
        before(+X,+Y)
	     Relation signifying that X is before Y.').

glossary(believes,'
	believes(+X,+Y)
	     Relation signifying that X believes Y.').

glossary(biologicalProductDeviations,'
        biologicalProductDeviations
	     Object signifying ambiguous legal term "biological
	     product deviations"').

glossary(biometricIdentifier,'
        biometricIdentifier(+X)
	     Object signifying biometric identifiers of X.').

glossary(birth,'
	birth(+X)
	     Object signifying the birth of X.').

glossary(bloodType,'
        bloodType(+X)
	     Object signifying the bloodtype of X.').

glossary(bodyFluidAnalysis,'
	bodyFluidAnalysis(+X)
	     Object signifying an analysis of the bodily fluid of X.').

glossary(bodyFluidSample,'
	bodyFluidSample(+X)
	     Object signifying a sample of the bodily fluid of X.').

glossary(bodyFluidTyping,'
        bodyFluidTyping(+X)
	     Object signifying a typing of the bodily fluid of X.').

glossary(brief,'
	brief(+X)
	     Attribute signifying that X is brief.').

glossary(by,'
        by(+X,+Y)
	     Relation signifying the preposition \'by\', that is,
	     X by Y.').

glossary(cadaveric,'
        cadaveric(+X)
	     Attribute signifying that X is cadaveric.').

glossary(carriesOut,'
        carriesOut(+X,+Y)
	     Relation signifying that X carries out Y.').

glossary(causes,'
        causes(+X,+Y)
	     Relation signifying that X causes Y.').

glossary(champus,'
	champus
	Source: HIPAA Section 160.103, health plan definition
	     The Civilian Health and Medical Program of
	     the Uniformed Services (CHAMPUS) (as defined in
	     10 U.S.C. 1072(4)).').

glossary(clear,'
        clear(+X)
	     Attribute signifying that X is clear.').

glossary(cms,'
	cms
	Source: HIPAA Section 160.103
	     CMS stands for Centers for Medicare & Medicaid
             Services within the Department of Health and Human
	     Services.').

glossary(coastGuard,'
        coastGuard
	     Actor signifying the US Coast Guard.').

glossary(coerce,'
	coerce(+X,+Y)
	     Relation signifying that X coerces Y.').

glossary(collaborates,'
        collaborates(+X,+Y)
	     Relation signifying that X collaborates with Y.').

glossary(collects,'
	collects(+X,+Y)
	     Relation signifying that X collects Y.').

glossary(combined,'
        combined(+X,+Y)
	     Relation signifying that X and Y have been combined,
             typically meaning in the same document. For example, 
	     two notices could be combined in the same document.
        -------------------------
	combined(+List)
	     Relation signifying that all members of List are combined.').

glossary(commonPractice,'
	commonPractice
	     Object signifying common practice').

glossary(communication,'
	communication
	     Object signifying a communication').

glossary(communications,'
        communications(+X)
	     Object signifying communications about X.').

glossary(complains,'
	complains(+X,+Y)
	     Relation signifying that X complains about Y.').

glossary(complete,'
	complete(+X)
	     Attribute signifying that X is complete.').

glossary(complianceDate,'
	complianceDate(+X)
	     The compliance date for X.
	Source: HIPAA Section 160.103
	     Compliance date means the date by which a
	     covered entity must comply with a standard,
	     implementation specification, requirement, or
	     modification adopted under this subchapter.').

glossary(conditionOf,'
	conditionOf(+X)
	     Object signifying the general condition or
	     location of X.').

glossary(confidential,'
	confidential(+X)
	     Attribute signifying that X is confidential').

glossary(confidentialityAgreement,'
	confidentialityAgreement(+X,+Y,+Z)
	     Relation signifying that X and Y have a confidentiality
	     agreement about Z.').

glossary(conflicts,'
        conflicts(+X,+Y)
	     Relation signifying that X and Y conflict.').

glossary(consents,'
	consents(+X,+Y)
	     Relation signifying that X consents to Y.').

glossary(consent,'
        consent(+X,+Y,+Z)
	     Object signifying a physical, real-world consent
	     that X gives to Y to perform Z. Typically signifies
	     a consent document.').

glossary(construes,'
	construes(+X,+Y,+Z)
	     Relation signifying that X construes Y to mean Z.').

glossary(contacts,'
        contacts(+X,+Y)
	     Relation signifying that X contacts Y.').

glossary(contemporaneously,'
        contemporaneously(+X)
	     Attribute signifying that X occurs contemporaneously.').

glossary(contract,'
        contract(+X)
	     Object signifying a contract for X.').

glossary(coordinates,'
        coordinates(+X,+Y)
	     Relation signifying that X coordinates Y.').

glossary(costBased,'
	costBased(+X)
	     Attribute signifying that X is cost-based.').

glossary(correctionalInstitution,'
	correctionalInstitution
	Source: HIPAA Section 164.501
	     A generic correctional insitution.
	-------------------------
	isCorrectionalInstitution(+X)
	     Attribute signifying that X is a correctional insitution.
	-------------------------
	     Correctional institution means any penal or
	     correctional facility, jail, reformatory, detention
	     center, work farm, halfway house, or residential
	     community program center operated by, or under
	     contract to, the United States, a State, a territory, a
	     political subdivision of a State or territory, or an
	     Indian tribe, for the confinement or rehabilitation of
	     persons charged with or convicted of a criminal
	     offense or other persons held in lawful custody.').

glossary(couldEndanger,'
	couldEndanger(+Act,+X)
	     Relation signifying that Act could endanger X.').

glossary(coveredEntity,'
	coveredEntity(+X)
	Source: HIPAA Section 160.103
	     Signifies that X is a covered entity.
	-------------------------
	     Covered entity means:
	     (1) A health plan.
	     (2) A health care clearinghouse.
	     (3) A health care provider who transmits any
	     health information in electronic form in connection
	     with a transaction covered by this subchapter.').

glossary(coveredUnder,'
	coveredUnder(+X,+Y)
	     Relation signifies that X is coverd under Y.').

glossary(credible,'
        credible(+X)
	     Attribute signifying that X is credible.').

glossary(criteria,'
        criteria(+X)
	     Object signifying the criteria for X.').

glossary(cures,'
	cures(+X,+Y)
	     Relation signifying that X cures Y, in the context of
	     curing a breat of contract.').

glossary(currentDate,'
        currentDate
	     Object signifying the current date.').

glossary(custody,'
	custody(+X)
	     Object signifying the custody of X.').

glossary(dataUseAgreement,'
        dataUseAgreement(+X,+Y)
	     Object signifying a data use agreement between X and Y.').

glossary(day,'
        day(+X)
	     Object signifying the day portion of the date
	     that X occurred, or X number of days.').

glossary(death,'
        death(+X)
	     Object signifying the death of X.').

glossary(deceased,'
	deceased(+X)
	     Attribute signifying that X is deceased.').

glossary(defends,'
	defends(+X,+Y)
	     Relation signifying that X defends against Y. Typically used to
	     signify that X is defending against a legal case (Y)
	     brought against it.').

glossary(deidentified,'
	deidentified(+X)
	     Attribute signifying that X has been stripped of identifying information.').

glossary(deidentifies,'
        deidentifies(+X,+Y)
	     Relation signifying that X deidentifies Y; typically Y issome PHI.').

glossary(delays,'
	delays(+X,+Y)
	     Relation signifying that X delays Y.').

glossary(demonstrates,'
	demonstrates(+X,+Y)
	     Relation signifying that X demonstrates Y.').

glossary(denies,'
	denies(+X,+Y)
	     Relation signifying that X denies Y.').

glossary(dentalRecord,'
        dentalRecord(+X)
	     Object signifying the dental records of X.').

glossary(departmentOfDefense,'
        departmentOfDefense
	     Actor signifying the US Department of Defense.').

glossary(departmentOfState,'
        departmentOfState
	     Actor signifying the US Department of State.').

glossary(departmentOfTransportation,'
        departmentOfTransportation
	     Actor signifying the US Department of Transportation.').

glossary(departmentOfVeteranAffairs,'
        departmentOfVeteranAffairs
	     Actor signifying the US Department of Veteran Affairs.').

glossary(derives,'
        derives(+X,+Y,+Z)
	     Relation signifying that X derives Y from Z.').

glossary(describes,'
        describes(+X,+Y)
	     Relation signifying that X describes Y.').

glossary(description,'
        description(+X)
	     Object signifying the description of X.').

glossary(designatedBy,'
        designatedBy(+X,+Y)
	     Relation signifying that X is or has been designated by Y.').

glossary(designed,'
	designed(+X,+Y)
	     Relation signifying that X is designed for Y or to do Y.').

glossary(detriment,'
	detriment(+X)
	     Object signifying determint to X.').

glossary(deviceIdentifiers,'
        deviceIdentifiers(+X)
	     Object signifying device identifiers of person X.').

glossary(directly,'
	directly(+X)
	     Attribute signifying that X is direct.').

glossary(directs,'
	directs(+X,+Y)
	     Relation signifying that X directs Y.').

glossary(directory,'
	directory
	     Object signifying a directory.').

glossary(disability,'
	disability(+X)
	     Object signifying a disability to X.
        disability(+Actor,+Power,+Source)
	     Relation signifying that Actor cannot have Power by
	     HIPAA Source section.').

glossary(disagrees,'
	disagrees(+X,+Y)
	     Relation signifying that X disagrees with Y.').

glossary(discharges,'
        discharges(+X,+Y)
	     Relation signifying that X discharges Y, for example an
	     armed force discharging a soldier, or a hospital dis-
	     charging a patient.').

glossary(discloses,'
	discloses(+X, +Target, +Info)
	Source: HIPAA Section 160.103
	     Relation signifying that X discloses Info to Target
	-------------------------
	     Disclosure means the release, transfer, provision
	     of, access to, or divulging in any other manner of
	     information outside the entity holding the
	     information.').

glossary(discontinues,'
        discontinues(+X,+Y)
	     Relation signifying that X discontinues Y.').

glossary(discriminates,'
	discriminates(+X,+Y)
	     Relation signifying that X discriminates against Y.').

glossary(discusses,'
	discusses(+X,+Y,+Z)
	     Relation signifying that X discusses Z with Y.').

glossary(disease,'
        disease(+X)
	     Object signifying disease to X.').

glossary(disenrolled,'
        disenrolled(+X,+Y)
	     Relation signifying that X has disenrolled from Y, typically a
	     health plan.').

glossary(displays,'
        displays(+X,+Y)
	     Relation signifying that X displays Y.').

glossary(disposition,'
	disposition(+X)
	     Object signifying the disposition of X, as appears in 164.530(d)(2).').

glossary(distributes,'
	distributes(+X,+Y,+Z)
	     Relation signifying that X distributes Z to Y.').

glossary(dna,'
        dna(+X)
	     Object signifying the DNA of X.').

glossary(dnaAnalysis,'
        dnaAnalysis(+X)
	     Object signifying a DNA analysis of the DNA of X.').

glossary(dob,'
	dob(+X)
	     Object signifying the date of birth of person X.').

glossary(does_not_supersede,'
        does_not_supersede(+X,+Y)
	     Factual meta-relation signifying that X does not supersede Y.').

glossary(domesticViolence,'
	domesticViolence(+X,+Y)
	     Relation signifying that X commits domestic violence against Y.').

glossary(drs,'
	drs
	Source: HIPAA Section 164.501
	     Signifies a generic designated record set
	-------------------------
	     Designated record set means:
	       (1) A group of records maintained by or for a
	     covered entity that is:
	       (i) The medical records and billing records about
	     individuals maintained by or for a covered health care
	     provider;
	       (ii) The enrollment, payment, claims adjudication,
	     and case or medical management record systems
	     maintained by or for a health plan; or
	       (iii) Used, in whole or in part, by or for the
	     covered entity to make decisions about individuals.
	       (2) For purposes of this paragraph, the term
	     record means any item, collection, or grouping of
	     information that includes protected health information
	     and is maintained, collected, used, or disseminated by
	     or for a covered entity.').

glossary(during,'
	during(+X,+Y)
	     Relation signifies that X occurs during Y.').

glossary(duties,'
	duties(+X)
	     Object signifying the duties of X.').

glossary(effectiveDate,'
	effectiveDate(+X)
	     Object signifying the effective date of X.').

glossary(ein,'
	ein(+X)
	Source: HIPAA Section 160.103
	     Object signifying the employer identification number of X
	-------------------------
	     EIN stands for the employer identification number
	     assigned by the Internal Revenue Service, U.S.
	     Department of the Treasury. The EIN is the taxpayer
	     identifying number of an individual or other entity
	     (whether or not an employer) assigned under one of
	     the following:
	       (1) 26 U.S.C. 6011(b), which is the portion of the
	     Internal Revenue Code dealing with identifying the
	     taxpayer in tax returns and statements, or
	     corresponding provisions of prior law.
	       (2) 26 U.S.C. 6109, which is the portion of the
	     Internal Revenue Code dealing with identifying
	     numbers in tax returns, statements, and other required
	     documents.').

glossary(electronicPHI,'
	electronicPHI
	Source: HIPAA Section 160.103
	     Electronic protected health information means
	     information that comes within paragraphs (1)(i) or
	     (1)(ii) of the definition of protected health
	     information as specified in this section.').

glossary(elects,'
	elects(+X,+Y)
	     Relation signifying that X elects (chooses) Y.').

glossary(eligible,'
        eligible(+X,+Y)
	     Relation signifying that X is eligible for Y. For
	     Example, eligible(individual,healthBenefits(hmo))
	     means the individual is eligible to receive health
	     benefits from HMO.').

glossary(email,'
        email
	     Object signifying an email.').

glossary(emailAddress,'
        emailAddress(+X)
	     Object signifying the email address of X.').

glossary(employeeWelfareBenefitPlan,'
	employeeWelfareBenefitPlan
	Source: HIPAA Section 160.103, health plan definition
	     An employee welfare benefit plan or any
	     other arrangement that is established or maintained
	     for the purpose of offering or providing health
	     benefits to the employees of two or more employers.').

glossary(employer,'
	employer
	Source: HIPAA Section 160.103
	     Employer is defined as it is in 26 U.S.C. 3401(d).').

glossary(employmentActions,'
        employmentActions
	Source HIPAA Section 164.504(f)(1)(ii)(C)
	     Ambiguous term that appears in: "[A group healthplan
	     sponsor shall] not use or disclose [protected health] 
	     information for employment actions and decisions or in 
	     connection with any other benefit or employee benefit 
	     plan of the plan sponsor."').

glossary(endangers,'
        endangers(+X,+Y)
	     Relation signifying that X endangers Y.').

glossary(enrolled,'
	enrolled(+X,+Y)
	     Relation signifying that X is enrolled in Y,
	     or is eligible to be enrolled in Y.').

glossary(escapes,'
        escapes(+X,+Y)
	     Relation signifying that X escapes from Y.').

glossary(excludes,'
	excludes(+X,+Y)
	     Relation signifying that X excludes Y.').

glossary(exercises,'
	exercises(+X,+Y)
	     Relation signifying that X exercises Y.').

glossary(expeditedReviews,'
	expeditedReviews(+X,+Y)
	     Relation signifying that X performs an expedited review of Y.').

glossary(exposedTo,'
        exposedTo(+X,+Y)
	     Relation signifying that person X has been exposed to Y,
	     typically a disease.').

glossary(experience,'
	experience(+X,+Y)
	     Object signifying the experience of X in Y.').

glossary(expirationDate,'
        expirationDate(+X)
	     Object signifying the expiration date of X.').

glossary(expirationEvents,'
        expirationEvents
	     Ambiguous legal term appearing in 164.508(b)(2)(i).
	     Answer from HHS http://www.hhs.gov/hipaafaq/use/476.html
	     "The Privacy Rule requires that an Authorization contain
	     either an expiration date or an expiration event that 
	     relates to the individual or the purpose of the use or
	     disclosure. For example, an Authorization may expire 
	     "one year from the date the Authorization is signed," 
	     "upon the minors age of majority," or "upon termination
	     of enrollment in the health plan."').
	     
glossary(explains,'
        explains(+X,+Y)
	     Relation signed that X explains Y.').

glossary(expressly,'
	expressly(+X, +Y)
	     Attribute signifying that X is stated expressly in Y or by Y.').

glossary(extends,'
	extends(+X,+Y,+Z)
	     Relation signifying that X extends Y by Z amount.').

glossary(eyeColor,'
	eyeColor(+X)
	     Attribute signifying the eye color of X.').

glossary(face,'
        face(+X)
	     Object signifying the face of X.').

glossary(face2face,'
	face2face(+Action)
	     Attribute signifying that Action occurs face to face.').

glossary(facialHair,'
        facialHair(+X)
	     Attribute signifying the facial hair of X.').

glossary(facilitates,'
	facilitates(+X,+Y)
	     Relation signifying that X facilitates Y.').

glossary(fails,'
	fails(+X)
	     Attribute signifying that X has failed.').

glossary(faxNumber,'
        faxNumber(+X)
	     Object signifying the fax number of X.').

glossary(isFederalAgency,'
	isFederalAgency(+X)
	     Attribute signifying that X is a federal agency.').

glossary(isFederalAgent,'
        isFederalAgent(+X)
	     Attribute signifying that X is a federal agent.').

glossary(federalEmployeesHealthProgram,'
	federalEmployeesHealthProgram
	Source: HIPAA Section 160.103, health plan definition
	     The Federal Employees Health Benefits
	     Program under 5 U.S.C. 8902, et seq.').

glossary(federalRegister,'
        federalRegister
	     Object signifying the US Federal Register.').

glossary(filledPrescription,'
	filledPrescription(+X)
	     Object signifying a filled prescription for X.').

glossary(fingerPrint,'
        fingerPrint(+X)
	     Object signifying a fingerprint of X.').

glossary(forAsLongAs,'
	forAsLongAs(+X,+Y)
	     Relation signifying that X occurs for as long as Y.').

glossary(forBestInterest,'
	forBestInterest(+Act,+Person)
	     Relation signifying that Act is for the best interests of Person.').

glossary(foresees,'
	foresees(+X,+Y)
	     Relation signifying that X foresees Y.').

glossary(form,'
	form(+X)
	     Object signifying the form of X.').

glossary(from,'
        from(+X,+Y)
	     Relation signifying the preposition "from"; X from Y').

glossary(format,'
	format(+X)
	     Object signifying the format of X.').

glossary(free,'
	free(+X)
	     Attribute signifying that X is free.').

glossary(frequency,'
	frequency(+X)
	     Object signifying the frequency of X.').

glossary(fundraising,'
	fundraising(+X)
	     Object signifying the fundraising activities of X.').

glossary(fundraisingMaterials,'
        fundraisingMaterials(+X)
	     Object signifying fundraising materials of organization X.').

glossary(further,'
	further(+X,+Y)
	     Relation signifying that X is further than Y.').

glossary(gender,'
        gender(+X)
	     Attribute signifying the gender of X.').

glossary(generalCondition,'
	generalCondition(+X)
	     Object signifying the general condition of X.').

glossary(generalPublic,'
        generalPublic
	     Actor signifying the general public at large.
').

glossary(gift,'
        gift
	     Object signifying a generic gift.').

glossary(gives,'
	gives(+X,+Y,+Z)
	     Relation signifying that X gives Z to Y.').

glossary(goodFaith,'
        goodFaith(+X)
	     Attribute signifying that X occurs, is performed, or
	     attempted in good faith.').

glossary(goodOrder,'
        goodOrder(+X)
	     Object signifying ambiguous legal term "good order" of X,
	     found at HIPAA 164.512(k)(5)(i)(F).').

glossary(groupHealthPlan,'
	groupHealthPlan
	Source: HIPAA Section 160.103
	     Group health plan (also see definition of health
	     plan in this section) means an employee welfare
	     benefit plan (as defined in section 3(1) of the
	     Employee Retirement Income and Security Act of
	     1974 (ERISA), 29 U.S.C. 1002(1)), including insured
	     and self-insured plans, to the extent that the plan
	     provides medical care (as defined in section
	     2791(a)(2) of the Public Health Service Act (PHS
	     Act), 42 U.S.C. 300gg91(a)(2)), including items and
	     services paid for as medical care, to employees or
	     their dependents directly or through insurance,
	     reimbursement, or otherwise, that:
	       (1) Has 50 or more participants (as defined in
	     section 3(7) of ERISA, 29 U.S.C. 1002(7)); or
	       (2) Is administered by an entity other than the
	     employer that established and maintains the plan.').

glossary(hairColor,'
        hairColor(+X)
	     Attribute signifying the hair color of X.').

glossary(harm,'
        harm(+X)
	     Object signifying the harm done to X.').

glossary(hasMoreThanOne,'
	hasMoreThanOne(+X,+Y)
	     Relation signifying that X has more than one of Y.').

glossary(hasRelationship,'
        hasRelationship(+X,+Y)
	     Ambiguous legal term appearing in 164.506(c)(4):
	     "A covered entity may disclose PHI to another CE
	     for healthcare operations activities of the CE that
	     receives the information, if each entity either has
	     or had a relationship with the individual who is the
	     subject of the PHI being requested."').

glossary(haveSameStartingDigits,'
        haveSameStartingDigits(+List,+NoDigits)
	     Relation signifying that the elements of List all share
	     the same starting digits, up to NoDigits.').

glossary(hhs,'
	hhs
	Source: HIPAA Section 160.103
	     HHS stands for the Department of Health and
	     Human Services.').

glossary(health,'
        health(+X)
	     Object signifying the health of person X.').

glossary(healthPlanBeneficiaryNumber,'
        healthPlanBeneficiaryNumber(+X)
	     Object signifying the health plan beneficiary number of X.').

glossary(healthBenefits,'
        healthBenefits(+X)
	     Object signifying the healthcare benefits offered by X.').

glossary(healthcare,'
	healthcare(+X,+Y)
	     Object signifying the healthcare provided to Y by X.
	-------------------------
	Source: HIPAA Section 160.103
	     Health care means care, services, or supplies
	     related to the health of an individual. Health care
	     includes, but is not limited to, the following:
	       (1) Preventive, diagnostic, therapeutic,
	     rehabilitative, maintenance, or palliative care, and
	     counseling, service, assessment, or procedure with
	     respect to the physical or mental condition, or
	     functional status, of an individual or that affects the
	     structure or function of the body; and
	       (2) Sale or dispensing of a drug, device,
	     equipment, or other item in accordance with a
	     prescription.').

glossary(healthcareOperations,'
	healthcareOperations
	Source: HIPAA Section 160.103
	     Signifies generic healthcare operations.
	-------------------------
	healthcareOperations(+X)
	     Signifies the healthcare operations of X.
	-------------------------
	Health care operations means any of the
	     following activities of the covered entity to the extent
	     that the activities are related to covered functions:
	       (1) Conducting quality assessment and
	     improvement activities, including outcomes
	     evaluation and development of clinical guidelines,
	     provided that the obtaining of generalizable
	     knowledge is not the primary purpose of any studies
	     resulting from such activities; population-based
	     activities relating to improving health or reducing
	     health care costs, protocol development, case
	     management and care coordination, contacting of
	     health care providers and patients with information
	     about treatment alternatives; and related functions
	     that do not include treatment;
	       (2) Reviewing the competence or qualifications of
	     health care professionals, evaluating practitioner and
	     provider performance, health plan performance,
	     conducting training programs in which students,
	     trainees, or practitioners in areas of health care learn
	     under supervision to practice or improve their skills
	     as health care providers, training of non-health care
	     professionals, accreditation, certification, licensing,
	     or credentialing activities;
	       (3) Underwriting, premium rating, and other
	     activities relating to the creation, renewal or
	     replacement of a contract of health insurance or
	     health benefits, and ceding, securing, or placing a
	     contract for reinsurance of risk relating to claims for
	     health care (including stop-loss insurance and excess
	     of loss insurance), provided that the requirements of
	     164.514(g) are met, if applicable;
	       (4) Conducting or arranging for medical review,
	     legal services, and auditing functions, including fraud
	     and abuse detection and compliance programs;
	       (5) Business planning and development, such as
	     conducting cost-management and planning-related
	     analyses related to managing and operating the entity,
	     including formulary development and administration,
	     development or improvement of methods of payment
	     or coverage policies; and
	       (6) Business management and general
	     administrative activities of the entity, including, but
	     not limited to:
	       (i) Management activities relating to
	     implementation of and compliance with the
	     requirements of this subchapter;
	       (ii) Customer service, including the provision of
	     data analyses for policy holders, plan sponsors, or
	     other customers, provided that protected health
	     information is not disclosed to such policy holder,
	     plan sponsor, or customer.
	       (iii) Resolution of internal grievances;
	       (iv) The sale, transfer, merger, or consolidation of
	     all or part of the covered entity with another covered
	     entity, or an entity that following such activity will
	     become a covered entity and due diligence related to
	     such activity; and
	       (v) Consistent with the applicable requirements of
	     164.514, creating de-identified health information or
	     a limited data set, and fundraising for the benefit of
	     the covered entity.').

glossary(healthcareProvider,'
	healthcareProvider
	Source: HIPAA Section 160.103
	     Signifies a generic healthcareProvider.
	-------------------------
	     Health care provider means a provider of services
	     (as defined in section 1861(u) of the Act, 42 U.S.C.
	     1395x(u)), a provider of medical or health services
	     (as defined in section 1861(s) of the Act, 42 U.S.C.
	     1395x(s)), and any other person or organization who
	     furnishes, bills, or is paid for health care in the
	     normal course of business.').

glossary(healthInformation,'
	healthInformation
	Source: HIPAA Section 160.103
	     Health information means any information,
	     whether oral or recorded in any form or medium, that:
	       (1) Is created or received by a health care
	     provider, health plan, public health authority,
	     employer, life insurer, school or university, or health
	     care clearinghouse; and
	       (2) Relates to the past, present, or future physical
	     or mental health or condition of an individual; the
	     provision of health care to an individual; or the past,
	     present, or future payment for the provision of health
	     care to an individual.').

glossary(healthInsuranceIssuer,'
	healthInsuranceIssuer
	Source: HIPAA Section 160.103
	     Health insurance issuer (as defined in section
	     2791(b)(2) of the PHS Act, 42 U.S.C.
	     300gg91(b)(2) and used in the definition of health
	     plan in this section) means an insurance company,
	     insurance service, or insurance organization
	     (including an HMO) that is licensed to engage in the
	     business of insurance in a State and is subject to State
	     law that regulates insurance. Such term does not
	     include a group health plan.').

glossary(height,'
        height(+X)
	     Attribute signifying the height of X.').

glossary(hipaa,'
	hipaa
	     Object signifying HIPAA.').

glossary(hmo,'
	hmo
	Source: HIPAA Section 160.103
	     Health maintenance organization (HMO) (as
	     defined in section 2791(b)(3) of the PHS Act, 42
	     U.S.C. 300gg91(b)(3) and used in the definition of
	     health plan in this section) means a federally qualified
	     HMO, an organization recognized as an HMO under
	     State law, or a similar organization regulated for
	     solvency under State law in the same manner and to
	     the same extent as such an HMO.').

glossary(howToHandle,'
	howToHandle(+X)
	     Object signifying the means to handle X.').

glossary(healthPlan,'
	healthPlan(X)
	Source: HIPAA Section 160.103
	     Signifies that X is a health plan.
	-------------------------
	     Health plan means an individual or group plan
	     that provides, or pays the cost of, medical care (as
	     defined in section 2791(a)(2) of the PHS Act, 42
	     U.S.C. 300gg91(a)(2)).
	       (1) Health plan includes the following, singly or
	     in combination:
	       (i) A group health plan, as defined in this section.
	       (ii) A health insurance issuer, as defined in this
	     section.
	       (iii) An HMO, as defined in this section.
	       (iv) Part A or Part B of the Medicare program
	     under title XVIII of the Act.
	       (v) The Medicaid program under title XIX of the
	     Act, 42 U.S.C. 1396, et seq.
	       (vi) An issuer of a Medicare supplemental policy
	     (as defined in section 1882(g)(1) of the Act, 42
	     U.S.C. 1395ss(g)(1)).
	       (vii) An issuer of a long-term care policy,
	     excluding a nursing home fixed-indemnity policy.
	       (viii) An employee welfare benefit plan or any
	     other arrangement that is established or maintained
	     for the purpose of offering or providing health
	     benefits to the employees of two or more employers.
	       (ix) The health care program for active military
	     personnel under title 10 of the United States Code.
	       (x) The veterans health care program under 38
	     U.S.C. chapter 17.
	       (xi) The Civilian Health and Medical Program of
	     the Uniformed Services (CHAMPUS) (as defined in
	     10 U.S.C. 1072(4)).
	       (xii) The Indian Health Service program under the
	     Indian Health Care Improvement Act, 25 U.S.C.
	     1601, et seq.
	       (xiii) The Federal Employees Health Benefits
	     Program under 5 U.S.C. 8902, et seq.
	       (xiv) An approved State child health plan under
	     title XXI of the Act, providing benefits for child
	     health assistance that meet the requirements of
	     section 2103 of the Act, 42 U.S.C. 1397, et seq.
	       (xv) The Medicare+Choice program under Part C
	     of title XVIII of the Act, 42 U.S.C. 1395w21
	     through 1395w28.
	       (xvi) A high risk pool that is a mechanism
	     established under State law to provide health
	     insurance coverage or comparable coverage to
	     eligible individuals.
	       (xvii) Any other individual or group plan, or
	     combination of individual or group plans, that
	     provides or pays for the cost of medical care (as
	     defined in section 2791(a)(2) of the PHS Act, 42
	     U.S.C. 300gg91(a)(2)).
	       (2) Health plan excludes:
	       (i) Any policy, plan, or program to the extent that
	     it provides, or pays for the cost of, excepted benefits
	     that are listed in section 2791(c)(1) of the PHS Act,
	     42 U.S.C. 300gg91(c)(1); and
	       (ii) A government-funded program (other than one
	     listed in paragraph (1)(i)(xvi) of this definition):
	       (A) Whose principal purpose is other than
	     providing, or paying the cost of, health care; or
	       (B) Whose principal activity is:
	       (1) The direct provision of health care to persons;
	     or
	       (2) The making of grants to fund the direct
	     provision of health care to persons.
	     Implementation specification means specific
	     requirements or instructions for implementing a
	     standard.').

glossary(identifiers,'
        identifiers
	     Object signifying undefined, ambiguous legal term appearing
	     in s164.512(i)(2)(i)(A)').

glossary(impedes,'
        impedes(+X,+Y)
	     Relation signifying that X impedes Y.').

glossary(implied,'
	implied(+X)
	     Attribute signifying that X is implied.').

glossary(importDefaultCoveredEntities,'
	importDefaultCoveredEntities
	     Assert this fact to import the 17 default covered entities.').

glossary(imposes,'
	imposes(+X,+Y,+Z)
	     Relation signifying that X imposes Z on Y.').

glossary(impracticable,'
        impracticable(+X)
	     Relation signifying that X is impracticable.').

glossary(improves,'
	improves(+X,+Y)
	     Relation signifying that X improves Y.').

glossary(inAccordanceWith,'
	inAccordanceWith(+X,+Y)
	     Relation signify that X is performed in accordance with Y.').

glossary(inAdvance,'
	inAdvance(+X,+Y)
	     Relation signify that X occurs in advance of Y.').

glossary(incapacitated,'
        incapacitated(+X)
	     Attribute signifying that X is incapacitated.').

glossary(includes,'
	includes(+X,+Y)
	     Relation signifying that X includes Y.').

glossary(includesSufficientDetail,'
	includesSufficientDetail(+X)
	     Attribute signifying that X includes sufficient detail.').

glossary(incomplete,'
        incomplete(+X)
	     Attribute signifying that X is incomplete. For example,
	     incomplete(authorization(individual,hmo,uses(hmo,phi(individual))))
	     means that the physical authorization was filled out
	     incompletely.').

glossary(incorrect,'
        incorrect(+X)
	     Attribute signifying that X is or contains incorrect 
	     information.').

glossary(inCustodyof,'
        inCustodyof(+X,+Y)
	     Relation signifying that X is in the custody of Y.
	-------------------------
	     Source: HIPAA Section 164.501
	     Other persons held in lawful custody includes juvenile
	     offenders adjudicated delinquent, aliens detained
	     awaiting deportation, persons committed to mental
	     institutions through the criminal justice system,
	     witnesses, or others awaiting charges or trial.').

glossary(indianHealthServiceProgram,'
	indianHealthServiceProgram
	Source: HIPAA Section 160.103, health plan definition
	     The Indian Health Service program under the
	     Indian Health Care Improvement Act, 25 U.S.C.
	     1601, et seq.').

glossary(inDirectTreatmentRelationship,'
	inDirectTreatmentRelationship(+Person,+HealthcareProvider)
	Source: HIPAA Section 164.501
	     Relation signifying that Person and HealthcareProvider are in a direct
	     treatment relationship.
	-------------------------
	     Direct treatment relationship means a treatment
	     relationship between an individual and a health care
	     provider that is not an indirect treatment relationship.').

glossary(inIndirectTreatmentRelationship,'
	inIndirectTreatmentRelationship(+Person,+HealthcareProvider)
	Source: HIPAA Section 164.501
	     Signifies that Person and HealthcareProvider are in an in direct
	     treatment relationship.
	-------------------------
	     Indirect treatment relationship means a
	     relationship between an individual and a health care
	     provider in which:
	       (1) The health care provider delivers health care
	     to the individual based on the orders of another health
	     care provider; and
	       (2) The health care provider typically provides
	     services or products, or reports the diagnosis or
	     results associated with the health care, directly to
	     another health care provider, who provides the
	     services or products or reports to the individual.').

glossary(insuranceContract,'
        insuranceContract(+X,+Y)
	     Object signifying an insurance contract between X and Y.').

glossary(identificationBadge,'
        identificationBadge(+X)
	     Object signifying an identification badge for X.').

glossary(immunity,'
        immunity(+Actor,+Counterparty,Power,Source)
	     Relation signifying that Actor is immune from Power
	     held by Counterparty, granted by HIPAA Source section.').

glossary(individual,'
	individual
	Source: HIPAA Section 160.103
	     Individual means the person who is the subject of
	     protected health information.').

glossary(individually,'
        individually(+X,+Y)
	     Relation signifying that X performs Y individually.').


glossary(individuallyIdentifiableHealthInfo,'
	individuallyIdentifiableHealthInfo(+X)
	     Signifies individually identifiable health
	     information that is about X.
	-------------------------
	Source: HIPAA Section 160.103
	     Individually identifiable health information is
	     information that is a subset of health information,
	     including demographic information collected from an
	     individual, and:
	       (1) Is created or received by a health care
	     provider, health plan, employer, or health care
	     clearinghouse; and
	       (2) Relates to the past, present, or future physical
	     or mental health or condition of an individual; the
	     provision of health care to an individual; or the past,
	     present, or future payment for the provision of health
	     care to an individual; and
	       (i) That identifies the individual; or
	       (ii) With respect to which there is a reasonable
	     basis to believe the information can be used to
	     identify the individual.').

glossary(inExerciseOfProfessionalJudgment,'
        inExerciseOfProfessionalJudgment(+X)
	     Attribute signifying the ambiguous legal term "in the exercise
	     of professional judgment."').

glossary(information,'
	information(+X)
	     Object signifying information about X.').

glossary(informs,'
	informs(+X,+Y,+Z)
	     Relation signifying that X informs Y about Z.').

glossary(injury,'
	injury(+X)
	     Object signifying an injury to X.').

glossary(inLieu,'
	inLieu(+X,+Y)
	     Relation signifying that X is performed in lieu of Y.').

glossary(inLocoParentis,'
	inLocoParentis(+X,+Y)
	     Relation signifying that X is acting in loco parentis for Y.').

glossary(inNonCompliance,'
	inNonCompliance(+X, +Source)
	     Relation signifying that X is not in compliance with HIPAA, at
	     Source subsection.').

glossary(inOrganizedHealthcareArrangement,'
        inOrganizedHealthcareArrangement(+X,+Y)
	     Relation signifying that X and Y are in an organized healthcare
	     arrangement.').

glossary(inPerson,'
	inPerson(+X)
	     Attribute signifying that X is performed in person.').

glossary(inPlainLanguage,'
        inPlainLanguage(+X)
	     Attribute signifying that X is written in plain language.').

glossary(inProgress,'
	inProgress(+X)
	     Attribute signifying that X is in progress.').

glossary(insteadOf,'
	insteadOf(+X,+Y)
	     Relation signifying that X occurs instead of Y.').

glossary(intends,'
        intends(+X,+Y)
	     Relation signifying that X inteds Y.').

glossary(intentional,'
	intentional(+X)
	     Attribute signifying that X is intentional.').

glossary(internalDocuments,'
        internalDocuments
	     Object ignifying internal documents.
	-------------------------
	Source: HIPAA Section 164.504(e)(2)(ii)(H)
	     "internal practices, books, and records relating to the 
	     use and dislosure of PHI received from, or created or 
	     received by the business associate on behalf of the 
	     covered entity"').

glossary(intimidates,'
	intimidates(+X,+Y)
	     Relating signifying that X intimidates Y.').

glossary(into,'
        into(+X,+Y)
	     Relating signifying the preposition "into", i.e. X into Y.').

glossary(invalid,'
	invalid(+X)
	     Attribute signifying that X is invalid under HIPAA.').

glossary(investigates,'
	investigates(+X,+Y)
	     Relation signifying that X investigates Y.').

glossary(involved,'
	involved(+X,+Y)
	     Relation signifying that X is involved in Y.').

glossary(ipAddress,'
        ipAddress(+X)
	     Object signifying the IP address of X.').

glossary(isAdministrativeTribunal,'
	isAdministrativeTribunal(+X)
	     Attribute signifying that X is an administrative tribunal.').

glossary(isAdult,'
	isAdult(+X)
	     Attribute signifying that X is an adult.').

glossary(isArmedForces,'
        isArmedForces(+X)
	     Attribute signifying that X is an armed force, either the Army, 
	     Navy, Marines, Air Force, or Coast Guard.').

glossary(isArmedForcesPersonnel,'
        isArmedForcesPersonnel(+X,+Y)
	     Attribute signifying that X is a member of Y, an armed force.').

glossary(isAttorney,'
	isAttorney(+X)
	     Attribute signifying that X is an attorney.').

glossary(isChairOf,'
        isChairOf(+X,+Y)
	     Relation signifying that X is the chair of Y.').

glossary(isChild,'
        isChild(+X)
	     Attribute signifying that X is a child.').

glossary(isCity,'
        isCity(+X)
	     Attribute signifying that X is a city.').

glossary(isClery,'
        isClery(+X)
	     Attribute signifying that X is a clergyman.').

glossary(isCommunicableDisease,'
        isCommunicableDisease(+X)
	     Attribute signifying that X is a communicable disease.').

glossary(isConditionOf,'
        isConditionOf(+X,+Y)
	     Relation signifying that X is a precondition of Y.').

glossary(isCoroner,'
        isCoroner(+X)
	     Attribute signifying that X is a coroner.').

glossary(isCorrectionalInstitution,'
        isCorrectionalInstitution(+X)
	     Attribute signifying that X is a correctional institution.').

glossary(isCounseling,'
	isCounseling(+X)
	     Attribute signifying that X is counseling.').

glossary(isCounterIntelligence,'
        isCounterIntelligence(+X)
	     Attribute signifying that X is a counter-intelligence
	     operation or activity.').

glossary(isCounty,'
        isCounty(+X)
	     Attribute signifying that X is a county.').

glossary(isCourt,'
	isCourt(+X)
	     Attribute signifying that X is a court of law.').

glossary(isCourtProceeding,'
        isCourtProceeding(+X)
	     Attribute signifying that X is a court proceeding, including
	     court orders, court ordered warrents, subpoenas, and summons 
	     issued by a judicial officer.').

glossary(isCrime,'
        isCrime(+X)
	     Attribute signifying that X is a crime.').

glossary(isCrimeVictim,'
	isCrimeVictim(+X,+Y)
	     Relation signifying that X is a victim of crime Y.').

glossary(isDataUseAgreement,'
        isDataUseAgreement(+X)
	     Attribute signifying that X is a data use agreement.').

glossary(isDemographicInformation,'
	isDemographicInformation(+X)
	     Attribute signifying that X is demographic information.').

glossary(isDesignatedRecordSet,'
	isDesignatedRecordSet(+X)
	     Attribute signifying that X is a designated record set.').

glossary(isEmancipatedMinor,'
	isEmancipatedMinor(+X)
	     Attribute signifying that X is an emancipated minor.').

glossary(isEmployeeOf,'
	isEmployeeOf(+Worker,+Boss)
	     Relation signifying that Worker is an employee of Boss.').

glossary(isEntireMedicalRecord,'
        isEntireMedicalRecord(+X)
	     Attribute signifying that X is an entire medical record.').

glossary(isEvidenceFor,'
        isEvidenceFor(+X,+Y)
	     Relation signifying that X is evidence for Y.').

glossary(isFoodProduct,'
        isFoodProduct(+X)
	     Attribute signifying that X is a food product.').

glossary(isFDAAgent,'
        isFDAAgent(+X)
	     Attribute signifying that X is "subject to the 
	     jurisdiction of the Food and Drug Administration
	     (FDA) with respect to an FDA-regulated product or
	     activity for which that person has responsibility,
	     for the purpose of activities related to the quality,
	     safety or effectiveness of such FDA-regulated product
	     or activity."').

glossary(isFDAProduct,'
        isFDAProduct(+X)
	     Attribute signifying that X is an FDA product.').

glossary(isForeign,'
	isForeign(+X)
	     Attribute signifying that X is foreign.').

glossary(isForeignAgent,'
        isForeignAgent(+X)
	     Attribute signifying that X is a foreign agent.').

glossary(isForeignArmedForcesPersonnel,'
        isForeignArmedForcesPersonnel(+X,+Y)
	     Attribute signifying that X is a member of Y, a foreign armed forces.').

glossary(isForeignNationalBeneficiary,'
	isForeignNationalBeneficiary(+X)
	     Attribute signifying that X is a foreign national beneficiary.').

glossary(isFugitive,'
        isFugitive(+X)
	     Attribute signifying that X is a fugitive.').

glossary(isFuneralDirector,'
	isFuneralDirector(+X)
	     Attribute signifying that X is a funeral director.').

glossary(isGovernmentAuthority,'
	isGovernmentAuthority(+X)
	     Attribute signifying that X is a government authority.').

glossary(isGovernmentBenefitProgram,'
        isGovernmentBenefitProgram(+X)
	     Attribute signifying that X is a government benefits program.').

glossary(isGovernmentProgram,'
        isGovernmentProgram(+X)
	     Attribute signifying that X is a government program.').

glossary(isGrandJury,'
        isGrandJury(+X)
	     Attribute signifying that X is a grand jury.').

glossary(isGuardian,'
	isGuardian(+X, +Y)
	     Attribute signifying that X is the guardian of Y.').

glossary(isHealthcareProvider,'
	isHealthcareProvider(+X, +Y)
	     Attribute signifying that X is a healthcare provider.').

glossary(isHealthcareProviderService,'
        isHealthcareProviderService(+X)
	     Attribute signifying that X is a service offered by a
	     health care provider.').

glossary(isHealthcareSystem,'
        isHealthcareSystem(+X)
	     Attribute signifying that X is part of the health care system.').

glossary(isHealthInsurance,'
        isHealthInsurance(+X)
	     Attribute signifying that X is health insurance.').

glossary(isHealthPlanService,'
	isHealthPlanService(+X)
	     Attribute signifying that X is a health plan service.').

glossary(isHIPAAIndividual,'
	isHIPAAIndividual(+X)
	     Attribute signifying that X is an individual according to HIPAA.').

glossary(isHealthOversightAgency,'
	isHealthOversightAgency(+X)
	      Attribute signifying that X is a health oversight agency.
	-------------------------
	Source: HIPAA Section 164.501
	     Health oversight agency means an agency or
	     authority of the United States, a State, a territory, a
	     political subdivision of a State or territory, or an
	     Indian tribe, or a person or entity acting under a grant
	     of authority from or contract with such public agency,
	     including the employees or agents of such public
	     agency or its contractors or persons or entities to
	     whom it has granted authority, that is authorized by
	     law to oversee the health care system (whether public
	     or private) or government programs in which health
	     information is necessary to determine eligibility or
	     compliance, or to enforce civil rights laws for which
	     health information is relevant.').

glossary(isIllness,'
        isIllness(+X)
	     Attribute signifying that X is an illness.').

glossary(isImmediate,'
	isImmediate(+X),
	     Attribute signifying that X is immediate. Used in context of
	     law enforcement activities in s164.512(f)(3)(ii)(B).').

glossary(isInjury,'
        isInjury(+X)
	     Attribute signifying that X is an injury.').

glossary(isInmate,'
	isInmate(+X)
	     Attribute signifying that X is an inmate.
	-------------------------
	Source: HIPAA Section 164.501
	     Inmate means a person incarcerated in or
	     otherwise confined to a correctional institution.').

glossary(isInstitutionallyRelatedFoundation,'
        isInstitutionallyRelatedFoundation(+X)
	     Attribute signifying that X is an institutionally related foundation.').

glossary(isIntelligence,'
        isIntelligence(+X)
	     Attribute signifying that X is an intelligence operation or activity.').

glossary(isInvestigation,'
        isInvestigation(+X)
	     Attribute signifying that X is an investigation.').

glossary(isIRB,'
        isIRB(+X)
	     Source: HIPAA Section 164.512(i)(1)(i)(A)
	     "An Institutional Review Board (IRB),
	     established in accordance with 7 CFR lc.107, 10 CFR
	     745.107, 14 CFR 1230.107, 15 CFR 27.107, 16 CFR
	     1028.107, 21 CFR 56.107, 22 CFR 225.107, 24 CFR
	     60.107, 28 CFR 46.107, 32 CFR 219.107, 34 CFR
	     97.107, 38 CFR 16.107, 40 CFR 26.107, 45 CFR
	     46.107, 45 CFR 690.107, or 49 CFR 11.107."').

glossary(isLaw,'
        isLaw(+X)
	     Attribute signifying that X is a law.').

glossary(isLawEnforcement,'
	isLawEnforcement(+X)
	     Attribute signifying that X is a law enforcement official.
	-------------------------
	Source: HIPAA Section 164.501
	     "Law enforcement official means an officer or
	     employee of any agency or authority of the United
	     States, a State, a territory, a political subdivision of a
	     State or territory, or an Indian tribe, who is
	     empowered by law to:
	     (1) Investigate or conduct an official inquiry into
	     a potential violation of law; or
	     (2) Prosecute or otherwise conduct a criminal,
	     civil, or administrative proceeding arising from an
	     alleged violation of law."').

glossary(isLawEnforcementActivity,'
        isLawEnforcementActivity(+X)
	     Attribute signifying that X is a law enforcement activity.').

glossary(isLawEnforcementInquiry,'
	isLawEnforcementInquiry(+X,+Y)
	     Attribute signifying that Y is a law enforcement inquiry
	     carried out by X.').

glossary(isLawEnforcementPurpose,'
        isLawEnforcementPurpose(+X)
	     Attribute signifying that X is a law enforcement purpose.').

glossary(isLegalPermission,'
	isLegalPermission(+X)
	     Attribute signifying that X is a legal permission, as in 
	     164.530(b) or (c)(1)').

glossary(isLHCP,'
	isLHCP(+X)
	     Attribute signifying that X is a licensed health care professional').

glossary(isMaterialWitness,'
        isMaterialWitness(+X,+Y)
	     Relation signifying that X is a material witness to case Y.').

glossary(isMedicalExaminer,'
	isMedicalExaminer(+X)
	     Attribute signifying that X is a medical examiner.').

glossary(isMilitaryCommandAuthority,'
	isMilitaryCommandAuthority(+X)
	     Attribute signifying that X is a military command authority.').

glossary(isMilitaryMission,'
        isMilitaryMission(+X)
	     Attribute signifying that X is a military mission.').

glossary(isMinimumNecessaryFor,'
        isMinimumNecessaryFor(+X,+Y)
	     Relation signifying that X is the minimum necessary for Y.').

glossary(isMinor,'
	isMinor(+X)
	     Attribute signifying that X is a minor. Assumption: We assume
	     that the set of unemancipated minors unioned with the
	     set of emancipated minors constitutes the set of all minors').

glossary(isMissingPerson,'
        isMissingPerson(+X)
             Attribute signifying that X is a missing person.').

glossary(isNamedInsured,'
        isNamedInsured(+X)
	     Attribute signifying that X is the named insured for an
	     insurance policy.').

glossary(isNonGovernmentalOrganization,'
	isNonGovernmentalOrganization(+X)
	     Attribute signifying that X is a non-governmental organization.').

glossary(isOffice,'
	isOffice(+X)
	     Attribute signifying that X is an office.').

glossary(isOrganProcurementOrganization,'
	isOrganProcurementOrganization(+X)
	     Attribute signifying that X is an organ procurement organization
	     or other entity "engaged in the procurement, banking, or 
	     transplantation of cadaveric organs, eyes, or tissue for the purpose
	     of facilitating organ, eye, or tissue donation and transplant."').
	     

glossary(isParent,'
	isParent(+X,+Y)
	     Attribute signifying that X is the parent of Y.').

glossary(isPartyTo,'
        isPartyTo(+X,+Y)
	     Relation signifying that X is a party to Y, for example, X is
	     a party to the court proceeding or dispute Y.').

glossary(isPerson,'
	isPerson(+X)
	     Attribute signifying that X is a person.').

glossary(isPractical,'
	isPractical(+X)
	     Attribute signifying that X is practical.').

glossary(isPresent,'
	isPresent(+X,+Y)
	     Relation signifying that X is present at Y.').

glossary(isPrecinct,'
        isPrecinct(+X)
	     Attribute signifying that X is a precinct.').

glossary(isPresent,'
        isPresent(+X)
	     Attribute signifying that X is present.').

glossary(isPrivacyBoard,'
        isPrivacyBoard(+X)
	     Attribute signifying that X is a privacy board according to
	     HIPAA section 164.512(i)(1)(i)(B):
	     "A privacy board that:
	     (1) Has members with varying backgrounds and
	     appropriate professional competency as necessary to
	     review the effect of the research protocol on the
	     individuals privacy rights and related interests;
	     (2) Includes at least one member who is not
	     affiliated with the covered entity, not affiliated with
	     any entity conducting or sponsoring the research, and
    	     not related to any person who is affiliated with any of
	     such entities; and
    	     (3) Does not have any member participating in a
	     review of any project in which the member has a
	     conflict of interest."').

glossary(isPrivacyOfficial,'
	isPrivacyOfficial(+X)
	     Attribute signifying that X is a privacy official.').

glossary(isPrivacyPractice,'
	isPrivacyPractice(+X)
	     Attribute signifying that X is a privacy practice.').

glossary(isProtectiveServicesAgency,'
	isProtectiveServicesAgency(+X)
	     Attribute signifying that X is a protective services agency,
	     (used in the context of child protection services in s164.512(c)(1))').

glossary(isPublicHealthAuthority,'
	isPublicHealthAuthority(+X)
	Source: 164.512(b)(1)(i)
	      Attribute signifying that X is a public health authority.
	-------------------------
	Source: HIPAA Section 164.501
	     Public health authority means an agency or
	     authority of the United States, a State, a territory, a
	     political subdivision of a State or territory, or an
	     Indian tribe, or a person or entity acting under a grant
	     of authority from or contract with such public agency,
	     including the employees or agents of such public
	     agency or its contractors or persons or entities to
	     whom it has granted authority, that is responsible for
	     public health matters as part of its official mandate.').

glossary(isPublicOfficial,'
	isPublicOfficial(+X)
	     Attribute signifying that X is a public official.').

glossary(isQualifiedProtectiveOrder,'
        isQualifiedProtectiveOrder(+X)
	     Attribute signifying that X is a qualified protective order, as
	     defined by s164.512(e)(1)(v).').

glossary(isRecurring,'
        isRecurring(+X)
	     Attribute signifying that X is recurring.').

glossary(isRelatedTo,'
        isRelatedTo(+X,+Y)
	     Relation signifying that X is related to Y, in the topical
	     sense, not in a family sense.').

glossary(isRelevantTo,'
        isRelevantTo(+X,+Y)
	     Relation signifying that X is relevant to Y.').

glossary(isReliefOrg,'
        isReliefOrg(+X)
	     Attribute signifying that X is a disaster relief
	     organization.').

glossary(isResearcher,'
	isResearcher(+X)
	     Attribute signifying that X is a researcher.').

glossary(isRoutine,'
        isRoutine(+X)
	     Attribute signifying that X is routine.').

glossary(isSocialService,'
	isSocialService(+X)
	     Attribute signifying that X is a social service (used
	     in the context of child protection in s164.512(c)(1)).').

glossary(isStandard,'
	isStandard(+X)
	     Attribute signifying that X is a standard.').

glossary(isState,'
        isState(+X)
	     Attribute signifying that X is one of the 50 US states.').

glossary(isStreetAddress,'
        isStreetAddress(+X)
	     Attribute signifying that X is a street address.').

glossary(isSubjectToCivilRightsLaws,'
        isSubjectToCivilRightsLaws(+X)
	     Attribute signifying ambiguous legal terminology at
	     s164.512(d)(1)(iv).').

glossary(isSubjectToGovermentRegulatoryPrograms,'
	isSubjectToGovermentRegulatoryPrograms(+X)
	     Attribute signifying ambiguous legal terminology at
	     s164.512(d)(1)(iii).').

glossary(isSuspect,'
        isSuspect(+X)
	     Attribute signifying that X is the suspect of a crime.').

glossary(isTherapy,'
        isTherapy(+X)
	     Attribute signifying that X is therapy.').

glossary(isTreatment,'
	isTreatment(+X)
	     Attribute signifying that X is a treatment.').

glossary(isUnemancipatedMinor,'
	isUnemancipatedMinor(+X)
	     Attribute signifying that X is an unemancipated minor').

glossary(isVerySmall,'
        isVerySmall(+X)
	     Attribute signifying that X is very small.').

glossary(isWorkersComp,'
        isWorkersComp(+X)
	     Attribute signifying that X is a workers compensation agency
	     or program, that provides benefits for work-related injuries
	     or illnesses without regard to fault.').

glossary(isZipCode,'
        isZipCode(+X)
	     Attribute signifying that X is a zip code.').

glossary(jepardizes,'
	jepardizes(+X,+Y)
	     Related signifying that X jepardizes Y.').

glossary(jointNotice,'
        jointNotice(+X)
	     Object signifying a joint notice about X.').

glossary(jurisdictionOver,'
        jurisdictionOver(+X,+Y)
	     Relation signifying that X has jurisdiction over Y, typically used
	     for court X presiding over court case Y.').

glossary(justificationFor,'
	justificationFor(+X,+Y)
	     Relation signifying that X is a justification for Y.').

glossary(lastKnownAddress,'
        lastKnownAddress(+X)
	     Object signifying the last known address of X.').

glossary(law,'
	law
	     Object signifying the law.').

glossary(lawful,'
        lawful(+X)
	     Attribute signifying that X is lawful.').

glossary(learns,'
        learns(+X,+Y)
	     Relation signifying that X learns Y.').

glossary(legalAction,'
	legalAction(+X,+Y)
	     Relation signifying legal action that X has brought against Y.').

glossary(legalOptions,'
        legalOptions(+X)
	     Object signifying the legal options of X.').

glossary(length,'
	length(+X)
	     Object signifying the length of X.').

glossary(lessThan,'
        lessThan(+X,+Y)
	     Relation signifying that X is less than Y.').

glossary(lessThanOrEqualTo,'
	lessThanOrEqualTo(+X,+Y)
	     Relation signifying that X is less than or equal to Y.').

glossary(lhcp,'
	lhcp
	     A generic licensed healthcare professional').

glossary(liability,'
	liability(+Actor,+Liability,+Source)
	     Relation signifying that Actor has Liability at HIPAA Source.').

glossary(licenseNumber,'
        licenseNumber(+X)
	     Object signifying a license number for X.').

glossary(licensePlateNumber,'
        licensePlateNumber(+X)
	     Object signifying a licence plate number for X.').

glossary(likely,'
	likely(+X)
	     Attribute signifying that X is likely').

glossary(limits,'
	limits(+X,+Y)
	     Relation signifying that X limits Y. To express conditions
	     on the limiting, use the relation to/2.').
	     
glossary(limited_to_requirements_of_law,'
        limited_to_requirements_of_law(+X,+Y,+Z)
	     Relation signifying that X limits Y to the requirements of Z
	     law. Expresses ambiguous legal wording at 164.512(a)(1):
	     "A covered entity may use or disclose PHI to the extent that
	     such use or disclosure is required by law and the use or 
	     disclosure complies with and is limited to the relevant
	     requirements of such law."').

glossary(limitedToExtendReasonablyPracticable,'
        limitedToExtendReasonablyPracticable(+X)
	     Attribute signifying amgibuous legal terminology in 
	     s164.512(f)(1)(ii)(C)(2)').

glossary(link,'
	link(+X)
	     Object signifying a link to X.').

glossary(locatedAt,'
        locatedAt(+X,+Y)
	     Relation signifying that X is located at Y.').

glossary(longTermCarePolicyIssuer,'
	longTermCarePolicyIssuer
	Source: HIPAA Section 160.103, health plan definition
	     An issuer of a long-term care policy,
	     excluding a nursing home fixed-indemnity policy.').

glossary(mails,'
	mails(+X,+Y,+Z)
	     Relation signifying that X mails Z to Y.').

glossary(maintenance,'
        maintenance(+X)
	     Object signifying the maintenance of X or for X.').
	  
glossary(majority,'
	majority(+X)
	     Object signifying the majority of X.').

glossary(makesEffective,'
	makesEffective(+X,+Y,+Z)
	     Relation signifying that X makes Y effective to Z.').

glossary(makesEfforts,'
        makesEfforts(+X,+Y)
	     Relation signifying that X makes efforts to do Y.').

glossary(makesReference,'
	makesReference(+X,+Y)
	     Relation signifying that X makes reference to Y.').

glossary(management,'
        management(+X)
	     Object signifying the management of X.').

glossary(marines,'
	marines
	     Actor signifying the US Marine Corp.').

glossary(markets,X) :-
        glossary(marketing,X).
glossary(marketing,'
	marketing
	Source: HIPAA Section 164.501
	markets(+X,+Y)
	     Relation signifying that X performs marketing to Y.
	-------------------------
	     Marketing means:
	       (1) To make a communication about a product or
	     service that encourages recipients of the
	     communication to purchase or use the product or
	     service, unless the communication is made:
	       (i) To describe a health-related product or service
	     (or payment for such product or service) that is
	     provided by, or included in a plan of benefits of, the
	     covered entity making the communication, including
	     communications about: the entities participating in a
	     health care provider network or health plan network;
	     replacement of, or enhancements to, a health plan;
	     and health-related products or services available only
	     to a health plan enrollee that add value to, but are not
	     part of, a plan of benefits.
	       (ii) For treatment of the individual; or
	       (iii) For case management or care coordination for
	     the individual, or to direct or recommend alternative
	     treatments, therapies, health care providers, or
	     settings of care to the individual.
	       (2) An arrangement between a covered entity and
	     any other entity whereby the covered entity discloses
	     protected health information to the other entity, in
	     exchange for direct or indirect remuneration, for the
	     other entity or its affiliate to make a communication
	     about its own product or service that encourages
	     recipients of the communication to purchase or use
	     that product or service.').

glossary(materially,'
        materially(+X)
	     Attribute signifying that X is the legally ambiguous term "materially"
	     or "material"').

%glossary(may,'
%	may(+X,+P,+S)
%	     Relation signifying that X has the permission P, from the
%	     section S').

glossary(mechanism,'
        mechanism
	     Ambiguous legal term appearing at 164.504(f)(2)(iii)(C).').

glossary(medicaid,'
	medicaid
	Source: HIPAA Section 160.103, health plan definition
	     The Medicaid program under title XIX of the
	     Act, 42 U.S.C. 1396, et seq.').

glossary(medicalRecordNumber,'
        medicalRecordNumber(+X)
	     Object signifying the medical record number of X.').

glossary(medicalSupplies,'
	medicalSupplies
	     Object signifying medical supplies.').

glossary(medicare,'
	medicare
	Source: HIPAA Section 160.103, health plan definition
	     Part A or Part B of the Medicare program
	     under title XVIII of the Act.').

glossary(medicarePlusChoice,'
	medicarePlusChoice
	Source: HIPAA Section 160.103, health plan definition
	     The Medicare+Choice program under Part C
	     of title XVIII of the Act, 42 U.S.C. 1395w21
	     through 1395w28.').

glossary(medicareSupplementalPolicyIssuer,'
	medicareSupplementalPolicyIssuer
	Source: HIPAA Section 160.103, health plan definition
	     An issuer of a Medicare supplemental policy
	     (as defined in section 1882(g)(1) of the Act, 42
	     U.S.C. 1395ss(g)(1)).').

glossary(meeting,'
	meeting(+X)
	     Object signifying a meeting of X.').

glossary(militaryHealthCareProgram,'
	militaryHealthCareProgram
	Source: HIPAA Section 160.103, health plan definition
	     The health care program for active military
	     personnel under title 10 of the United States Code.').

glossary(minimal,'
        minimal
	     Object signifying the ambiguous legal word "minimal".').

glossary(minimizes,'
	minimizes(+X,+Y)
	     Relation signifying that X minimizes Y').

glossary(month,'
        month(+X)
	     Object signifying the month portion of the date that
	     X occurred.').

glossary(moreThan,'
        moreThan(+X,+Y)
	     Relation signifiying that X is more than Y.').

glossary(moreThanOne,'
	moreThanOne(+X)
	     Attribute signifiying that X is more than one.').

glossary(multiple,'
	multiple(+X)
	     Attribute signifying that X occurs multiple times.').

glossary(navy,'
        navy
	     Actor signifying the US Navy.').

glossary(necessitates,'
        necessitates(+X,+Y)
	     Relation signifying that X necessitates Y.').

glossary(neglects,'
	neglects(+X,+Y)
	     Relation signifying that X neglects Y.').

glossary(noLaterThan,'
	noLaterThan(+X,+Y)
	     Relation signifying that X occurs no later than Y.').

glossary(nominalValue,'
        nominalValue(+Object)
	     Attribute signifying that Object is of nominal value.').

glossary(noRight,'
	noRight(Actor,Right,Source)
	     Relation signifying that Actor does not have Right, according
	     to Source section of HIPAA.').

glossary(not_required_by_any_external_law,'
	not_required_by_any_external_law(+X)
	     Relation signifying that X is not required by any external law,
	     ambiguous term that is untestable.').

glossary(notEffective,'
	notEffective(+X)
	     Attribute signifying that X is not effective.').

glossary(notice,'
	notice
	     Object signifying a generic notice.
        -----------------------
	notice(+X)
	     Object signifying a notice for X.').

glossary(notifies,'
        notifies(+X,+Y,+Z)
	     Relation signifying that X notifies Y about Z.').

glossary(numberOr,'
	numberOf(+X)
	     Object signifying the number of X.').

glossary(objects,'
        objects(+X,+Action)
	     Relation signifying that X objects to Action.').

glossary(occurInConjunction,'
	 occurInConjunction(+X,+Y)
	     Relation signifying that X and Y occur at the same time or in conjunction.').

glossary(offers,'
        offers(+X,+Y,+Z)
	     Relation signifying that X offers Z to Y.').

glossary(on,'
	on(+X,+Y)
	     Relation signifying the preposition "on", i.e. X on Y.').

glossary(occursOnce,'
	occursOnce(+X)
	     Attribute signifying that X occurs once.').

glossary(onGovernmentLetterhead,'
        onGovernmentLetterhead(+X)
	     Attribute signifying that X is on government letterhead.').

glossary(only,'
        only(+X)
	     Relation signifying that X is the only one, there are no others.').

glossary(onsite,'
	onsite(+X)
	     Attribute signifying that X is onsite.').

glossary(opportunity,'
	opportunity(+X)
	     Attribute signifying the opportunity to perform X.').

glossary(optsOut,'
        optsOut(+X,+Y)
	     Relation signifying that X opts out of Y.').

glossary(oral,'
	oral(+X)
	     Attribute signifying that X is verbal or oral.').

glossary(orders,'
	orders(+X,+Y,+Z)
	     Relation signifying that X orders Y to do action Z.').

glossary(organizedHealthcareArrangement,'
	organizedHealthcareArrangement([])
	Source: HIPAA Section 160.103
	     Signifies that the members of the given list are in
	     an organized healthcare arrangement.
	-------------------------
	     Organized health care arrangement means:
	       (1) A clinically integrated care setting in which
	     individuals typically receive health care from more
	     than one health care provider;
	       (2) An organized system of health care in which
	     more than one covered entity participates and in
	     which the participating covered entities:
	       (i) Hold themselves out to the public as
	     participating in a joint arrangement; and
	     (ii) Participate in joint activities that include at
	     least one of the following:
	       (A) Utilization review, in which health care
	     decisions by participating covered entities are
	     reviewed by other participating covered entities or by
	     a third party on their behalf;
	       (B) Quality assessment and improvement
	     activities, in which treatment provided by
	     participating covered entities is assessed by other
	     participating covered entities or by a third party on
	     their behalf; or
	       (C) Payment activities, if the financial risk for
	     delivering health care is shared, in part or in whole,
	     by participating covered entities through the joint
	     arrangement and if protected health information
	     created or received by a covered entity is reviewed by
	     other participating covered entities or by a third party
	     on their behalf for the purpose of administering the
	     sharing of financial risk.
	       (3) A group health plan and a health insurance
	     issuer or HMO with respect to such group health
	     plan, but only with respect to protected health
	     information created or received by such health
	     insurance issuer or HMO that relates to individuals
	     who are or who have been participants or
	     beneficiaries in such group health plan;
	       (4) A group health plan and one or more other
	     group health plans each of which are maintained by
	     the same plan sponsor; or
	       (5) The group health plans described in paragraph
	     (4) of this definition and health insurance issuers or
	     HMOs with respect to such group health plans, but
	     only with respect to protected health information
	     created or received by such health insurance issuers
	     or HMOs that relates to individuals who are or have
	     been participants or beneficiaries in any of such
	     group health plans.').

glossary(originator,'
	originator(+X)
	     Actors signifying the originator of X.').

glossary(otherContactMeans,'
	otherContactMeans(+X)
	     Object signifying other contact means than X.').

glossary(oversees,'
        oversees(+X,+Y)
	     Relation signifying that X oversees Y.').

glossary(paper,'
        paper(+X)
	     Attribute signifying that X is on paper.').

glossary(parole,'
        parole(+X)
	     Object signifying the parole of X.').

glossary(participates,'
        participates(+X,+Y)
	     Relation signifying that X participates in Y, usually some sort of health
	     plan or research.').

glossary(payment,'
	payment
	Source: HIPAA Section 164.501
	     Signifies generic payment activities.
	-------------------------
	payment(+X)
	     Signifies the payment activities of X.
	-------------------------
	     Payment means:
	       (1) The activities undertaken by:
	       (i) A health plan to obtain premiums or to
	     determine or fulfill its responsibility for coverage and
	     provision of benefits under the health plan; or
	       (ii) A health care provider or health plan to obtain
	     or provide reimbursement for the provision of health
	     care; and
	       (2) The activities in paragraph (1) of this
	     definition relate to the individual to whom health care
	     is provided and include, but are not limited to:
	       (i) Determinations of eligibility or coverage
	     (including coordination of benefits or the
	     determination of cost sharing amounts), and
	     adjudication or subrogation of health benefit claims;
	       (ii) Risk adjusting amounts due based on enrollee
	     health status and demographic characteristics;
	       (iii) Billing, claims management, collection
	     activities, obtaining payment under a contract for
	     reinsurance (including stop-loss insurance and excess
	     of loss insurance), and related health care data
	     processing;
	       (iv) Review of health care services with respect to
	     medical necessity, coverage under a health plan,
	     appropriateness of care, or justification of charges;
	       (v) Utilization review activities, including
	     precertification and preauthorization of services,
	     concurrent and retrospective review of services; and
	       (vi) Disclosure to consumer reporting agencies of
	     any of the following protected health information
	     relating to collection of premiums or reimbursement:
	       (A) Name and address;
	       (B) Date of birth;
	       (C) Social security number;
	       (D) Payment history;
	       (E) Account number; and
	       (F) Name and address of the health care provider
	     and/or health plan.').

glossary(people,'
	people(+X)
	     Object signifies X number of people.').

glossary(performsMultipleCoveredFunctions,'
        performsMultipleCoveredFunctions(+X)
	     Attribute signifying that X performs multiple functions covered under
	     HIPAA.').

glossary(periodicity,'
	periodicity(+X)
	     Object signifying the periodicity of X.').

glossary(permits,'
        permits(+X,+Y)
	     Relation signifying that X permits Y.').

glossary(permitted_by_external_law,'
	permitted_by_external_law(+X,+Y,+Z)
	     Relation signifying that X is permitted by external 
	     law Z to perform Y.').

glossary(permitted_by_law,'
        permitted_by_law(+X,+Y,+Z)
	     Relation signifying that X is permitted by law Z to perform Y.').

glossary(perpetrates,'
        perpetrates(+X,+Crime)
	     Relation signifying that X perpetrates Crime.').

glossary(person,'
	person(+X)
	Source: HIPAA Section 160.103
	     Signifies that X is a person according to HIPAA.
	-------------------------
	     Person means a natural person, trust or estate,
	     partnership, corporation, professional association or
	     corporation, or other entity, public or private.').

glossary(personalRepresentative,'
        personalRepresentative
	     Signifies a generic personal representative.').

glossary(photo,'
        photo(+X)
	     Object signifying a photo of X.').

glossary(physical,'
        physical(+X)
	     Attribute signifying that X is physical.').

glossary(picksUp,'
	picksUp(+X,+Y)
	     Relation signifying that X picks up Y.').

glossary(placeOfBirth,'
        placeOfBirth(+X)
	     Object signifying the place of birth of X.').

glossary(plan,'
	plan(+X)
	     Object signifying the plan for X.').

glossary(population,'
	population(+X)
	     Object signifying the population of X.').

glossary(postMarket,'
        postMarket(+Drug)
	     Object signifying post market activities for Drug.').

glossary(posts,'
        posts(+X,+Y)
	     Relation signifying that X posts Y.').

glossary(power,'
        power(+Actor,+LegalRelation,+Power,+Source)
	     Relation signifying that Actor has Power to change
	     LegalRelation by HIPAA Source section.').

glossary(practicable,'
        practicable(+X)
	     Attribute signifying ambigious legal term "practicable"
	     or "practicably".').

glossary(premises,'
	premises(+X)
	     Object signifying the physical premises of X.').

glossary(premium,'
        premium(+X)
	     Object signifying the insurance premium for X.').

glossary(prepares,'
        prepares(+X,+Y)
	     Relation signifying that X prepares Y.').

glossary(presents,'
        presents(+X,+Y)
	     Relation signifying that X presents Y.').

glossary(president,'
        president(+X)
	     Actor signifying the president of country X.').

glossary(privacy,'
        privacy(+X)
	     Object signifying the privacy of X.').

glossary(probation,'
        probation(+X)
	     Object signifying the probation of X.').

glossary(productDefects,'
        productDefects(+X)
	     Object signifying the defects of product X,
	     including use and labeling problems.').

glossary(professionalStandards,'
	professionalStandards
	     Signifies "professional or clinical standards",
	     HIPAA section 164.502(i).').

glossary(prohibited_by_external_law,'
	prohibited_by_external_law(+X,+Y,+Z)
	     Relation signifying that X is prohibited by external law Z from doing Y.').

glossary(prohibits,'
        prohibits(+X,+Y)
	     Relation signifying that X prohibits Y.').

glossary(promptly,'
        promptly(+X)
	     Attribute signifying that X must be performed promptly.').

glossary(prominent,'
	prominent(+X)
	     Attribute signifying that X is prominent.').

glossary(promptly,'
        promptly(+X)
	     Attribute signifying that X is performed promptly.').

glossary(propensity,'
	propensity(+X,+Y)
	     Object signifying Xs propensity for Y.').

glossary(proposal,'
        proposal(+X)
	     Object signifying the proposal for X.').

glossary(provides,'
        provides(+X,+Y,+Z)
	     Relation signifying that X provides Z to Y. The
	     compliment of receives(X,Y,Z)').

glossary(publicHealth,'
        publicHealth
	     Object signifying generic public health purposes.').

glossary(publicHealthBenefitsClaim,'
        publicHealthBenefitsClaim(+X)
	     Object signifying a claim by X for public health benefits.').


glossary(publicHealthInterventions,'
        publicHealthInterventions
	     Object signifying public health interventions as specified in
	     HIPAA 164.512(b)(1)(i).').

glossary(publicHealthSurveillance,'
	publicHealthSurveillance
	     Object signifying public health surveillance as specified in
	     HIPAA 164.512(b)(1)(i).').

glossary(publishes,'
        publishes(+X,+Y,+Z)
	     Relation signifying that X publishes Z in Y.').

glossary(pursuantTo,'
	pursuantTo(+X,+Y)
	     Relation signifying that X occurs pursuant to Y.').

glossary(race,'
        race(+X)
	     Attribute signifying the race of X.').

glossary(rates,'
        rates(+X,+Y)
	     Relation signifying that X rates Y.').

glossary(readilyProducable,'
	readilyProducable(+X)
	     Attribute signifying that X is readily producable.').

glossary(reads,'
        reads(+X,+Y)
	     Relation signifying that X reads Y.').

glossary(reasonsFor,'
	reasonsFor(+X)
	     Object signifying the reasons for X.').

glossary(reasonToSupport,'
	reasonToSupport(+X)
	     Object signifying a reson to support X.').

glossary(rebuttal,'
	rebuttal(+X)
	     Object signifying a rebuttal to X.').

glossary(recalls,'
        recalls(+X,+Y)
	     Relation signifying that X recalls a product Y. Covers all recall
	     activities such as recall, repair, replacement, or 
	     ambiguous legal term "lookback."').

glossary(refers,'
	refers(+X,+Y,+Z)
	     Relation signifying that X refers Z to Y.').

glossary(rehabilitation,'
	rehabilitation(+X)
	     Object signifying the rehabilitation of X.').

glossary(reidentifies,'
        reidentifies(+X,+Y)
	     Relation signifying that X reidentifies Y.').

glossary(reidentificationCode,'
	reidentificationCode(+X)
	Source: HIPAA Section 160.502(d)(2)(i)
	     Object signifying a reidentifaction code for X, where X is
	     deidentified information
	-------------------------
	     "code or other means of record identification designed
	     to enable coded or otherwise deidentified information 
	     to be reidentified"').

glossary(relavent,'
	relavent(+X)
	     Relation signifying that X is relavent.').

glossary(relies,'
        relies(+X,+Y)
	     Relavent signifying that X relies on Y.').

glossary(religiousAffiliation,'
	religiousAffiliation(+X)
	     Object signifying the religious affiliation of X.').

glossary(renews,'
        renews(+X,+Y)
	     Relation signifying that X renews Y.').

glossary(replaces,'
	replaces(+X,+Y)
	     Relation signifying that X replaces Y.').

glossary(represents,'
	represents(+X,+Y)
	     Relation signifying that X is the legal representative of Y.
        -------------------------
	     Relation signifying the awkward legal language "represents that", for example,
	     s164.512(c)(1)(iii)(B): "public official...represents that the PHI for which
	     disclosure is sought is not intended to be used against the individual".').

glossary(required_by_external_law,'
        required_by_external_law(+X,+Y,+Z)
	     Relation signifying that X is required to do Y by external law Z.').

glossary(requiredOrPermittedByHIPAA,'
        requiredOrPermittedByHIPAA(+X,+Action)
	     Relation signifying that actor X is required or permitted by
	     HIPAA to perform Action.').

glossary(requires,'
	requires(+X,+Info)
	     Relation signifies that X requires Info. Note that the 
	     predicate "for" must be used to specify the purpose why 
	     Info is required.
        requires(+X,+Y,+Z)
             Relation signifies that X requires Z from Y').

glossary(requests,'
	requests(+X,+Y,+Z)
	     Relation signifying that X requests Z from Y.').

glossary(research,'
	research
	Source: HIPAA Section 164.501
	     Object signifying generic research.
	-------------------------
	     Research means a systematic investigation,
	     including research development, testing, and
	     evaluation, designed to develop or contribute to
	     generalizable knowledge.').

glossary(researchProtocol,'
        researchProtocol
	     Object signifying ambiguous legal term "research protocol
	     or for similar purposes preparatory to research."').

glossary(reserves,'
	reserves(+X,+Y)
	     Relation signifying that X reserves Y (for example, a right).').

glossary(resolves,'
	resolves(+X,+Y)
	     Relation signifying that X resolves issue Y.').

glossary(restricts,'
        restricts(+X,+Y)
	     Relation signifying that X restricts Y.
	-------------------------
        restricts(+X,+Y,+Z)
	     Relation signifying that X restricts Y in Z scenario.').

glossary(restrictionsAndConditions,'
        restrictionsAndConditions(+X)
	     Object signifying the restrictions and conditions with respect to X.').

glossary(resultOf,'
        resultOf(+X,+Y)
	     Relation signifying that X is the result of Y.').

glossary(retaliatoryAction,'
	retaliatoryAction(+X,+Y)
	     Relation signifying that X takes a retalitory action against Y.').

glossary(returns,'
        returns(+X,+Y,+Z)
	     Relation signifying that X returns Z entirely to Y without maintaining
	     any other copies.').

glossary(reveals,'
	reveals(+X,+Y)
	     Relation signifying that X reveals Y.').

glossary(revokes,'
        revokes(+X,+Y)
	     Relation signifying that X revokes Y; Y is typically an
	     authorization of some kind.').

glossary(rhFactor,'
        rhFactor(+X)
	     Object signifying the RH factor of X.').

glossary(riskToFrom,'
        riskToFrom(+X,+Y)
	     Relation signifying that X is at risk from Y.').

glossary(safety,'
        safety(+X)
	     Object signifying the safety of X.').

glossary(satisfactory,'
	satisfactory(+X)
	     Ambiguous legal adjective signifying that X must be satisfactory.').

glossary(scar,'
	scar(+X)
	     Object signifying a scar of X.').

glossary(secretary,'
        secretary(+X)
	     Actor signifying the secretary of X; X is usually a US department.').

glossary(secretaryOfHHS,'
	secretaryOfHHS	
        Source: HIPAA Section 160.103
	     Signifies the Secretary of Health and Human Services (HHS).
	-------------------------
	     Secretary means the Secretary of Health and
	     Human Services or any other officer or employee of
	     HHS to whom the authority involved has been
	     delegated.').

glossary(sends,'
	sends(+X,+Y,+Z)
	     Relation signifying that X sends Z to Y.').

glossary(separates,'
        separates(+X,+Y)
	     Relation signifying that X separates from Y.').

glossary(serious,'
        serious(+X)
	     Attribute signifying that X is serious, a legally ambiguous term.').

glossary(serveSimilarOrSamePopulations,'
        serveSimilarOrSamePopulations(+X,+Y)
	     Relation signifying that X and Y serve the same or similar populations,
	     as seen in HIPAA s164.512(k)(6)(ii).').

glossary(serviceDeliverySite,'
        serviceDeliverySite(+X)
	     Object signifying the service delivery site for X.').

glossary(services,'
	services(+X,+Y)
	     Object signifying the services provided to Y by X.').

glossary(signs,'
	signs(+X,+Y)
	     Relation signifying that X has placed his or her signature
	     on Y.').

glossary(smallHealthPlan,'
	smallHealthPlan
	Source: HIPAA Section 160.103
	     Small health plan means a health plan with annual
	     receipts of $5 million or less.
	     Standard means a rule, condition, or requirement:
	       (1) Describing the following information for
	     products, systems, services or practices:
	       (i) Classification of components.
	       (ii) Specification of materials, performance, or
	     operations; or
	       (iii) Delineation of procedures; or
	       (2) With respect to the privacy of individually
	     identifiable health information.').

glossary(solely,'
        solely(+X)
	     Attribute signifying the "soleliness" of X.').

glossary(specifies,'
	specifies(+X,+Y)
	     Relation signifying that X specifies Y.').

glossary(sponsors,'
	sponsors(+X,+Y)
	     Relation signifying that X sponsors Y.').

glossary(ssn,'
        ssn(+X)
	     Object signifying the social security number of X.').

glossary(standard,'
	standard
	Source: HIPAA Section 160.103
	     Standard means a rule, condition, or requirement:
	       (1) Describing the following information for
	     products, systems, services or practices:
	       (i) Classification of components.
	       (ii) Specification of materials, performance, or
	     operations; or
	       (iii) Delineation of procedures; or
	       (2) With respect to the privacy of individually
	     identifiable health information.').	

glossary(standardSettingOrganization,'
	standardSettingOrganization
	Source: HIPAA Section 160.103
	     Standard setting organization (SSO)means an
	     organization accredited by the American National
	     Standards Institute that develops and maintains
	     standards for information transactions or data
	     elements, or any other standard that is necessary for,
	     or will facilitate the implementation of, this part.').

glossary(state,'
	state
	Source: HIPAA Section 160.103
	     State refers to one of the following:
	     (1) For a health plan established or regulated by
	     Federal law, State has the meaning set forth in the
	     applicable section of the United States Code for such
	     health plan.
	     (2) For all other purposes, State means any of the
	     several States, the District of Columbia, the
	     Commonwealth of Puerto Rico, the Virgin Islands,
	     and Guam.').

glossary(stateChildHealthPlan,'
	stateChildHealthPlan
	Source: HIPAA Section 160.103, health plan definition
	     An approved State child health plan under
	     title XXI of the Act, providing benefits for child
	     health assistance that meet the requirements of
	     section 2103 of the Act, 42 U.S.C. 1397, et seq.').

glossary(stateHighRiskPoolPlan,'
	stateHighRiskPoolPlan
	Source: HIPAA Section 160.103, health plan definition
	     A high risk pool that is a mechanism
	     established under State law to provide health
	     insurance coverage or comparable coverage to
	     eligible individuals.').

glossary(states,'
        states(+X,+Y)
	     Relation signifying that X states Y.').

glossary(statement,'
        statement(+X)
	     Object signifying a statement, whether verbal or written
	     stating X.').

glossary(statisticalMethods,'
        statisticalMethods
	     Object signifying ambiguous legal language expressed in
	     HIPAA s164.514(b): "generally accepted statistical and 
	     scientific principles and methods."').

glossary(stipulates,'
        stipulates(+X,+Y)
	     Relation signifying that X stipulates Y.').

glossary(subject,'
	subject(+X,+Y)
	     Relation signifying that X is subject to Y.').

glossary(subjectOf,'
        subjectOf(+X,+Y)
	     Relation signifying that X is the subject of Y, for
	     example, X is the subject of investigation Y.').

glossary(submits,'
        submits(+X,+Y,+Z)
	     Relation signifying that X submits Z to Y.').

glossary(subpoenas,'
        subpoenas(+X,+Y,+Z)
	     Relation signifying that X subpeonas Y for information Z.
	     Represents both subpeonas, discovery requests, and other
	     lawful processes, as listed in s164.512(e)(1)(ii).').

glossary(summary,'
	summary(+X)
	     Object signifying a summary of X.').

glossary(summaryHealthInformation,'
	summaryHealthInformation
	     Signifies generic summary health information.
	-------------------------
	     Summary health information means information,
	     that may be individually identifiable health
	     information, and:
	       (1) That summarizes the claims history, claims
	     expenses, or type of claims experienced by
	     individuals for whom a plan sponsor has provided
	     health benefits under a group health plan; and
	       (2) From which the information described at
	     164.514(b)(2)(i) has been deleted, except that the
	     geographic information described in
	     164.514(b)(2)(i)(B) need only be aggregated to the
	     level of a five digit zip code.').

glossary(supervisedRelease,'
        supervisedRelease(+X)
	     Object signifying the supervised release of X.').

glossary(surveils,'
        surveils(+X,+Y)
	     Relation signifying that X surveils Y.').

glossary(takesStepsTo,'
        takesStepsTo(+X,+Y)
	     Relation signifying that X takes steps to perform Y.').

glossary(tattoo,'
        tattoo(+X)
	     Object signifying a tatoo of X.').

glossary(telephoneNumber,'
        telephoneNumber(+X)
	     Object signifying the telephone number of X.').

glossary(temporarily,'
	temporarily(+X)
	     Attribute signifying that X is temporary.').

glossary(threaten,'
	threaten(+X,+Y)
	     Relation signifying that X threatens Y.').

glossary(time,'
	time(+X)
	     Object signifying the time that X occurred.').

glossary(timely,'
	timely(+X)
	     Attribute signifying that X is timely.').

glossary(timePeriod,'
        timePeriod(+X)
	     Object signifying the time period that X is valid or able
	     to be performed.').

glossary(toTheExtentPossible,'
	toTheExtentPossible(+X)
	     Attribute signifying that X occurs to the extent possible.').

glossary(tradingPartnerAgreement,'
	tradingPartnerAgreement(+X,+Y)
	Source: HIPAA Section 160.103
	     Relation signifying that X and Y are in a trading 
	     partner agreement.
	-------------------------
	     Trading partner agreement means an agreement
	     related to the exchange of information in electronic
	     transactions, whether the agreement is distinct or part
	     of a larger agreement, between each party to the
	     agreement. (For example, a trading partner agreement
	     may specify, among other things, the duties and
	     responsibilities of each party to the agreement in
	     conducting a standard transaction.)').

glossary(trainingPrograms,'
        trainingPrograms(+X)
	Object signifying the training programs of X.
	-------------------------
	Source: HIPAA Section 164.508(a)(2)(B)
	      Signifies training programs, as follows:
	      "training programs in which students, trainees, or 
	      practitioners in mental health learn under supervision
	      to practice or improve their skills in group, joint,
	      family, or individual counseling."').

glossary(transaction,'
	transation(+X,+Y)
	Source: HIPAA Section 160.103
	     Relation signifing a transaction from X to Y.
	-------------------------
	     Transaction means the transmission of
	     information between two parties to carry out financial
	     or administrative activities related to health care. It
	     includes the following types of information
	     transmissions:
	       (1) Health care claims or equivalent encounter
	     information.
	       (2) Health care payment and remittance advice.
	       (3) Coordination of benefits.
	       (4) Health care claim status.
	       (5) Enrollment and disenrollment in a health plan.
	       (6) Eligibility for a health plan.
	       (7) Health plan premium payments.
	       (8) Referral certification and authorization.
	       (9) First report of injury.
	       (10) Health claims attachments.
	       (11) Other transactions that the Secretary may
	     prescribe by regulation.').

glossary(transplants,'
        transplants(+X,+Y, +Z, +W)
	     Relation signifying that X transplants Y to from Z to W.').

glossary(transports,'
        transports(+X,+Y,+Z,+W)
	     Relation signifying that X transports Y from Z to W.').

glossary(treatAs,'
	treatAs(+X,+Y)
	     Signifies that X should receive the same legal treatment as Y.').

glossary(treats,'
        treats(+X,+Y)
	     Relation signifying that X provides treatment for Y.').

glossary(treatment,'
       	treatment(+X)
	     Object signifying generic treatment activities of X.
	-------------------------
	     Source: HIPAA Section 164.501
	     Treatment means the provision, coordination, or
	     management of health care and related services by
	     one or more health care providers, including the
	     coordination or management of health care by a
	     health care provider with a third party; consultation
	     between health care providers relating to a patient; or
	     the referral of a patient for health care from one
	     health care provider to another.').

glossary(unavailable,'
	unavailable(+X)
	     Attribute signifying that X is unavailable.').

glossary(under,'
        under(+X,+Y)
	     Relating signifying that X occurs under Y, for example, giving
	     an individual health benefits under a health plan.').

glossary(underwrites,'
        underwrites(+X,+Y)
	     Relation signifying that X underwrites Y.').

glossary(unintentional,'
	unintentional(+X)
	     Attribute signifying that X is unintentional.').

glossary(unlawfulConduct,'
        unlawfulConduct(X)
	     Attribute signifying that that X engages in unlawful 
	     conduct--"conduct that is unlawful or otherwise 
	     violates professional or clinical standards, or that
	     the care, services, or conditions provided by the 
	     covered entity potentially endangers one or more 
	     patients, workers, or the public." HIPAA section 164.502(i)').

glossary(upon,'
	upon(+X,+Y)
	     Relation signifying the phrase "X upon Y"').

glossary(url,'
	url(+X)
	     Object signifying the url of X.').

glossary(usesAgainst,'
        usesAgainst(+X,+Y,+Z)
	     Relation signifying that X uses Z against Y. Appears in
	     s164.512(c)(1)(iii)(B).').

glossary(valid,'
        valid(+X)
	     Attribute signifying that X is valid under HIPAA.').

glossary(verifies,'
        verifies(+X,+Y)
	     Relation signifying that X verifies Y.').

glossary(veteransHealthCareProgram,'
	veteransHealthCareProgram, health plan definition
	Source: HIPAA Section 160.103, health plan definition
	     The veterans health care program under 38
	     U.S.C. chapter 17.').

glossary(vin,'
        vin(+X)
	     Object signifying the Vehicle Identification Number (VIN)
	     for a car owned by X.').

glossary(violentAct,'
	violentAct(+X,+Y)
	     Relation signifying that X abuses, neglects, or commits
	     domestic violence against Y.').

glossary(violentCrime,'
        violentCrime(+X,+Y)
	     Object signifying a violent crime committed by X against Y.').

glossary(voicePrint,'
	voicePrint(+X)
	     Object signifying a voice print of X.').

glossary(waits,'
	waits(+X,+Y)
	     Relation signifying that X waits for Y.').

glossary(waiver,'
	waiver(+X,+Y)
	     Object signifying a waiver from X to waive action Y.').

glossary(waives,'
	waives(+X,+Y)
	     Relation signifying that X waives Y.').

glossary(website,'
	website(+X)
	     Object signifying the website of X').

glossary(weight,'
	weight(+X)
	     Attribute signifying the weight of X.').

glossary(withdraws,'
	withdraws(+X,+Y)
	     Relation signifying that X withdraws Y.').

glossary(within,'
	within(+X,+Y)
	     Relation signifying that X occurs within Y.
        within(+X,+Y,+Z)
	     Relation signifying that X occurs within Y time
	     units of Z.').

glossary(without,'
        without(+X,+Y)
	     Relation signifying that X occurs without Y.').

glossary(withRespectTo,'
	withRespectTo(+X,+Y)
	     Relation signifying that X is with respect to Y.').

glossary(workforce,'
	workforce(+X)
	     Object signifying the workforce of X.
	Source: HIPAA Section 160.103
	     Workforce means employees, volunteers, trainees,
	     and other persons whose conduct, in the performance
	     of work for a covered entity, is under the direct
	     control of such entity, whether or not they are paid by
	     the covered entity.').

glossary(workplace,'
        workplace(+X)
	     Object signifying the workplace of X.').

glossary(workplaceRelated,'
        workplaceRelated(+X)
	     Attribute signifying that X is workplace related.').

glossary(wouldBeLikelyTo,'
	wouldBeLikelyTo(+X,+Y)
	     Related signifying that X would be likely to lead to Y.').

glossary(written,'
        written(+X)
	     Attribute signifying that X is written.').

glossary(writtenContract,'
	writtenContract(+X,+Y)
	Source: as appears in HIPAA Section 164.502(e)(2)
	     "a written contract or other written agreement or arrangement"
	     Signifies a written contract between X and Y.').

glossary(xor,'
        xor(+X,+Y)
	     Relation signifying either X or Y, but not both.').

glossary(xRays,'
	xRays(+X)
	     Object signifying x-rays of X.').

glossary(year,'
	year(+X)
	     Object signifying the year portion of the date that X occurred,
	     or X number of years.').

% eof

