% Contains a list of all the HIPAA relations.

:- multifile
        authority/2,
	discloses/3,
	invalid/1,
	valid/1,
	obtains/2.
:- dynamic hasTried/2.

% The dynamic external cross references.
:- multifile permitted_by_external_law/3,
	permitted_by_law/3,
	required_by_external_law/3.
:- dynamic
        authorized_by_law/3,
        limited_to_requirements_of_law/3,
	permitted_by_external_law/3,
	permitted_by_law/3,
	prohibited_by_external_law/3,
        required_by_external_law/3.

relation(authorized_by_law).
relation(required_by_external_law).
relation(permitted_by_external_law).
relation(permitted_by_law).
relation(prohibited_by_external_law).
relation(limited_to_requirements_of_law).

% [IGNORE_PRECONDITIONS]
permitted_by_law(X) :-
	permitted_by_external_law(X).
% [IGNORE_PRECONDITIONS]
required_by_law(X) :-
	required_by_external_law(X,_,_).

% The dynamic factual predicates. These predicates are used
%  when modeling factual statements in the HIPAA Rules
:- multifile
       	does_not_supersede/2,
	inNonCompliance/2,
	notEffective/1.

relation(does_not_supersede).

% The dynamic relations
:- dynamic
	able/2,
	abuses/2,
	accepts/2,
	access/2,
	accessible/2,
	actOnBehalf/2,
	actsUnderDirectionOf/2,
	administers/2,
	admits/2,
	adverselyAffects/2,
	agrees/2,
	alerts/3,
	amends/2,
	appends/3,
	approves/2,
	areConsistent/2,
	areFamilyMembers/2,
	areFriends/2,
	areIntegral/2,
	asNecessary/2,
	assigns/3,
	assures/3,
	at/2,
	atDirectionOf/3,
	attempts/2,
	avoids/2,
	because/2,
	before/2,
	believes/2,
	by/2,
	carriesOut/2,
	causes/2,
	coerce/2,
	collaborates/2,
	collects/2,
	combined/1,
	combined/2,
	complains/2,
	conflicts/2,
	consents/2,
	construes/3,
	contacts/2,
	coordinates/2,
	couldEndanger/2,
	coveredUnder/2,
	cures/2,
	defends/2,
	delays/2,
	demonstrates/2,
	denies/2,
	derives/3,
	describes/2,
	designatedBy/2,
	designed/2,
	directs/2,
	disagrees/2,
	discharges/2,
	discontinues/2,
	discriminates/2,
	discusses/3,
	disenrolled/2,
	displays/2,
	distributes/3,
	domesticViolence/2,
	during/2,
	elects/2,
	eligible/2,
	endangers/2,
	exercises/2,
	excludes/2,
	expeditedReviews/2,
	explains/2,
	extends/3,
	inCustodyof/2,
	intimidates/2,
	isEmployeeOf/2,
	jepardizes/2,
	enrolled/2,
	escapes/2,
	exercises/2,
	exposedTo/2,
	expressly/2,
	facilitates/2,
	forAsLongAs/2,
	forBestInterest/2,
	foresees/2,
	from/2,
	further/2,
	gives/3,
	hasMoreThanOne/2,
	hasRelationship/2,
	haveSameStartingDigits/2,
	impedes/2,
	improves/2,
	inAccordanceWith/2,
	inAdvance/2,
	inDirectTreatmentRelationship/2,
	includes/2,
	incomplete/1,
	incorrect/1,
	individually/2,
	informs/3,
	inLieu/2,
	inLocoParentis/2,
	insteadOf/2,
	intends/2,
	intimidates/2,
	into/2,
	investigates/2,
	involved/2,
	isChairOf/2,
	isConditionOf/2,
	isCrimeVictim/2,
	isEvidenceFor/2,
	isGuardian/2,
	isMaterialWitness/2,
	isMinimumNecessaryFor/2,
	isMinor/2,
	isParent/2,
	isPartyTo/2,
	isPresent/2,
	isRelatedTo/2,
	isRelevantTo/2,
	isUnemancipatedMinor/2,
	jurisdictionOver/2,
	justificationFor/2,
	learns/2,
	lessThan/2,
	lessThanOrEqualTo/2,
	limits/2,
	locatedAt/2,
	mails/3,
	makesEffective/3,
	makesEfforts/2,
	makesReference/2,
	moreThan/2,
	moreThanOne/1,
	necessitates/2,
	neglects/2,
	noLaterThan/2,
	notifies/3,
	objects/2,
	occurInConjunction/2,
	offers/3,
	on/2,
	only/1,
	optsOut/2,
	orders/3,
	oversees/2,
	participates/2,
	permits/2,
	perpetrates/2,
	picksUp/2,
	posts/2,
	prepares/2,
	presents/2,
	prohibits/2,
	protects/2,
	provides/3,
	publishes/3,
	pursuantTo/2,
	rates/2,
	reads/2,
	recalls/2,
	refers/3,
	reidentifies/2,
	relies/2,
	renews/2,
	replaces/2,
	represents/2,
	requests/3,
	requiredOrPermittedByHIPAA/2,
	requires/2,
	requires/3,
	reserves/2,
	resolves/2,
	restricts/2,
	restricts/3,
	resultOf/2,
	returns/3,
	reveals/2,
	revokes/2,
	riskToFrom/2,
	sends/3,
	separates/2,
	serveSimilarOrSamePopulations/2,
	signs/2,
	specifies/2,
	sponsors/2,
	states/2,
	stipulates/2,
	subject/2,
	subjectOf/2,
	submits/3,
	subpoenas/3,
	surveils/2,
	takesStepsTo/2,
	threaten/2,
	transplants/4,
	transports/4,
	treats/2,
	under/2,
	underwrites/2,
	unlawfulConduct/1,
	upon/2,
	usesAgainst/3,
	verifies/2,
	waits/2,
	waives/2,
	withdraws/2,
	within/2,
	within/3,
	without/2,
	withRespectTo/2,
	wm/1,
	wouldBeLikelyTo/2,
	xor/2.


% TESTING
maintains(healthcareProvider,phi(individual)).
phi(individual).
contains(phi(individual),name(individual)).
treatment(healthcareProvider).
payment(healthcareProvider).
healthcareOperations(healthcareOperations).
electronic(phi(individual)).



relation(able).
relation(abuses).
relation(accepts).
relation(access).
relation(accessible).
relation(actOnBehalf).
relation(actsUnderDirectionOf).
relation(administers).
relation(admits).
relation(adverselyAffects).
relation(agrees).
relation(alerts).
relation(amends).
relation(appends).
relation(approves).
relation(areConsistent).
relation(areFamilyMembers).
relation(areFriends).
relation(areIntegral).
relation(asNecessary).
relation(assigns).
relation(assures).
relation(at).
relation(atDirectionOf).
relation(attempts).
relation(authority).
relation(avoids).
relation(because).
relation(before).
relation(believes).
relation(by).
relation(carriesOut).
relation(causes).
relation(changes).
relation(coerce).
relation(collects).
relation(combined).
relation(complains).
relation(conflicts).
relation(consents).
relation(construes).
relation(contacts).
relation(coordinates).
relation(couldEndanger).
relation(coveredEntity).
relation(coveredUnder).
relation(cures).
relation(defends).
relation(delays).
relation(demonstrates).
relation(denies).
relation(derives).
relation(describes).
relation(designatedBy).
relation(designed).
relation(directs).
relation(disagrees).
relation(discharges).
relation(discontinues).
relation(discriminates).
relation(discusses).
relation(disenrolled).
relation(displays).
relation(distributes).
relation(domesticViolence).
relation(during).
relation(elects).
relation(eligible).
relation(endangers).
relation(enrolled).
relation(escapes).
relation(excludes).
relation(exercises).
relation(expeditedReviews).
relation(explains).
relation(exposedTo).
relation(expressly).
relation(extends).
relation(facilitates).
relation(forAsLongAs).
relation(forBestInterest).
relation(foresees).
relation(from).
relation(further).
relation(gives).
relation(hasMoreThanOne).
relation(hasRelationship).
relation(haveSameStartingDigits).
relation(healthPlan).
relation(healthcareClearinghouse).
relation(impedes).
relation(improves).
relation(inAccordanceWith).
relation(inAdvance).
relation(includes).
relation(incomplete).
relation(incorrect).
relation(inCustodyof).
relation(inDirectTreatmentRelationship).
relation(individually).
relation(individuallyIdentifiableHealthInfo).
relation(informs).
relation(inLieu).
relation(inLocoParentis).
relation(inOrganizedHealthcareArrangement).
relation(insteadOf).
relation(intends).
relation(intimidates).
relation(into).
relation(investigates).
relation(involved).
relation(isAttorney).
relation(isChairOf).
relation(isConditionOf).
relation(isCrimeVictim).
relation(isEmployeeOf).
relation(isEvidenceFor).
relation(isGuardian).
relation(isMaterialWitness).
relation(isMinimumNecessaryFor).
relation(isMinor).
relation(isParent).
relation(isPartyTo).
relation(isPresent).
relation(isRelevantTo).
relation(isRelatedTo).
relation(isUnemancipatedMinor).
relation(jepardizes).
relation(jurisdictionOver).
relation(justificationFor).
relation(learns).
relation(lessThan).
relation(lessThanOrEqualTo).
relation(limits).
relation(locatedAt).
relation(mails).
relation(makesEffective).
relation(makesEfforts).
relation(makesReference).
relation(markets).
relation(moreThan).
relation(moreThanOne).
relation(necessitates).
relation(neglects).
relation(noLaterThan).
relation(notifies).
relation(objects).
relation(occurInConjunction).
relation(offers).
relation(on).
relation(only).
relation(optsOut).
relation(orders).
relation(organizedHealthcareArrangement).
relation(oversees).
relation(participates).
relation(permits).
relation(perpetrates).
relation(person).
relation(picksUp).
relation(posts).
relation(prepares).
relation(presents).
relation(prohibits).
relation(protects).
relation(provides).
relation(publishes).
relation(pursuantTo).
relation(rates).
relation(reads).
relation(recalls).
relation(refers).
relation(reidentifies).
relation(relies).
relation(renews).
relation(replaces).
relation(represents).
relation(requests).
relation(requiredOrPermittedByHIPAA).
relation(requires).
relation(reserves).
relation(resolves).
relation(restricts).
relation(resultOf).
relation(returns).
relation(reveals).
relation(revokes).
relation(riskToFrom).
relation(sends).
relation(separates).
relation(serveSimilarOrSamePopulations).
relation(signs).
relation(specifies).
relation(sponsors).
relation(states).
relation(stipulates).
relation(subject).
relation(subjectOf).
relation(subpoenas).
relation(surveils).
relation(takesStepsTo).
relation(threaten).
relation(tradingPartnerAgreement).
relation(transplants).
relation(transports).
relation(treatAs).
relation(treats).
relation(under).
relation(underwrites).
relation(unlawfulConduct).
relation(upon).
relation(usesAgainst).
relation(verifies).
relation(violentAct).
relation(waits).
relation(waives).
relation(withdraws).
relation(within).
relation(without).
relation(withRespectTo).
relation(wouldBeLikelyTo).
relation(xor).

% Relations involving relations
% [IGNORE_PRECONDITIONS]
violentAct(Attacker,Victim) :-
	domesticViolence(Attacker,Victim).
% [IGNORE_PRECONDITIONS]
violentAct(Attacker,Victim) :-
	abuses(Attacker,Victim).
% [IGNORE_PRECONDITIONS]
violentAct(Attacker,Victim) :-
	neglects(Attacker,Victim).

isThreateningAct(CE,Individual,intimidates(CE,Individual)).
isThreateningAct(CE,Individual,threaten(CE,Individual)).
isThreateningAct(CE,Individual,coerce(CE,Individual)).
isThreateningAct(CE,Individual,discriminates(CE,Individual)).
isThreateningAct(CE,Individual,retaliatoryAction(CE,Individual)).

% [IGNORE_PRECONDITIONS]
unlawfulConduct(Organization) :-
	violates(Organization, professionalStandards).
% [IGNORE_PRECONDITIONS]
unlawfulConduct(Organization) :-
	couldEndanger(Organization,_).

% ASSUMPTION: health oversight agencies have the 
%   authority to investigate potential wrong doing.
% [IGNORE_PRECONDITIONS]
authority(Agency, investigates(Agency, unlawfulConduct(CE))) :-
	isHealthOversightAgency(Agency),
	isCoveredEntity(CE).

% If a CE uses PHI for a particular purpose, they are using PHI; same with
% disclosures
% [IGNORE_PRECONDITIONS]
uses(CE,PHI) :-
	for(uses(CE,PHI),Purpose).
% [IGNORE_PRECONDITIONS]
discloses(CE,ThirdParty,PHI) :-
	for(discloses(CE,ThirdParty,PHI),Purpose).

% Grouping creates or receives
createsOrReceives(X,_,PHI,creates(X,PHI)).
createsOrReceives(X,Y,PHI,receives(X,Y,PHI)).

% ASSUMPTION: When information is disclosed to an entity, that entity
%   maintains that information
% [IGNORE_PRECONDITIONS]
maintains(X,Info) :-
	discloses(Y,X,Info).

% Setting up the geographical size knowledge. Needed for s164.514(b)(2)(i)(B)
% NOTE: These are gross simplifications intended to make the model more efficient
% in the common cases. There are exceptions to these rules, for example,
% New York City > Rhode Island
% [IGNORE_PRECONDITIONS]
smallerThan(ZipCode,State) :-
	isState(State),
	isZipCode(ZipCode).
% [IGNORE_PRECONDITIONS]
smallerThan(StreetAddress,State) :-
	isState(State),
	isStreetAddress(StreetAddress).
% [IGNORE_PRECONDITIONS]
smallerThan(City,State) :-
	isState(State),
	isCity(City).
% [IGNORE_PRECONDITIONS]
smallerThan(County,State) :-
	isState(State),
	isCounty(County).
% [IGNORE_PRECONDITIONS]
smallerThan(Precinct,State) :-
	isState(State),
	isPrecinct(Precinct).
% [IGNORE_PRECONDITIONS]
smallerThan(StreetAddress,City) :-
	isCity(City),
	isStreetAddress(StreetAddress).
% [IGNORE_PRECONDITIONS]
smallerThan(StreetAddress,County) :-
	isStreetAddress(StreetAddress),
	isCounty(County).
% [IGNORE_PRECONDITIONS]
smallerThan(StreetAddress,Precinct) :-
	isStreetAddress(StreetAddress),
	isPrecinct(Precinct).
% [IGNORE_PRECONDITIONS]
smallerThan(StreetAddress,ZipCode) :-
	isStreetAddress(StreetAddress),
	isZipCode(ZipCode).

% [IGNORE_PRECONDITIONS]
requiredOrPermittedByHIPAA(CE,UsesOrDiscloses) :-
	privilege(CE, UsesOrDiscloses, Section),
	isSubsectionOf(Section,'164').
% [IGNORE_PRECONDITIONS]
requiredOrPermittedByHIPAA(CE,UsesOrDiscloses) :-
	obligation(CE, UsesOrDiscloses, Section),
	isSubsectionOf(Section,'164').

%obligation(X,Y,S) :-
%	wm(hasTried(obligation(X,Y,S),1)) ->
%	  (   
%	    retract(wm(hasTried(obligation(X,Y,X),1))),
%	    asserta(wm(hasTried(obligation(X,Y,S),2))),
%	    fail
%	  );
%	  assert(wm(hasTried(obligation(X,Y,S),1))),
%	   (   not(wm(hasTried(obligation(X,Y,S),2))),
%	       obligation(X,Y,S)) ->
%	       assert(obligation(X,Y,S)).

%obligation(jeremy,eats,'1').
%obligation(X,Y,'2') :-
%	obligation(X,Y,Source),
%	isSubsectionOf(Source,'1').

%-------------------------------------------------
% Reflexive relations
%-------------------------------------------------
% brother(X,Y) :-
%	wm(hasTried(brother(Y,X),1)) ->
	%(
	 % retract(wm(hasTried(brother(Y,X),1))),
	  %asserta(wm(hasTried(brother(Y,X),2))),
	  %fail
	%);

	%asserta(wm(hasTried(brother(Y,X),1))),
	%(not(wm(hasTried(brother(Y,X),2))) ,
        %  brother(Y,X)) ->
	%    asserta(brother(X,Y)).

% START BROKEN
%brother(jeremy,justin).
%brother(Y,X) :-
%	brother(X,Y),
%	reflexive(X,Y,brother).
%reflexive(Arg1,Arg2,Pred) :-
%	Y=.. [Pred,Arg1,Arg2],
%	X=.. [Pred,Arg2,Arg1],
%	wm(hasTried(Y,1)) ->
%	(
%	   retract(wm(hasTried(Y,1))),
%	   asserta(wm(hasTried(Y,2))),
%	   fail
%	);
%	asserta(wm(hasTried(Y,1))),
%	( not(wm(hasTried(Y,2))) ,
%	  Y) ->
%	  asserta(X).
% END BROKEN

% [IGNORE_PRECONDITIONS]
collaborates(X,Y) :-
	wm(hasTried(collaborates(Y,X),1)) ->
	(
	  retract(wm(hasTried(collaborates(Y,X),1))),
	  asserta(wm(hasTried(collaborates(Y,X),2))),
	  fail
	);

	asserta(wm(hasTried(collaborates(Y,X),1))),
	(not(wm(hasTried(collaborates(Y,X),2))) ,
          collaborates(Y,X)) ->
	    asserta(collaborates(X,Y)).
% [IGNORE_PRECONDITIONS]
areBusinessAssociates(X,Y) :-
	wm(hasTried(areBusinessAssociates(Y,X),1)) ->
	(
	  retract(wm(hasTried(areBusinessAssociates(Y,X),1))),
	  asserta(wm(hasTried(areBusinessAssociates(Y,X),2))),
	  fail
	);

	asserta(wm(hasTried(areBusinessAssociates(Y,X),1))),
	(not(wm(hasTried(areBusinessAssociates(Y,X),2))) ,
          areBusinessAssociates(Y,X)) ->
	    asserta(areBusinessAssociates(X,Y)).
% [IGNORE_PRECONDITIONS]
areConsistent(X,Y) :-
	wm(hasTried(areConsistent(Y,X),1)) ->
	(
	  retract(wm(hasTried(areConsistent(Y,X),1))),
	  asserta(wm(hasTried(areConsistent(Y,X),2))),
	  fail
	);

	asserta(wm(hasTried(areConsistent(Y,X),1))),
	(not(wm(hasTried(areConsistent(Y,X),2))) ,
          areConsistent(Y,X)) ->
	    asserta(areConsistent(X,Y)).
% [IGNORE_PRECONDITIONS]
combined(X,Y) :-
	wm(hasTried(combined(Y,X),1)) ->
	(
	  retract(wm(hasTried(combined(Y,X),1))),
	  asserta(wm(hasTried(combined(Y,X),2))),
	  fail
	);

	asserta(wm(hasTried(combined(Y,X),1))),
	(not(wm(hasTried(combined(Y,X),2))) ,
          combined(Y,X)) ->
	    asserta(combined(X,Y)).
% [IGNORE_PRECONDITIONS]
conflicts(X,Y) :-
	wm(hasTried(conflicts(Y,X),1)) ->
	(
	  retract(wm(hasTried(conflicts(Y,X),1))),
	  asserta(wm(hasTried(conflicts(Y,X),2))),
	  fail
	);

	asserta(wm(hasTried(conflicts(Y,X),1))),
	(not(wm(hasTried(conflicts(Y,X),2))) ,
          conflicts(Y,X)) ->
	    asserta(conflicts(X,Y)).
% [IGNORE_PRECONDITIONS]
areFriends(X,Y) :-
	wm(hasTried(areFriends(Y,X),1)) ->
	(
	  retract(wm(hasTried(areFriends(Y,X),1))),
	  asserta(wm(hasTried(areFriends(Y,X),2))),
	  fail
	);

	asserta(wm(hasTried(areFriends(Y,X),1))),
	(not(wm(hasTried(areFriends(Y,X),2))) ,
          areFriends(Y,X)) ->
	    asserta(areFriends(X,Y)).
% [IGNORE_PRECONDITIONS]
areFamilyMembers(X,Y) :-
	wm(hasTried(areFamilyMembers(Y,X),1)) ->
	(
	  retract(wm(hasTried(areFamilyMembers(Y,X),1))),
	  asserta(wm(hasTried(areFamilyMembers(Y,X),2))),
	  fail
	);

	asserta(wm(hasTried(areFamilyMembers(Y,X),1))),
	(not(wm(hasTried(areFamilyMembers(Y,X),2))) ,
          areFamilyMembers(Y,X)) ->
	    asserta(areFamilyMembers(X,Y)).
% [IGNORE_PRECONDITIONS]
isRelatedTo(X,Y) :-
	wm(hasTried(isRelatedTo(Y,X),1)) ->
	(
	  retract(wm(hasTried(isRelatedTo(Y,X),1))),
	  asserta(wm(hasTried(isRelatedTo(Y,X),2))),
	  fail
	);

	asserta(wm(hasTried(isRelatedTo(Y,X),1))),
	(not(wm(hasTried(isRelatedTo(Y,X),2))) ,
          isRelatedTo(Y,X)) ->
	    asserta(isRelatedTo(X,Y)).

% EOF
