
% meta_rule
%  Some rules create, remove, or modify existing rules,
%  i.e., they are meta-rules. These rules are denoted
%  as meta_rule(X), where X is the meta-rule. When using
%  query(+Goal), the meta-rules will be executed, then
%  removed when the query has completed. Rules added
%  as a result of a meta-rule are signified by mRule(X).
:- multifile meta_rule/1, mRule/1, wm/1.

:- dynamic wm/1.

%------------------------------------------------
% Setting up the query mechanism
% [IGNORE_PRECONDITIONS]
query(X) :-
	ignore(call_meta_rules),
	call(X),
	ignore(clear_wm),
	ignore(remove_meta_rules).

% Iteratively calls the meta rules.
% [IGNORE_PRECONDITIONS]
call_meta_rules :-
	forall(meta_rule(X), call(X)).

% Iteratively removes the meta rules.
% [IGNORE_PRECONDITIONS]
remove_meta_rules :-
	forall(mRule(X), retract(X)).

% Clear out working memory
% [IGNORE_PRECONDITIONS]
clear_wm :-
	retract(wm(_)).
%------------------------------------------------


%------------------------------------------------
% Setting up the working memory
%  Working memory ensures the model behaves as
%  a production rule model.
% [IGNORE_PRECONDITIONS]
wm(X) :-
	call(X).

% add_to_wm(+Goal)
%  Used to add a Goal to working memory. Uses asserta
%  to ensure that working memory elements are before the
%  working memory rule, so that if it has been proven, it
%  will not be called.
% [IGNORE_PRECONDITIONS]
add_to_wm(X) :-
	asserta(wm(X)).
%------------------------------------------------
