% Models section 164.306 of the HIPAA Security Rule

s164_306a1(CE,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	createsReceivesMaintainsOrTransmits(CE,PHI,CRMT),
	CRMT,
	add_to_wm(s164_306(CE,PHI)).
obligation(CE,
	   ensures(CE,confidentiality(PHI)),
	   '164.306(a)(1)') :-
	wm(s164_306a1(CE,PHI)).
implied(right(Individual,
	      ensures(CE,confidentiality(PHI)),
	      '164.306(a)(1)')) :-
	about(PHI,Individual),
	wm(s164_306a1(CE,PHI)).
obligation(CE,
	   ensures(CE,integrity(PHI)),
	   '164.306(a)(1)') :-
	wm(s164_306a1(CE,PHI)).
implied(right(Individual,
	      ensures(CE,integrity(PHI)),
	      '164.306(a)(1)')) :-
	about(PHI,Individual),
	wm(s164_306a1(CE,PHI)).
obligation(CE,
	   ensures(CE,availability(PHI)),
	   '164.306(a)(1)') :-
	wm(s164_306a1(CE,PHI)).
implied(right(Individual,
	      ensures(CE,availability(PHI)),
	      '164.306(a)(1)')) :-
	about(PHI,Individual),
	wm(s164_306a1(CE,PHI)).

s164_306a2(CE,PHI,ThreatsOrHazards) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	createsReceivesMaintainsOrTransmits(CE,PHI,CRMT),
	CRMT,
	reasonable(anticipates(CE,ThreatsOrHazards)),
	add_to_wm(s164_306a2(CE,PHI,ThreatsOrHazards)).
obligation(CE,
	   protects(CE,PHI,ThreatsOrHazards),
	   '164.306(a)(2)') :-
	wm(s164_306a2(CE,PHI,ThreatsOrHazards)).
implied(right(Individual,
	      protects(CE,PHI,ThreatsOrHazards),
	      '164.306(a)(2)')) :-
	about(PHI,Individual),
	wm(s164_306a2(CE,PHI,ThreatsOrHazards)).

% TODO: add ref from Section to subpart E
s164_306a3(CE,UsesOrDiscloses,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsesOrDiscloses),
	reasonable(anticipates(CE,UsesOrDiscloses)),
	not(privilege(CE,UsesOrDiscloses,Section)),
	not(obligation(CE,UsesOrDiscloses,Section)),
	add_to_wm(s164_306a3(CE,UsesOrDiscloses,PHI)).
obligation(CE,
	   protects(CE,PHI,UsesOrDiscloses),
	   '164.306(a)(3)') :-
	wm(s164_306a3(CE,UsesOrDiscloses,PHI)).
implied(right(Individual,
	      protects(CE,PHI,UsesOrDiscloses),
	      '164.306(a)(3)')) :-
	about(PHI,Individual),
	wm(s164_306a3(CE,UsesOrDiscloses,PHI)).

s164_306a4(CE,Employee) :-
	isCoveredEntity(CE),
	isMemberOfWorkforce(Employee,CE),
	add_to_wm(s164_306a4(CE,Employee)).
obligation(CE,
	   ensures(CE,
		   complies(Employee,hipaaSecurityRule)),
	   '164.306(a)(4)') :-
	wm(s164_306a4(CE,Employee)).
implied(right(Individual,
	      ensures(CE,
		      complies(Employee,hipaaSecurityRule)),
	   '164.306(a)(4)')) :-
	wm(s164_306a4(CE,Employee)).
		   
s164_306b1(CE,SecurityMeasure) :-
	allows(SecurityMeasure,
	       reasonable(implements(CE,specifications(hipaaSecurityRule)))),
	appropriate(SecurityMeasure,
		    reasonable(implements(CE,specifications(hipaaSecurityRule)))),
	isCoveredEntity(CE),
	isSecurityMeasure(SecurityMeasure),
	add_to_wm(s164_306b1(CE,SecurityMeasure)).
privilege(CE,
	  uses(CE,
	       any(SecurityMeasure)),
	  '164.306(b)(1)') :-
	wm(s164_306b1(CE,SecurityMeasure)).
implied(noRight(Individual,
		right(Individual,
		      not(uses(CE,
			       any(SecurityMeasure))),
		      _),
		'164.306(b)(1)')) :-
	wm(s164_306b1(CE,SecurityMeasure)).

s164_306b2(CE,Factor,SecurityMeasure) :-
	isCoveredEntity(CE),
	is_s164_306b2_factor(CE,SecurityMeasure,Factor),
	isSecurityMeasure(SecurityMeasure),
	add_to_wm(s164_306b2(CE,Factor,SecurityMeasure)).
obligation(CE,
	   when(accountFor(Factor),
		decides(CE,
			 uses(CE,
			      SecurityMeasure))),
	   '164.306(b)(2)') :-
	wm(s164_306b2(CE,Factor,SecurityMeasure)).
implied(right(Individual,
	      when(accountFor(Factor),
		   deciding(CE,
			    uses(CE,
				 SecurityMeasure))),
	      '164.306(b)(2)')) :-
	wm(s164_306b2(CE,Factor,SecurityMeasure)).

is_s164_306b2_factor(CE,_,size(CE)).
is_s164_306b2_factor(CE,_,complexity(CE)).
is_s164_306b2_factor(CE,_,capabilities(CE)).
is_s164_306b2_factor(CE,_,technicalInfrastructure(CE)).
is_s164_306b2_factor(CE,_,hardwareSecurityCapabilities(CE)).
is_s164_306b2_factor(CE,_,softwareSecurityCapabilities(CE)).
is_s164_306b2_factor(_,SecurityMeasure,cost(SecurityMeasure)).
is_s164_306b2_factor(_,_,probability(Risk)) :-
	isPotentialRisk(Risk,PHI),
	isPHI(PHI),
	electronic(PHI).
is_s164_306b2_factor(_,_,criticality(Risk)) :-
	isPotentialRisk(Risk,PHI),
	isPHI(PHI),
	electronic(PHI).

% TODO model internal cross-references at 164.306(c)?

% TODO: cross-reference to addressable standards in 308, 310, 312, 314, and 316
s164_306d3i(CE,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_306d3i(CE,PHI)).
obligation(CE,
	   assesses(CE,
		    reasonable(in(safeguards(CE,PHI),
				  environment(CE)))),
	   '164.306(d)(3)(i)') :-
	wm(s164_306d3i(CE,PHI)).
obligation(CE,
	   assesses(CE,
		    appropriate(in(safeguards(CE,PHI),
				   environment(CE)))),
	   '164.306(d)(3)(i)') :-
	wm(s164_306d3i(CE,PHI)).
implied(right(Individual,
	      assesses(CE,
		       reasonable(in(safeguards(CE,PHI),
				     environment(CE)))),
	      '164.306(d)(3)(i)')) :-
	about(PHI,Individual),
	wm(s164_306d3i(CE,PHI)).
implied(right(Individual,
	      assesses(CE,
		       appropriate(in(safeguards(CE,PHI),
				      environment(CE)))),
	      '164.306(d)(3)(i)')) :-
	about(PHI,Individual),
	wm(s164_306d3i(CE,PHI)).

% TODO: forward reference at 164.306(d)(3)(ii)

% TODO: cross ref to backwards to 164.105 and forwards to 164.316 at
% 164.306(e)


% eof
