% Models section 164.308 of the HIPAA Security Rule

s164_308a1i(CE,PoliciesAndProcedures,Goal) :-
	isCoveredEntity(CE),
	is_s164_308a1i_securityGoal(CE,Goal),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	add_to_wm(s164_308a1i(CE,PoliciesAndProcedures,Goal)).
is_s164_308a1i_securityGoal(CE,prevents(CE,securityViolation)).
is_s164_308a1i_securityGoal(CE,detects(CE,securityViolation)).
is_s164_308a1i_securityGoal(CE,contains(CE,securityViolation)).
is_s164_308a1i_securityGoal(CE,corrects(CE,securityViolation)).
obligation(CE,
	   to(implements(PoliciesAndProcedures),
	      Goal),
	   '164.308(a)(1)(i)') :-
	wm(s164_308a1i(CE,PoliciesAndProcedures,Goal)).
implied(right(Individual,
	      Goal,
	      '164.308(a)(1)(i)')) :-
	wm(s164_308a1i(CE,PoliciesAndProcedures,Goal)).

s164_308a1iiA(CE,PHI,PHI_Attribute) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	is_s164_308a1iiA_PHIattribute(PHI,PHI_Attribute),
	add_to_wm(s164_308a1iiA(CE,PHI,PHI_Attribute)).
is_s164_308a1iiA_PHIattribute(PHI,confidentiality(PHI)).
is_s164_308a1iiA_PHIattribute(PHI,integrity(PHI)).
is_s164_308a1iiA_PHIattribute(PHI,availability(PHI)).
obligation(CE,
	   conducts(CE,
		    accurate(assessment(potential(threats(PHI_Attribute))))),
	   '164.308(a)(1)(ii)(A)') :-
	wm(s164_308a1iiA(CE,PHI,PHI_Attribute)).
obligation(CE,
	   conducts(CE,
		    thorough(assessment(potential(threats(PHI_Attribute))))),
	   '164.308(a)(1)(ii)(A)') :-
	wm(s164_308a1iiA(CE,PHI,PHI_Attribute)).
implied(right(Individual,
	      PHI_Attribute,
	      '164.308(a)(1)(ii)(A)')) :-
	about(PHI,Individual),
	wm(s164_308a1iiA(CE,PHI,PHI_Attribute)).

s164_308a1iiB(CE,ReasonableAndAppropriateLevel,X) :-
	isCoveredEntity(CE),
	isReasonableAndAppropriateLevel(ReasonableAndAppropriateLevel),
	handle_crossRefTo_s164_306a(CE,X),
	add_to_wm(s164_308a1iiB(CE,ReasonableAndAppropriateLevel,X)).
isReasonableAndAppropriateLevel(reasonable(level)).
isReasonableAndAppropriateLevel(appropriate(level)).
:- dynamic handle_crossRefTo_s164_306a/2.
obligation(CE,
	   implements(CE,
		      sufficient(securityMeasures,
				 reduces(securityMeasures,
					 risk(X),
					 ReasonableAndAppropriateLevel))),
	   '164.308(a)(1)(ii)(B)') :-
	wm(s164_308a1iiB(CE,ReasonableAndAppropriateLevel,X)).
implied(right(Individual,
	      sufficient(securityMeasures,
			 reduces(securityMeasures,
				 risk(X),
				 ReasonableAndAppropriateLevel)),
	      '164.308(a)(1)(ii)(B)')) :-
	wm(s164_308a1iiB(CE,ReasonableAndAppropriateLevel,X)).

s164_308a1iiC(CE,Employee,PoliciesAndProcedures) :-
	isCoveredEntity(CE),
	isMemberOfWorkforce(Employee,CE),
	not(complies(Employee,security(PoliciesAndProcedures))),
	isProceduresOrPolicies(PoliciesAndProcedures),
	add_to_wm(s164_308a1iiC(CE,Employee,PoliciesAndProcedures)).
obligation(CE,
	   applies(CE,
		   appropriate(sanctions(Employee))),
	   '164.308(a)(1)(ii)(C)') :-
	wm(s164_308a1iiC(CE,Employee,PoliciesAndProcedures)).
% TODO: what is the implied right?

s164_308a1iiD(CE) :-
	isCoveredEntity(CE),
	add_to_wm(s164_308a1iiD(CE)).
obligation(CE,
	   implements(CE,
		      procedure(regular(reviews(CE,
						records(informationSystemActivities))))),
	   '164.308(a)(1)(ii)(D)') :-
	wm(s164_308a1iiD(CE)).
% TODO: how to handle examples in the legal text, i.e. in 164.308(a)(1)(ii)(D)
% solution: use the example/2 predicate
% TODO: what is the implied right?

s164_308a2(CE,SecurityOfficial,PoliciesAndProcedures) :-
	isCoveredEntity(CE),
	isResponsible(SecurityOfficial,
		      develops(CE,PoliciesAndProcedures)),
	isResponsible(SecurityOfficial,
		      implements(CE,PoliciesAndProcedures)),
	isProceduresOrPolicies(PoliciesAndProcedures),
	add_to_wm(s164_308a2(CE,SecurityOfficial,PoliciesAndProcedures)).
obligation(CE,
	   identifies(CE,
		      SecurityOfficial),
	   '164.308(a)(2)') :-
	wm(s164_308a2(CE,SecurityOfficial,PoliciesAndProcedures)).
% TODO: what is the implied right?

% TODO: forward ref to 164.308(a)(4) at 164.308(a)(3)(i)

s164_308a3iiA(CE,Employee,PHI) :-
	isCoveredEntity(CE),
	isMemberOfWorkforce(Employee,CE),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_308a3iiA(CE,Employee,PHI)).
obligation(CE,
	   addressable(implements(CE,
				  procedure(authorization(_,
							  Employee,
							  with(work(Employee),PHI))))),
	   '164.308(a)(3)(ii)(A)') :-
	wm(s164_308a3iiA(CE,Employee,PHI)).
% TODO: what is the implied right?
obligation(CE,
	   addressable(implements(CE,
				  procedure(supervises(CE,
						       with(work(Employee),PHI))))),
	   '164.308(a)(3)(ii)(A)') :-
	wm(s164_308a3iiA(CE,Employee,PHI)).
% TODO: what is the implied right?
obligation(CE,
	   addressable(implements(CE,
				  procedure(authorization(_,
							  Employee,
							  in(accesses(_,PHI),
							     location(Employee)))))),
	   '164.308(a)(3)(ii)(A)') :-
	wm(s164_308a3iiA(CE,Employee,PHI)).
% TODO: what is the implied right?
obligation(CE,
	   addressable(implements(CE,
				  procedure(supervises(CE,
						       in(accesses(_,PHI),
							  location(Employee)))))),
	   '164.308(a)(3)(ii)(A)') :-
	wm(s164_308a3iiA(CE,Employee,PHI)).
% TODO: what is the implied right?

s164_308a3iiB(CE,Employee,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	isMemberOfWorkforce(Employee,CE),
	add_to_wm(s164_308a3iiB(CE,Employee,PHI)).
obligation(CE,
	   addressable(implements(CE,
				  procedure(determines(CE,
						       appropriate(accesses(Employee,PHI)))))),
	   '164.308(a)(3)(ii)(B)') :-
	wm(s164_308a3iiB(CE,Employee,PHI)).
% TODO: what is the implied right?

s164_308a3iiC(CE,Employee,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	isMemberOfWorkforce(Employee,CE),
	add_to_wm(s164_308a3iiC(CE,Employee,PHI)).
obligation(CE,
	   addressable(implements(CE,
				  procedure(when(end(isMemberOfWorkforce(Employee,CE)),
						 terminates(CE,
							    accesses(Employee,PHI)))))),
	   '164.308(a)(3)(ii)(C)') :-
	wm(s164_308a3iiC(CE,Employee,PHI)).
implied(right(Individual,
	      not(after(accesses(Employee,PHI),
			terminates(end(isMemberOfWorkforce(Employee,CE))))),
	      '164.308(a)(3)(ii)(C)')) :-
	about(PHI,Individual),
	wm(s164_308a3iiC(CE,Employee,PHI)).
obligation(CE,
	   addressable(implements(CE,
				  procedure(when(determines(CE,
							    not(appropriate(accesses(Employee,PHI)))),
						 terminates(CE,
							    accesses(Employee,PHI)))))),
	   '164.308(a)(3)(ii)(C)') :-
	wm(s164_308a3iiC(CE,Employee,PHI)).
implied(right(Individual,
	      not(after(accesses(Employee,PHI),
			determines(CE,
				   not(appropriate(accesses(Employee,PHI)))))),
	      '164.308(a)(3)(ii)(C)')) :-
	about(PHI,Individual),
	wm(s164_308a3iiC(CE,Employee,PHI)).

s164_308a4i(CE,PoliciesAndProcedures,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	add_to_wm(s164_308a4i(CE,PoliciesAndProcedures,PHI)).
obligation(CE,
	   for(PoliciesAndProcedures,
	       authorizes(CE,accesses(_,PHI))),
	   '164.308(a)(4)(i)') :-
	wm(s164_308a4i(CE,PoliciesAndProcedures,PHI)).
% TODO: what is the implied right?

s164_308a4iiA(HCC,PoliciesAndProcedures,LargerOrganization,PHI) :-
	isHealthcareClearinghouse(HCC),
	isPartOf(HCC,LargerOrganization),
	smallerThan(HCC,LargerOrganization),
	isPHI(PHI),
	electronic(PHI),
	isProceduresOrPolicies(HCC,PoliciesAndProcedures),
	add_to_wm(s164_308a4iiA(HCC,PoliciesAndProcedures,LargerOrganization,PHI)).
obligation(HCC,
	   implements(HCC,
		      for(PoliciesAndProcedures,
			  protects(HCC,PHI,unauthorized(accesses(LargerOrganization,PHI))))),
	   '164.308(a)(4)(ii)(A)') :-
	wm(s164_308a4iiA(HCC,PoliciesAndProcedures,LargerOrganization,PHI)).
implied(right(Individual,
	      protects(HCC,PHI,unauthorized(accesses(LargerOrganization,PHI))),
	      '164.308(a)(4)(ii)(A)')) :-
	about(PHI,Individual),
	wm(s164_308a4iiA(HCC,PoliciesAndProcedures,LargerOrganization,PHI)).

s164_308a4iiB(CE,PoliciesAndProcedures,PHI) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_308a4iiB(CE,PoliciesAndProcedures,PHI)).
obligation(CE,
	   addressable(implements(areConsistent(for(PoliciesAndProcedures,
						    grants(CE,
							   accesses(_,PHI))),
					        accessAuthorizationPolicy(CE)))),
	   '164.308(a)(4)(ii)(B)') :-
	wm(s164_308a4iiB(CE,PoliciesAndProcedures,PHI)).
% TODO: what is the implied right?
% TODO: what about the example list at s164.308(a)(4)(ii)(B)?

s164_308a4iiC(CE,User,WorkstationTransactionProgramOrProcess,PoliciesAndProcedures) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	uses(User,WorkstationTransactionProgramOrProcess),
	isWorkstationTransactionProgramOrProcess(WorkstationTransactionProgramOrProcess),
	establishes(PoliciesAndProcedures,
		    right(User,
			  accesses(User,WorkstationTransactionProgramOrProcess),
			  _)),
	documents(PoliciesAndProcedures,
		  right(User,
			accesses(User,WorkstationTransactionProgramOrProcess),
			_)),
	reviews(PoliciesAndProcedures,
		right(User,
		      accesses(User,WorkstationTransactionProgramOrProcess),
		      _)),
	modifies(PoliciesAndProcedures,
		 right(User,
		       accesses(User,WorkstationTransactionProgramOrProcess),
		       _)),
	add_to_wm(s164_308a4iiC(CE,User,WorkstationTransactionProgramOrProcess,PoliciesAndProcedures)).
isWorkstationTransactionProgramOrProcess(workstation).
isWorkstationTransactionProgramOrProcess(transaction).
isWorkstationTransactionProgramOrProcess(program).
isWorkstationTransactionProgramOrProcess(process(_)).
obligation(CE,
	   addressable(implements(CE,PoliciesAndProcedures)),
	   '164.308(a)(4)(ii)(C)') :-
	wm(s164_308a4iiC(CE,User,WorkstationTransactionProgramOrProcess,PoliciesAndProcedures)).
% TODO what is the implied right? a user's right to access the
% workstation, etc?

s164_308a5i(CE,Employee) :-
	isCoveredEntity(CE),
	isMemberOfWorkforce(Employee,CE),
	add_to_wm(s164_308a5i(CE,Employee)).
obligation(CE,
	   implements(trains(CE,
			     Employee,
			     securityAwareness)),
	   '164.308(a)(5)(i)') :-
	wm(s164_308a5i(CE,Employee)).
implied(right(Employee,
	      trains(CE,
		     Employee,
		     securityAwareness),
	   '164.308(a)(5)(i)')) :-
	wm(s164_308a5i(CE,Employee)).
obligation(CE,
	   implements(trains(CE,
			     Manager,
			     securityAwareness)),
	   '164.308(a)(5)(i)') :-
	isManager(Manager),
	wm(s164_308a5i(CE,Manager)).
implied(right(Manager,
	      trains(CE,
		     Manager,
		     securityAwareness),
	   '164.308(a)(5)(i)')) :-
	isManager(Manager),
	wm(s164_308a5i(CE,Manager)).

s164_308a5iiA(CE) :-
	isCoveredEntity(CE),
	add_to_wm(s164_308a5iiA(CE)).
obligation(CE,
	   addressable(implements(CE,periodic(securityUpdates))),
	   '164.308(a)(5)(ii)(A)') :-
	wm(s164_308a5iiA(CE)).
% TODO what is the implied right?

s164_308a5iiB(CE,Purpose) :-
	isCoveredEntity(CE),
	is_s164_308a5iiB_purpose(CE,Purpose),
	add_to_wm(s164_308a5iiB(CE,Purpose)).
is_s164_308a5iiB_purpose(CE,guards(CE,MaliciousSoftware)) :-
	isMaliciousSoftware(MaliciousSoftware).
is_s164_308a5iiB_purpose(CE,detects(CE,MaliciousSoftware)) :-
	isMaliciousSoftware(MaliciousSoftware).
is_s164_308a5iiB_purpose(CE,reports(CE,_,MaliciousSoftware)) :-
	isMaliciousSoftware(MaliciousSoftware).
obligation(CE,
	   addressable(implements(CE,
				  for(procedure(CE),Purpose))),
	   '164.308(a)(5)(ii)(B)') :-
	wm(s164_308a5iiB(CE,Purpose)).
% TODO what is the implied right?

s164_308a5iiC(CE) :-
	isCoveredEntity(CE),
	add_to_wm(s164_308a5iiC(CE)).
obligation(CE,
	   addressable(implements(CE,
				  for(procedure(CE),
				      monitors(CE,
					       loginAttempts(_))))),
	   '164.308(a)(5)(ii)(C)') :-
	wm(s164_308a5iiC(CE)).
obligation(CE,
	   addressable(implements(CE,
				  for(procedure(CE),
				      reports(CE,
					      _,
					      discrepancy(loginAttempts(_)))))),
	   '164.308(a)(5)(ii)(C)') :-
	wm(s164_308a5iiC(CE)).
% TODO what is the implied right?

s164_308a5iiD(CE,Purpose) :-
	isCoveredEntity(CE),
	is_s164_308a5iiD_purpose(Purpose),
	add_to_wm(s164_308a5iiD(CE,Purpose)).
is_s164_308a5iiD_purpose(creates(_,password(_))).
is_s164_308a5iiD_purpose(changes(_,password(_))).
is_s164_308a5iiD_purpose(safeguards(_,password(_))).
obligation(CE,
	   addressable(implements(CE,
				  for(procedure(CE),
				      Purpose))),
	   '164.308(a)(5)(ii)(D)') :-
	wm(s164_308a5iiD(CE,Purpose)).
% TODO what is the implied right?

s164_308a6i(CE,SecurityIncident,PoliciesAndProcedures) :-
	isCoveredEntity(CE),
	isSecurityIncident(SecurityIncident),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	add_to_wm(s164_308a6i(CE,SecurityIncident,PoliciesAndProcedures)).
obligation(CE,
	   implements(CE,
		      to(PoliciesAndProcedures,
			 addresses(CE,
				   SecurityIncident))),
	   '164.308(a)(6)(i)') :-
	wm(s164_308a6i(CE,SecurityIncident,PoliciesAndProcedures)).
% TODO what is the implied right?

s164_308a6ii(CE,SecurityIncident) :-
	isCoveredEntity(CE),
	isSecurityIncident(SecurityIncident),
	knows(CE,SecurityIncident),
	add_to_wm(s164_308a6ii(CE,SecurityIncident)).
s164_308a6ii(CE,SecurityIncident) :-
	isCoveredEntity(CE),
	isSecurityIncident(SecurityIncident),
	suspects(CE,SecurityIncident),
	add_to_wm(s164_308a6ii(CE,SecurityIncident)).
obligation(CE,
	   identifies(CE,SecurityIncident),
	   '164.308(a)(6)(ii)') :-
	wm(s164_308a6ii(CE,SecurityIncident)).
obligation(CE,
	   mitigates(CE,
		     harmfulEffects(SecurityIncident)),
	   '164.308(a)(6)(ii)') :-
	knows(CE,harmfulEffects(SecurityIncident)),
	wm(s164_308a6ii(CE,SecurityIncident)).
obligation(CE,
	   documents(CE,SecurityIncident),
	   '164.308(a)(6)(ii)') :-
	wm(s164_308a6ii(CE,SecurityIncident)).
obligation(CE,
	   documents(CE,outcome(SecurityIncident)),
	   '164.308(a)(6)(ii)') :-
	wm(s164_308a6ii(CE,SecurityIncident)).
% TODO what are the implied rights?

s164_308a7i(CE,System,Emergency,PoliciesAndProcedures,PHI) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	isEmergency(Emergency),
	damages(Emergency,System),
	isSystem(System),
	contains(System,PHI),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_308a7i(CE,System,Emergency,PoliciesAndProcedures,PHI)).
isEmergency(fire).
isEmergency(vandalism).
isEmergency(failure(System)) :-
	isSystem(System).
isEmergency(NaturalDisaster) :-
	isNaturalDisaster(NaturalDisaster).
obligation(CE,
	   establishes(CE,
		       for(PoliciesAndProcedures,
			   responds(CE,Emergency))),
	   '164.308(a)(7)(i)') :-
	wm(s164_308a7i(CE,System,Emergency,PoliciesAndProcedures,PHI)).
obligation(CE,
	   asNeeded(implements(CE,
			       for(PoliciesAndProcedures,
				   responds(CE,Emergency)))),
	   '164.308(a)(7)(i)') :-
	wm(s164_308a7i(CE,System,Emergency,PoliciesAndProcedures,PHI)).
% TODO what is the implied right?

s164_308a7iiA(CE,Purpose,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	is_s164_308a7iiA_purpose(CE,PHI,Purpose),
	add_to_wm(s164_308a7iiA(CE,Purpose,PHI)).
is_s164_308a7iiA_purpose(CE,PHI,creates(CE,retrievable(exact(copy(PHI),PHI)))).
is_s164_308a7iiA_purpose(CE,PHI,maintains(CE,retrievable(exact(copy(PHI),PHI)))).
obligation(CE,
	   establishes(CE,
		       to(procedure(CE),Purpose)),
	   '164.308(a)(7)(ii)(A)') :-
	wm(s164_308a7iiA(CE,Purpose,PHI)).
obligation(CE,
	   implments(CE,
		     to(procedure(CE),Purpose)),
	   '164.308(a)(7)(ii)(A)') :-
	wm(s164_308a7iiA(CE,Purpose,PHI)).
% TODO what is the implied right?

s164_308a7iiB(CE) :-
	isCoveredEntity(CE),
	add_to_wm(s164_308a7iiB(CE)).
obligation(CE,
	   establishes(CE,
		       to(procedure(CE),
			  restores(CE,loss(data)))),
	   '164.308(a)(7)(ii)(B)') :-
	wm(s164_308a7iiB(CE)).
obligation(CE,
	   asNeeded(implments(CE,
			      to(procedure(CE),
				 restores(CE,loss(data))))),
	   '164.308(a)(7)(ii)(B)') :-
	wm(s164_308a7iiB(CE)).
% TODO what is the implied right

s164_308a7iiC(CE,PHI) :-
	isCoveredEntity(CE),
	critical(businessProcesses(CE)),
	for(businessProcesses(CE),
	    protects(CE,
		     security(PHI))),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_308a7iiC(CE,PHI)).
obligation(CE,
	   establishes(CE,
		       to(procedure(CE),
			  while(continues(CE,businessProcesses(CE)),
				inEmergencyMode(CE)))),
	   '164.308(a)(7)(ii)(C)') :-
	wm(s164_308a7iiC(CE,PHI)).
obligation(CE,
	   asNeeded(implments(CE,
			      to(procedure(CE),
				 while(continues(CE,businessProcesses(CE)),
				       inEmergencyMode(CE))))),
	   '164.308(a)(7)(ii)(C)') :-
	wm(s164_308a7iiC(CE,PHI)).
implied(right(Individual,
	      protects(CE,security(PHI)),
	      '164.308(a)(7)(ii)(C)')) :-
	about(PHI,Individual),
	wm(s164_308a7iiC(CE,PHI)).

s164_308a7iiD(CE,Purpose) :-
	isCoveredEntity(CE),
	is_s164_308a7iiD_purpose(CE,Purpose),
	add_to_wm(s164_308a7iiD(CE,Purpose)).
is_s164_308a7iiD_purpose(CE,tests(CE,contingencyPlans(CE))).
is_s164_308a7iiD_purpose(CE,revises(CE,contingencyPlans(CE))).
obligation(CE,
	   addressable(implments(CE,
				 for(procedure(CE),Purpose))),
	   '164.308(a)(7)(ii)(D)') :-
	wm(s164_308a7iiD(CE,Purpose)).
% TODO what is the implied right?

s164_308a7iiE(CE,ApplicationsOrData,Component) :-
	isCoveredEntity(CE),
	isApplicationsOrData(ApplicationsOrData),
	isComponentOf(Component,contingencyPlans(CE)),
	add_to_wm(s164_308a7iiE(CE,ApplicationsOrData,Component)).
isApplicationsOrData(data).
isApplicationsOrData(application).
obligation(CE,
	   addressable(assesses(CE,
				cricicality(ApplicationsOrData,Component))),
	   '164.308(a)(7)(ii)(E)') :-
	wm(s164_308a7iiE(CE,ApplicationsOrData,Component)).
% TODO what is the implied right?

s164_308a8(CE,PoliciesAndProcedures) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	add_to_wm(s164_308a8(CE,PoliciesAndProcedures)).
is_s164_308a8_changes(CE,environment(CE)).
is_s164_308a8_changes(CE,operations(CE)).
obligation(CE,
	   performs(CE,
		    initially(based(periodic(technical(evaluates(CE,
								 PoliciesAndProcedures,
								 meets(PoliciesAndProcedures,
								       requirements(hipaaSecurityRule))))),
				    standards(hipaaSecurityRule)))),
	   '164.308(a)(8)') :-
	wm(s164_308a8(CE,PoliciesAndProcedures)).
obligation(CE,
	   performs(CE,
		    initially(based(periodic(nontechnical(evaluates(CE,
								    PoliciesAndProcedures,
								    meets(PoliciesAndProcedures,
									  requirements(hipaaSecurityRule))))),
				    standards(hipaaSecurityRule)))),
	   '164.308(a)(8)') :-
	wm(s164_308a8(CE,PoliciesAndProcedures)).
obligation(CE,
	   performs(CE,
		    subsequent(based(periodic(technical(evaluates(CE,
								 PoliciesAndProcedures,
								 meets(PoliciesAndProcedures,
								       requirements(hipaaSecurityRule))))),
				     changes(Changes)),
			       based(periodic(technical(evaluates(CE,
								    PoliciesAndProcedures,
								    meets(PoliciesAndProcedures,
									  requirements(hipaaSecurityRule))))),
				     standards(hipaaSecurityRule)))),
	   '164.308(a)(8)') :-
	is_s164_308a8_changes(CE,Changes),
	affects(Changes,
		security(PHI)),
	isPHI(PHI),
	electronic(PHI),
	wm(s164_308a8(CE,PoliciesAndProcedures)).
obligation(CE,
	   performs(CE,
		    subsequent(based(periodic(nontechnical(evaluates(CE,
								     PoliciesAndProcedures,
								     meets(PoliciesAndProcedures,
									   requirements(hipaaSecurityRule))))),
				     changes(Changes)),
			       based(periodic(nontechnical(evaluates(CE,
								     PoliciesAndProcedures,
								     meets(PoliciesAndProcedures,
									   requirements(hipaaSecurityRule))))),
				     standards(hipaaSecurityRule)))),
	   '164.308(a)(8)') :-
	is_s164_308a8_changes(CE,Changes),
	affects(Changes,
		security(PHI)),
	isPHI(PHI),
	electronic(PHI),
	wm(s164_308a8(CE,PoliciesAndProcedures)).

s164_308b1(CE,BA,AllowedAction,PHI) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isPHI(PHI),
	electronic(PHI),
	is_s164_308b1_action(BA,PHI,AllowedAction),
	obtains(CE,
		BA,
		satisfactory(assures(BA,
				     CE,
				     appropriate(safeguards(BA,PHI))))),
	% TODO cross-reference to s164.314(a)
	not(s164_308b1_exception(CE,BA,PHI)),
	add_to_wm(s164_308b1(CE,BA,AllowedAction,PHI)).
is_s164_308b1_action(BA,PHI,creates(BA,PHI)).
is_s164_308b1_action(BA,PHI,receives(BA,_,PHI)).
is_s164_308b1_action(BA,PHI,maintains(BA,PHI)).
is_s164_308b1_action(BA,PHI,transmits(BA,_,PHI)).
% TODO this is really a power
privilege(CE,
	  permits(BA,
		  actOnBehalf(BA,
			      AllowedAction,
			      CE)),
	  '164.308(b)(1)') :-
	wm(s164_308b1(CE,BA,AllowedAction,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(permits(BA,
				  actOnBehalf(BA,
					      AllowedAction,
					      CE))),
		      _),
		'164.308(b)(1)')) :-
	wm(s164_308b1(CE,BA,AllowedAction,PHI)).

s164_308b1_only_conditions(CE,BA,AllowedAction,PHI) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isPHI(PHI),
	electronic(PHI),
	is_s164_308b1_action(BA,PHI,AllowedAction),
	not(obtains(CE,
		    BA,
		    satisfactory(assures(BA,
					 CE,
					 appropriate(safeguards(BA,PHI)))))),
	% TODO cross-reference to s164.314(a)
	not(s164_308b1_exception(CE,BA,PHI)),
	add_to_wm(s164_308b1_only_conditions(CE,BA,AllowedAction,PHI)).
obligation(CE,
	   not(permits(BA,
		       actOnBehalf(BA,
				   AllowedAction,
				   CE))),
	  '164.308(b)(1)') :-
	wm(s164_308b1_only_conditions(CE,BA,AllowedAction,PHI)).
implied(right(Individual,
	      not(permits(BA,
			  actOnBehalf(BA,
				      AllowedAction,
				      CE))),
	      '164.308(b)(1)')) :-
	about(PHI,Individual),
	wm(s164_308b1_only_conditions(CE,BA,AllowedAction,PHI)).

s164_308b1_exception(CE,BA,PHI) :-
	electronic(PHI),
	concerns(transmits(CE,BA,PHI),
		 treats(_,Individual)),
	about(PHI,Individual).
s164_308b1_exception(GHPorHMOorHII,BA,PHI) :-
	transmits(GHPorHMOorHII,BA,PHI),
	actOnBehalf(GHPorHMOorHII,
		    transmits(GHPorHMOorHII,BA,PHI),
		    GHP),
	isGroupHealthPlan(GHP),
	isGHPorHIIorHMO(GHPorHMOorHII),
% TODO: cross-refs to 164.314(b) and 164.504(f) at 164.308(b)(2)(ii)
	isPlanSponsor(BA,GHPorHMOorHII).
% TODO: cross-refs to 164.502(e)(1)(ii)(C) and 164.502(e)(1)(ii)(C) at
% 164.308(b)(2)(iii)

inNonCompliance(CE, '164.308(b)(3)') :-
	violates(CE,
		 satisfactory(assures(CE,
				      OtherCE,
				      _))),
	isCoveredEntity(CE),
	isCoveredEntity(OtherCE),
	areBusinessAssociates(CE,OtherCE).
% TODO: cross-ref to 164.314(a) at 164.308(b)(3)

s164_308b4(CE,BA,PHI) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isPHI(PHI),
	% TODO: cross ref to 164.308(b)(4) at 164.314(a)
	add_to_wm(s164_308b4(CE,BA,PHI)).
obligation(CE,
	   through(documents(CE,
			     satisfactory(assures(BA,
						  CE,
						  safeguards(BA,PHI)))),
		   writtenContract(CE,BA)),
	   '164.308(b)(4)') :-
	wm(s164_308b4(CE,BA,PHI)).
% TODO what is the implied right?


% eof








