% Models section 164.310 of the HIPAA Security Rule

s164_310a1(CE,PoliciesAndProcedures,Asset) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	is_s164_310a1_asset(CE,Asset),
	add_to_wm(s164_310a1(CE,PoliciesAndProcedures,Asset)).
is_s164_310a1_asset(_,InformationSystem) :-
	isInformationSystem(InformationSystem),
	electronic(InformationSystem).
is_s164_310a1_asset(CE,facility(CE)) :-
	contains(facility(CE),InformationSystem),
	isInformationSystem(InformationSystem),
	electronic(InformationSystem).
obligation(CE,
	   to(implements(CE,PoliciesAndProcedures),
	      while(limits(CE,
			   physical(accesses(_,Asset))),
		    ensures(CE,
			    proper(authorized(Person,
					      accesses(Person,Asset)))))),
	   '164.310(a)(1)') :-
	wm(s164_310a1(CE,PoliciesAndProcedures,Asset)).
implied(right(Person,
	      accesses(Person,Asset),
	      '164.310(a)(1)')) :-
	authorized(Person,accesses(Person,Asset)),
	wm(s164_310a1(CE,PoliciesAndProcedures,Asset)).

s164_310a2i(CE) :-
	isCoveredEntity(CE),
	add_to_wm(s164_310a2i(CE)).
obligation(CE,
	   addressable(establishes(CE,
				   for(procedure(CE),
				       allows(CE,
					      for(accesses(_,
							   facility(CE)),
						  restores(CE,loss(data))))))),
	   '164.310(a)(2)(i)') :-
	wm(s164_310a2i(CE)).
obligation(CE,
	   addressable(asNeeded(implements(CE,
					   procedure(allows(CE,
							    for(accesses(_,
									 facility(CE)),
								restores(CE,loss(data)))))))),
	   '164.310(a)(2)(i)') :-
	wm(s164_310a2i(CE)).
% TODO what is the implied right?

s164_310a2ii(CE,PoliciesAndProcedures,Asset,Threats) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	is_s164_310a2ii_asset(CE,Asset),
	is_s164_310a2ii_threat(Asset,Threats),
	add_to_wm(s164_310a2ii(CE,PoliciesAndProcedures,Asset,Threats)).
is_s164_310a2ii_asset(CE,facility(CE)).
is_s164_310a2ii_asset(CE,Equipment) :-
	isEquipment(Equipment),
	contains(facility(CE),Equipment).
is_s164_310a2ii_threat(Asset,unauthorized(physical(accesses(_,Asset)))).
is_s164_310a2ii_threat(Asset,tampers(_,Asset)).
is_s164_310a2ii_threat(Asset,steals(_,Asset)).
obligation(CE,
	   implements(CE,
		      to(PoliciesAndProcedures,
			 from(safeguards(CE,Asset),
			      Threats))),
	   '164.310(a)(2)(ii)') :-
	wm(s164_310a2ii(CE,PoliciesAndProcedures,Asset,Threats)).
% TODO what is the implied right?

s164_310a2iii(CE,ControlledElement) :-
	isCoveredEntity(CE),
	is_s164_310a2iii_controlledElement(CE,Person,ControlledElement),
	add_to_wm(s164_310a2iii(CE,ControlledElement)).
is_s164_310a2iii_controlledElement(CE,Person,controls(CE,accesses(Person,facility(CE)))).
is_s164_310a2iii_controlledElement(CE,Person,validates(CE,accesses(Person,facility(CE)))).
is_s164_310a2iii_controlledElement(CE,Visitor,controls(CE,accesses(Visitor,facility(CE)))) :-
	visits(Visitor,facility(CE)).
is_s164_310a2iii_controlledElement(CE,Person,controls(CE,
						      accesses(Person,
							       Software))) :-
	isSoftware(Software),
	for(Software,tests(CE,Software)).
is_s164_310a2iii_controlledElement(CE,Person,controls(CE,
						      accesses(Person,
							       Software))) :-
	isSoftware(Software),
	for(Software,revises(CE,Software)).
obligation(CE,
	   addressable(implements(CE,
				  to(procedure(CE),
				     isBasedOn(ControlledElement,
					       (   role(Person),
						   function(Person)
					       ))))),
	   '164.310(a)(2)(iii)') :-
	wm(s164_310a2iii(CE,ControlledElement)).
% TODO what is the implied right?

s164_310a2iv(CE,PoliciesAndProcedures,RepairsOrModifications) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	is_s164_310a2iv_reparisOrModifications(CE,RepairsOrModifications),
	add_to_wm(s164_310a2iv(CE,PoliciesAndProcedures,RepairsOrModifications)).
is_s164_310a2iv_reparisOrModifications(CE,repairs(CE,Component)) :-
	physical(Component),
	isComponentOf(Component,facility(CE)).
is_s164_310a2iv_reparisOrModifications(CE,modifies(CE,Component)) :-
	physical(Component),
	isComponentOf(Component,facility(CE)).
obligation(CE,
	   addressable(implements(CE,
				  to(PoliciesAndProcedures,
				     documents(CE,
					       RepairsOrModifications)))),
	   '164.310(a)(2)(iv)') :-
	wm(s164_310a2iv(CE,PoliciesAndProcedures,RepairsOrModifications)).
% TODO what is the implied right?

s164_310b(CE,PolicySpecification,PolicySpecification) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PolicySpecification),
	is_s164_310b_policySpecification(CE,PolicySpecification),
	add_to_wm(s164_310b(CE,PolicySpecification,PolicySpecification)).
is_s164_310b_policySpecification(_,function(workstation)).
is_s164_310b_policySpecification(_,how(function(workstation))).
is_s164_310b_policySpecification(_,physical(attributes(workstation))) :-
	accesses(workstation,PHI),
	isPHI(PHI),
	electronic(PHI).
is_s164_310b_policySpecification(_,physical(attributes(environment(workstation)))) :-
	accesses(workstation,PHI),
	isPHI(PHI),
	electronic(PHI).
obligation(CE,
	   implements(CE,
		      that(PoliciesAndProcedures,
			   specifies(PoliciesAndProcedures,
				     PolicySpecification))),
	   '164.310(b)') :-
	wm(s164_310b(CE,PolicySpecification,PolicySpecification)).
% TODO what is the implied right?

s164_310c(CE,AuthorizedUsers,PHI) :-
	isCoveredEntity(CE),
	authorized(AuthorizedUsers,
		   accesses(AuthorizedUsers,workstation)),
	accesses(workstation,PHI),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_310c(CE,AuthorizedUsers,PHI)).
obligation(CE,
	   to(implements(CE,
			 physical(safeguards(CE,workstation))),
	      to(restricts(CE,
			   accesses(_,workstation)),
		 AuthorizedUsers)),
	   '164.310(c)') :-
	wm(s164_310c(CE,AuthorizedUsers,PHI)).
implied(right(AuthorizedUsers,
	      accesses(AuthorizedUsers,workstation),
	      '164.310(c)')) :-
	wm(s164_310c(CE,AuthorizedUsers,PHI)).

s164_310d1(CE,PoliciesAndProcedures,GovernedAction) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	is_s164_310d1_governedAction(CE,GovernedAction),
	add_to_wm(s164_310d1(CE,PoliciesAndProcedures,GovernedAction)).
is_s164_310d1_governedAction(CE,receives(CE,_,hardware)) :-
	contains(hardware,PHI),
	isPHI(PHI),
	electronic(PHI).
is_s164_310d1_governedAction(CE,removes(CE,hardware)) :-
	contains(hardware,PHI),
	isPHI(PHI),
	electronic(PHI).
is_s164_310d1_governedAction(CE,receives(CE,_,electronicMedia)) :-
	contains(electronicMedia,PHI),
	isPHI(PHI),
	electronic(PHI).
is_s164_310d1_governedAction(CE,removes(CE,electronicMedia)) :-
	contains(electronicMedia,PHI),
	isPHI(PHI),
	electronic(PHI).
obligation(CE,
	   implements(CE,
		      to(PoliciesAndProcedures,
			 governs(CE,GovernedAction))),
	   '164.310(d)(1)') :-
	wm(s164_310d1(CE,PoliciesAndProcedures,GovernedAction)).
% TODO what is the implied right?

s164_310d2i(CE,PoliciesAndProcedures,Asset) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	is_s164_310d2i_asset(Asset),
	add_to_wm(s164_310d2i(CE,PoliciesAndProcedures,Asset)).
is_s164_310d2i_asset(PHI) :-
	isPHI(PHI),
	electronic(PHI).
is_s164_310d2i_asset(hardware) :-
	contains(hardware,PHI),
	isPHI(PHI),
	electronic(PHI).
is_s164_310d2i_asset(electronicMedia) :-
	contains(electronicMedia,PHI),
	isPHI(PHI),
	electronic(PHI).
obligation(CE,
	   implied(CE,
		   to(PoliciesAndProcedures,
		      addresses(PoliciesAndProcedures,
				finalDisposition(Asset)))),
	   '164.310(d)(2)(i)') :-
	wm(s164_310d2i(CE,PoliciesAndProcedures,Asset)).
% TODO what is the implied right?

s164_310d2ii(CE,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_310d2ii(CE,PHI)).
obligation(CE,
	   implements(CE,
		      for(procedure(CE),
			  before(reuses(CE,electronic),
				 from(removes(CE,PHI),
				      electronicMedia)))),
	   '164.310(d)(2)(ii)') :-
	wm(s164_310d2ii(CE,PHI)).
% TODO what is the implied right?

s164_310d2iii(CE,Asset) :-
	isCoveredEntity(CE),
	is_s164_310d2iii_asset(Asset),
	add_to_wm(s164_310d2iii(CE,Asset)).
is_s164_310d2iii_asset(hardware).
is_s164_310d2iii_asset(electronicMedia).
is_s164_310d2iii_asset(Person) :-
	responsible(Person,hardware).
is_s164_310d2iii_asset(Person) :-
	responsible(Person,electronicMedia).
obligation(CE,
	   maintains(CE,
		     record(movement(Asset))),
	   '164.310(d)(2)(iii)') :-
	wm(s164_310d2iii(CE,Asset)).
% TODO what is the implied right?

s164_310d2iv(CE,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	retrievable(copy(PHI)),
	exact(copy(PHI),PHI),
	add_to_wm(s164_310d2iv(CE,PHI)).
obligation(CE,
	   addressable(before(moves(CE,equipment),
			      creates(CE,copy(PHI)))),
	   '164.310(d)(iv)') :-
	wm(s164_310d2iv(CE,PHI)).
% TODO what is the implied right?

% eof
