% Models section 164.312 of the HIPAA Security Rule

s164_312a1(CE,Person,PoliciesAndProcedures,InformationSystem) :-
	isCoveredEntity(CE),
	isInformationSystem(InformationSystem),
        % TODO cross ref to 164.308(a)(4)
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	is_s164_308a4_person(Person),
	maintains(InformationSystem,PHI),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_312a1(CE,Person,PoliciesAndProcedures,InformationSystem)).
:- dynamic is_s164_308a4_person/1.
obligation(CE,
	   implements(CE,
		      to(for(technical(PoliciesAndProcedures),
			     electronic(InformationSystem)),
			 allows(CE,
			        accesses(Person,InformationSystem)))),
	   '164.312(a)(1)') :-
	wm(s164_312a1(CE,Person,PoliciesAndProcedures,InformationSystem)).
% TODO what is the implied right?

s164_312a1_onlyConditions(CE,Person,PoliciesAndProcedures,InformationSystem) :-
	isCoveredEntity(CE),
	isInformationSystem(InformationSystem),
        % TODO cross ref to 164.308(a)(4)
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	not(is_s164_308a4_person(Person)),
	maintains(InformationSystem,PHI),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_312a1_onlyConditions(CE,Person,PoliciesAndProcedures,InformationSystem)).
obligation(CE,
	   not(allows(CE,accesses(Person,InformationSystem))),
	   '164.312(a)(1)') :-
	wm(s164_312a1_onlyConditions(CE,Person,PoliciesAndProcedures,InformationSystem)).
% TODO what is the implied right?

s164_312a2i(CE,User,Purpose,NameOrNum) :-
	isCoveredEntity(CE),
	isUser(User,_),
	isNameOrNum(User,NameOrNum),
	is_s164_312a2i_purpose(CE,User,Purpose),
	add_to_wm(s164_312a2i(CE,User,Purpose,NameOrNum)).
is_s164_312a2i_purpose(CE,User,tracks(CE,identity(User))).
is_s164_312a2i_purpose(CE,User,identifies(CE,User)).
isNameOrNum(User,name(User)).
isNameOrNum(_,Num) :-
	isNumber(Num).
obligation(CE,
	   for(to(assigns(CE,unique(NameOrNum)),
		  User),
	       Purpose),
	   '164.312(a)(2)(i)') :-
	wm(s164_312a2i(CE,User,Purpose,NameOrNum)).
% TODO what is the implied right?

s164_312a2ii(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	isInEmergency(Individual),
	about(PHI,Individual),
	isNecessaryFor(PHI,treats(CE,Individual)),
	add_to_wm(s164_312a2ii(CE,Individual,PHI)).
obligation(CE,
	   establishes(CE,
		       for(procedure(CE),
			   obtains(CE,PHI))),
	   '164.312(a)(2)(ii)') :-
	wm(s164_312a2ii(CE,Individual,PHI)).
% TODO what is the implied right?
obligation(CE,
	   asNeeded(implements(CE,
			       for(procedure(CE),
				   obtains(CE,PHI)))),
	   '164.312(a)(2)(ii)') :-
	wm(s164_312a2ii(CE,Individual,PHI)).
% TODO what is the implied right?

s164_312a2iii(CE) :-
	isCoveredEntity(CE),
	add_to_wm(s164_312a2iii(CE)).
obligation(CE,
	   addressable(implements(CE,
				  to(procedure(CE),
				     after(terminates(CE,session),
					   predetermines(CE,inactivityTime))))),
	   '164.312(a)(2)(iii)') :-
	wm(s164_312a2iii(CE)).
% TODO what is the implied right?

s164_312a2iv(CE,Purpose,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	is_s164_312a2iv_purpose(PHI,Purpose),
	add_to_wm(s164_312a2iv(CE,Purpose,PHI)).
is_s164_312a2iv_purpose(PHI,encrypts(mechanism,PHI)).
is_s164_312a2iv_purpose(PHI,decrypts(mechanism,PHI)).
obligation(CE,
	   addressable(implements(CE,
				  to(mechanism,
				     Purpose))),
	   '164.312(a)(2)(iv)') :-
	wm(s164_312a2iv(CE,Purpose,PHI)).
implied(right(Individual,
	      encrypts(CE,PHI),
	      '164.312(a)(2)(iv)')) :-
	about(PHI,Individual),
	wm(s164_312a2iv(CE,Purpose,PHI)).

s164_312b(CE,Mechanism,Purpose) :-
	isCoveredEntity(CE),
	is_s164_312b_mechanism(Mechanism),
	is_s164_312b_purpose(CE,Purpose),
	add_to_wm(s164_312b(CE,Mechanism,Purpose)).
is_s164_312b_mechanism(Hardware) :-
	isHardware(Hardware).
is_s164_312b_mechanism(Software) :-
	isSoftware(Software).
is_s164_312b_mechanism(mechanism).
is_s164_312b_purpose(CE,records(CE,activity(InformationSystem))) :-
	isInformationSystem(InformationSystem),
	contains(InformationSystem,PHI),
	isPHI(PHI),
	electronic(PHI).
is_s164_312b_purpose(CE,examines(CE,activity(InformationSystem))) :-
	isInformationSystem(InformationSystem),
	contains(InformationSystem,PHI),
	isPHI(PHI),
	electronic(PHI).
obligation(CE,
	   implements(CE,
		      to(Mechanism,
			 Purpose)),
	   '164.312(b)') :-
	wm(s164_312b(CE,Mechanism,Purpose)).
% TODO what is the implied right?

s164_312c1(CE,PoliciesAndProcedures,Threat,PHI) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PoliciesAndProcedures),
	isPHI(PHI),
	electronic(PHI),
	is_s164_312c_threat(PHI,Threat),
	add_to_wm(s164_312c1(CE,PoliciesAndProcedures,Threat,PHI)).
is_s164_312c_threat(PHI,unauthorized(alters(_,PHI))).
is_s164_312c_threat(PHI,unauthorized(destroys(_,PHI))).
obligation(CE,
	   implements(CE,
		      to(PoliciesAndProcedures,
			 from(protects(CE,PHI),
			      Threat))),
	   '164.312(c)(1)') :-
	wm(s164_312c1(CE,PoliciesAndProcedures,Threat,PHI)).
implied(right(Individual,
	      from(protects(CE,PHI),
		   Threat),
	   '164.312(c)(1)')) :-
	about(PHI,Individual),
	wm(s164_312c1(CE,PoliciesAndProcedures,Threat,PHI)).

s164_312c2(CE,Threat,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	is_s164_312c_threat(PHI,Threat),
	add_to_wm(s164_312c2(CE,Threat,PHI)).
obligation(CE,
	   addressable(implements(CE,
				  to(mechanism,
				     corroborates(mechanism,
						  not(Threat))))),
	   '164.312(c)(2)') :-
	wm(s164_312c2(CE,Threat,PHI)).
implied(right(Individual,
	      addressable(from(protects(CE,PHI),
			       Threat)),
	      '164.312(c)(2)')) :-
	about(PHI,Individual),
	wm(s164_312c2(CE,Threat,PHI)).

s164_312d(CE,Person,PHI) :-
	isCoveredEntity(CE),
	seeks(Person,
	      accesses(Person,PHI)),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_312d(CE,Person,PHI)).
obligation(CE,
	   implements(CE,
		      to(procedure(CE),
			 verifies(CE,
				  areSame(Person,
					  claims(Person,
						 identity(Person)))))),
	   '164.312(d)') :-
	wm(s164_312d(CE,Person,PHI)).
implied(right(Individual,
	      not(accesses(Person1,
			   PHI)),
	      '164.312(d)')) :-
	claims(Person1,
	       identity(Person)),
	about(PHI,Individual),
	wm(s164_312d(CE,Person,PHI)).

s164_312e1(CE,SecurityMeasures,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	isSecurityMeasure(SecurityMeasures),
	over(transmits(CE,_,PHI),
	     electronic(communicationsNetwork)),
	add_to_wm(s164_312e1(CE,SecurityMeasures,PHI)).
obligation(CE,
	   implements(CE,
		      to(technical(SecurityMeasures),
			 from(guards(CE,PHI),
			      unauthorized(accesses(_,PHI))))),
	   '164.312(e)(1)') :-
	wm(s164_312e1(CE,SecurityMeasures,PHI)).
implied(right(Individual,
	      from(guards(CE,PHI),
		   unauthorized(accesses(_,PHI))),
	      '164.312(e)(1)')) :-
	about(PHI,Individual),
	wm(s164_312e1(CE,SecurityMeasures,PHI)).

s164_312e2i(CE,SecurityMeasures,PHI) :-
	isCoveredEntity(CE),
	isSecurityMeasure(SecurityMeasures),
	isPHI(PHI),
	add_to_wm(s164_312e2i(CE,SecurityMeasures,PHI)).
% TODO until what is disposed of?
obligation(CE,
	   addressable(implements(CE,
				  to(SecurityMeasures,
				     ensures(SecurityMeasures,
					     without(not(improper(modifies(X,PHI))),
						     detects(CE,modifies(X,PHI))))))),
	   '164.312(e)(2)(i)') :-
	wm(s164_312e2i(CE,SecurityMeasures,PHI)).
implied(right(Individual,
	      addressable(without(not(improper(modifies(X,PHI))),
				  detects(CE,modifies(X,PHI)))),
	      '164.312(e)(2)(i)')) :-
	about(PHI,Individual),
	wm(s164_312e2i(CE,SecurityMeasures,PHI)).

s164_312e2ii(CE,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_312e2ii(CE,PHI)).
obligation(CE,
	   addressable(implements(CE,
				  to(mechanism,
				     when(encrypts(CE,PHI),
					  deems(_,appropriate(encrypts(CE,PHI))))))),
	   '164.312(e)(2)(ii)') :-
	wm(s164_312e2ii(CE,PHI)).
implied(right(Individual,
	      addressable(encrypts(CE,PHI)),
	      '164.312(e)(2)(ii)')) :-
	about(PHI,Individual),
	deems(_,appropriate(encrypts(CE,PHI))),
	wm(s164_312e2ii(CE,PHI)).

% eof
