% Models section 164.314 of the HIPAA Security Rule

inNonCompliance(CE, ('164.502(e)','164.314(a)')) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	knows(CE,
	      pattern(activity(BA))),
	violates(activity(BA),
		 obligation(BA,_,writtenContract(CE,BA))),
	not(Step),
	s164_314a1i_steps(CE,BA,Step).
s164_314a1i_steps(CE,BA,reasonable(takesStepsTo(CE,ends(CE,
							violates(activity(BA),
								 obligation(BA,_,writtenContract(CE,BA))))))).
s164_314a1i_steps(CE,BA,terminates(CE,writtenContract(CE,BA))) :-
	unsuccessful(reasonable(takesStepsTo(CE,ends(CE,
						     violates(activity(BA),
							      obligation(BA,_,writtenContract(CE,BA))))))),
	feasible(terminates(CE,writtenContract(CE,BA))).
s164_314a1i_steps(CE,BA,reports(CE,secretaryOfHHS,violates(activity(BA),
							   obligation(BA,_,writtenContract(CE,BA))))).

s164_314a2iA(CE,BA,Safeguards,Asset,CRMT,Contract,PHI) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	Contract,
	isPHI(PHI),
	electronic(PHI),
	createsReceivesMaintainsOrTransmits(BA,PHI,CRMT),
	CRMT,
	onBehalfOf(BA,CE,CRMT),
	is_s164_314a2iA_safeguards(BA,PHI,Safeguards),
	is_s164_314a2iA_asset(PHI,Asset),
	add_to_wm(s164_314a2iA(CE,BA,Safeguards,Asset,CRMT,Contract,PHI)).
is_s164_314a2iA_safeguards(BA,PHI,administrative(safeguards(BA,PHI))).
is_s164_314a2iA_safeguards(BA,PHI,physical(safeguards(BA,PHI))).
is_s164_314a2iA_safeguards(BA,PHI,technical(safeguards(BA,PHI))).
is_s164_314a2iA_asset(PHI,confidentiality(PHI)).
is_s164_314a2iA_asset(PHI,integrity(PHI)).
is_s164_314a2iA_asset(PHI,availability(PHI)).
liability(BA,
	  to(implements(BA,Safeguards),
	     Asset),
	  '164.314(a)(2)(i)(A)') :-
	wm(s164_314a2iA(CE,BA,Safeguards,Asset,CRMT,writtenContract(CE,BA),PHI)).
implied(power(CE,
	      writtenContract(CE,BA),
	      requires(CE,BA,to(implements(BA,Safeguards),
				Asset)),
	      '164.314(a)(2)(i)(A)')) :-
	wm(s164_314a2iA(CE,BA,Safeguards,Asset,CRMT,writtenContract(CE,BA),PHI)).

s164_314a2iB(CE,BA,Subcontractor,Action,Contract,PHI) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	Contract,
	isPHI(PHI),
	electronic(PHI),
	provides(BA,Subcontractor,PHI),
	is_s164_314a2iB_action(Subcontractor,PHI,Action),
	add_to_wm(s164_314a2iB(CE,BA,Subcontractor,Action,Contract,PHI)).
is_s164_314a2iB_action(Subcontractor,PHI,reasonable(safeguards(Subcontractor,PHI))).
is_s164_314a2iB_action(Subcontractor,PHI,appropriate(safeguards(Subcontractor,PHI))).
liability(BA,
	  ensures(BA,
		  agrees(Subcontractor,
			 implements(Subcontractor,
				    Action))),
	  '164.314(a)(2)(i)(B)') :-
	wm(s164_314a2iB(CE,BA,Subcontractor,Action,writtenContract(CE,BA),PHI)).
implied(power(CE,
	      writtenContract(CE,BA),
	      requires(CE,BA,ensures(BA,
				     agrees(Subcontractor,
					    implements(Subcontractor,
						       Action)))),
	      '164.314(a)(2)(i)(B)')) :-
	wm(s164_314a2iB(CE,BA,Subcontractor,Action,writtenContract(CE,BA),PHI)).

s164_314a2iC(CE,BA,SecurityIncident) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isSecurityIncident(SecurityIncident),
	becomesAwareOf(BA,SecurityIncident),
	add_to_wm(s164_314a2iC(CE,BA,SecurityIncident)).
liability(BA,
	  reports(BA,CE,SecurityIncident),
	  '164.314(a)(2)(i)(C)') :-
	wm(s164_314a2iC(CE,BA,SecurityIncident)).
implied(power(CE,
	      writtenContract(CE,BA),
	      requires(CE,BA,reports(BA,CE,SecurityIncident)),
	      '164.314(a)(2)(i)(C)')) :-
	wm(s164_314a2iC(CE,BA,SecurityIncident)).

s164_314a2iD(CE,BA,Contract) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	Contract,
	determines(CE,violates(BA,Contract)),
	add_to_wm(s164_314a2iD(CE,BA,Contract)).
power(CE,
      writtenContract(CE,BA),
      terminates(CE,writtenContract(CE,BA)),
      '164.314(a)(2)(i)(D)') :-
	wm(s164_314a2iD(CE,BA,writtenContract(CE,BA))).
implied(liability(BA,
		  terminates(CE,writtenContract(CE,BA)),
		  '164.314(a)(2)(i)(D)')) :-
	wm(s164_314a2iD(CE,BA,writtenContract(CE,BA))).

inCompliance(CE,'164.314(a)(1)') :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isGovernmentEntity(CE),
	isGovernmentEntity(BA),
	mou(CE,BA).
liability(BA,
	  to(implements(BA,Safeguards),
	     Asset),
	  '164.314(a)(2)(ii)(A)(1)') :-
	wm(s164_314a2iA(CE,BA,Safeguards,Asset,CRMT,mou(CE,BA),PHI)).
implied(power(CE,
	      mou(CE,BA),
	      requires(CE,BA,to(implements(BA,Safeguards),
				Asset)),
	      '164.314(a)(2)(ii)(A)(1)')) :-
	wm(s164_314a2iA(CE,BA,Safeguards,Asset,CRMT,mou(CE,BA),PHI)).
liability(BA,
	  ensures(BA,
		  agrees(Subcontractor,
			 implements(Subcontractor,
				    Action))),
	  '164.314(a)(2)(ii)(A)(1)') :-
	wm(s164_314a2iB(CE,BA,Subcontractor,Action,mou(CE,BA),PHI)).
implied(power(CE,
	      mou(CE,BA),
	      requires(CE,BA,ensures(BA,
				     agrees(Subcontractor,
					    implements(Subcontractor,
						       Action)))),
	      '164.314(a)(2)(ii)(A)(1)')) :-
	wm(s164_314a2iB(CE,BA,Subcontractor,Action,mou(CE,BA),PHI)).
liability(BA,
	  reports(BA,CE,SecurityIncident),
	  '164.314(a)(2)(ii)(A)(1)') :-
	wm(s164_314a2iC(CE,BA,SecurityIncident)).
implied(power(CE,
	      writtenContract(CE,BA),
	      requires(CE,BA,reports(BA,CE,SecurityIncident)),
	      '164.314(a)(2)(ii)(A)(1)')) :-
	wm(s164_314a2iC(CE,BA,SecurityIncident)).
power(CE,
      writtenContract(CE,BA),
      terminates(CE,mou(CE,BA)),
      '164.314(a)(2)(ii)(A)(1)') :-
	wm(s164_314a2iD(CE,BA,mou(CE,BA))).
implied(liability(BA,
		  terminates(CE,mou(CE,BA)),
		  '164.314(a)(2)(ii)(A)(1)')) :-
	wm(s164_314a2iD(CE,BA,mou(CE,BA))).

% TODO general cross-ref to other law at 164.314(a)(2)(A)(2)

s164_314a2iiB(CE,BA,CRMT,Law,Requirement,Source,PHI) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isPHI(PHI),
	electronic(PHI),
	createsReceivesMaintainsOrTransmits(BA,PHI,CRMT),
	isSubsectionOf(Source,'164.314(a)(2)(i)'),  % TODO do structure for this
	liability(BA,Requirement,Source),
	required_by_law(BA,CRMT,Law),
	add_to_wm(s164_314a2iiB(CE,BA,CRMT,Law,Requirement,Source,PHI)).
% TODO: cross-ref to (a)(2)(ii)(A) seems incorrect; the cross-ref talks about
% assurances, but (a)(2)(ii)(A) does not talk about assurances--it talks about MOU's 
% between government entities.
power(CE,
      writtenContract(CE,BA),
      without(onBehalfOf(BA,CE,CRMT),
	      Requirement),
      '164.314(a)(2)(ii)(B)') :-
	wm(s164_314a2iiB(CE,BA,CRMT,Law,Requirement,Source,PHI)).
% TODO figure out recursive reference for the implied liability

s164_314a2iiC(CE,BA,Contract) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isContract(CE,BA,Contract),
	Contract,
	inconsistent(contains(Contract,terminates(CE,Contract)),
		     obligation(CE,_,_)),
	add_to_wm(s164_314a2iiC(CE,BA,Contract)).
s164_314a2iiC(CE,BA,Contract) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isContract(CE,BA,Contract),
	Contract,
	inconsistent(contains(Contract,terminates(CE,Contract)),
		     obligation(BA,_,_)),
	add_to_wm(s164_314a2iiC(CE,BA,Contract)).
isContract(CE,BA,writtenContract(CE,BA)).
isContract(CE,BA,mou(CE,BA)).
privilege(CE,
	  omits(CE,
		Contract,
		power(CE,Contract,terminates(CE,Contract),_)),
	  '164.314(a)(2)(ii)(C)') :-
	wm(s164_314a2iiC(CE,BA,Contract)).
implied(noRight(BA,
		right(BA,
		      knows(BA,power(CE,Contract,terminates(CE,Contract),_)),
		      _),
		'164.314(a)(2)(ii)(C)')) :-
	wm(s164_314a2iiC(CE,BA,Contract)).

s164_314b1(GHP,PlanSponsor,CRMT,Action,PHI) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	electronic(PHI),
	createsReceivesMaintainsOrTransmits(PlanSponsor,PHI,CRMT),
	onBehalfOf(PlanSponsor,GHP,CRMT),
	is_s164_314b1_action(PlanSponsor,PHI,Action),
	add_to_wm(s164_314b1(GHP,PlanSponsor,CRMT,Action,PHI)).
is_s164_314b1_action(PlanSponsor,PHI,reasonable(safeguards(PlanSponsor,PHI))).
is_s164_314b1_action(PlanSponsor,PHI,appropriate(safeguards(PlanSponsor,PHI))).
obligation(GHP,
	   ensures(GHP,
		   provides(planDocuments(GHP),
			    PlanSponsor,
			    Action)),
	   '164.314(b)(1)') :-
	wm(s164_314b1(GHP,PlanSponsor,CRMT,Action,PHI)).
implied(right(Individual,
	      safeguards(PlanSponsor,PHI),
	      '164.314(b)(1)')) :-
	about(PHI,Individual),
	wm(s164_314b1(GHP,PlanSponsor,CRMT,Action,PHI)).

s164_314b2i(GHP,PlanSponsor,CRMT,Safeguards,Purpose,PHI) :-
	isPlanSponsor(PlanSponsor,GHP),
	isGroupHealthPlan(GHP),
	isPHI(PHI),
	electronic(PHI),
	createsReceivesMaintainsOrTransmits(PlanSponsor,PHI,CRMT),
	onBehalfOf(PlanSponsor,GHP,CRMT),
	is_s164_314b2i_safeguards(PlanSponsor,PHI,Safeguards),
	is_s164_314b2i_purpose(PlanSponsor,PHI,Purpose),
	add_to_wm(s164_314b2i(GHP,PlanSponsor,CRMT,Safeguards,Purpose,PHI)).
is_s164_314b2i_safeguards(PlanSponsor,PHI,administrative(safeguards(PlanSponsor,PHI))).
is_s164_314b2i_safeguards(PlanSponsor,PHI,physical(safeguards(PlanSponsor,PHI))).
is_s164_314b2i_safeguards(PlanSponsor,PHI,technical(safeguards(PlanSponsor,PHI))).
is_s164_314b2i_purpose(PlanSponsor,PHI,reasonable(protects(PlanSponsor,confidentiality(PHI)))).
is_s164_314b2i_purpose(PlanSponsor,PHI,reasonable(protects(PlanSponsor,integrity(PHI)))).
is_s164_314b2i_purpose(PlanSponsor,PHI,reasonable(protects(PlanSponsor,availability(PHI)))).
is_s164_314b2i_purpose(PlanSponsor,PHI,appropriate(protects(PlanSponsor,confidentiality(PHI)))).
is_s164_314b2i_purpose(PlanSponsor,PHI,appropriate(protects(PlanSponsor,integrity(PHI)))).
is_s164_314b2i_purpose(PlanSponsor,PHI,appropriate(protects(PlanSponsor,availability(PHI)))).
liability(PlanSponsor,
	  to(implements(PlanSponsor,Safeguards),
	     Purpose),
	  '164.314(b)(2)(i)') :-
	wm(s164_314b2i(GHP,PlanSponsor,CRMT,Safeguards,Purpose,PHI)).
implied(power(GHP,
	      planDocuments(GHP),
	      requires(GHP,
		       PlanSponsor,
		       to(implements(PlanSponsor,Safeguards),
			  Purpose)),
	      '164.314(b)(2)(i)')) :-
	wm(s164_314b2i(GHP,PlanSponsor,CRMT,Safeguards,Purpose,PHI)).

s164_314b2ii(GHP,PlanSponsor,ReasonableAndAppropriateSecurityMeasures) :-
	isPlanSponsor(PlanSponsor,GHP),
	isGroupHealthPlan(GHP),
	isReasonableAndAppropriateSecurityMeasures(ReasonableAndAppropriateSecurityMeasures),
	add_to_wm(s164_314b2ii(GHP,PlanSponsor,ReasonableAndAppropriateSecurityMeasures)).
% TODO cross ref to 164.504(f)(2)(iii) at 164.314(b)(2)(ii)
isReasonableAndAppropriateSecurityMeasures(reasonable(SecurityMeasures)) :-
	isSecurityMeasure(SecurityMeasures).
isReasonableAndAppropriateSecurityMeasures(appropriate(SecurityMeasures)) :-
	isSecurityMeasure(SecurityMeasures).
liability(PlanSponsor,
	  ensures(PlanSponsor,
		  supports(PlanSponsor,
			   by(adequate(separates(PlanSponsor,
						 Sep1,
						 Sep2)),
			      ReasonableAndAppropriateSecurityMeasures))),
	  '164.314(b)(2)(ii)') :-
	wm(s164_314b2ii(GHP,PlanSponsor,ReasonableAndAppropriateSecurityMeasures)).
implied(power(GHP,
	      planDocuments(GHP),
	      requires(GHP,
		       PlanSponsor,
		       supports(PlanSponsor,
				by(adequate(separates(PlanSponsor,
						      Sep1,
						      Sep2)),
				   ReasonableAndAppropriateSecurityMeasures))),
	      '164.314(b)(2)(ii)')) :-
	wm(s164_314b2ii(GHP,PlanSponsor,ReasonableAndAppropriateSecurityMeasures)).

s164_314b2iii(GHP,PlanSponsor,Subcontractor,ReasonableAndAppropriateSecurityMeasures,PHI) :-
	isPlanSponsor(PlanSponsor,GHP),
	isGroupHealthPlan(GHP),
	isReasonableAndAppropriateSecurityMeasures(ReasonableAndAppropriateSecurityMeasures),
	provides(PlanSponsor,Subcontractor,PHI),
	isPHI(PHI),
	electronic(PHI),
	add_to_wm(s164_314b2iii(GHP,PlanSponsor,Subcontractor,ReasonableAndAppropriateSecurityMeasures,PHI)).
liability(PlanSponsor,
	  ensures(PlanSponsor,
		  agrees(Subcontractor,
			 to(implements(Subcontractor,
				       ReasonableAndAppropriateSecurityMeasures),
			    protects(Subcontractor,PHI)))),
	  '164.314(b)(2)(iii)') :-
	wm(s164_314b2iii(GHP,PlanSponsor,Subcontractor,ReasonableAndAppropriateSecurityMeasures,PHI)).
implied(power(GHP,
	      planDocuments(GHP,PlanSponsor),
	      requires(GHP,
		       PlanSponsor,
		       ensures(PlanSponsor,
			       agrees(Subcontractor,
				      to(implements(Subcontractor,
						    ReasonableAndAppropriateSecurityMeasures),
					 protects(Subcontractor,PHI))))),
	      '164.314(b)(2)(iii)')) :-
	wm(s164_314b2iii(GHP,PlanSponsor,Subcontractor,ReasonableAndAppropriateSecurityMeasures,PHI)).
		       
s164_314b2iv(GHP,PlanSponsor,SecurityIncident) :-
	isPlanSponsor(PlanSponsor,GHP),
	isGroupHealthPlan(GHP),
	isSecurityIncident(SecurityIncident),
	becomesAwareOf(PlanSponsor,SecurityIncident),
	add_to_wm(s164_314b2iv(GHP,PlanSponsor,SecurityIncident)).
liability(PlanSponsor,
	  reports(PlanSponsor,
		  GHP,
		  SecurityIncident),
	  '164.314(b)(2)(iv)') :-
	wm(s164_314b2iv(GHP,PlanSponsor,SecurityIncident)).
implied(power(GHP,
	      planDocuments(GHP,PlanSponsor),
	      reports(PlanSponsor,
		      GHP,
		      SecurityIncident),
	      '164.314(b)(2)(iv)')) :-
	wm(s164_314b2iv(GHP,PlanSponsor,SecurityIncident)).

% eof







