% Contains the glossary of HIPAA terms
:- multifile glossary/1, glossary/2.

:- style_check(-atom).

glossary(X) :-
	glossary(X,Text),
	writef(Text).

glossary(actors) :-
	write('GLOSSARY OF ACTORS'), nl,
	write('------------------'), nl,
	findall(Actor, actor(Actor), AList),
	printList(AList).
glossary(objects) :-
	nl, write('GLOSSARY OF OBJECTS'), nl,
	write('-------------------'), nl,
	findall(Obj, object(Obj), OList),
	printList(OList).
glossary(relations) :-
	nl, write('GLOSSARY OF RELATIONS'), nl,
	write('---------------------'), nl,
	findall(Relation, relation(Relation), RList),
	printList(RList).
glossary(attributes) :-
	nl, write('GLOSSARY OF ATTRIBUTES'), nl,
	write('---------------------'), nl,
	findall(Attribute, attribute(Attribute), AList),
	printList(AList).

glossary(about,'
	about(+X,+Y)
	     Relation signifying that X is about Y. Commonly used for the subject
	     of PHI or other documents. The model has rules for the built
	     in PHI predicates, so that about(phi(individual), individual) is
	     automatically is satisfied by phi(individual)').

glossary(accurate,'
	accurate(+X)
	     Attribute signifying that X is accurate.').

glossary(actOnBehalf,'
	actOnBehalf(+X,+Y)
	     Relation signifying that X acts on behalf for Y.
        actOnBehalf(+X,+Y,+Z)
	     Relation signifying that X performs Y on Zs behalf').

glossary(administrative,'
	administrative(+X)
	     Attribute signifying that X is administrative').

glossary(affects,'
        affects(+X,+Y)
	     Relation signifying that X affects Y.').

glossary(after,'
        after(+X,+Y)
	     Relation signifying that X occurs after Y, temporally.').

glossary(anticipates,'
        anticipates(+X,+Y)
	     Relation signifying that X anticipates Y.').

glossary(applies,'
	applies(+X,+Y,+Z)
	     Relation signifying that X applies in Z in Y scenario.
        applies(+X,+Y)
	     Relation signifying that X applies in Y scenario, for example,
	     law X is applicable to Y scenario.').

glossary(appropriate,'
        appropriate(+X)
	     Attribute signifying that X is the legally ambiguous attribute
	     "appropriate".').

glossary(areBusinessAssociates,'
	areBusinessAssociates(+X,+Y)
	Source: HIPAA Section 160.103
	     Relation signifying that X is the business associate of Y
	-------------------------
	     Business associate:
	     (1) Except as provided in paragraph (2) of this
	     definition, business associate means, with respect to a
	     covered entity, a person who:
	     (i) On behalf of such covered entity or of an
	     organized health care arrangement (as defined in
	     164.501 of this subchapter) in which the covered
	     entity participates, but other than in the capacity of a
	     member of the workforce of such covered entity or
	     arrangement, performs, or assists in the performance
	     of:
	     (A) A function or activity involving the use or
	     disclosure of individually identifiable health
	     information, including claims processing or
	     administration, data analysis, processing or
	     administration, utilization review, quality assurance,
	     billing, benefit management, practice management,
	     and repricing; or
	     (B) Any other function or activity regulated by
	     this subchapter; or
	     (ii) Provides, other than in the capacity of a
	     member of the workforce of such covered entity,
	     legal, actuarial, accounting, consulting, data
	     aggregation (as defined in 164.501 of this
	     subchapter), management, administrative,
	     accreditation, or financial services to or for such
	     covered entity, or to or for an organized health care
	     arrangement in which the covered entity participates,
	     where the provision of the service involves the
	     disclosure of individually identifiable health
	     information from such covered entity or arrangement,
	     or from another business associate of such covered
	     entity or arrangement, to the person.
	     (2) A covered entity participating in an organized
	     health care arrangement that performs a function or
	     activity as described by paragraph (1)(i) of this
	     definition for or on behalf of such organized health
	     care arrangement, or that provides a service as
	     described in paragraph (1)(ii) of this definition to or
	     for such organized health care arrangement, does not,
	     simply through the performance of such function or
	     activity or the provision of such service, become a
	     business associate of other covered entities
	     participating in such organized health care
	     arrangement.
	     (3) A covered entity may be a business associate
	     of another covered entity.').

glossary(arePsychotherapyNotes,'
        arePsychotherapyNotes(+X)
	     Attribute signifying that X is classified as psycotherapy notes.').

glossary(authorization,'
        authorization(+X,+Y,+Z)
	     Object signifying the physical media or verbal authorization
	     that X gives to Y to perform Z.').

glossary(authorizes,'
	authorizes(+X,+Y)
	     Relation signifying that X authorizes Y.
        authorizes(+X,+Y,+Z)
	     Relation signifying the act of X authorizing Y to do Z.').

glossary(available,'
        available(+X,+Y)
	     Relation signifying that X is available to Y.').

glossary(becomesAwareOf,'
        becomesAwareOf(+X,+Y)
	     Relation signifying that X becomes aware of Y.').

glossary(changes,'
	changes(+X,+Y)
	     Relation signifying that X changes Y.
        changes(+X)
	     Object signifying changes to X.').

glossary(complies,'
	complies(+X,+Y)
	     Relation signifying that X complies with Y.').

glossary(conducts,'
        conducts(+X,+Y)
	     Relation signifying that X conducts Y.').

glossary(contains,'
        contains(+X,+Y)
	     Relation signifying that X contains Y.').

glossary(controls,'
	controls(+X,+Y)
	     Relation signifying that X controls Y.').

glossary(copy,'
        copy(+X)
	     Object signifying a copy of X.').

glossary(cost,'
	cost(+X)
	     Object signifying the cost of X.').

glossary(creates,'
        creates(+X,+Y)
	     Relation signifying that X creates Y.').

glossary(date,'
	date(+X)
	     Object signifying the date that X occurred.').

glossary(deems,'
	deems(+X,+Y)
	     Relation signifying that X deems Y.').

glossary(destroys,'
        destroys(+X,+Y)
	     Relation signifying that X destroys Y.').

glossary(detects,'
        detects(+X,+Y)
	     Relation signifying that X detects Y.').

glossary(determines,'
	determines(+X,+Y)
	     Relation signifying that X has made the determination Y.').

glossary(develops,'
        develops(+X,+Y)
	     Relation signifying that X develops Y.').

glossary(documents,'
        documents(+X,+Y)
	     Relation signifying that X documents Y.').

glossary(effective,'
	effective(+X,+Y)
	     Relation signifying that X is effective for Y.').

glossary(electronic,'
        electronic(+X)
	     Attribute signifying that X is electronic.').

glossary(electronicMedia,'
	electronicMedia
	Source: HIPAA Section 160.103
	     Electronic media means:
	       (1) Electronic storage media including memory
	     devices in computers (hard drives) and any
	     removable/transportable digital memory medium,
	     such as magnetic tape or disk, optical disk, or digital
	     memory card; or
	       (2) Transmission media used to exchange
	     information already in electronic storage media.
	     Transmission media include, for example, the internet
	     (wide-open), extranet (using internet technology to
	     link a business with information accessible only to
	     collaborating parties), leased lines, dial-up lines,
	     private networks, and the physical movement of
	     removable/transportable electronic storage media.
	     Certain transmissions, including of paper, via
	     facsimile, and of voice, via telephone, are not
	     considered to be transmissions via electronic media,
	     because the information being exchanged did not
	     exist in electronic form before the transmission.').

glossary(end,'
        end(+X)
	     Object signifying the end of X.').

glossary(ensures,'
	ensures(+X,+Y)
	     Relation signifying that X ensures that Y occurs.').

glossary(evaluates,'
        evaluates(+X,+Y)
	     Relation signifying that X evaluates Y.
        evaluates(+X,+Y,+Z)
	     Relation signifying that X evaluates Y for Z or based on Z.').

glossary(feasible,'
        feasible(+X)
	     Attribute signifying the ambiguous legal term
	     that X is feasible.').

glossary(for,'
	for(+Action,+Purpose)
	     Relation signifying that Action is for Purpose').

glossary(grants,'
	grants(+X,+Y)
	     Relation signifying that X grants Y.').

glossary(harmfulEffects,'
	harmfulEffects(+X)
	     Object signifying the harmful effects caused by X.').

glossary(how,'
	how(+X)
	     Object signifying how to X.').

glossary(implements,'
        implements(+X,+Y)
	     Relation signifying that X implements Y.').

glossary(identity,'
        identity(+X)
	     Object signifying the identity of X.').

glossary(identifies,'
        identifies(+X,+Y)
	     Relation signifying that X identifies Y.').

glossary(in,'
	in(+X,+Y)
	     Relation signifying that X is in Y, physically or spacially. Does
	     not signify that X occurs in Y amount of time. See the
	     within(X,Y) predicate for this.').

glossary(inCompliance,'
	inCompliance(+X,+Y,+Z)
	     Relation signifying that X is in compliance with 
	     regulation Y in Z scenario.
        inCompliance(+X,+Y)
	     Relation signifying that X is in compliance with regulation Y.').

glossary(isComponentOf,'
        isComponentOf(+X,+Y)
	     Relation signifying that X is a component of Y.').

glossary(isCoveredEntity,'
	isCoveredEntity(+X)
	     Attribute signifying that X is a covered entity.').

glossary(isGovernmentEntity,'
        isGovernmentEntity(+X)
	     Attribute signifying that X is a government entity.').

glossary(isGroupHealthPlan,'
        isGroupHealthPlan(+X)
	     Attribute signifying that X is a group health plan.').

glossary(isHealthcareClearinghouse,'
	isHealthcareClearinghouse(+X)
	     Attribute signifying that X is a healthcare clearing house.
	-------------------------
	     	Source: HIPAA Section 160.103
	     Health care clearinghouse means a public or
	     private entity, including a billing service, repricing
	     company, community health management information
	     system or community health information system, and
	     value-added networks and switches, that does either
	     of the following functions:
	       (1) Processes or facilitates the processing of
	     health information received from another entity in a
	     nonstandard format or containing nonstandard data
	     content into standard data elements or a standard
	     transaction.
	       (2) Receives a standard transaction from another
	     entity and processes or facilitates the processing of
	     health information into nonstandard format or
	     nonstandard data content for the receiving entity.').

glossary(isHealthInsuranceIssuer,'
	isHealthInsuranceIssuer(+X, +Y)
	     Attribute signifying that X is a health insurance issuer.').

glossary(isHMO,'
	isHMO(+X,+Y)
	     Attribute signifying that X is a health maintenance organization.').

glossary(isInEmergency,'
	isInEmergency(+X)
	     Attribute signifying that X is in an emergency situation
	     or is incapacitated.').

glossary(isMemberOfWorkforce,'
        isMemberOfWorkforce(+X,+Y)
	     Relation signifying that X is a member of the workforce of Y.').

glossary(isNecessaryFor,'
        isNecessaryFor(+X,+Y)
	     Relation signifying that X is necessary for Y.').

glossary(isPHI,'
	isPHI(+X)
	     Attribute signifying that X is Personal Health Information.').

glossary(isPlanSponsor,'
	isPlanSponsor(+X,+Y)
	Source: HIPAA Section 160.103
	     Attribute signifying that X is the plan sponsor of Y.').

glossary(isResponsible,'
	isResponsible(+X,+Y)
	     Relation signifying that X is responsible for Y.').

glossary(knows,'
        knows(+X,+Fact)
	     Relation signifying that X knows Fact.').

glossary(last,'
	last(+X)
	     Attribute signifying the last of X.').

glossary(location,'
        location(+X)
	     Object signifying the location of X.').

glossary(maintains,'
	maintains(+X,+Info)
	     Relation signifying that X maintains Info, for example PHI.').

glossary(meets,'
        meets(+X,+Y)
	     Relation signifying that X meets Y.').

glossary(mitigates,'
	mitigates(+X,+Y)
	     Relation signifying that X mitigates Y').

glossary(modifies,'
	modifies(+X,+Y)
	     Relation signifying that X modifies Y.').

glossary(mou,'
        mou(+X,+Y)
	     Object signifying a memorandum of understanding (MOU) between
	     X and Y.').

glossary(name,'
	name(+X)
	     Object signifying the name of X.').

glossary(obtains,'
	obtains(+X,+Y)
	     Relation signifying that X obtains Y
	obtains(+X,+Y,+Z)
	     Relation signifying that X obtains Z from Y.').

glossary(pattern,'
        pattern(+X)
	     Object signifying a pattern of X.').

glossary(phi,'
	phi(+X)
	Source: HIPAA Section 160.103
	     Signifies generic protected health information about X. There
	     are also other, more specific kinds of PHI signified by
	     isPHI(Y)
	-------------------------
	     Protected health information means individually
	     identifiable health information:
	       (1) Except as provided in paragraph (2) of this
	     definition, that is:
	       (i) Transmitted by electronic media;
	       (ii) Maintained in electronic media; or
	       (iii) Transmitted or maintained in any other form
	     or medium.
	       (2) Protected health information excludes
	     individually identifiable health information in:
	       (i) Education records covered by the Family
	     Educational Rights and Privacy Act, as amended, 20
	     U.S.C. 1232g;
	       (ii) Records described at 20 U.S.C.
	     1232g(a)(4)(B)(iv); and
	       (iii) Employment records held by a covered entity
	     in its role as employer.').

glossary(policies,'
        policies(+X)
	     Object signifying the policies of X.').

glossary(prevents,'
        prevents(+X,+Y)
	     Relation signifying that X prevents Y.').

glossary(planDocuments,'
	planDocuments(+X)
	     Object signifying plan documents for health plan X.').

glossary(program,'
	program
	     Object signifying a generic program.').

glossary(procedures,'
        procedures(+X)
	     Object signifying the procedures of X or for X.').

glossary(protects,'
        protects(+X,+Y)
	     Relation signifying that X protects Y.
        protects(+X,+Y,+Z)
	     Relation signifying that X protects Y from Z.').

glossary(psychotherapyNotes,'
	psychotherapyNotes(+X)s
	Source: HIPAA Section 164.501
	     Object signifying generic psychotherapy notes about X.
	-------------------------
	     Psychotherapy notes means notes recorded (in
	     any medium) by a health care provider who is a
	     mental health professional documenting or analyzing
	     the contents of conversation during a private
	     counseling session or a group, joint, or family
	     counseling session and that are separated from the
	     rest of the individuals medical record. Psychotherapy
	     notes excludes medication prescription and
	     monitoring, counseling session start and stop times,
	     the modalities and frequencies of treatment furnished,
	     results of clinical tests, and any summary of the
	     following items: Diagnosis, functional status, the
	     treatment plan, symptoms, prognosis, and progress to
	     date.').

glossary(reasonable,'
	reasonable(+X)
	     Attribute signifying ambiguous legal adjective that X 
	     must be reasonable.').

glossary(receives,'
        receives(+X,+Y,+Z)
	     Relation signifying that X receives Z from Y.').

glossary(removes,'
        removes(+X,+Y)
	     Relation signifying that X removes Y.').

glossary(reports,'
        reports(+X,+Y,+Z)
	     Relation signifying that X reports Z to Y.').

glossary(required_by_law,'
        required_by_law(+X,+Y,+Z)
	     Relation signifying that X is required to do Y by law Z.').

glossary(responsible,'
	responsible(+X,+Y)
	     Relation signifying that X is responsible for Y.').

glossary(reviews,'
	reviews(+X,+Y)
	     Relation signifying that X reviews Y.').

glossary(revises,'
	revises(+X,+Y)
	     Relation signifying that X revises Y.').

glossary(risk,'
        risk(+X)
	     Object signifying the risk to X.').

glossary(safeguards,'
	safeguards(+X,+Y)
	     Relation signifying that X safeguards Y.').

glossary(sanctions,'
	sanctions
	     Object signifying sanctions.
	sanctions(+X)
	     Object signifying sanctions placed on X.').

glossary(security,'
	security(+X)
	     Object signifying the security of X.').

glossary(seeks,'
        seeks(+X,+Y)
	     Relation signifying that X seeks Y.').

glossary(size,'
	size(+X)
	     Relation signifying the size of X.').

glossary(smallerThan,'
        smallerThan(+X,+Y)
	     Relation signifying that X is smaller than Y.').

glossary(sufficient,'
	sufficient(+X,+Y)
	     Relation signifying that X is sufficient to meet condition Y.').

glossary(suspects,'
	suspects(+X,+Y)
	     Relation signifying that X suspects Y.').

glossary(technical,'
        technical(+X)
	     Attribute signifying that X is technical.').

glossary(terminates,'
        terminates(+X,+Y)
	     Relation signifying that X terminates Y.').

glossary(through,'
	through(+X,+Y)
	     Relation signifying that Y is the means for X.').

glossary(to,'
        to(+X,+Y)
	     Relation signifying that X occurs to Y.').

glossary(tracks,'
        tracks(+X,+Y)
	     Relation signifying that X tracks Y.').

glossary(unsuccessful,'
        unsuccessful(+X)
	     Attribute signifying that X is unsuccessful.').

glossary(uses,'
	uses(+X,+Y)
	     Relation signifying X uses Y.
	-------------------------
	     	Source: HIPAA Section 160.103
	     Use means, with respect to individually
	     identifiable health information, the sharing,
	     employment, application, utilization, examination, or
	     analysis of such information within an entity that
	     maintains such information.').

glossary(violates,'
	violates(+X,+Y)
	     Relation signifying that X has violated Y.').

glossary(while,'
        while(+X,+Y)
	     Relation signifying that X occurs while Y.').

% eof
