% Models section 164.502 of the HIPAA Privacy Rule

s164_502a(CE,PHI,UsageOrDisclosure) :-
	isCoveredEntity(CE),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	isPHI(PHI),
	not(obligation(CE,UsageOrDisclosure,_)),
	not(privilege(CE,UsageOrDisclosure,_)),
	% TODO cross ref to 160 subpart C
	add_to_wm(s164_502a(CE,PHI,UsageOrDisclosure)).
obligation(CE,
	   not(UsageOrDisclosure),
	   '164.502(a)') :-
	wm(s164_502a(CE,PHI,UsageOrDisclosure)).
implied(right(Individual,
	      not(UsageOrDisclosure),
	      '164.502(a)')) :-
	about(PHI,Individual),
	wm(s164_502a(CE,PHI,UsageOrDisclosure)).

s164_502a1i(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI, Individual),
	add_to_wm(s164_502a1i(CE,Individual,PHI)).
privilege(CE,
	  discloses(CE,Individual,PHI),
	  '164.502(a)(1)(i)') :-
	wm(s164_502a1i(CE,Individual,PHI)).
implied(noRight(Individual,
	        right(Individual,
		      not(discloses(CE,
				    Individual,
				    PHI)),
		      _),
		'164.502(a)(1)(i)')) :-
	wm(s164_502a1i(CE,Individual,PHI)).

s164_502a1ii(CE,UsageOrDisclosure,PHI,TPO) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	valid_HIPAA_TPO(TPO),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	add_to_wm(s164_502a1ii(CE,UsageOrDisclosure,PHI,TPO)).
privilege(CE,
	  for(UsageOrDisclosure,
	      TPO),
	  '164.502(a)(1)(ii)') :-
	wm(s164_502a1ii(CE,UsageOrDisclosure,PHI,TPO)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      TPO)),
		      _),
		'164.502(a)(1)(ii)')) :-
	wm(s164_502a1ii(CE,UsageOrDisclosure,PHI,TPO)).

% TODO cross-references at 164.502(a)(1)(iii)-(vi)
% TODO cross-references at 164.502(a)(1)(i)-(ii)

s164_502b1(CE,PHI,Purpose) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	not(minimumNecessaryException(CE, PHI, Purpose)),
       	add_to_wm(s164_502b1(CE,PHI,Purpose)).
obligation(CE,
	   reasonable(minimizes(CE,
				for(requires(CE,
					     PHI),
				    Purpose))),
	   '164.502(b)(1)') :-
	wm(s164_502b1(CE,PHI,Purpose)).
implied(right(Individual,
	      only(discloses(CE,
			     _,
			     PHI)),
	      '164.502(b)(1)')) :-
	for(requires(CE,PHI),
	    _),
	about(PHI,Individual),
	wm(s164_502b1(CE,PHI)).

s164_502b2(CE,PHI,Purpose) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	minimumNecessaryException(CE, PHI, Purpose),
	add_to_wm(s164_502b2(CE,PHI,Purpose)).
privilege(CE,
	  not(reasonable(minimizes(CE,
				   for(requires(CE,
						PHI),
				       Purpose)))),
	  '164.502(b)(2)') :-
	wm(s164_502b2(CE,PHI,Purpose)).
implied(noRight(Individual,
		right(Individual,
		      only(discloses(CE,
				     _,
				     PHI)),
		      _),
	        '164.502(b)(2)')) :-
	wm(s164_502b2(CE,PHI,Purpose)).
		
minimumNecessaryException(CE, PHI, Purpose) :-
	wm(s164_502b2i(CE,PHI,Purpose))   ;
	wm(s164_502b2ii(CE,PHI,Purpose))  ;
	wm(s164_502b2ii(CE,PHI,Purpose))  ;
	wm(s164_502b2iii(CE,PHI,Purpose)) ;
	wm(s164_502b2iv(CE,PHI,Purpose))  ;
	wm(s164_502b2v(CE,PHI,Purpose))   ;
	wm(s164_502b2vi(CE,PHI,Purpose,_)).
s164_502b2i(HealthcareProvider,PHI,treatment) :-
	isHealthcareProvider(HealthcareProvider),
	isPHI(PHI),
	add_to_wm(s164_502b2i(healthcareProvider,PHI,treatment)).
s164_502b2ii(CE,PHI,discloses(CE,PHI,Individual)) :-
	isHIPAAIndividual(Individual),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI, Individual),
	add_to_wm(s164_502b2ii(CE,PHI,discloses(CE,PHI,Individual))).
s164_502b2iii(CE,PHI,Purpose) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	authorizes(Individual,CE,for(UsageOrDisclosure,Purpose)),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	add_to_wm(s164_502b2iii(CE,PHI,Purpose)).
s164_502b2iv(CE,PHI,Purpose) :-
	isCoveredEntity(CE),
	isPHI(PHI),
% TODO cross ref to 160 subpart C
	add_to_wm(s164_502b2iv(CE,PHI,Purpose)).
s164_502b2v(CE,PHI,Purpose) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	wm(s164_512a1(CE,UsageOrDisclosure,PHI)),
	for(UsageOrDisclosure,Purpose),
	add_to_wm(s164_502b2v(CE,PHI,Purpose)).
s164_502b2vi(CE,PHI,Purpose,Obligation) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	for(requires(CE,PHI), obligation(CE,Obligation,_)),%
	add_to_wm(s164_502b2vi(CE,PHI,Purpose,Obligation)).

% Section 164.502(c) is a forward reference to 164.522, and does not
% require any additional statements to model it.

s164_502d1(CE,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	add_to_wm(s164_502d1(CE,PHI)).
privilege(CE,
	  for(uses(CE,PHI),
	      creates(CE,deidentified(PHI))),
	  '164.502(d)(1)') :-
	wm(s164_502d1(CE,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(uses(CE,PHI),
			      creates(CE,discloses(PHI)))),
		      _),
		'164.502(d)(1)')) :-
	wm(s164_502d1(CE,PHI)).
s164_502d1_BA(CE,BA,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	areBusinessAssociates(CE,BA),
	add_to_wm(s164_502d1_BA(CE,BA,PHI)).
privilege(CE,
	  for(discloses(CE,BA,PHI),
	      creates(BA,deidentified(PHI))),
	  '164.502(d)(1)') :-
	wm(s164_502d1_BA(CE,BA,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,PHI,BA),
			      creates(BA,deidentified(PHI)))),
		      _),
		'164.502(d)(1)')) :-
	wm(s164_502d1_BA(CE,BA,PHI)).
obligation(CE,
	   not(for(discloses(CE,ThirdParty,PHI),
		   creates(ThirdParty,deidentified(PHI)))),
	   '164.502(d)(1)') :-
	not(areBusinessAssociates(CE,ThirdParty)),
	isCoveredEntity(CE),
	isPHI(PHI).
implied(right(Individual,
	      not(for(discloses(CE,ThirdParty,PHI),
	     creates(ThirdParty,deidentified(PHI)))),
     '164.502(d)(1)')) :-
	not(areBusinessAssociates(CE,ThirdParty)),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual).

discloses(CE,ThirdParty,PHI) :-
	deidentified(PHI),
	discloses(CE, ThirdParty,reidentificationCode(PHI)).

s164_502d2ii_privilege(CE,ThirdParty,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	reidentifies(CE,deidentified(PHI)),
% TODO figure out recursive call
%	isSubsectionOf(Source,'164'),
%	privilege(CE, UsageOrDisclosure, Source),
	add_to_wm(s164_502d2ii_privilege(CE,ThirdParty,UsageOrDisclosure,PHI)).
privilege(CE,
	  UsageOrDisclosure,
	  '164.502(d)(2)(ii)') :-
	wm(s164_502d2ii_privilege(CE,ThirdParty,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(UsageOrDisclosure),
		      _),
		'164.502(d)(2)(ii)')) :-
	wm(s164_502d2ii_privilege(CE,ThirdParty,UsageOrDisclosure,PHI)).	
s164_502d2ii_obligation(CE,ThirdParty,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	reidentifies(CE,deidentified(PHI)),
% TODO figure out recursive call
%	obligation(CE, UsageOrDisclosure, Source),
%	isSubsectionOf(Source,'164'),
	add_to_wm(s164_502d2ii_obligation(CE,ThirdParty,UsageOrDisclosure,PHI)).
obligation(CE,
	   UsageOrDisclosure,
	   '164.502(d)(2)(ii)') :-
	wm(s164_502d2ii_obligation(CE,ThirdParty,UsageOrDisclosure,PHI)).
% TODO: add implied right

s164_502e1i(CE,BA,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	areBusinessAssociates(CE,BA),
	obtains(CE, satisfactory(assures(BA,CE,safeguards(BA,PHI)))),
	not(s164_502e1i_exception(CE,BA,PHI)),
	add_to_wm(s164_502e1i(CE,BA,PHI)).
privilege(CE,
	  discloses(CE,BA,PHI),
	  '164.502(e)(1)(i)') :-
	wm(s164_502e1i(CE,BA,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,BA,PHI)),
		      _),
		'164.502(e)(1)(i)')) :-
	wm(s164_502e1i(CE,BA,PHI)).
privilege(CE,
	  allows(CE,
		 CreatesOrReceives),
	  '164.502(e)(1)(i)') :-
	createsOrReceives(CE,BA,PHI,CreatesOrReceives),%
	wm(s164_502e1i(CE,BA,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(allows(CE,
				 CreatesOrReceives)),
		      _),
		'164.502(e)(1)(i)')) :-
	createsOrReceives(CE,BA,PHI,CreatesOrReceives),%
	wm(s164_502e1i(CE,BA,PHI)).
s164_502e1i_liability(BA,CE,PHI) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isPHI(PHI),
	not(s164_502e1i_exception(CE,BA,PHI)),
	add_to_wm(s164_502e1i_liability(BA,CE,PHI)).
liability(BA,
	  safeguards(BA,PHI),
	  '164.502(e)(1)(i)') :-
	wm(s164_502e1i_liability(BA,CE,PHI)).
implied(power(CE,
	      areBusinessAssociates(CE,BA),
	      obtains(CE, satisfactory(assures(BA,CE,safeguards(BA,PHI)))),
	      '164.502(e)(1)(i)')) :-
	wm(s164_502e1i_liability(BA,CE,PHI)).

s164_502e1i_exception(CE,BA,PHI) :-
	wm(s164_502e1iiA(CE,BA,PHI)) ;
	wm(s164_502e1iiB(CE,BA,PHI)) ;
	wm(s164_502e1iiC(CE,BA,PHI)) ;
	wm(s164_502e1iiC_externalLaw(CE,BA,PHI)).
	
s164_502e1iiA(CE,HCP,PHI) :-
	isCoveredEntity(CE),
	isHealthcareProvider(HCP),
	areBusinessAssociates(CE,HCP),
	isPHI(PHI),
	for(discloses(CE,HCP,PHI), treatment),
	add_to_wm(s164_502e1iiA(CE,HCP,PHI)).
s164_502e1iiB(GHPorHIIorHMO,PlanSponsor,PHI) :-
% TODO: is the GHP a BA of PS?
	isGroupHealthPlanOrHealthInsuranceIssuerOrHMO(GHPorHIIorHMO),
	isPlanSponsor(PlanSponsor, GHPorHIIorHMO),
	isPHI(PHI),
	add_to_wm(s164_502e1iiB(GHPorHIIorHMO,PlanSponsor,PHI)).
isGroupHealthPlanOrHealthInsuranceIssuerOrHMO(GHP) :-
	isGroupHealthPlan(GHP).
isGroupHealthPlanOrHealthInsuranceIssuerOrHMO(HII) :-
	isHealthcareProvider(HII).
isGroupHealthPlanOrHealthInsuranceIssuerOrHMO(HMO) :-
	isHMO(HMO).
s164_502e1iiC(GovernmentProgram,Agency,PHI) :-
	isHealthPlan(GovernmentProgram),
	isGovernmentProgram(GovernmentProgram),
	determines(Agency, enrolled(Individual, GovernmentProgram)),
	isHIPAAIndividual(Individual),
	not(GovernmentProgram = Agency),
	isPHI(PHI),
	add_to_wm(s164_502e1iiC(GovernmentProgram,Agency,PHI)).
s164_502e1iiC_externalLaw(GovernmentProgram,Agency,PHI) :- 
% TODO: is the GP a BA of Agency?
	isHealthPlan(GovernmentProgram),
	isGovernmentProgram(GovernmentProgram),
	collects(Agency,PHI),
	for(uses(_,PHI),determines(_,enrolled(Individual,GovernmentProgram))),
	isHIPAAIndividual(Individual),
	not(GovernmentProgram = Agency),
	isPHI(PHI),
        permitted_by_external_law(Agency,
				  for(uses(_,PHI),determines(_,enrolled(Individual,GovernmentProgram))),
				  _),
	isHIPAAIndividual(Individual),
	add_to_wm(s164_502e1iiC_externalLaw(GovernmentProgram,Agency,PHI)).

s164_502e1iii(CE,BA,Assurances) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isCoveredEntity(BA),
	satisfactory(assures(BA,CE,Assurances)),
	violates(BA, satisfactory(assures(BA,CE,Assurances))),
	add_to_wm(s164_502e1iii(CE,BA,Assurances)).
inNonCompliance(CE, '164.502(e)(1)(iii)') :-
	wm(s164_502e1iii(CE,BA,Assurances)).

s164_502e2(CE,BA,Assurances,PHI) :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	isPHI(PHI),
	satisfactory(assures(BA,CE,safeguards(BA,PHI))),
	add_to_wm(s164_502e2(CE,BA,Assurances,PHI)).
obligation(CE,
	   through(documents(CE,
			     satisfactory(assures(BA,CE,Assurances))),
		   writtenContract),
     '164.502(e)(2)') :-
	wm(s164_502e2(CE,BA,Assurances,PHI)).

meta_rule(s164_502f).

s164_502f :-%
	isHIPAAIndividual(Individual),%
	deceased(Individual),%
	forall( (isCoveredEntity(CE), obligation(CE,X,Source), isSubsectionOf(Source,'164.502')), (%
		assert(obligation(CE,X,'164.502(f)')),%
		assert(mRule(obligation(CE,X,'164.502(f)'))))%
	).%

s164_502g1(CE,Representative,Individual) :-
	represents(Representative,Individual),
	isCoveredEntity(CE),
	not(wm(s164_502g3(CE,Representative,Individual))),
	not(wm(s164_502g5(CE,Representative,Individual))),
	add_to_wm(s164_502g1(CE,Representative,Individual)).
s164_502g5(CE,Representative,Individual) :-
	s164_502g5iA(CE,Representative,Individual) ;
	s164_502g5iB(CE,Representative,Individual) ;
	s164_502g5ii(CE,Representative,Individual).
obligation(CE,
	   treatAs(Representative, Individual),
	   '164.502(g)(1)') :-
	wm(s164_502g1(CE,Representative,Individual)).
implied(right(Representative,
	      treatAs(Representative,Individual),
	      '164.502(g)(1)')) :-
	wm(s164_502g1(CE,Representative,Individual)).

s164_502g2(CE,Representative,Individual) :-
	authority(Representative, actOnBehalf(Representative,Individual)),
	isCoveredEntity(CE),
	isAdultorEmancipatedMinor(Individual),
	Representative \= Individual,
	add_to_wm(s164_502g2(CE,Representative,Individual)).
isAdultorEmancipatedMinor(Individual) :-
	isAdult(Individual).
isAdultorEmancipatedMinor(Individual) :-
	isEmancipatedMinor(Individual).
obligation(CE,
	   treatAs(Representative,
		   represents(Representative,Individual)),
	   '164.502(g)(2)') :-
	wm(s164_502g2(CE,Representative,Individual)).
implied(right(Representative,
	      treatAs(Representative,
		      represents(Representative,Individual)),
	      '164.502(g)(2)')) :-
	wm(s164_502g2(CE,Representative,Individual)).

s164_502g3(CE,Representative,Individual) :-
	authority(Representative, actOnBehalf(Representative,Individual)),
	isCoveredEntity(CE),
	not(s164_502g3_exception(CE,Representative,Individual,_)),
	isUnemancipatedMinor(Individual),
	add_to_wm(s164_502g3(CE,Representative,Individual)).
obligation(CE,
	   treatAs(Representative,
		   represents(Representative,Individual)),
	   '164.502(g)(3)') :-
	wm(s164_502g3(CE,Representative,Individual)).
implied(right(Representative,
	      treatAs(Representative,
		      represents(Representative,Individual)),
	      '164.502(g)(3)')) :-
	wm(s164_502g3(CE,Representative,Individual)).

obligation(Representative,
	   not(represents(Representative,Individual)),
	   '164.502(g)(3)(i)') :-
	s164_502g3_exception(_,Representative,Individual,_).
implied(right(Individual,
	      not(representative(Representative,Individual)),
	      '164.502(g)(3)(i)')) :-
	s164_502g3_exception(_,Representative,Individual,_).
      
authority(Individual, actOnBehalf(Individual,Individual)) :-
	s164_502g3_exception(_,_,Individual,_).

s164_502g3_exception(CE,Representative,Minor,TPO) :-
	wm(s164_502g3iA(CE,Minor,Representative,TPO)) ;
	wm(s164_502g3iB_minor(_,Representative,Minor,TPO)) ;
	wm(s164_502g3iB_court(_,Representative,Minor,TPO)) ;
	wm(s164_502g3iB_person(_,Representative,_,TPO)) ;
	wm(s164_502g3iC(CE,Representative,Minor,TPO)).
	
s164_502g3iA(CE,Minor,Representative,TPO) :-
	isCoveredEntity(CE),
	isMinor(Minor),
	consents(Minor, TPO),
	valid_HIPAA_TPO(TPO),
	not(requests(Minor,CE, treatAs(Representative,represents(Representative,Minor)))),
	not(required_by_external_law(CE, obtains(CE, consents(Minor,TPO)),_)),
	add_to_wm(s164_502g3iA(CE,Minor,Representative,TPO)).
s164_502g3iB_minor(_,Representative,Minor,TPO) :-
	not(requires(TPO, consents(Representative,TPO))),
	isParentalAuthority(Representative,Minor),
	consents(Minor,TPO),
	add_to_wm(s164_502g3iB_minor(_,Representative,Minor,TPO)).
s164_502g3iB_court(_,Representative,Minor,TPO) :-
	not(requires(TPO, consents(Representative,TPO))),
	isParentalAuthority(Representative,Minor),
	consents(Court,TPO),
	isCourt(Court),
	add_to_wm(s164_502g3iB_court(_,Representative,Minor,TPO)).
s164_502g3iB_person(_,Representative,_,TPO) :-
	not(requires(TPO, consents(Representative,TPO))),
	consents(PersonAuthorizedByLaw,TPO),
	authority(PersonAuthorizedByLaw,consents(PersonAuthorizedByLaw,TPO)),
	add_to_wm(s164_502g3iB_person(_,Representative,_,TPO)).

s164_502g3iC(CE,Representative,Minor,TPO) :-
	isParentalAuthority(Representative, Minor),
	isCoveredEntity(CE),
	consents(Representative, confidentialityAgreement(CE,Minor,TPO)),
	add_to_wm(s164_502g3iC(CE,Representative,Minor,TPO)).

s164_502g3iiA(CE,Parent,Minor,PHI) :-
	isCoveredEntity(CE),
	isParentalAuthority(Parent,Minor),
	isPHI(PHI),
	about(PHI,Minor),
	permitted_by_external_law(CE,
				  discloses(CE,Parent,PHI),
				  _),
	add_to_wm(s164_502g3iiA(CE,Parent,Minor,PHI)).
privilege(CE,
	  discloses(CE,Parent,PHI),
	  '164.502(g)(3)(ii)(A)') :-
	wm(s164_502g3iiA(CE,Parent,Minor,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,Parent,PHI)),
		      _),
		'164.502(g)(3)(ii)(A)')) :-
	wm(s164_502g3iiA(CE,Parent,Minor,PHI)).

s164_502g3iiB(CE,Parent,Minor,PHI) :-
	isCoveredEntity(CE),
	isParentalAuthority(Parent,Minor),
	isPHI(PHI),
	about(PHI,Minor),
	prohibited_by_external_law(CE,
				   discloses(CE,Parent,PHI),
				   _),
	add_to_wm(s164_502g3iiB(CE,Parent,Minor,PHI)).
obligation(CE,
	   discloses(CE,Parent,PHI),
	   '164.502(g)(3)(ii)(B)') :-
	wm(s164_502g3iiB(CE,Parent,Minor,PHI)).
implied(right(Parent,
	      receives(Parent,
		       CE,
		       PHI),
	      '164.502(g)(3)(ii)(B)')) :-
	wm(s164_502g3iiB(CE,Parent,Minor,PHI)).

s164_502g3iiC(CE,Parent,Minor,LHCP,PHI) :-
	isCoveredEntity(CE),
	isParentalAuthority(Parent,Minor),
	isPHI(PHI),
	about(PHI,Minor),
	permitted_by_external_law(CE,
				  discloses(CE,Parent,PHI),
				  _),
	determines(LHCP, discloses(CE,Parent,PHI)),
	isLHCP(LHCP),
	add_to_wm(s164_502g3iiC(CE,Parent,Minor,LHCP,PHI)).
privilege(CE,
	  inAccordanceWith(discloses(CE,Parent,PHI),
			   '164.524'),
	  '164.502(g)(3)(ii)(C)') :-
	wm(s164_502g3iiC(CE,Parent,Minor,LHCP,PHI)).
implied(noRight(Minor,
		right(Minor,
		      not(inAccordanceWith(discloses(CE,Parent,PHI),
					   '164.524')),
		      _),
		'164.502(g)(3)(ii)(C)')) :-
	wm(s164_502g3iiC(CE,Parent,Minor,LHCP,PHI)).

s164_502g3iiC(CE,Parent,Minor,LHCP,PHI) :-
	isCoveredEntity(CE),
	isParentalAuthority(Parent,Minor),
	isPHI(PHI),
	about(PHI,Minor),
	permitted_by_external_law(CE,
				  not(discloses(CE,
						Parent,
						PHI)),
				  _),
	determines(LHCP, not(discloses(CE,Parent,PHI))),
	isLHCP(LHCP),
	inAccordanceWith(not(discloses(CE,Parent,PHI)),'164.524'),
	add_to_wm(s164_502g3iiC(CE,Parent,Minor,LHCP,PHI)).
privilege(CE,
	  not(discloses(CE,Parent,PHI)),
	  '164.502(g)(3)(ii)(C)') :-
	wm(s164_502g3iiC(CE,Parent,Minor,LHCP,PHI)).
implied(noRight(CE,
		right(Parent,
		      discloses(CE,Parent,PHI),
		      _),
		'164.502(g)(3)(ii)(C)')) :-
	wm(s164_502g3iiC(CE,Parent,Minor,LHCP,PHI)).
	
s164_502g4(CE,Executor,Individual) :-
	deceased(Individual),
	isCoveredEntity(CE),
	authority(Executor, actOnBehalf(Executor,Individual)),
	add_to_wm(s164_502g4(CE,Executor,Individual)).
obligation(CE,
	   treatAs(Executor,Individual),
	   '164.502(g)(4)') :-
	wm(s164_502g4(CE,Executor,Individual)).
implied(right(Executor,
	      treatAs(Executor,Individual),
	      '164.502(g)(4)')) :-
	wm(s164_502g4(CE,Executor,Individual)).

s164_502g5iA(CE,Representative,Individual) :-
	isCoveredEntity(CE),
	isHIPAAIndividual(Individual),
	reasonable(believes(CE, violentAct(Representative,Individual))),
	add_to_wm(s164_502g5iA(CE,Representative,Individual)).
privilege(CE,
	  not(treatAs(Representative, Individual)),
	  '164.502(g)(5)(i)(A)') :-
	wm(s164_502g5iA(CE,Representative,Individual)).
implied(noRight(Representative,
		right(Representative,
		      treatAs(Representative,Individual),
		      _),
		'164.502(g)(5)(i)(A)')) :-
	wm(s164_502g5iA(CE,Representative,Individual)).


s164_502g5iB(CE,Representative,Individual) :-
	isCoveredEntity(CE),
	isHIPAAIndividual(Individual),
	couldEndanger(treatAs(Representative,Individual), Individual),
	add_to_wm(s164_502g5iB(CE,Representative,Individual)).
privilege(CE,
	  not(treatAs(Representative, Individual)),
	  '164.502(g)(5)(i)(B)') :-
	wm(s164_502g5iB(CE,Representative,Individual)).
implied(noRight(Representative,
		right(Representative,
		      treatAs(Representative, Individual),
		      _),
		'164.502(g)(5)(i)(B)')) :-
	wm(s164_502g5iB(CE,Representative,Individual)).

s164_502g5ii(CE,Representative,Individual) :-
	isCoveredEntity(CE),
	isHIPAAIndividual(Individual),
	determines(CE, not(bestInterest(treatAs(Representative,Individual), Individual))),
	add_to_wm(s164_502g5ii(CE,Representative,Individual)).
privilege(CE, 
	  not(treatAs(Representative, Individual)),
	  '164.502(g)(5)(ii)') :-
	wm(s164_502g5ii(CE,Representative,Individual)).
implied(noRight(Representative,
		right(Representative,
		      treatAs(Representative,Individual),
		      _),
    '164.502(g)(5)(ii)')) :-
	wm(s164_502g5ii(CE,Representative,Individual)).

s164_502i(CE,ThirdParty,Purpose,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	obligation(CE,maintains(CE,notice(_)),Section),
	isSubsectionOf(Section,'164.520'),
	not(in(for(UsageOrDisclosure,Purpose), notice(_))),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	add_to_wm(s164_502i(CE,ThirdParty,Purpose,UsageOrDisclosure,PHI)).
obligation(CE,
	   not(for(UsageOrDisclosure,
		   Purpose)),
	   '164.502(i)') :-
	wm(s164_502i(CE,ThirdParty,Purpose,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      not(for(UsageOrDisclosure,
		      Purpose)),
	      '164.502(i)')) :-
	about(PHI,Individual),
	wm(s164_502i(CE,ThirdParty,Purpose,UsageOrDisclosure,PHI)).

inCompliance(CE,'164.502',discloses(WhistleBlower, Agency,PHI)) :-
	wm(s164_502j1iiA(CE,WhistleBlower,Agency,PHI)),
	add_to_wm(s164_502j1i(CE,WhistleBlower,Agency,PHI)).
inCompliance(CE,'164.502',discloses(WhistleBlower, Agency,PHI)) :-
	wm(s164_502j1iiB(CE,WhistleBlower,Agency,PHI)),
	add_to_wm(s164_502j1i(CE,WhistleBlower,Agency,PHI)).

s164_502j1iiA(CE,WhistleBlower,Agency,PHI) :-
	(   isEmployeeOf(WhistleBlower,CE)
	    ; 
	    areBusinessAssociates(CE,WhistleBlower)
	),
	isHealthOversightAgency(Agency),
	isPHI(PHI),
	isCoveredEntity(CE),
	believes(WhistleBlower, unlawfulConduct(CE)),
	authority(Agency, investigates(Agency, unlawfulConduct(CE))),
	add_to_wm(s164_502j1iiA(CE,WhistleBlower,Agency,PHI)).

privilege(WhistleBlower,
	  for(discloses(WhistleBlower,
			Agency,
			PHI),
	      investigates(Agency,
			   unlawfulConduct(CE))),
	  '164.502(1)(ii)(A)') :-
	wm(s164_502j1iiA(CE,WhistleBlower,Agency,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(WhistleBlower,
				    Agency,
				    PHI)),
		      _),
		    '164.502(1)(ii)(A)')) :-
	wm(s164_502j1iiA(CE,WhistleBlower,Agency,PHI)).

s164_502j1iiB(CE,WhistleBlower,Attorney,PHI) :-
	(   isEmployeeOf(WhistleBlower,CE)
	    ; 
	    areBusinessAssociates(CE,WhistleBlower)
	),
	isCoveredEntity(CE),
	isAttorney(Attorney),
	isPHI(PHI),
	add_to_wm(s164_502j1iiB(CE,WhistleBlower,Attorney,PHI)).
privilege(WhistleBlower,
	  for(discloses(WhistleBlower,Attorney,PHI),
	      determines(Attorney,
			 legalOptions(WhistleBlower))),
	  '164.502(1)(ii)(B)') :-
	wm(s164_502j1iiB(CE,WhistleBlower,Attorney,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(WhistleBlower,Attorney,PHI)),
		      _),
		'164.502(1)(ii)(B)')) :-
	wm(s164_502j1iiB(CE,WhistleBlower,Attorney,PHI)).

s164_502j2i(CE,Victim,Suspect,LE,PHI) :-
	violentAct(Suspect,Victim),
	isPHI(PHI),
	isEmployeeOf(Victim,CE),
	isCoveredEntity(CE),
	about(PHI,Suspect),
	is_s164_512f2i_info(Suspect,PHI),
	isLawEnforcement(LE),
	add_to_wm(s164_502j2i(CE,Victim,Suspect,LE,PHI)).
privilege(Victim,
	  discloses(Victim, LE, PHI),
	  '164.512(j)(2)(i)') :-
	wm(s164_502j2i(CE,Victim,Suspect,LE,PHI)).
implied(noRight(Suspect,
		right(Suspect,
		      not(discloses(Victim,LE,PHI)),
		      _),
		'164.512(j)(2)(i)')) :-
	wm(s164_502j2i(CE,Victim,Suspect,LE,PHI)).

inCompliance(CE,'164.502', discloses(Victim, LE, PHI)) :-
	wm(s164_502j2i(CE,Victim,Suspect,LE,PHI)).

% EOF
















