% Models section 164.504 of the HIPAA Privacy Rule

% TODO standard at 164.504(e)(1)(i)

inNonCompliance(CE, '164.504(e)(1)(ii)') :-
	isCoveredEntity(CE),
	areBusinessAssociates(CE,BA),
	knows(CE, violates(BA, writtenContract(CE,BA))),
	not(reasonable(takesStepsTo(CE, end(violates(BA, writtenContract(CE,BA)))))),
        not(terminates(CE, writtenContract(CE,BA))),
	not(reports(CE,secretaryOfHHS,violates(BA, writtenContract(CE,BA)))),
	add_to_wm(wm(s164_504e1ii(CE,BA))).

s164_504e2i(CE,BA,ThirdParty,UsageOrDisclosure,PHI) :-
	isUsageOrDisclosure(BA,ThirdParty,PHI,UsageOrDisclosure),
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
	add_to_wm(s164_504e2i(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    UsageOrDisclosure),
	   '164.504(e)(2)(i)') :-
	wm(s164_504e2i(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
s164_504e2i_authorizes(CE,BA,ThirdParty,UsageOrDisclosure,PHI) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
	requiredOrPermittedByHIPAA(CE,UsageOrDisclosure),
	isUsageOrDisclosure(BA,ThirdParty,PHI,UsageOrDisclosure),
	add_to_wm(s164_504e2i_authorizes(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
obligation(CE,
	   not(authorizes(writtenContract(CE,BA),
			  UsageOrDisclosure)),
	   '164.504(e)(2)(i)') :-
	wm(s164_504e2i_authorizes(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      not(UsageOrDisclosure),
	      '164.504(e)(2)(i)')) :-
	about(PHI,Individual),
	wm(s164_504e2i(CE,BA,ThirdParty,UsageOrDisclosure,PHI))
	;
	wm(s164_504e2i_authorizes(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
liability(BA,
	  not(UsageOrDisclosure),
	  '164.504(e)(2)(i)') :-
	wm(s164_504e2i_authorizes(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
implied(power(CE,
	      writtenContract(CE,BA),
	      not(authorizes(writtenContract(CE,BA),
			     UsageOrDisclosure)),
     '164.504(e)(2)(i)')) :-
	wm(s164_504e2i_authorizes(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
disability(CE,
	   power(CE,
		 writtenContract(CE,BA),
		 authorizes(writtenContract(CE,BA),
			    UsageOrDisclosure),
		 _),
	   '164.504(e)(2)(i)') :-
	wm(s164_504e2i_authorizes(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
implied(immunity(BA,
		 power(CE,
		       writtenContract(CE,BA),
		       authorizes(writtenContract(CE,BA),
				  UsageOrDisclosure),
		       _),
		 '164.504(e)(2)(i)')) :-
	wm(s164_504e2i_authorizes(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).

s164_504e2iA(CE,BA,ThirdParty,UsageOrDisclosure,PHI) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(BA,ThirdParty,PHI,UsageOrDisclosure),
	add_to_wm(s164_504e2iA(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
% TODO need to redo rules for section 164.504e2i
privilege(CE,
	  contains(writtenContract(CE,BA),
		   for(UsageOrDisclosure,
		       administrativeTasks(BA))),
    '164.504(e)(2)(i)(A)') :-
	wm(s164_504e2iA(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      administrativeTasks(BA))),
		      _),
		'164.504(e)(2)(i)(A)')) :-
	about(PHI,Individual),
	wm(s164_504e2iA(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).

s164_504e2iB(CE,BA,ThirdParty,UsageOrDisclosure,PHI) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(BA,ThirdParty,aggregated(PHI),UsageOrDisclosure),
	add_to_wm(s164_504e2iB(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
privilege(CE,
	  contains(writtenContract(CE,BA),
		   for(UsageOrDisclosure, healthcareOperations)),
	  '164.504(e)(2)(i)(B)') :-
	wm(s164_504e2iB(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      healthcareOperations)),
		      _),
		'164.504(e)(2)(i)(B)')) :-
	about(PHI,Individual),
	wm(s164_504e2iB(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).

s164_504e2iiA(CE,BA,ThirdParty,UsageOrDisclosure,Purpose,PHI) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(BA,ThirdParty,PHI,UsageOrDisclosure),
	not(permitted_by_law(BA,
			     Purpose,
			     _)),
	not(obligation(_,contains(writtenContract(CE,BA), for(uses(BA,PHI),Purpose)),_)),
	add_to_wm(s164_504e2iiA(CE,BA,ThirdParty,UsageOrDisclosure,Purpose,PHI)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    not(for(UsageOrDisclosure,
			    Purpose))),
	   '164.504(e)(2)(ii)(A)') :-
	wm(s164_504e2iiA(CE,BA,ThirdParty,UsageOrDisclosure,Purpose,PHI)).
implied(right(Individual,
	      not(for(UsageOrDisclosure,
		      Purpose)),
	      '164.504(e)(2)(ii)(A)')) :-
	about(PHI,Individual),
	wm(s164_504e2iiA(CE,BA,ThirdParty,UsageOrDisclosure,Purpose,PHI)).
liability(BA,
	  not(for(UsageOrDisclosure,
		      Purpose)),
     '164.504(e)(2)(ii)(A)') :-
	wm(s164_504e2iiA(CE,BA,ThirdParty,UsageOrDisclosure,Purpose,PHI)).
implied(power(CE,
	      writtenContract(CE,BA),
	      not(for(UsageOrDisclosure,
		      Purpose)),
	      '164.504(e)(2)(ii)(A)')) :-
	wm(s164_504e2iiA(CE,BA,ThirdParty,UsageOrDisclosure,Purpose,PHI)).

s164_504e2iiB(CE,BA,ThirdParty,UsageOrDisclosure,PHI) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(BA,ThirdParty,PHI,UsageOrDisclosure),
	contains(writtenContract(CE,BA), UsageOrDisclosure),
	add_to_wm(s164_504e2iiB(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    for(safeguards(BA,PHI),
			prevents(BA, UsageOrDisclosure))),
	   '164.504(e)(2)(ii)(B)') :-
	wm(s164_504e2iiB(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      for(safeguards(BA,PHI),
		  prevents(BA,UsageOrDisclosure)),
	      '164.504(e)(2)(ii)(B)')) :-
	about(PHI,Individual),
	wm(s164_504e2iiB(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
liability(BA,
	  for(safeguards(BA,PHI),
		  prevents(BA,UsageOrDisclosure)),
	  '164.504(e)(2)(ii)(B)') :-
	wm(s164_504e2iiB(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
implied(power(CE,
	      writtenContract(CE,BA),
	      for(safeguards(BA,PHI),
		  prevents(BA,UsageOrDisclosure)),
	      '164.504(e)(2)(ii)(B)')) :-
	wm(s164_504e2iiB(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
	      
s164_504e2iiC(CE,BA,ThirdParty,UsageOrDisclosure,PHI) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isUsageOrDisclosure(BA,ThirdParty,PHI,UsageOrDisclosure),
	isPHI(PHI),
% TODO how to identify these preconditions
	not(obligation(CE, contains(writtenContract(CE,BA), UsageOrDisclosure), _)),
	not(privilege(CE, contains(writtenContract(CE,BA), UsageOrDisclosure), _)),
	add_to_wm(s164_504e2iiC(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    reports(BA,CE, UsageOrDisclosure)),
	   '164.504(e)(2)(ii)(C)') :-
	wm(s164_504e2iiC(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
implied(right(CE,
	      knows(CE,UsageOrDisclosure),
	      '164.504(e)(2)(ii)(C)')) :-
	wm(s164_504e2iiC(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
liability(BA,
	  reports(BA,CE, UsageOrDisclosure),
	  '164.504(e)(2)(ii)(C)') :-
	wm(s164_504e2iiC(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).
implied(power(CE,
	      writtenContract(CE,BA),
	      reports(BA,CE, UsageOrDisclosure),
	      '164.504(e)(2)(ii)(C)')) :-
	wm(s164_504e2iiC(CE,BA,ThirdParty,UsageOrDisclosure,PHI)).

s164_504e2iiD(CE,BA,Agent,PHI) :-
	areBusinessAssociates(CE,BA),
	areBusinessAssociates(BA,Agent),
	isCoveredEntity(CE),
	isPHI(PHI),
	add_to_wm(s164_504e2iiD(CE,BA,Agent,PHI)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    ensures(BA,
			    agrees(Agent,
				   restrictionsAndConditions(PHI)))),
	   '164.504(e)(2)(ii)(D)') :-
	wm(s164_504e2iiD(CE,BA,Agent,PHI)).
implied(right(Individual,
	      not(discloses(BA,Agent,PHI)),
	      '164.504(e)(2)(ii)(D)')) :-
	about(PHI,Individual),
	not(agrees(Agent,restrictionsAndConditions(PHI))),
	wm(s164_504e2iiD_requiredByLaw(CE,BA,Agent,PHI)).
liability(BA,
	  ensures(BA,
		  agrees(Agent,
			 restrictionsAndConditions(PHI))),
	  '164.504(e)(2)(ii)(D)') :-
	wm(s164_504e2iiD(CE,BA,Agent,PHI)).
implied(power(CE,
	      writtenContract(CE,BA),
	      ensures(BA,
		      agrees(Agent,
			     restrictionsAndConditions(PHI))),
	      '164.504(e)(2)(ii)(D)')) :-
	wm(s164_504e2iiD(CE,BA,Agent,PHI)).

s164_504e2iiE(CE,BA,X) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isSubsectionOf(Source,'164.524'),
	obligation(CE,X,Source),
	add_to_wm(s164_504e2iiE(CE,BA,X)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    X),
	   '164.504(e)(2)(ii)(E)') :-
	wm(s164_504e2iiE(CE,BA,X)).
liability(BA,
	  X,
	  '164.504(e)(2)(ii)(E)') :-
	wm(s164_504e2iiE(CE,BA,X)).
implied(power(CE,
	      writtenContract(CE,BA),
	      X,
	      '164.504(e)(2)(ii)(E)')) :-
	wm(s164_504e2iiE(CE,BA,X)).

s164_504e2iiF(CE,BA,X) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isSubsectionOf(Source,'164.526'),
	obligation(CE,X,Source),
	add_to_wm(s164_504e2iiF(CE,BA,X)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    X),
	   '164.504(e)(2)(ii)(F)') :-
	wm(s164_504e2iiF(CE,BA,X)).
liability(BA,
	  X,
	  '164.504(e)(2)(ii)(F)') :-
	wm(s164_504e2iiF(CE,BA,X)).
implied(power(CE,
	      writtenContract(CE,BA),
	      X,
	      '164.504(e)(2)(ii)(F)')) :-
	wm(s164_504e2iiF(CE,BA,X)).

s164_504e2iiG(CE,BA,X) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isSubsectionOf(Source,'164.528'),
	obligation(CE,X,Source),
	add_to_wm(s164_504e2iiG(CE,BA,X)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    X),
	   '164.504(e)(2)(ii)(G)') :-
	wm(s164_504e2iiG(CE,BA,X)).
liability(BA,
	  X,
	  '164.504(e)(2)(ii)(G)') :-
	wm(s164_504e2iiG(CE,BA,X)).
implied(power(CE,
	      writtenContract(CE,BA),
	      X,
	      '164.504(e)(2)(ii)(G)')) :-
	wm(s164_504e2iiG(CE,BA,X)).

s164_504e2iiH(CE,BA) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	add_to_wm(s164_504e2iiH(CE,BA)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    obligation(BA,
			       for(discloses(BA, secretaryOfHHS, internalDocuments),
				   inCompliance(BA,'164.504',
						writtenContract(CE,BA))),
			       '164.504(e)(2)(ii)(H)')),
	   '164.504(e)(2)(ii)(H)') :-
	wm(s164_504e2iiH(CE,BA)).
implied(right(secretaryOfHHS,
	      receives(secretaryOfHHS,BA,internalDocuments),
	      '164.504(e)(2)(ii)(H)')) :-
	wm(s164_504e2iiH(CE,BA)).
liability(BA,
	  for(discloses(BA, secretaryOfHHS, internalDocuments),
	      inCompliance(BA,'164.504',
			   writtenContract(CE,BA))),
	  '164.504(e)(2)(ii)(H)') :-
	wm(s164_504e2iiH(CE,BA)).
implied(power(CE,
	      writtenContract(CE,BA),
	      for(discloses(BA, secretaryOfHHS, internalDocuments),
		  inCompliance(BA,'164.504',
			       writtenContract(CE,BA))),
	  '164.504(e)(2)(ii)(H)')) :-
	wm(s164_504e2iiH(CE,BA)).

s164_504e2iiI_destroysOrReturns(CE,BA,DestroysOrReturns,PHI) :-
	areBusinessAssociates(CE,BA),
	terminates(_,writtenContract(CE,BA)),
	destroysOrReturns(BA,CE,PHI,DestroysOrReturns),
	isPHI(PHI),
	isCoveredEntity(CE),
	feasible(destroys(BA,PHI)),
	add_to_wm(s164_504e2iiI_destroysOrReturns(CE,BA,DestroysOrReturns,PHI)).
destroysOrReturns(BA,_,PHI,destroys(BA,PHI)).
destroysOrReturns(BA,CE,PHI,returns(BA,CE,PHI)).
obligation(CE,
     contains(writtenContract(CE,BA),
	      DestroysOrReturns),
     '164.504(e)(2)(ii)(I)') :-
	wm(s164_504e2iiI_destroysOrReturns(CE,BA,DestroysOrReturns,PHI)).
implied(right(Individual,
	      DestroysOrReturns,
	      '164.504(e)(2)(ii)(I)')) :-
	about(PHI,Individual),
	wm(s164_504e2iiI_destroysOrReturns(CE,BA,DestroysOrReturns,PHI)).
liability(BA,
	  DestroysOrReturns,
	   '164.504(e)(2)(ii)(I)') :-
	wm(s164_504e2iiI_destroysOrReturns(CE,BA,DestroysOrReturns,PHI)).
implied(power(CE,
	      writtenContract(CE,BA),
	      DestroysOrReturns,
     '164.504(e)(2)(ii)(I)')) :-
	wm(s164_504e2iiI_destroysOrReturns(CE,BA,DestroysOrReturns,PHI)).
s164_504e2iiI_safeguards(CE,BA,PHI) :-
	areBusinessAssociates(CE,BA),
	terminates(_,writtenContract(CE,BA)),
	isPHI(PHI),
	isCoveredEntity(CE),
	not(feasible(returns(BA,CE,PHI))),
	not(feasible(destroys(BA,PHI))),
	add_to_wm(s164_504e2iiI_safeguards(CE,BA,PHI)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    safeguards(BA,PHI)),
	   '164.504(e)(2)(ii)(I)') :-
	wm(s164_504e2iiI_safeguards(CE,BA,PHI)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    minimizes(BA, UsageOrDisclosure)),
	   '164.504(e)(2)(ii)(I)') :-
	(   causes(UsageOrDisclosure, not(feasible(returns(BA,CE,PHI))))
	    ;
	    causes(UsageOrDisclosure, not(feasible(destroys(BA,PHI))))
	),
	isUsageOrDisclosure(BA,ThirdParty,PHI,UsageOrDisclosure),
	wm(s164_504e2iiI_safeguards(CE,BA,PHI)).
implied(right(Individual,
	      safeguards(BA,PHI),
	      '164.504(e)(2)(ii)(I)')) :-
	about(PHI,Individual),
	wm(s164_504e2iiI_safeguards(CE,BA,PHI)).
implied(right(Individual,
	      not(UsageOrDisclosure),
	      '164.504(e)(2)(ii)(I)')) :-
	about(PHI,Individual),
	(   causes(UsageOrDisclosure, not(feasible(returns(BA,CE,PHI))))
	    ;
	    causes(UsageOrDisclosure, not(feasible(destroys(BA,PHI))))
	),
	isUsageOrDisclosure(BA,ThirdParty,PHI,UsageOrDisclosure),
	wm(s164_504e2iiI_safeguards(CE,BA,PHI)).
liability(BA,
	  safeguards(BA,PHI),
     '164.504(e)(2)(ii)(I)') :-
	wm(s164_504e2iiI_safeguards(CE,BA,PHI)).
implied(power(CE,
	      writtenContract(CE,BA),
	      minimizes(BA, UsageOrDisclosure),
     '164.504(e)(2)(ii)(I)')) :-
	(   causes(UsageOrDisclosure, not(feasible(returns(BA,CE,PHI))))
	    ;
	    causes(UsageOrDisclosure, not(feasible(destroys(BA,PHI))))
	),
	isUsageOrDisclosure(BA,ThirdParty,PHI,UsageOrDisclosure),
	wm(s164_504e2iiI_safeguards(CE,BA,PHI)).

s164_504e2iii(CE,BA) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	determines(CE, violates(BA, writtenContract(CE,BA))),
	not(s164_504e2iii_exception(CE,BA)),
	add_to_wm(s164_504e2iii(CE,BA)).
obligation(CE,
	   contains(writtenContract(CE,BA),
		    authority(CE,
			      terminates(CE,
					 writtenContract(CE, BA)))),
	   '164.504(e)(2)(iii)') :-
	wm(s164_504e2iii(CE,BA)).
implied(right(CE,
	      terminates(CE,
			 writtenContract(CE,BA)),
	      '164.504(e)(2)(iii)')) :-
	wm(s164_504e2iii(CE,BA)).
power(CE,
      writtenContract(CE,BA),
      terminates(CE,
		 writtenContract(CE,BA)),
      '164.504(e)(2)(iii)') :-
	wm(s164_504e2iii(CE,BA)).
liability(BA,
	  terminates(CE,
		     writtenContract(CE,BA)),
	  '164.504(e)(2)(iii)') :-
	wm(s164_504e2iii(CE,BA)).

meta_rule(s164_504e3iA).
s164_504e3iA :-
        areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isGovernmentEntity(CE),
	isGovernmentEntity(BA),
	forall((
	          obligation(CE,contains(writtenContract(CE,BA), X), Source) ,
	          isSubsectionOf(Source, '164.504(e)')
	       ),
	       (
		  assert(obligation(CE, contains(mou, X), '164.504(e)(3)(i)(A)')),
		  assert(mRule(obligation(CE, contains(mou, X), '164.504(e)(3)(i)(A)')))
	       )
	).
s164_504e3iA :-
        areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isGovernmentEntity(CE),
	isGovernmentEntity(BA),
	forall((
	          privilege(CE,contains(writtenContract(CE,BA), X), Source) ,
	          isSubsectionOf(Source, '164.504(e)')
	       ),
	       (
		  assert(privilege(CE, contains(mou, X), '164.504(e)(3)(i)(A)')),
		  assert(mRule(privilege(CE, contains(mou, X), '164.504(e)(3)(i)(A)')))
	       )
	).

meta_rule(s164_504e3iB).
s164_504e3iB :-
        areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isGovernmentEntity(CE),
	isGovernmentEntity(BA),
	forall((
	          obligation(CE,contains(writtenContract(CE,BA), X), Source) ,
		  required_by_external_law(BA, X, _),
	          isSubsectionOf(Source, '164.504(e)(2)')
	       ),
	       (
		  assert(obligation(CE, contains(mou, X), '164.504(e)(3)(i)(B)')),
		  assert(mRule(obligation(CE, contains(mou, X), '164.504(e)(3)(i)(B)')))
	       )
	).
s164_504e3iB :-
        areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isGovernmentEntity(CE),
	isGovernmentEntity(BA),
	forall((
	          privilege(CE,contains(writtenContract(CE,BA), X), Source) ,
		  permitted_by_external_law(BA,X,_),
	          isSubsectionOf(Source, '164.504(e)')
	       ),
	       (
		  assert(privilege(CE, contains(mou, X), '164.504(e)(3)(i)(B)')),
		  assert(mRule(privilege(CE, contains(mou, X), '164.504(e)(3)(i)(B)')))
	       )
	).

s164_504e3ii(CE,BA,Function,PHI) :-
        areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
        required_by_external_law(BA, Function, _),
	attempts(CE, obtains(CE, mou(CE,BA))),
	not(obtains(CE,mou(CE,BA))),
	documents(CE, not(obtains(CE, mou(CE,BA)))),
	add_to_wm(s164_504e3ii(CE,BA,Function,PHI)).
privilege(CE,
	  discloses(CE,BA,PHI),
	  '164.504(e)(3)(ii)') :-
	wm(s164_504e3ii(CE,BA,Function,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,BA,PHI)),
		      _),
		'164.504(e)(3)(ii)')) :-
	wm(s164_504e3ii(CE,BA,Function,PHI)).

s164_504e2iii_exception(CE, BA) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	(
	    conflicts(contains(writtenContract(CE,BA),
			       authority(CE,
					 terminates(CE,
						    writtenContract(CE,BA)))),
		      required_by_external_law(CE,_,_))
	;
	    conflicts(contains(writtenContract(CE,BA),
			       authority(CE,
					 terminates(CE, writtenContract(CE, BA)))),
		      required_by_external_law(BA,_,_))
	),
	add_to_wm(s164_504e3iii(CE,BA)).

s164_504e4iA(CE,BA,Purpose,PHI) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
	s164_504e4i_purpose(Purpose),
	add_to_wm(s164_504e4iA(CE,BA,Purpose,PHI)).
privilege(CE,
	  contains(writtenContract(CE,BA),
		   for(uses(BA,PHI), Purpose)),
	  '164.504(e)(4)(i)(A)') :-
	wm(s164_504e4iA(CE,BA,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(uses(BA,PHI),
			      Purpose)),
		      _),
		'164.504(e)(4)(i)(A)')) :-
	about(PHI,Individual),
	wm(s164_504e4iA(CE,BA,Purpose,PHI)).

s164_504e4i_purpose(administrativeTasks(BA)) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE).
s164_504e4i_purpose(required_by_external_law(BA,_,_)) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE).

s164_504e4iiA(CE,BA,Purpose,PHI) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
	s164_504e4i_purpose(Purpose),
        required_by_external_law(BA, discloses(BA,_,PHI), _),
	add_to_wm(s164_504e4iiA(CE,BA,Purpose,PHI)).
privilege(CE,
	  contains(writtenContract(CE,BA),
		   for(discloses(BA,_,PHI), Purpose)),
	  '164.504(e)(4)(ii)(A)') :-
	wm(s164_504e4iiA(CE,BA,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(BA,_,PHI),
			      Purpose)),
		      _),
		'164.504(e)(4)(ii)(A)')) :-
	about(PHI,Individual),
	wm(s164_504e4iiA(CE,BA,Purpose,PHI)).

s164_504e4iiB1(CE,BA,Person,Purpose,Assurances,PHI) :-
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	isPHI(PHI),
	s164_504e4i_purpose(Purpose),
	reasonable(assures(Person,BA,Assurances)),
	s164_504e4iiB1_assurance(Person, PHI, Purpose, Assurances),
	add_to_wm(s164_504e4iiB1(CE,BA,Person,Purpose,Assurances,PHI)).
s164_504e4iiB1_assurance(Person,
			PHI,
			PurposeOfDisclosure,
			safeguards(Person, PHI)).
s164_504e4iiB1_assurance(Person,
			PHI,
			PurposeOfDisclosure,
			not(discloses(Person,X,PHI))) :-
	not(required_by_law(Person,
			    discloses(Person,X,PHI),
			    _)),
	not(s164_504e4i_purpose(PurposeOfDisclosure)).
s164_504e4iiB1_assurance(Person,
			PHI,
			PurposeOfDisclosure,
			not(uses(Person,PHI))) :-
	not(required_by_law(Person,
			    uses(Person,PHI),
			    _)),
	not(s164_504e4i_purpose(PurposeOfDisclosure)).
privilege(CE,
	  contains(writtenContract(CE,BA),
		   for(discloses(BA,Person,PHI), Purpose)),
	  '164.504(e)(4)(ii)(B)(1)') :-
	wm(s164_504e4iiB1(CE,BA,Person,Purpose,Assurances,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(BA,Person,PHI),
			      Purpose)),
		      _),
		'164.504(e)(4)(ii)(B)(1)')) :-
	wm(s164_504e4iiB1(CE,BA,Person,Purpose,Assurances,PHI)).
liability(Person,
	  Assurances,
	  '164.504(e)(4)(ii)(B)(1)') :-
	wm(s164_504e4iiB1(CE,BA,Person,Purpose,Assurances,PHI)).
implied(power(BA,
	      discloses(BA,Person,PHI),
	      requires(BA,
		       Person,
		       Assurances),
	      '164.504(e)(4)(ii)(B)(1)')) :-
	wm(s164_504e4iiB1(CE,BA,Person,Purpose,Assurances,PHI)).
	      
s164_504e4iiB2(CE,BA,Person,ThirdParty,PHI) :-
	discloses(BA,Person,PHI),
	isPHI(PHI),
	areBusinessAssociates(CE,BA),
	isCoveredEntity(CE),
	knows(ThirdParty, PHI),
	ThirdParty \= Person,
	add_to_wm(s164_504e4iiB2(CE,BA,Person,ThirdParty,PHI)).
obligation(Person,
	   reports(Person,
		   BA,
		   knows(ThirdParty, PHI)),
	   '164.504(e)(4)(ii)(B)(2)') :-
	wm(s164_504e4iiB2(CE,BA,Person,ThirdParty,PHI)).
implied(right(BA,
	      knows(BA,
		    knows(ThirdParty,PHI)),
	      '164.504(e)(4)(ii)(B)(2)')) :-
	wm(s164_504e4iiB2(CE,BA,Person,ThirdParty,PHI)).		  

s164_504f1i(GHP,Actor,PlanSponsor,UsageOrDisclosure,PHI,Purpose) :-
	isGroupHealthPlan(GHP),
	isGroupHealthPlanActor(Actor),
	isPHI(PHI),
	not(s164_504f1i_exception(GHP,Actor,PlanSponsor,Purpose)),
	isPlanSponsor(PlanSponsor,GHP),
	discloses(GHP,PlanSponsor,PHI),
	isUsageOrDisclosure(PlanSponsor,_,PHI,UsageOrDisclosure),
	add_to_wm(s164_504f1i(GHP,Actor,PlanSponsor,PHI,Purpose)).
s164_504f1i_exception(GHP,Actor,PlanSponsor,Purpose) :-
	(   s164_504f1iiA(GHP,PlanSponsor,_) ;
	    s164_504f1iiB(Actor,GHP,PlanSponsor,Purpose,_) ;
	    s164_504f1iii_participates(Actor,GHP,PlanSponsor,Individual) ; 
	    s164_504f1iii_enrolledOrDisenrolled(Actor,GHP,PlanSponsor,_,Individual)
	).
	
obligation(GHP,
	   contains(planDocuments(GHP),
		    for(ensures(GHP, restricts(Actor, for(UsageOrDisclosure,
							  Purpose))))),
	   '164.504(f)(1)(i)') :-
	requiredOrPermittedByHIPAA(PlanSponsor,not(UsageOrDisclosure)),
	wm(s164_504f1i(GHP,Actor,PlanSponsor,UsageOrDisclosure,PHI,Purpose)).
implied(right(Individual,
	      not(for(UsageOrDisclosure),
		  Purpose),
	      '164.504(f)(1)(i)')) :-
	not(requiredOrPermittedByHIPAA(PlanSponsor,UsageOrDisclosure)),
	about(PHI,Individual),
	wm(s164_504f1i(GHP,PlanSponsor,UsageOrDisclosure,PHI,Purpose)).

s164_504f1iiA(Actor,PlanSponsor,summary(PHI)) :-
	isGroupHealthPlanActor(Actor),
	isPlanSponsor(PlanSponsor,Actor),
	requests(PlanSponsor,
		 Actor,
		 for(summary(PHI),
		     obtains(PlanSponsor, premiumBids))),
	add_to_wm(s164_504f1iiA(Actor,PlanSponsor,summary(PHI))).
isGroupHealthPlanActor(X) :-
	isGroupHealthPlan(X).
isGroupHealthPlanActor(X) :-
	isHealthInsuranceIssuer(X).
isGroupHealthPlanActor(X) :-
	isHMO(X).
privilege(Actor,
	  discloses(Actor,PlanSponsor,summary(PHI)),
	  '164.504(f)(1)(ii)(A)') :-
	wm(s164_504f1iiA(Actor,PlanSponsor,summary(PHI))).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(Actor,PlanSponsor,summary(PHI))),
		      _),
		'164.504(f)(1)(ii)(A)')) :-
	about(PHI,Individual),
	wm(s164_504f1iiA(Actor,PlanSponsor,summary(PHI))).

s164_504f1iiB(Actor,GHP,PlanSponsor,Purpose,summary(PHI)) :-
	isGroupHealthPlanActor(Actor),
	isPlanSponsor(PlanSponsor,Actor),
	isPHI(PHI),
	requests(PlanSponsor, Actor, for(summary(PHI), Purpose)),
	modifyAmendOrTerminate(Actor,GHP,Purpose),
	isGroupHealthPlan(GHP),
	add_to_wm(s164_504f1iiB(Actor,GHP,PlanSponsor,Purpose,summary(PHI))).
modifyAmendOrTerminate(X,Y,modifies(X,Y)).
modifyAmendOrTerminate(X,Y,amends(X,Y)).
modifyAmendOrTerminate(X,Y,terminates(X,Y)).
privilege(Actor,
	  discloses(Actor,PlanSponsor,summary(PHI)),
	  '164.504(f)(1)(ii)(B)') :-
	wm(s164_504f1iiB(Actor,GHP,PlanSponsor,Purpose,summary(PHI))).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(Actor,PlanSponsor,summary(PHI))),
		      _),
		'164.504(f)(1)(ii)(B)')) :-
	about(PHI,Individual),
	wm(s164_504f1iiB(Actor,GHP,PlanSponsor,Purpose,summary(PHI))).

s164_504f1iii_participates(Actor,GHP,PlanSponsor,Individual) :-
	isGroupHealthPlanActor(Actor),
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,Actor),
	isHIPAAIndividual(Individual),
	enrolled(Individual,GHP),
	add_to_wm(s164_504f1iii_participates(Actor,GHP,PlanSponsor,Individual)).
privilege(Actor,
	  discloses(Actor,PlanSponsor,participates(Individual,GHP)),
	  '164.504(f)(1)(iii)') :-
	wm(s164_504f1iii_participates(Actor,GHP,PlanSponsor,Individual)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(Actor,PlanSponsor,participates(Individual,GHP))),
		      _),			  
		'164.504(f)(1)(iii)')) :-
	wm(s164_504f1iii_participates(Actor,GHP,PlanSponsor,Individual)).
s164_504f1iii_enrolledOrDisenrolled(Actor,GHP,PlanSponsor,EnrolledOrDisenrolled,Individual) :-
	isGroupHealthPlanActor(Actor),
	isGroupHealthPlanActor(X),
	enrollsOrDisenrolls(Individual,X,EnrolledOrDisenrolled),
	EnrolledOrDisenrolled,
	isPlanSponsor(PlanSponsor,Actor),
	isHIPAAIndividual(Individual),
	add_to_wm(s164_504f1iii_enrolledOrDisenrolled(Actor,GHP,PlanSponsor,EnrolledOrDisenrolled,Individual)).
enrollsOrDisenrolls(Individual,X,enrolled(Individual,X)).
enrollsOrDisenrolls(Individual,X,disenrolled(Individual,X)).
privilege(Actor,
    discloses(Actor,PlanSponsor,EnrolledOrDisenrolled),
    '164.504(f)(1)(iii)') :-
	wm(s164_504f1iii_enrolledOrDisenrolled(Actor,GHP,PlanSponsor,EnrolledOrDisenrolled,Individual)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(Actor,PlanSponsor,EnrolledOrDisenrolled)),
		      _),
		'164.504(f)(1)(iii)')) :-
	wm(s164_504f1iii_enrolledOrDisenrolled(Actor,GHP,PlanSponsor,EnrolledOrDisenrolled,Individual)).

s164_504f2i_permitted(GHP,PlanSponsor,Source,ThirdParty,UsageOrDisclosure,PHI) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	privilege(PlanSponsor,UsageOrDisclosure,Source),
	isUsageOrDisclosure(PlanSponsor,ThirdParty,PHI,UsageOrDisclosure),
	add_to_wm(s164_504f2i_permitted(GHP,PlanSponsor,Source,ThirdParty,UsageOrDisclosure,PHI)).
obligation(GHP,
	   contains(planDocuments(GHP),
		    privilege(PlanSponsor,
			      UsageOrDisclosure,
			      Source)),
	   '164.504(f)(2)(i)') :-
	wm(s164_504f2i_permitted(GHP,PlanSponsor,Source,ThirdParty,UsageOrDisclosure,PHI)).
% TODO add implied right

s164_504f2i_required(GHP,PlanSponsor,Source,ThirdParty,UsageOrDisclosure,PHI) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	obligation(PlanSponsor,discloses(PlanSponsor,ThirdParty,PHI),Source),
	isUsageOrDisclosure(PlanSponsor,ThirdParty,PHI,UsageOrDisclosure),
	add_to_wm(s164_504f2i_required(GHP,PlanSponsor,Source,ThirdParty,UsageOrDisclosure,PHI)).
obligation(GHP,
	   contains(planDocuments(GHP),
		    obligation(PlanSponsor,
			       UsageOrDisclosure,
			       Source)),
	   '164.504(f)(2)(i)') :-
	wm(s164_504f2i_required(GHP,PlanSponsor,Source,ThirdParty,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      right(Individual,
		    UsageOrDisclosure,
		    Source),
	      '164.504(f)(2)(i)')) :-
	wm(s164_504f2i_required(GHP,PlanSponsor,Source,ThirdParty,UsageOrDisclosure,PHI)).

s164_504f2ii(GHP,PlanSponsor,Amendments,PHI) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	s164_504f2ii_amendments(GHP,PlanSponsor,Amendments),
	contains(planDocuments(GHP), Amendments),
	agrees(PlanSponsor, Amendments),
        add_to_wm(s164_504f2ii(GHP,PlanSponsor,Amendments,PHI)).
obligation(GHP,
	   contains(planDocuments(GHP),
		    before(receives(GHP,
				    PlanSponsor,
				    Amendments),
			   discloses(GHP,PlanSponsor,PHI))),
	   '164.504(f)(2)(ii)') :-
	wm(s164_504f2ii(GHP,PlanSponsor,Amendments,PHI)).
implied(right(Individual,
	      Amendments,
	      '164.504(f)(2)(ii)')) :-
	about(PHI,Individual),
	wm(s164_504f2ii(GHP,PlanSponsor,Amendments,PHI)).
obligation(GHP,
	   not(before(discloses(GHP,PlanSponsor,PHI),
		      receives(GHP,
			       PlanSponsor,
			       Amendments))),
	   '164.504(f)(2)(ii)') :-
	wm(s164_504f2ii(GHP,PlanSponsor,Amendments,PHI)).
implied(right(Individual,
	      not(before(discloses(GHP,PlanSponsor,PHI),
			 receives(GHP,
				  PlanSponsor,
				  Amendments))),
	      '164.504(f)(2)(ii)')) :-
	about(PHI,Individual),
	wm(s164_504f2ii(GHP,PlanSponsor,Amendments,PHI)).

s164_504f2iiA(GHP,PlanSponsor,ThirdParty,UsageOrDisclosure,PHI) :-
	not(permitted_by_law(PlanSponsor,
			     UsageOrDisclosure,
			     _)),
	not(required_by_law(PlanSponsor,
			    UsageOrDisclosure,
			    _)),
	not(contains(planDocuments(GHP),UsageOrDisclosure)),
	isPHI(PHI),
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isUsageOrDisclosure(PlanSponsor,ThirdParty,PHI,UsageOrDisclosure),
	add_to_wm(s164_504f2iiA(GHP,PlanSponsor,ThirdParty,UsageOrDisclosure,PHI)).
s164_504f2ii_amendments(GHP,PlanSponsor,not(UsageOrDisclosure)) :-
	wm(s164_504f2iiA(GHP,PlanSponsor,ThirdParty,UsageOrDisclosure,PHI)).
obligation(PlanSponsor,
	   not(UsageOrDisclosure),
	   '164.504(f)(2)(ii)(A)') :-
	wm(s164_504f2iiA(GHP,PlanSponsor,ThirdParty,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      not(UsageOrDisclosure),
	      '164.504(f)(2)(ii)(A)')) :-
	wm(s164_504f2iiA(GHP,PlanSponsor,ThirdParty,UsageOrDisclosure,PHI)).

s164_504f2iiB(GHP,PlanSponsor,Agent,PHI) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	discloses(PlanSponsor,Agent,PHI),
	isPHI(PHI),
	add_to_wm(s164_504f2iiB(GHP,PlanSponsor,Agent,PHI)).
obligation(GHP,
	   ensures(PlanSponsor,
		   agrees(Agent,restrictionsAndConditions(PHI))),
	   '164.504(f)(2)(ii)(B)') :-
	wm(s164_504f2iiB(GHP,PlanSponsor,Agent,PHI)).
implied(right(Individual,
	      not(discloses(PlanSponsor,Agent,PHI)),
	      '164.504(f)(2)(ii)(B)')) :-
	about(PHI,Individual),
	not(agrees(Agent,restrictionsAndConditions(PHI))),
	wm(s164_504f2iiB(GHP,PlanSponsor,Agent,PHI)).
s164_504f2ii_amendments(GHP,
			PlanSponsor,
			ensures(PlanSponsor,
				agrees(Agent,restrictionsAndConditions(PHI)))) :-
	wm(s164_504f2iiB(GHP,PlanSponsor,Agent,PHI)).

s164_504f2iiC(GHP,PlanSponsor,PHI) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	add_to_wm(s164_504f2iiC(GHP,PlanSponsor,PHI)).
obligation(GHP,
	   not(for(uses(PlanSponsor, PHI),
		   employmentActions)),
	   '164.504(f)(2)(ii)(C)') :-
	wm(s164_504f2iiC(GHP,PlanSponsor,PHI)).
implied(right(Individual,
	      not(for(uses(PlanSponsor,PHI),
		      employmentActions)),
	      '164.504(f)(2)(ii)(C)')) :-
	about(PHI,Individual),
	wm(s164_504f2iiC(GHP,PlanSponsor,PHI)).
s164_504f2ii_amendments(GHP,
			PlanSponsor,
			not(for(uses(PlanSponsor, PHI),
				employmentActions))) :-
	wm(s164_504f2iiC(GHP,PlanSponsor,PHI)).

s164_504f2iiD(GHP,PlanSponsor,UsageOrDisclosure,PHI) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isUsageOrDisclosure(PlanSponsor,_,PHI,UsageOrDisclosure),
	isPHI(PHI),
% TODO preconditions
	not(obligation(CE, contains(writtenContract(CE,PlanSponsor), UsageOrDisclosure), _)),
	not(privilege(CE, contains(writtenContract(CE,PlanSponsor), UsageOrDisclosure), _)),
	not(obligation(PlanSponsor,UsageOrDisclosure,_)),
	not(privilege(PlanSponsor,UsageOrDisclosure,_)),
	add_to_wm(s164_504f2iiD(GHP,PlanSponsor,UsageOrDisclosure,PHI)).
obligation(GHP,
	   reports(PlanSponsor,GHP,UsageOrDisclosure),
	   '164.504(f)(2)(ii)(D)') :-
	wm(s164_504f2iiD(GHP,PlanSponsor,UsageOrDisclosure,PHI)).
implied(right(GHP,
	      receives(GHP,PlanSponsor,UsageOrDisclosure),
	      '164.504(f)(2)(ii)(D)')) :-
	wm(s164_504f2iiD(GHP,PlanSponsor,UsageOrDisclosure,PHI)).
s164_504f2ii_amendments(GHP,
			PlanSponsor,
			reports(PlanSponsor,GHP,UsageOrDisclosure)) :-
	wm(s164_504f2iiD(GHP,PlanSponsor,UsageOrDisclosure,PHI)).

s164_504f2iiE(GHP,PlanSponsor,X) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isSubsectionOf(Source,'164.524'),
	obligation(GHP,X,Source),
	add_to_wm(s164_504f2iiE(GHP,PlanSponsor,X)).
obligation(GHP,
	   contains(planDocuments(GHP),X),
	   '164.504(f)(2)(ii)(E)') :-
	wm(s164_504f2iiE(GHP,PlanSponsor,X)).
liability(PlanSponsor,         % TODO liability?
	  X,
	  '164.504(f)(2)(ii)(E)') :-
	wm(s164_504f2iiE(GHP,PlanSponsor,X)).
implied(power(GHP,
	      planDocuments(GHP),
	      X,
	      '164.504(f)(2)(ii)(E)')) :-
	wm(s164_504f2iiE(GHP,PlanSponsor,X)).

s164_504f2iiF(GHP,PlanSponsor,X) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isSubsectionOf(Source,'164.526'),
	obligation(GHP,X,Source),
	add_to_wm(s164_504f2iiF(GHP,PlanSponsor,X)).
obligation(GHP,
	   contains(planDocuments(GHP),X),
	   '164.504(f)(2)(ii)(F)') :-
	wm(s164_504f2iiF(GHP,PlanSponsor,X)).
liability(PlanSponsor,
	  X,
	  '164.504(f)(2)(ii)(F)') :-
	wm(s164_504f2iiF(GHP,PlanSponsor,X)).
implied(power(GHP,
	      planDocuments(GHP),
	      X,
	      '164.504(f)(2)(ii)(F)')) :-
	wm(s164_504f2iiF(GHP,PlanSponsor,X)).

s164_504f2iiG(GHP,PlanSponsor,X) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isSubsectionOf(Source,'164.528'),
	obligation(GHP,X,Source),
	add_to_wm(s164_504f2iiG(GHP,PlanSponsor,X)).
obligation(GHP,
	   contains(planDocuments(GHP),X),
	   '164.504(f)(2)(ii)(G)') :-
	wm(s164_504f2iiG(GHP,PlanSponsor,X)).
liability(PlanSponsor,
	  X,
	  '164.504(f)(2)(ii)(G)') :-
	wm(s164_504f2iiG(GHP,PlanSponsor,X)).
implied(power(GHP,
	      planDocuments(GHP),
	      X,
	      '164.504(f)(2)(ii)(G)')) :-
	wm(s164_504f2iiG(GHP,PlanSponsor,X)).

s164_504f2iiH(GHP,PlanSponsor,PHI) :-
	isGroupHealthPlan(GHP),
	discloses(GHP,PlanSponsor,PHI),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	add_to_wm(s164_504f2iiH(GHP,PlanSponsor,PHI)).
obligation(PlanSponsor,
	   for(discloses(PlanSponsor, secretaryOfHHS, internalDocuments),
	       inCompliance(GHP, '164')),
	   '164.504(f)(2)(ii)(H)') :-
	wm(s164_504f2iiH(GHP,PlanSponsor,PHI)).
implied(right(secretaryOfHHS,
	      receives(secretaryOfHHS,PlanSponsor,internalDocuments),
	      '164.504(f)(2)(ii)(H)')) :-
	wm(s164_504f2iiH(GHP,PlanSponsor,PHI)).
s164_504f2ii_amendments(GHP,
			PlanSponsor,
			for(discloses(PlanSponsor,
				      secretaryOfHHS,
				      internalDocuments),
			    inCompliance(GHP, '164'))) :-
	wm(s164_504f2iiH(GHP,PlanSponsor,PHI)).

s164_504f2iiI(GHP,PlanSponsor,Purpose,PHI) :-
	isGroupHealthPlan(GHP),
	for(discloses(GHP,PlanSponsor,PHI), Purpose),
	not(for(requires(PlanSponsor, PHI), Purpose)),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	add_to_wm(s164_504f2iiI(GHP,PlanSponsor,Purpose,PHI)).
s164_504f2iiI_destroys(GHP,PlanSponsor,Purpose,PHI) :-
	wm(s164_504f2iiI(GHP,PlanSponsor,Purpose,PHI)),
	feasible(destroys(PlanSponsor,PHI)),
	add_to_wm(s164_504f2iiI_destroys(GHP,PlanSponsor,Purpose,PHI)).
s164_504f2iiI_returns(GHP,PlanSponsor,Purpose,PHI) :-
	wm(s164_504f2iiI(GHP,PlanSponsor,Purpose,PHI)),
	feasible(returns(PlanSponsor,PHI)),
	add_to_wm(s164_504f2iiI_returns(GHP,PlanSponsor,Purpose,PHI)).
s164_504f2iiI_notFeasible(GHP,PlanSponsor,Purpose,UsageOrDisclosure,PHI) :-
	wm(s164_504f2iiI(GHP,PlanSponsor,Purpose,PHI)),
	not(feasible(returns(PlanSponsor,GHP,PHI))),
	not(feasible(destroys(PlanSponsor,PHI))),
	(   causes(UsageOrDisclosure, not(feasible(returns(PlanSponsor,GHP,PHI))))
	    ;
	    causes(UsageOrDisclosure, not(feasible(destroys(PlanSponsor,PHI))))
	), 
	add_to_wm(s164_504f2iiI_notFeasible(GHP,PlanSponsor,Purpose,UsageOrDisclosure,PHI)).
obligation(PlanSponsor,
	   destroys(PlanSponsor,PHI),
	   '164.504(f)(2)(ii)(I)') :-
	wm(s164_504f2iiI_destroys(GHP,PlanSponsor,Purpose,PHI)).
implied(right(Individual,
	      destroys(PlanSponsor,PHI),
	      '164.504(f)(2)(ii)(I)')) :-
	about(PHI,Individual),
	wm(s164_504f2iiI_destroys(GHP,PlanSponsor,Purpose,PHI)).
s164_504f2ii_amendments(GHP,
			PlanSponsor,
			destroys(PlanSponsor,PHI)) :-
	wm(s164_504f2iiI_destroys(GHP,PlanSponsor,Purpose,PHI)).
obligation(PlanSponsor,
	   returns(PlanSponsor,PHI),
	   '164.504(f)(2)(ii)(I)') :-
	wm(s164_504f2iiI_returns(GHP,PlanSponsor,Purpose,PHI)).
implied(right(GHP,
	      receives(GHP,PlanSponsor,PHI),
	      '164.504(f)(2)(ii)(I)')) :-
	wm(s164_504f2iiI_returns(GHP,PlanSponsor,Purpose,PHI)).
s164_504f2ii_amendments(GHP,
			PlanSponsor,
			returns(PlanSponsor,PHI)) :-
	wm(s164_504f2iiI_returns(GHP,PlanSponsor,Purpose,PHI)).
obligation(PlanSponsor,
	   minimizes(PlanSponsor,UsageOrDisclosure),
	   '164.504(f)(2)(ii)(I)') :-
	wm(s164_504f2iiI_notFeasible(GHP,PlanSponsor,Purpose,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      not(UsageOrDisclosure),
	      '164.504(f)(2)(ii)(I)')) :-
	about(PHI,Individual),
	wm(s164_504f2iiI_notFeasible(GHP,PlanSponsor,Purpose,UsageOrDisclosure,PHI)).
s164_504f2ii_amendments(GHP,
			PlanSponsor,
			minimizes(PlanSponsor,UsageOrDisclosure)) :-
	wm(s164_504f2iiI_notFeasible(GHP,PlanSponsor,Purpose,UsageOrDisclosure,PHI)).

s164_504f2iiiA(GHP,PlanSponsor,Employee,PHI) :-
	isGroupHealthPlan(GHP),
	isEmployeeOf(Employee, PlanSponsor),
	isPlanSponsor(PlanSponsor,GHP),
	access(Employee,PHI),
	isPHI(PHI),
       	add_to_wm(s164_504f2iiiA(GHP,PlanSponsor,Employee,PHI)).
obligation(GHP,
	   contains(planDocuments(GHP), Employee),
	   '164.504(f)(2)(iii)(A)') :-
	wm(s164_504f2iiiA(GHP,PlanSponsor,Employee,PHI)).
implied(right(Individual,
	      knows(Individual,Employee),
	      '164.504(f)(2)(iii)(A)')) :-
	wm(s164_504f2iiiA(GHP,PlanSponsor,Employee,PHI)).

s164_504f2iiiB(GHP,PlanSponsor,Employee,PHI) :-
	isGroupHealthPlan(GHP),
	isEmployeeOf(Employee, PlanSponsor),
	isPlanSponsor(PlanSponsor,GHP),
	access(Employee,PHI),
	isPHI(PHI),
       	add_to_wm(s164_504f2iiiB(GHP,PlanSponsor,Employee,PHI)).
obligation(GHP,
	   contains(planDocuments(GHP),
		    restricts(PlanSponsor,
			      to(access(Employee,PHI),
				 administrativeTasks(GHP)))),
	   '164.504(f)(2)(iii)(B)') :-
	wm(s164_504f2iiiB(GHP,PlanSponsor,Employee,PHI)).
implied(right(Individual,
	      not(for(access(Employee,PHI),
		      Purpose)),
	      '164.504(f)(2)(iii)(B)')) :-
	about(PHI,Individual),
	Purpose \= administrativeTasks(GHP),
	wm(s164_504f2iiiB(GHP,PlanSponsor,Employee,PHI)).

s164_504f2iiiC(GHP,PlanSponsor,Action,Source,PHI) :-
	isGroupHealthPlan(GHP),
	isEmployeeOf(Employee, PlanSponsor),
	isPlanSponsor(PlanSponsor,GHP),
	access(Employee,PHI),
	isPHI(PHI),
	causes(Employee, inNonCompliance(Action,Source)),
       	add_to_wm(s164_504f2iiiC(GHP,PlanSponsor,Action,Source,PHI)).
obligation(GHP,
	   contains(planDocuments(GHP),
		    provides(PlanSponsor,
			     for(mechanism,
				 resolves(PlanSponsor,
					  inNonCompliance(Action,Source))))),
	   '164.504(f)(2)(iii)(C)') :- 
	wm(s164_504f2iiiC(GHP,PlanSponsor,Action,Source,PHI)).
implied(right(Individual,
	      provides(PlanSponsor,
		       for(mechanism,
			   resolves(PlanSponsor,
				    inNonCompliance(Action,Source)))),
	      '164.504(f)(2)(iii)(C)')) :- 
	about(PHI,Individual),
	wm(s164_504f2iiiC(GHP,PlanSponsor,Action,Source,PHI)).

s164_504f3i(GHP,PlanSponsor,PHI) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	add_to_wm(s164_504f3i(GHP,PlanSponsor,PHI)).
privilege(GHP,
	  for(discloses(GHP,PlanSponsor,PHI),
	      administrativeTasks(GHP)),
	  '164.504(f)(3)(i)') :-
	wm(s164_504f3i(GHP,PlanSponsor,PHI)).
implied(noRight(Individual,
	        right(Individual,
		      not(for(discloses(GHP,PlanSponsor,PHI),
			      administrativeTasks(GHP))),
		      _),
		'164.504(f)(3)(i)')) :-
	wm(s164_504f3i(GHP,PlanSponsor,PHI)).
obligation(GHP,
	   not(for(discloses(GHP,PlanSponsor,PHI),
		   administrativeTasks(GHP))),
	   '164.504(f)(3)(i)') :-
	isSubsectionOf(Source,'164.504(f)(2)'),
	obligation(GHP,X,Source),
	wm(s164_504f3i(GHP,PlanSponsor,PHI)).

s164_504f3ii_exception(GHP,
		       PlanSponsor,
		       PHI,
		       for(discloses(GHP,PlanSponsor,PHI),
			   administrativeTasks(GHP))).
s164_504f3ii(GHP,PlanSponsor,HIIorHMO,Purpose,PHI) :-
	isGroupHealthPlan(GHP),
	isHealthInsuranceIssuerOrHMO(HIIorHMO),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	s164_504f3ii_exception(GHP,PlanSponsor,PHI,Purpose),
	add_to_wm(s164_504f3ii(GHP,PlanSponsor,HIIorHMO,Purpose)).
obligation(GHP,
	   not(for(discloses(HIIorHMO,PlanSponsor,PHI),
		   Purpose)),
	   '164.504(f)(3)(ii)') :-
	wm(s164_504f3ii(GHP,PlanSponsor,HIIorHMO,Purpose,PHI)).

% cross reference to 164.520(b)(1)(iii)(C) in '164.504(f)(3)(iii)'

s164_504f3iv(GHP,PlanSponsor,PHI) :-
	isGroupHealthPlan(GHP),
	isPlanSponsor(PlanSponsor,GHP),
	isPHI(PHI),
	add_to_wm(s164_504f3iv(GHP,PlanSponsor,PHI)).
obligation(GHP,
	   not(for(discloses(GHP,PlanSponsor,PHI), employmentActions)), 
	   '164.504(f)(3)(iv)') :-
	wm(s164_504f3iv(GHP,PlanSponsor,PHI)).
implied(right(Individual,
	      not(for(discloses(GHP,PlanSponsor,PHI), employmentActions)), 
	      '164.504(f)(3)(iv)')) :-
	about(PHI,Individual),
	wm(s164_504f3iv(GHP,PlanSponsor,PHI)).      

s164_504g2_healthPlanService(CE,HealthPlanService,HealthcareProviderService,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	performsMultipleCoveredFunctions(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	receives(Individual,CE,HealthPlanService),
	isHealthPlanService(HealthPlanService),
	not(receives(Individual,CE,HealthcareProviderService)),
	isHealthcareProviderService(HealthcareProviderService),
	add_to_wm(s164_504g2_healthPlanService(CE,HealthPlanService,HealthcareProviderService,UsageOrDisclosure,PHI)).
privilege(CE,
	  only(for(UsageOrDisclosure,
		   HealthPlanService)),
	  '164.504(g)(2)') :-
	wm(s164_504g2_healthPlanService(CE,HealthPlanService,HealthcareProviderService,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(UsageOrDisclosure),
		      _),
		'164.504(g)(2)')) :-
	wm(s164_504g2_healthPlanService(CE,HealthPlanService,HealthcareProviderService,UsageOrDisclosure,PHI)).
s164_504g2_providerService(CE,HealthPlanService,HealthcareProviderService,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	performsMultipleCoveredFunctions(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	not(receives(Individual,CE,HealthPlanService)),
	isHealthPlanService(HealthPlanService),
	receives(Individual,CE,HealthcareProviderService),
	isHealthcareProviderService(HealthcareProviderService),
	add_to_wm(s164_504g2_providerService(CE,HealthPlanService,HealthcareProviderService,UsageOrDisclosure,PHI)).
privilege(CE,
	  only(for(UsageOrDisclosure,
		   HealthcareProviderService)),
	  '164.504(g)(2)') :-
	wm(s164_504g2_providerService(CE,HealthPlanService,HealthcareProviderService,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(UsageOrDisclosure),
		      _),
		'164.504(g)(2)')) :-
	wm(s164_504g2_providerService(CE,HealthPlanService,HealthcareProviderService,UsageOrDisclosure,PHI)).

% eof
