% Models section 164.506 of the HIPAA Privacy Rule

s164_506a(CE,UsageOrDisclosure,PHI,TPO) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	valid_HIPAA_TPO(TPO),
	not(s164_506a_exception(CE,UsageOrDisclosure)),
	add_to_wm(wm(s164_506a(CE,UsageOrDisclosure,PHI,TPO))).
privilege(CE, for(UsageOrDisclosure,TPO), '164.506(a)') :-
	wm(s164_506a(CE,UsageOrDisclosure,PHI,TPO)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,TPO)),
		      _),
		'164.506(a)')) :-
	wm(s164_506a(CE,UsageOrDisclosure,PHI,TPO)).
s164_506a_exception(CE,UsageOrDisclosure) :-
	under(requires(CE,
		       obtains(CE,
			       Individual,
			       authorizes(Individual,
					  CE,
					  for(UsageOrDisclosure,
					      _)))),
	      '164.508(a)(2)').
s164_506a_exception(CE,UsageOrDisclosure) :-
	under(requires(CE,
		       obtains(CE,
			       Individual,
			       authorizes(Individual,
					  CE,
					  for(UsageOrDisclosure,
					      _)))),
	      '164.508(a)(3)').

s164_506b1(CE,Individual,UsageOrDisclosure,TPO,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	valid_HIPAA_TPO(TPO),
	isHIPAAIndividual(Individual),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	add_to_wm(s164_506b1(CE,Individual,UsageOrDisclosure,TPO,PHI)).
privilege(CE,
	  obtains(CE,
		  consents(Individual,
			   for(UsageOrDisclosure,
			       TPO))),
	  '164.506(b)(1)') :-
	wm(s164_506b1(CE,Individual,UsageOrDisclosure,TPO,PHI)).
implied(noRight(Individual,
		right(Individual,
		      consents(Individual,
			       for(UsageOrDisclosure)),
		      _),
		'164.506(b)(1)')) :-
	about(PHI,Individual),
	wm(s164_506b1(CE,Individual,UsageOrDisclosure,TPO,PHI)).

s164_506b2(CE, Individual, UsageOrDisclosure,PHI, TPO) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	valid_HIPAA_TPO(TPO),
	isHIPAAIndividual(Individual),
	under(requires(CE,
		       obtains(CE,
			       Individual,
			       authorizes(Individual,
					  CE,
					  for(UsageOrDisclosure,
					      _)))),
	      '164.508(a)(3)'),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	add_to_wm(wm(s164_506b2(CE,Individual,UsageOrDisclosure,PHI,TPO))).
notEffective(consents(Individual, for(UsageOrDisclosure, TPO))) :-
	wm(s164_506b2(CE,Individual,UsageOrDisclosure,PHI,TPO)).

s164_506c1(CE,TPO,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	valid_HIPAA_TPO(TPO),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	add_to_wm(s164_506c1(CE,TPO,UsageOrDisclosure,PHI)).
privilege(CE,
	  for(UsageOrDisclosure,TPO),
	  '164.506(c)(1)') :-
	wm(s164_506c1(CE,TPO,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,TPO)),
		      _),
		'164.506(c)(1)')) :-
	about(PHI,Individual),
	wm(s164_506c1(CE,TPO,UsageOrDisclosure,PHI)).

s164_506c2(CE,HealthCareProvider,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isHealthcareProvider(HealthCareProvider),
	add_to_wm(wm(s164_506c2(CE,HealthCareProvider,PHI))).
privilege(CE,
	  for(discloses(CE,HealthCareProvider,PHI),
	      treatment(HealthCareProvider)),
	  '164.506(c)(2)') :-
	wm(s164_506c2(CE,HealthCareProvider,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,HealthCareProvider,PHI),
			      treatment(HealthCareProvider))),
		      _),
		'164.506(c)(2)')) :-
	about(PHI,Individual),
	wm(s164_506c2(CE,HealthCareProvider,PHI)).

s164_506c3(CE,OtherCE,PHI) :-
	isCoveredEntity(CE),
	isCoveredEntity(OtherCE),
	isPHI(PHI),
	add_to_wm(wm(s164_506c3(CE,OtherCE,PHI))).
privilege(CE,
	  for(discloses(CE,OtherCE,PHI),
	      payment(OtherCE)),
	  '164.506(c)(3)') :-
	wm(s164_506c3(CE,OtherCE,PHI)).
privilege(CE,
	  for(discloses(CE,HealthCareProvider,PHI),
	      payment(HealthCareProvider)),
	  '164.506(c)(3)') :-
	isHealthcareProvider(HealthCareProvider),
	wm(s164_506c3(CE,HealthCareProvider,PHI)).
implied(noRight(Individual,
		right(Individual,
		      for(discloses(CE,OtherCE,PHI),
			  payment(OtherCE)),
		      _),
		'164.506(c)(3)')) :-
	about(PHI,Individual),
	wm(s164_506c3(CE,OtherCE,PHI)).
implied(noRight(Individual,
		right(Individual,
		      for(discloses(CE,HealthCareProvider,PHI),
			  payment(HealthCareProvider)),
		      _),
		'164.506(c)(3)')) :-
	about(PHI,Individual),
	isHealthcareProvider(HealthCareProvider),
	wm(s164_506c3(CE,HealthCareProvider,PHI)).

% TODO include all the activities stated in 164.501?
:- dynamic s164_506c4_purpose/4.

s164_506c4(CE,OtherCE,Purpose,PHI) :-
	isCoveredEntity(CE),
	isCoveredEntity(OtherCE),
	hasRelationship(CE,Individual),
	hasRelationship(OtherCE,Individual),
	about(PHI,Individual),
	(   about(PHI,hasRelationship(CE,Individual))
	    ; 
	    about(PHI,hasRelationship(OtherCE,Individual))
	),
	isPHI(PHI),
	s164_506c4_purpose(CE,OtherCE,PHI,Purpose),
	add_to_wm(s164_506c4(CE,OtherCE,Purpose,PHI)).
s164_506c4_purpose(CE,_,PHI,TPO) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	valid_HIPAA_TPO(TPO).
s164_506c4_purpose(CE,HealthCareProvider,PHI,treatment(HealthCareProvider)) :-
	isCoveredEntity(CE),
	isHealthcareProvider(HealthCareProvider),
	isPHI(PHI).
s164_506c4_purpose(_,OtherCE,_,detects(OtherCE,healthcareFraud)) :-
	isCoveredEntity(OtherCE).
privilege(CE,
	  for(discloses(CE,OtherCE,PHI),
	      Purpose),
	  '164.506(c)(4)') :-
	wm(s164_506c4(CE,OtherCE,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,OtherCE,PHI),
			      Purpose)),
		      _),
		'164.506(c)(4)')) :-
	about(PHI,Individual),
	wm(s164_506c4(CE,OtherCE,Purpose,PHI)).

s164_506c5(CE,OtherCE,PHI) :-
	isCoveredEntity(CE),
	isCoveredEntity(OtherCE),
	inOrganizedHealthcareArrangement(CE,OtherCE),
	isPHI(PHI),
	add_to_wm(s164_506c5(CE,OtherCE,PHI)).
privilege(CE,
	  for(discloses(CE,OtherCE,PHI),
	      healthcareOperations(OtherCE)),
	  '164.506(c)(5)') :-
	wm(s164_506c5(CE,OtherCE,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,OtherCE,PHI),
			      healthcareOperations(OtherCE))),
		      _),
		'164.506(c)(5)')) :-
	about(PHI,Individual),
	wm(s164_506c5(CE,OtherCE,PHI)).

% eof
