﻿% Models section 164.508 of the HIPAA Privacy Rule

:- style_check(-atom).

s164_508a1(CE,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	not(obtains(CE, authorizes(Individual,CE,UsageOrDisclosure))),
	about(PHI,Individual),
	add_to_wm(s164_508a1(CE,Individual,UsageOrDisclosure,PHI)).
obligation(CE,
	   not(UsageOrDisclosure),
	   '164.508(a)(1)') :-
	wm(s164_508a1(CE,Individual,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      authorizes(Individual,CE,UsageOrDisclosure),
	      '164.508(a)(1)')) :-
	wm(s164_508a1(CE,Individual,UsageOrDisclosure,PHI)).
s164_508a1_consistent(CE,
		      Individual,
		      UsageOrDisclosure,
		      AuthorizedUsageOrdDisclosure,
		      PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	obtains(CE, authorizes(Individual,CE,AuthorizedUsageOrdDisclosure)),
	about(PHI,Individual),
	add_to_wm(s164_508a1_consistent(CE,
					Individual,
					UsageOrDisclosure,
					AuthorizedUsageOrdDisclosure,
					PHI)).
obligation(CE,
	   areConsistent(UsageOrDisclosure,
			 AuthorizedUsageOrdDisclosure),
	   '164.508(a)(1)') :-
	wm(s164_508a1_consistent(CE,
				 Individual,
				 UsageOrDisclosure,
				 AuthorizedUsageOrdDisclosure,
				 PHI)).
implied(right(Individual,
	      not(UsageOrDisclosure),
	      '164.508(a)(1)')) :-
	not(areConsistent(UsageOrDisclosure,
			  AuthorizedUsageOrdDisclosure)),
	wm(s164_508a1_consistent(CE,
				 Individual,
				 UsageOrDisclosure,
				 AuthorizedUsageOrdDisclosure,
				 PHI)).

s164_508a2(CE,Individual,Purpose,UsageOrDisclosure,PsychotherapyNotes) :-
	isCoveredEntity(CE),
	arePsychotherapyNotes(PsychotherapyNotes),
	about(PsychotherapyNotes,Individual),
	isUsageOrDisclosure(CE,_,PsychotherapyNotes,UsageOrDisclosure),
	not(s164_508a2_exception(CE,UsageOrDisclosure,Purpose)),
	not((    privilege(CE,UsageOrDisclosure,Section),
		 isSubsectionOf(Section,'164.532')
	    )),
	add_to_wm(s164_508a2(CE,
			     Individual,
			     Purpose,
			     UsageOrDisclosure,
			     PsychotherapyNotes)).

s164_508a2_exception(CE,_,treatment(CE)).
s164_508a2_exception(CE,_,trainingPrograms(CE)).
s164_508a2_exception(CE,_,defends(CE,legalAction(Individual,CE))).
obligation(CE,
	   obtains(CE,
		   authorizes(Individual,
			      CE,
			      for(UsageOrDisclosure,
				  Purpose))),
	   '164.508(a)(2)') :-
	wm(s164_508a2(CE,Individual,Purpose,UsageOrDisclosure,PsychotherapyNotes)).
implied(right(Individual,
	      authorizes(Individual,
			 CE,
			 for(UsageOrDisclosure,
			    Purpose)),
	      '164.508(a)(2)')) :-
	wm(s164_508a2(CE,Individual,Purpose,UsageOrDisclosure,PsychotherapyNotes)).
power(Individual,
      for(UsageOrDisclosure, Purpose),
      authorizes(Individual,
			 CE,
			 for(UsageOrDisclosure,
			    Purpose)),
      '164.508(a)(2)') :-
	wm(s164_508a2(CE,Individual,Purpose,UsageOrDisclosure,PsychotherapyNotes)).
implied(liability(CE,
		  not(for(UsageOrDisclosure,Purpose)),
		  '164.508(a)(2)')) :-
	not(authorizes(Individual,
			 CE,
			 for(UsageOrDisclosure,
			     Purpose))),
	wm(s164_508a2(CE,Individual,Purpose,UsageOrDisclosure,PsychotherapyNotes)).

% TODO handle recursive call
s164_508a2_exception(CE,UsageOrDisclosure,_) :-
	obligation(CE,UsageOrDisclosure,'164.502(a)(2)(ii)').
	
s164_508a2_exception(CE,UsageOrDisclosure,_) :-
	privilege(CE,UsageOrDisclosure,Source),
	isSubsectionOf(Source,'164.512(a)').
s164_508a2_exception(CE,UsageOrDisclosure,_) :-
	privilege(CE,UsageOrDisclosure,Source),
	isSubsectionOf(Source,'164.512(d)').
s164_508a2_exception(CE,UsageOrDisclosure,_) :-
	privilege(CE,UsageOrDisclosure,Source),
	isSubsectionOf(Source,'164.512(g)(1)').
s164_508a2_exception(CE,UsageOrDisclosure,_) :-
	privilege(CE,UsageOrDisclosure,Source),
	isSubsectionOf(Source,'164.512(j)(1)(i)').

s164_508a3i(CE,Individual,Marketing,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	not(s164_508a3i_exception(CE,Individual,Marketing)),
	add_to_wm(s164_508a3i(CE,Individual,Marketing,UsageOrDisclosure,PHI)).
s164_508a3i_exception(CE,Individual,face2face(markets(CE,Individual))).
s164_508a3i_exception(CE,Individual,receives(Individual,CE,gift)) :-
	nominalValue(gift).
obligation(CE,
	   obtains(CE,
		   authorizes(Individual,
			      CE,
			      for(UsageOrDisclosure, Marketing))),
	   '164.508(a)(3)(i)') :-
	wm(s164_508a3i(CE,Individual,Marketing,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      authorizes(Individual,
			 CE,
			 for(UsageOrDisclosure, Marketing)),
	      '164.508(a)(3)(i)')) :-
	wm(s164_508a3i(CE,Individual,Marketing,UsageOrDisclosure,PHI)).
power(Individual,
      for(UsageOrDisclosure, Marketing),
      authorizes(Individual,
			 CE,
			 for(UsageOrDisclosure, Marketing)),
	      '164.508(a)(3)(i)') :-
	wm(s164_508a3i(CE,Individual,Marketing,UsageOrDisclosure,PHI)).
implied(liability(CE,
		  not(for(UsageOrDisclosure, Marketing)),
		  '164.508(a)(3)(i)')) :-
	not(authorizes(Individual,
			 CE,
			 for(UsageOrDisclosure, Marketing))),
	wm(s164_508a3i(CE,Individual,Marketing,UsageOrDisclosure,PHI)).

s164_508a3ii(CE,Individual,ThirdParty) :-
	from(receives(CE,ThirdParty,renumeration), markets(CE,Individual)),
	isCoveredEntity(CE),
	isHIPAAIndividual(Individual),
	add_to_wm(s164_508a3ii(CE,Individual,ThirdParty)).
obligation(CE,
	   contains(authorization(Individual,CE,_),
		    receives(CE,ThirdParty,renumeration)),
	   '164.508(a)(3)(ii)') :-
	wm(s164_508a3ii(CE,Individual,ThirdParty)).
implied(right(Individual,
	      knows(receives(CE,ThirdParty,renumeration)),
	      '164.508(a)(3)(ii)')) :-
	wm(s164_508a3ii(CE,Individual,ThirdParty)).

valid(authorization(Individual,CE,ActionAuthorized)) :-
	wm(s164_508a3ii(CE,Individual,_)),
        wm(s164_508c1(CE,Individual,Element)),
	wm(s164_508c2(CE,Individual,Element)).

s164_508b1ii(CE,Individual,ActionAuthorized,AdditionalElements) :-
	areConsistent(AdditionalElements,
		      RequiredElement),
	obligation(CE,
		   contains(authorization(Individual,
					  CE,
					  ActionAuthorized),
			    RequiredElement),
		   Source),
	isSubsectionOf(Source,'164.508'),
	isCoveredEntity(CE),
	add_to_wm(s164_508b1ii(CE,Individual,ActionAuthorized,AdditionalElements)).
privilege(CE,
	  contains(authorization(Individual,CE,ActionAuthorized),
		   AdditionalElements),
	  '164.508(b)(1)(ii)') :-
	wm(s164_508b1ii(CE,Individual,ActionAuthorized,AdditionalElements)).
implied(noRight(Individual,
		right(Individual,
		      not(contains(authorization(Individual,CE,Authorization),
				   AdditionalElements)),
		      _),
		'164.508(b)(1)(ii)')) :-
	wm(s164_508b1ii(CE,Individual,ActionAuthorized,AdditionalElements)).

invalid(authorization(Individual,CE,ActionAuthorized)) :-
	after(currentDate,
	      expirationDate(authorization(Individual,CE,ActionAuthorized))),
	isCoveredEntity(CE),
	isHIPAAIndividual(Individual),
	add_to_wm(s164_508b2i(CE,Individual,ActionAuthorized)).
invalid(authorization(Individual,CE,ActionAuthorized)) :-
	knows(CE,
	      after(expirationEvents,
		    expirationDate(authorization(Individual,CE,ActionAuthorized)))),
	isCoveredEntity(CE),
	isHIPAAIndividual(Individual),
	add_to_wm(s164_508b2i(CE,Individual,ActionAuthorized)).

invalid(authorization(Individual,CE,ActionAuthorized)) :-
	incomplete(authorization(Individual,CE,ActionAuthorized)),
	isCoveredEntity(CE),
	isHIPAAIndividual(Individual),
	add_to_wm(s164_508b2ii(CE,Individual,ActionAuthorized)).

invalid(authorization(Individual,CE,ActionAuthorized)) :-
	knows(CE,
	      terminates(Individual,
			 authorization(Individual,CE,ActionAuthorized))),
	isCoveredEntity(CE),
	isHIPAAIndividual(Individual),
	add_to_wm(s164_508b2iii(CE,Individual,ActionAuthorized)).

% Forward ref to b3 and b4 at 164.508(b)(2)(iv)

invalid(authorization(Individual,CE,ActionAuthorized)) :-
	knows(CE,
	      incorrect(authorization(Individual,CE,ActionAuthorized))),
	isCoveredEntity(CE),
	isHIPAAIndividual(Individual),
	add_to_wm(s164_508b2v(CE,Individual,ActionAuthorized)).

s164_508b3(CE,Individual,ActionAuthorized,OtherDocument) :-
	not(s164_508b3_exception(CE,Individual,ActionAuthorized,OtherDocument)),
	isCoveredEntity(CE),
	add_to_wm(s164_508b3(CE,Individual,ActionAuthorized,OtherDocument)).
obligation(CE, 
	   not(combined(authorization(Individual,CE,ActionAuthorized),
			OtherDocument)),
	   '164.508(b)(3)') :-
	wm(s164_508b3(CE,Individual,ActionAuthorized,OtherDocument)).
implied(right(Individual,
	      not(combined(authorization(Individual,CE,ActionAuthorized),
			   OtherDocument)),
	      '164.508(b)(3)')) :-
	wm(s164_508b3(CE,Individual,ActionAuthorized,OtherDocument)).

s164_508b3i(CE,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	about(PHI,Individual),
	add_to_wm(s164_508b3i(CE,Individual,PHI)).
s164_508b3_exception(CE,
		     Individual,
		     for(UsageOrDisclosure, research),
		     consent(Individual, CE, participates(Individual,research))) :-
	wm(s164_508b3i(CE,Individual,UsageOrDisclosure,PHI)).
privilege(CE,
	  combined(authorization(Individual,CE,for(UsageOrDisclosure, research)),
		   consent(Individual, CE, participates(Individual,research))),
	  '164.508(b)(3)(i)') :-
	wm(s164_508b3i(CE,Individual,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(combined(authorization(Individual,
						 CE,
						 for(UsageOrDisclosure, research)),
				   consent(Individual,
					   CE,
					   participates(Individual,research)))),
		      _),
		'164.508(b)(3)(i)')) :-
	wm(s164_508b3i(CE,Individual,UsageOrDisclosure,PHI)).

s164_508b3ii(CE,Individual,UsageOrDisclosure,PsychotherapyNotes) :-
	isCoveredEntity(CE),
	arePsychotherapyNotes(PsychotherapyNotes),
	about(PsychotherapyNotes,Individual),
	isUsageOrDisclosure(CE,_,PsychotherapyNotes,UsageOrDisclosure),
	add_to_wm(s164_508b3ii(CE,Individual,UsageOrDisclosure,PsychotherapyNotes)).
s164_508b3_exception(CE,
		     Individual,
		     UsageOrDisclosure,
		     authorization(Individual,CE,UsageOrDisclosure)) :-
	wm(s164_508b3ii(CE,Individual,UsageOrDisclosure,PsychotherapyNotes)).
privilege(CE,
	  combined(authorization(Individual,CE,UsageOrDisclosure),
		   authorization(Individual,CE,UsageOrDisclosure)),
	  '164.508(b)(3)(ii)') :-
	wm(s164_508b3ii(CE,Individual,UsageOrDisclosure,PsychotherapyNotes)).
implied(noRight(Individual,
		right(Individual,
		      not(combined(authorization(Individual,CE,UsageOrDisclosure),
				   authorization(Individual,CE,UsageOrDisclosure))),
		      _),
		'164.508(b)(3)(ii)')) :-
	wm(s164_508b3ii(CE,Individual,UsageOrDisclosure,PsychotherapyNotes)).
obligation(CE,
	   not(combined(authorization(Individual,CE,UsageOrDisclosure),
			X)),
	   '164.508(b)(3)(ii)') :-
	X \= authorization(Individual,CE,UsageOrDisclosure),
	wm(s164_508b3ii(CE,Individual,UsageOrDisclosure,PsychotherapyNotes)).
implied(right(Individual,
	      not(combined(authorization(Individual,CE,UsageOrDisclosure),
			   X)),
	      '164.508(b)(3)(ii)')) :-
	X \= authorization(Individual,CE,UsageOrDisclosure),
	wm(s164_508b3ii(CE,Individual,UsageOrDisclosure,PsychotherapyNotes)).

s164_508b3iii(CE,Individual,X,Y) :-
	authorization(Individual,CE,X),
	authorization(Individual,CE,Y),
	not(s164_508b3iii_exception(CE,Individual,X)),
	not(s164_508b3iii_exception(CE,Individual,Y)),
	isCoveredEntity(CE),
	not(isConditionOf(authorization(Individual,CE,X),
			  Paragragh_b4_Action)),
	s164_508b4_use(CE, Individual,Paragragh_b4_Action),
	add_to_wm(s164_508b3iii(CE,Individual,X,Y)).
s164_508b3iii_exception(CE,Individual,UsageOrDisclosure) :-
	isCoveredEntity(CE),
	arePsychotherapyNotes(PsychotherapyNotes),
	about(PsychotherapyNotes,Individual),
	isUsageOrDisclosure(CE,_,PsychotherapyNotes,UsageOrDisclosure).
s164_508b3_exception(CE,
		     Individual,
		     X,
		     Y) :-
	s164_508b3iii(CE,Individual,X,Y).
privilege(CE,
	  combined(authorization(Individual,CE,X),
		   authorization(Individual,CE,Y)),
	  '164.508(b)(3)(iii)') :-
	wm(s164_508b3iii(CE,Individual,X,Y)).
implied(noRight(Individual,
		right(Individual,
		      not(combined(authorization(Individual,CE,X),
				   authorization(Individual,CE,Y))),
		      _),
		'164.508(b)(3)(iii)')) :-
	wm(s164_508b3iii(CE,Individual,X,Y)).

s164_508b4(CE,Individual,Condition,Use) :-
	not(s164_508b4_exception(CE, Condition, Use)),
	isCoveredEntity(CE),
	s164_508b4_use(CE,Individual,Use),
	add_to_wm(s164_508b4(CE,Individual,Condition,Use)).
s164_508b4_use(CE, _, treatment(CE)).
s164_508b4_use(CE, _, payment(CE)).
s164_508b4_use(HP, Individual, enrolled(Individual,HP)) :-
	isHealthPlan(HP).
s164_508b4_use(CE, Individual, eligible(Individual,healthBenefits(CE))).
obligation(CE,
	   not(isConditionOf(authorization(Individual,CE,_),Use)),
	   '164.508(b)(4)') :-
	wm(s164_508b4(CE,Individual,authorization(Individual,CE,_),Use)).
implied(right(Individual,
	      without(Use,
		      authorization(Individual,CE,_)),
	      '164.508(b)(4)')) :-
	wm(s164_508b4(CE,Individual,authorization(Individual,CE,_),Use)).

s164_508b4i(HealthcareProvider, Individual, research, treatment(HealthcareProvider)) :-
	isHealthcareProvider(HealthcareProvider),
	isRelatedTo(research, treatment(HealthcareProvider)),
        add_to_wm(s164_508b4i(HealthcareProvider,Individual,research,treatment(HealthcareProvider))).
s164_508b4_exception(HealthcareProvider,
		     authorization(Individual,HealthcareProvider,research),
		     treatment(HealthcareProvider)) :-
	wm(s164_508b4i(HealthcareProvider,Individual,research,treatment(HealthcareProvider))).
privilege(HealthcareProvider,
	  isConditionOf(authorization(Individual,HealthcareProvider,research),
			treatment(HealthcareProvider)),
	  '164.508(b)(4)(i)') :-
	wm(s164_508b4i(HealthcareProvider,Individual,research,treatment(HealthcareProvider))).
implied(noRight(Individual,
		right(Individual,
		      without(treatment(HealthcareProvider),
			      authorization(Individual,HealthcareProvider,research)),
		      _),
		'164.508(b)(4)(i)')) :-
	wm(s164_508b4i(HealthcareProvider,Individual,research,treatment(HealthcareProvider))).

s164_508b4iiA(HealthPlan,Individual) :-
	for(requests(HealthPlan,
		     Individual,
		     authorization(Individual,
				   HealthPlan,
				   determines(HealthPlan,
					      eligible(Individual,HealthPlan))
		                   )),
	    underwriting(HealthPlan)
	),
	isHealthPlan(HealthPlan),
	not((for(authorization(Individual,
			      HealthPlan,
			      determines(HealthPlan,
					 eligible(Individual,HealthPlan))
		              ),
		uses(HealthPlan,PsychotherapyNotes)),
	    arePsychotherapyNotes(PsychotherapyNotes),
	    about(PsychotherapyNotes,Individual))
	),
	not((for(authorization(Individual,
			      HealthPlan,
			      determines(HealthPlan,
					 eligible(Individual,HealthPlan))
		              ),
		discloses(HealthPlan,_,PsychotherapyNotes)),
	    arePsychotherapyNotes(PsychotherapyNotes),
	    about(PsychotherapyNotes,Individual))
	),
	not(wm(s164_508a2(HealthPlan,
			  Individual,
			  determines(HealthPlan,
					   eligible(Individual,HealthPlan)),
			  UsageOrDisclosure,
			  PsychotherapyNotes))),
	isUsageOrDisclosure(HealthPlan,_,PHI,UsageOrDisclosure),
	isPHI(PHI),
	add_to_wm(s164_508b4iiA(HealthPlan,Individual)).
s164_508b4_exception(HealthPlan,
		     authorization(Individual,
				   HealthPlan,
				   determines(HealthPlan,
					      eligible(Individual,HealthPlan))
		                   ),
		     determines(HealthPlan,eligible(Individual,HealthPlan))) :-
	wm(s164_508b4iiA(HealthPlan,Individual)).
privilege(HealthPlan,
	  isConditionOf(authorization(Individual,
				      HealthPlan,
				      determines(HealthPlan,
						 eligible(Individual,HealthPlan))),
			enrolled(Individual,HealthPlan)),
	  '164.508(b)(4)(ii)(A)') :-
	wm(s164_508b4iiA(HealthPlan,Individual)).
implied(noRight(Individual,
		right(Individual,
		      without(enrolled(Individual,HealthPlan),
			      authorization(Individual,
					    HealthPlan,
					    determines(HealthPlan,
						       eligible(Individual,HealthPlan)))),
		      _),
		 '164.508(b)(4)(ii)(A)')) :-
	wm(s164_508b4iiA(HealthPlan,Individual)).

s164_508b4iii(CE,ThirdParty,Individual,PHI) :-
	only(for(creates(CE,PHI),
		 discloses(CE,ThirdParty,PHI))),
	isCoveredEntity(CE),
        isPHI(PHI),
	add_to_wm(s164_508b4iii(CE,ThirdParty,Individual,PHI)).
privilege(CE,
	  isConditionOf(authorization(Individual,
				      CE,
				      discloses(CE,ThirdParty,PHI)),
			healthcare(CE,Individual)),
	  '164.508(b)(4)(iii)') :-
	wm(s164_508b4iii(CE,ThirdParty,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      without(healthcare(CE,Individual),
			      authorization(Individual,
					    CE,
					    discloses(CE,ThirdParty,PHI))),
		      _),
		'164.508(b)(4)(iii)')) :-
	wm(s164_508b4iii(CE,ThirdParty,Individual,PHI)).

s164_508b5(CE,Individual,AuthorizedAction) :-
	authorizes(Individual,CE,AuthorizedAction),
	isCoveredEntity(CE),
	written(revokes(Individual,
 	                authorization(Individual,
			              CE,
				      AuthorizedAction))
	),
	not(after(revokes(Individual,
			  authorization(Individual,
					   CE,
					   AuthorizedAction)),
		  AuthorizedAction)),
	add_to_wm(s164_508b5(CE,Individual,AuthorizedAction)).
power(Individual,
      authorization(Individual,CE,AuthorizedAction),
      revokes(Individual,
	      authorization(Individual,CE,AuthorizedAction)),
    '164.508(b)(5)') :-
	wm(s164_508b5(CE,Individual,AuthorizedAction)).
implied(liability(CE,
		  not(prevents(CE,
			       revokes(Individual,
				       authorization(Individual,
						     CE,
						     AuthorizedAction)))),
		  '164.508(b)(5)')) :-
	wm(s164_508b5(CE,Individual,AuthorizedAction)).

s164_508b6(CE,Individual,AuthorizedAction) :-
	signs(Individual,
	      authorization(Individual,
			    CE,
			    AuthorizedAction)),
	isCoveredEntity(CE),
	add_to_wm(s164_508b6(CE,Individual,AuthorizedAction)).
obligation(CE,
	   documents(CE,
		     authorization(Individual,
				   CE,
				   AuthorizedAction)),
	   '164.508(b)(6)') :-
	wm(s164_508b6(CE,Individual,AuthorizedAction)).
% TODO add implied right
obligation(CE,
	   maintains(CE,
		     authorization(Individual,
				   CE,
				   AuthorizedAction)),
	   '164.508(b)(6)') :-
	wm(s164_508b6(CE,Individual,AuthorizedAction)).
% TODO add implied right

s164_508c1(CE,Individual,Element) :-
	isCoveredEntity(CE),
	isRequiredAuthorizationElement(Element),
	add_to_wm(s164_508c1(CE,Individual,Element)).
obligation(CE,
	   contains(authorization(Individual,
				  CE,
				  AuthorizedAction),
		    Element),
	   '164.508(c)(1)') :-
	wm(s164_508c1(CE,Individual,Element)).
implied(right(Individual,
	      knows(Individual,Element),
	      '164.508(c)(1)')) :-
	wm(s164_508c1(CE,Individual,Element)).

isRequiredAuthorizationElement('A description of the information to be used or disclosed that identifies the information in a specific and meaningful fashion.').
isRequiredAuthorizationElement('The name or other specific identification of the person(s), or class of persons, authorized to make the requested use or disclosure.').
isRequiredAuthorizationElement('The name or other specific identification of the person(s), or class of persons, to whom the covered entity may make the requested use or disclosure.').
isRequiredAuthorizationElement('The name or other specific identification of the person(s), or class of persons, to whom the covered entity may make the requested use or disclosure.').
isRequiredAuthorizationElement('A description of each purpose of the requested use or disclosure. The statement “at the request of the individual” is a sufficient description of the purpose when an individual initiates the authorization and does not, or elects not to, provide a statement of the purpose.').
isRequiredAuthorizationElement('An expiration date or an expiration event that relates to the individual or the purpose of the use or disclosure. The statement “end of the research study,” “none,” or similar language is sufficient if the authorization is for a use or disclosure of protected health information for research, including for the creation and maintenance of a research database or research repository.').
isRequiredAuthorizationElement('Signature of the individual and date. If the authorization is signed by a personal representative of the individual, a description of such representative\'s authority to act for the individual must also be provided.').

s164_508c2(CE,Individual,Element) :-
	isCoveredEntity(CE),
	adequate(for(Element,notice)),
	isRequiredToPlaceIndividualOnNotice(Element),
	add_to_wm(s164_508c2(CE,Individual,Element)).
obligation(CE,
	   contains(authorization(Individual,
				  CE,
				  AuthorizedAction),
		    Element),
	   '164.508(c)(2)') :-
	wm(s164_508c2(CE,Individual,Element)).
implied(right(Individual,
	      knows(Individual,Element),
	      '164.508(c)(2)')) :-
	wm(s164_508c2(CE,Individual,Element)).

isRequiredToPlaceIndividualOnNotice('The individual\'s right to revoke the authorization in writing').
isRequiredToPlaceIndividualOnNotice('The exceptions to the right to revoke and a description of how the individual may revoke the authorization').
% forward ref to 164.520 at 164.508(c)(2)(i)(B)
isRequiredToPlaceIndividualOnNotice(xor(obligation(CE,
					     not(isConditionOf(Condition,
							       Use)),
					     '164.508(b)(4)'),
					'The consequences to the individual of a refusal to sign the authorization when, in accordance with paragraph (b)(4) of this section, the covered entity can condition treatment, enrollment in the health plan, or eligibility for benefits on failure to obtain such authorization.')) :-
	obligation(CE, not(isConditionOf(Condition,Use)), '164.508(b)(4)'),
	isCoveredEntity(CE).
isRequiredToPlaceIndividualOnNotice('The potential for information disclosed pursuant to the authorization to be subject to redisclosure by the recipient and no longer be protected by this subpart.').

s164_508c3(CE,Individual) :-
	isCoveredEntity(CE),
	add_to_wm(s164_508c3(CE,Individual)).
obligation(CE,
	   inPlainLanguage(authorization(Individual,
					 CE,
					 _)),
	   '164.508(c)(3)') :-
	wm(s164_508c3(CE,Individual)).
implied(right(Individual,
	      inPlainLanguage(authorization(Individual,
					    CE,
					    _)),
	      '164.508(c)(3)')) :-
	wm(s164_508c3(CE,Individual)).

s164_508c4(CE,Individual,AuthorizedAction) :-
	isCoveredEntity(CE),
	(for(authorization(Individual,
			  CE,
			  AuthorizedAction),
	    uses(CE,PHI))
	;
	for(authorization(Individual,
			  CE,
			  AuthorizedAction),
	    discloses(CE,_,PHI))
	),
	isPHI(PHI),
	add_to_wm(s164_508c4(CE,Individual,PHI,AuthorizedAction)).     
obligation(CE,
	   provides(CE,
		    Individual,
		    copy(signs(Individual,
			       authorization(Individual,
					     CE,
					     AuthorizedAction)))),
	   '164.508(c)(4)') :-
	wm(s164_508c4(CE,Individual,AuthorizedAction)).
implied(right(Individual,
	      receives(Individual,
		       CE,
		       copy(signs(Individual,
				  authorization(Individual,
						CE,
						AuthorizedAction)))),
	      '164.508(c)(4)')) :-
	wm(s164_508c4(CE,Individual,AuthorizedAction)).

% eof
