% Models section 164.510 of the HIPAA Privacy Rule

s164_510(CE,Individual,PHI,UsageOrDisclosure) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	(   privilege(CE,
		      for(UsageOrDisclosure,
			  _),
		      Section)
	    ; 
	    privilege(CE,UsageOrDisclosure,Section)
	),
	isSubsectionOf(Section,'164.510('),%
	add_to_wm(s164_510(CE,Individual,PHI,UsageOrDisclosure)).
isAgreementOrObjection(CE,Individual,PHI,UsageOrDisclosure,agrees(Individual,
								  UsageOrDisclosure)) :-
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure).
isAgreementOrObjection(CE,Individual,PHI,UsageOrDisclosure,objects(Individual,
								   UsageOrDisclosure)) :-
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure).
privilege(CE,
	  oral(informs(CE,
		       Individual,
		       UsageOrDisclosure)),
	  '164.510') :-
	wm(s164_510(CE,Individual,PHI,UsageOrDisclosure)).
implied(noRight(Individual,
		right(Individual,
		      written(informs(CE,
				      Individual,
				      UsageOrDisclosure)),
		      _),
		'164.510')) :-
	wm(s164_510(CE,Individual,PHI,UsageOrDisclosure)).
privilege(CE,
	  obtains(oral(AgreementOrObjection)),
	  '164.510') :-
	isAgreementOrObjection(CE,Individual,PHI,UsageOrDisclosure,AgreementOrObjection),
	wm(s164_510(CE,Individual,PHI,UsageOrDisclosure)).
implied(noRight(Individual,
		right(Individual,
		      written(AgreementOrObjection),
		      _),
		'164.510')) :-
	isAgreementOrObjection(CE,Individual,PHI,UsageOrDisclosure,AgreementOrObjection),
	wm(s164_510(CE,Individual,PHI,UsageOrDisclosure)).
	
s164_510a1i(HealthcareProvider,Individual,Info) :-
	about(Info,Individual),
        isHealthcareProvider(HealthcareProvider), % TODO change this to CHCP
	s164_510a1_info(Individual,Info),
	not(s164_510a1_exception(HealthcareProvider,Individual,Info)),
        add_to_wm(s164_510a1i(HealthcareProvider,Individual,Info)).
s164_510a1_info(X,name(X)).
s164_510a1_info(X,location(X)).
s164_510a1_info(X,generalCondition(X)).
s164_510a1_info(X,religiousAffiliation(X)).
privilege(HealthcareProvider,
	  for(uses(HealthcareProvider,
		   Info),
		   maintains(HealthcareProvider,
			     directory)),
	  '164.510(a)(1)(i)') :-
        wm(s164_510a1i(HealthcareProvider,Individual,Info)).
implied(noRight(Individual,
		right(Individual,
		      not(for(uses(HealthcareProvider,
				   Info),
				   maintains(HealthcareProvider,
					     directory))),
		      _),
		'164.510(a)(1)(i)')) :-
	wm(s164_510a1i(HealthcareProvider,Individual,Info)).
obligation(HealthcareProvider,
	   not(for(uses(HealthcareProvider,
			Info),
		   maintains(HealthcareProvider,
			     directory))),
	   '164.510(a)(1)(i)') :-
	treats(HealthcareProvider,Individual),
	isHIPAAIndividual(Individual),
	about(Info,Individual),
        isHealthcareProvider(HealthcareProvider),
	s164_510a1_info(Individual,Info),
	s164_510a1_exception(HealthcareProvider,Individual,Info),
        add_to_wm(s164_510a1i(HealthcareProvider,Individual,Info)).
implied(right(Individual,
	      not(for(uses(HealthcareProvider,
			   Info),
		      maintains(HealthcareProvider,
				directory))),
	      '164.510(a)(1)(i)')) :-
	treats(HealthcareProvider,Individual),
	isHIPAAIndividual(Individual),
	about(Info,Individual),
        isHealthcareProvider(HealthcareProvider),
	s164_510a1_info(Individual,Info),
	s164_510a1_exception(HealthcareProvider,Individual,Info),
        add_to_wm(s164_510a1i(HealthcareProvider,Individual,Info)).

s164_510a1iiA(HealthcareProvider,Individual,Info,Clergy) :-
        isHealthcareProvider(HealthcareProvider),
	s164_510a1_info(Individual,Info),
	about(Info,Individual),
	isClery(Clergy),
	not(s164_510a1_exception(HealthcareProvider,Individual,Info)),
	add_to_wm(s164_510a1iiA(HealthcareProvider,Individual,Info,Clergy)).
privilege(HealthcareProvider,
	  discloses(HealthcareProvider,
		    Clergy,
		    Info),
	  '164.510(a)(1)(ii)(A)') :-
	wm(s164_510a1iiA(HealthcareProvider,Individual,Info,Clergy)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(HealthcareProvider,
				    Clergy,
				    Info)),
		      _),
		'164.510(a)(1)(ii)(A)')) :-
	wm(s164_510a1iiA(HealthcareProvider,Individual,Info,Clergy)).

s164_510a1iiB(HealthcareProvider,Individual,Info,Visitor) :-
        isHealthcareProvider(HealthcareProvider),
	by(requests(Visitor,HealthcareProvider,Individual),
	   name(Individual)),
	s164_510a1iiB_info(Individual,Info),
       	about(Info,Individual),
	not(s164_510a1_exception(HealthcareProvider,Individual,Info)),
	add_to_wm(s164_510a1iiB(HealthcareProvider,Individual,Info,Visitor)).
s164_510a1iiB_info(X,name(X)).
s164_510a1iiB_info(X,location(X)).
s164_510a1iiB_info(X,generalCondition(X)).
privilege(HealthcareProvider,
	  discloses(HealthcareProvider,
		    Visitor,
		    Info),
	  '164.510(a)(1)(ii)(B)') :-
	wm(s164_510a1iiB(HealthcareProvider,Individual,Info,Visitor)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(HealthcareProvider,
				    Visitor,
				    Info)),
		      _),
		'164.510(a)(1)(ii)(B)')) :-
	wm(s164_510a1iiB(HealthcareProvider,Individual,Info,Visitor)).

s164_510a2(HealthcareProvider,Individual,UsageOrDisclosure,Info) :-
	isHealthcareProvider(HealthcareProvider),
	s164_510a1_info(Individual,Info),
	about(Info,Individual),
	isUsageOrDisclosure(HealthcareProvider,_,Info,UsageOrDisclosure),
	privilege(HealthcareProvider,
		  for(UsageOrDisclosure,
		      Info,
		      maintains(HealthcareProvider,
				directory)),
		  Section),
	isSubsectionOf(Section,'164.510(a)(1)'),
	add_to_wm(s164_510a2(HealthcareProvider,Individual,UsageOrDisclosure,Info)).
restrictsOrProhibits(HealthcareProvider,
		     Individual,
		     UsageOrDisclosure,
		     restricts(Individual,
			       for(UsageOrDisclosure,
				   maintains(HealthcareProvider,
					     directory)))).
restrictsOrProhibits(HealthcareProvider,
		     Individual,
		     UsageOrDisclosure,
		     prohibits(Individual,
			       for(UsageOrDisclosure,
				   maintains(HealthcareProvider,
					     directory)))).
s164_510a1_exception(HealthcareProvider,Individual,Info) :-
	restricts(Individual,
		  for(UsageOrDisclosure,
		      maintains(HealthcareProvider,
				directory))),
	wm(s164_510a2(HealthcareProvider,Individual,UsageOrDisclosure,Info)).
s164_510a1_exception(HealthcareProvider,Individual,Info) :-
	prohibits(Individual,
		  for(UsageOrDisclosure,
		      maintains(HealthcareProvider,
				directory))),
	wm(s164_510a2(HealthcareProvider,Individual,UsageOrDisclosure,Info)).
obligation(HealthcareProvider,
	   informs(HealthcareProvider,
		   Individual,
		   for(UsageOrDisclosure,
		       maintains(HealthcareProvider,
				 directory))),
	   '164.510(a)(2)') :-
	wm(s164_510a2(HealthcareProvider,Individual,UsageOrDisclosure,Info)).
implied(right(Individual,
	      notice(for(UsageOrDisclosure,
			 maintains(HealthcareProvider,
				   directory))),
	      '164.510(a)(2)')) :-
	wm(s164_510a2(HealthcareProvider,Individual,UsageOrDisclosure,Info)).
obligation(HealthcareProvider,
	   provides(HealthcareProvider,
		    Individual,
		    opportunity(RestrictsOrProhibits)),
	   '164.510(a)(2)') :-
	restrictsOrProhibits(HealthcareProvider,
			     Individual,
			     UsageOrDisclosure,
			     RestrictsOrProhibits),
	wm(s164_510a2(HealthcareProvider,Individual,UsageOrDisclosure,Info)).
implied(right(Individual,
	      RestrictsOrProhibits,
	      '164.510(a)(2)')) :-
	restrictsOrProhibits(HealthcareProvider,
			     Individual,
			     UsageOrDisclosure,
			     RestrictsOrProhibits),
	wm(s164_510a2(HealthcareProvider,Individual,UsageOrDisclosure,Info)).

s164_510a3i_knowsPreferences(HealthcareProvider,Individual,UsageOrDisclosure,Info) :-
	privilege(HealthcareProvider,
            for(UsageOrDisclosure,
	        maintains(HealthcareProvider,
		          directory)),
	    '164.510(a)(1)(i)'),
	isInEmergency(Individual),
	knows(HealthcareProvider,
	      prefers(Individual,
		      for(UsageOrDisclosure,
	                  maintains(HealthcareProvider,
		                    directory)))),
	areConsistent(prefers(Individual,
			      for(UsageOrDisclosure,
				  maintains(HealthcareProvider,
					    directory))),
		      for(UsageOrDisclosure,
			  maintains(HealthcareProvider,
				    directory))),
	determines(HealthcareProvider,
		   forBestInterest(for(UsageOrDisclosure,
				       maintains(HealthcareProvider,
						 directory)),
				   Individual)),
	isHealthcareProvider(HealthcareProvider),
	isUsageOrDisclosure(HealthcareProvider,_,Info,UsageOrDisclosure),
	s164_510a1_info(Individual,Info),
	add_to_wm(s164_510a3i_knowsPreferences(HealthcareProvider,Individual,UsageOrDisclosure,Info)).
privilege(HealthcareProvider,
	  for(UsageOrDisclosure,
	      maintains(HealthcareProvider,
			directory)),
	  '164.510(a)(3)(i)') :-
	wm(s164_510a3i_knowsPreferences(HealthcareProvider,Individual,UsageOrDisclosure,Info)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure),
			  maintains(HealthcareProvider,
				    directory)),
		      _),
		'164.510(a)(3)(i)')) :-
	wm(s164_510a3i_knowsPreferences(HealthcareProvider,Individual,UsageOrDisclosure,Info)).

s164_510a3i_doesntKnowPreferences(HealthcareProvider,Individual,UsageOrDisclosure,Info) :-
	privilege(HealthcareProvider,
		  for(UsageOrDisclosure,
		      maintains(HealthcareProvider,
				directory)),
		  '164.510(a)(1)(i)'),
	isInEmergency(Individual),
	not(knows(HealthcareProvider,
	      prefers(Individual,
		      for(UsageOrDisclosure,
	                  maintains(HealthcareProvider,
		                    directory))))),
	determines(HealthcareProvider,
		   forBestInterest(for(UsageOrDisclosure,
				       maintains(HealthcareProvider,
						 directory)),
				   Individual)),
	isHealthcareProvider(HealthcareProvider),
	isUsageOrDisclosure(HealthcareProvider,_,Info,UsageOrDisclosure),
	s164_510a1_info(Individual,Info),
	add_to_wm(s164_510a3i_doesntKnowPreferences(HealthcareProvider,
						    Individual,
						    UsageOrDisclosure,
						    Info)).
privilege(HealthcareProvider,
	  for(UsageOrDisclosure,
	      maintains(HealthcareProvider,
			directory)),
	  '164.510(a)(3)(i)') :-
	wm(s164_510a3i_doesntKnowPreferences(HealthcareProvider,
					     Individual,
					     UsageOrDisclosure,
					     Info)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      maintains(HealthcareProvider,
					directory))),
		      _),
		'164.510(a)(3)(i)')) :-
	wm(s164_510a3i_doesntKnowPreferences(HealthcareProvider,
					     Individual,
					     UsageOrDisclosure,
					     Info)).
obligation(HealthcareProvider,
	   provides(HealthcareProvider,
		    Individual,
		    opportunity(RestrictsOrProhibits)),
	   '164.510(a)(3)(ii)') :-
	restrictsOrProhibits(HealthcareProvider,
			     Individual,
			     UsageOrDisclosure,
			     RestrictsOrProhibits),
	(   wm(s164_510a3i_knowsPreferences(HealthcareProvider,
					    Individual,
					    UsageOrDisclosure,
					    Info))
	    ;
	    wm(s164_510a3i_doesntKnowPreferences(HealthcareProvider,
						 Individual,
						 UsageOrDisclosure,
						 Info))
	),
	isPractical(provides(HealthcareProvider,
	                     Individual,
			     opportunity(RestrictsOrProhibits))).
implied(right(Individual,
	      RestrictsOrProhibits,
	      '164.510(a)(3)(ii)')) :-
	restrictsOrProhibits(HealthcareProvider,
			     Individual,
			     UsageOrDisclosure,
			     RestrictsOrProhibits),
	(   wm(s164_510a3i_knowsPreferences(HealthcareProvider,
					    Individual,
					    UsageOrDisclosure,
					    Info))
	    ;
	    wm(s164_510a3i_doesntKnowPreferences(HealthcareProvider,
						 Individual,
						 UsageOrDisclosure,
						 Info))
	),
	isPractical(provides(HealthcareProvider,
	                     Individual,
			     opportunity(RestrictsOrProhibits))).

s164_510b1i(CE,Individual,ThirdParty,PHI) :-
	is164_510b1i_thirdParty(ThirdParty,Individual),
	isCoveredEntity(CE),
	isPHI(PHI),
	isPresent(Individual),
	about(PHI,Individual),
	obtains(CE,
		agrees(Individual,
		       discloses(CE,
				 ThirdParty,
				 PHI))),
	add_to_wm(s164_510b1i(CE,Individual,ThirdParty,PHI)).
s164_510b1i(CE,Individual,ThirdParty,PHI) :-
	is164_510b1i_thirdParty(ThirdParty,Individual),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isPresent(Individual),
	provides(CE,
		 Individual,
		 opportunity(objects(Individual,
				     discloses(CE,
					       ThirdParty,
					       PHI)))),
	not(objects(Individual,
		    discloses(CE,
			      ThirdParty,
			      PHI))),
	add_to_wm(s164_510b1i(CE,Individual,ThirdParty,PHI)).
s164_510b1i(CE,Individual,ThirdParty,PHI) :-
	is164_510b1i_thirdParty(ThirdParty,Individual),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isPresent(Individual),
	determines(CE,
		   not(objects(Individual,
		               discloses(CE,
			                 ThirdParty,
			                 PHI)))),
      	add_to_wm(s164_510b1i(CE,Individual,ThirdParty,PHI)).
s164_510b1i(CE,Individual,ThirdParty,PHI) :-
	s164_510b3(CE,Individual,ThirdParty,PHI).
is164_510b1i_thirdParty(ThirdParty,Individual) :-
	areFamilyMembers(Individual,ThirdParty).
is164_510b1i_thirdParty(ThirdParty,Individual) :-
	areFriends(Individual,ThirdParty).
is164_510b1i_thirdParty(ThirdParty,Individual) :-
	permits(Individual, discloses(_,ThirdParty,PHI)),
	isPHI(PHI),
	about(PHI,Individual).
privilege(CE,
	  discloses(CE,ThirdParty,PHI),
	  '164.510(b)(1)(i)') :-
	about(PHI,treats(CE,Individual)),
	wm(s164_510b1i(CE,Individual,ThirdParty,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,ThirdParty,PHI)),
		      _),
		'164.510(b)(1)(i)')) :-
	about(PHI,treats(CE,Individual)),
	wm(s164_510b1i(CE,Individual,ThirdParty,PHI)).
privilege(CE,
	  discloses(CE,ThirdParty,PHI),
	  '164.510(b)(1)(i)') :-
	about(PHI,payment),
	wm(s164_510b1i(CE,Individual,ThirdParty,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,ThirdParty,PHI)),
		      _),
		'164.510(b)(1)(i)')) :-
	about(PHI,payment),
	wm(s164_510b1i(CE,Individual,ThirdParty,PHI)).

s164_510b1ii(CE,Individual,ThirdParty,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	is164_510b1ii_thirdParty(ThirdParty,Individual),
	add_to_wm(s164_510b1ii(CE,Individual,ThirdParty,UsageOrDisclosure,PHI)).
% forward ref to (b)(2-4) at 164.510(b)(1)(ii)
is164_510b1ii_thirdParty(ThirdParty,Individual) :-
	areFamilyMembers(Individual,ThirdParty).
is164_510b1ii_thirdParty(ThirdParty,Individual) :-
	represents(ThirdParty,Individual).
is164_510b1ii_thirdParty(ThirdParty,Individual) :-
	isResponsible(ThirdParty,careOf(Individual)).
privilege(CE,
	  for(UsageOrDisclosure,
	      informs(CE,
		      ThirdParty,
		      conditionOf(Individual))),
	  '164.510(b)(1)(ii)') :-
	wm(s164_510b1ii(CE,Individual,ThirdParty,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      informs(CE,
				      ThirdParty,
				      conditionOf(Individual)))),
		      _),
		'164.510(b)(1)(ii)')) :-
	wm(s164_510b1ii(CE,Individual,ThirdParty,UsageOrDisclosure,PHI)).

s164_510b2ii(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	isPresent(Individual),
	add_to_wm(s164_510b2ii(CE,Individual,PHI)).
obligation(CE,
	   provides(CE,
		    opportunity(objects(Individual,
					discloses(CE,
						  _,
						  PHI)))),
	   '164.510(b)(2)(ii)') :-
	wm(s164_510b2ii(CE,Individual,PHI)).
implied(right(Individual,
	      objects(Individual,
		      discloses(CE,
				_,
				PHI)),
     '164.510(b)(2)(ii)')) :-
	wm(s164_510b2ii(CE,Individual,PHI)).

s164_510b3(CE,Individual,ThirdParty,PHI) :-
	is164_510b1i_thirdParty(ThirdParty,Individual),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isNotPresentOrInEmergency(Individual),
	determines(CE,
		   forBestInterest(discloses(CE,
					     ThirdParty,
					     PHI),
				   Individual)),	
	add_to_wm(s164_510b3(CE,Individual,ThirdParty,PHI)).
isNotPresentOrInEmergency(Individual) :-
	not(isPresent(Individual)).
isNotPresentOrInEmergency(Individual) :-
	isInEmergency(Individual).
is164_506b3_phi(Individual,filledPrescription(Individual)).
is164_506b3_phi(_,medicalSupplies).
is164_506b3_phi(Individual,xRays(Individual)).
obligation(CE,
	   minimizes(CE,
		     discloses(CE,ThirdParty,PHI)),
	   '164.510(b)(3)') :-
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).
implied(right(Individual,
	      minimizes(CE,
			discloses(CE,
				  ThirdParty,
				  PHI)),
	      '164.510(b)(3)')) :-
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).
privilege(CE,
	  for(uses(CE,
		   professionalJudgement),
	      determines(CE,
			 forBestInterest(discloses(CE,
						   ThirdParty,
						   PHI),
					 Individual))),
	  '164.510(b)(3)') :-
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,ThirdParty,PHI)),
		      _),
		'164.510(b)(3)')) :-
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).
privilege(CE,
	  for(uses(CE,
		   (	 professionalJudgement,
			 experience(CE, commonPractice)
		   )),
	      determines(CE,
			 forBestInterest(allows(CE,
						ThirdParty,
						picksUp(ThirdParty,PHI)),
					 Individual))),
	  '164.510(b)(3)') :-
	is164_506b3_phi(Individual,PHI),
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(allows(CE,
				 ThirdParty,
				 picksUp(ThirdParty,PHI))),
		      _),
		'164.510(b)(3)')) :-
	is164_506b3_phi(Individual,PHI),
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).

s164_510b4(CE,Individual,ThirdParty,DisasterReliefOrganization,UsageOrDisclosure,PHI) :-
	isReliefOrg(DisasterReliefOrganization),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,DisasterReliefOrganization,PHI,UsageOrDisclosure),
	is164_510b1ii_thirdParty(ThirdParty,Individual),
	add_to_wm(s164_510b4(CE,Individual,ThirdParty,DisasterReliefOrganization,UsageOrDisclosure,PHI)).
privilege(CE,
	  for(UsageOrDisclosure,
	      informs(CE,
		      DisasterReliefOrganization,
		      conditionOf(Individual))),
	  '164.510(b)(4)') :-
	wm(s164_510b4(CE,Individual,_,DisasterReliefOrganization,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      informs(CE,
				      DisasterReliefOrganization,
				      conditionOf(Individual)))),
		      _),
		'164.510(b)(4)')) :-
	wm(s164_510b4(CE,Individual,_,DisasterReliefOrganization,UsageOrDisclosure,PHI)).
obligation(CE,
	   provides(CE,
		    opportunity(objects(Individual,
					discloses(CE,_,PHI)))),
	   '164.510(b)(4)') :-
	determines(CE,
		   not(interferes(discloses(CE,
					    DisasterReliefOrganization,
					    PHI),
				  informs(CE,
		                          ThirdParty,
	                                  conditionOf(Individual))))),
	wm(s164_510b4(CE,
		      Individual,
		      ThirdParty,
		      DisasterReliefOrganization,
		      discloses(CE,DisasterReliefOrganization,PHI),
		      PHI)),	
	wm(s164_510b2ii(CE,Individual,PHI)).
implied(right(Individual,
	      objects(Individual,
		      discloses(CE,_,PHI)),
	      '164.510(b)(4)')) :-
	determines(CE,
		   not(interferes(discloses(CE,
					    DisasterReliefOrganization,
					    PHI),
				  informs(CE,
		                          ThirdParty,
					  conditionOf(Individual))))),
	wm(s164_510b4(CE,
		      Individual,
		      ThirdParty,
		      DisasterReliefOrganization,
		      discloses(CE,DisasterReliefOrganization,PHI),
		      PHI)),	
	wm(s164_510b2ii(CE,Individual,PHI)).
obligation(CE,
	   minimizes(CE,
		     discloses(CE,
			       ThirdParty,
			       PHI)),
	   '164.510(b)(4)') :-
	determines(CE,
		   not(interferes(discloses(CE,
					    DisasterReliefOrganization,
					    PHI),
				  informs(CE,
		                          ThirdParty,
	                                  conditionOf(Individual))))),
	wm(s164_510b4(CE,Individual,ThirdParty,DisasterReliefOrganization,discloses(CE,DisasterReliefOrganization,PHI),PHI)),
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).
implied(right(Individual,
	      minimizes(CE,
			discloses(CE,
				  ThirdParty,
				  PHI)),
	      '164.510(b)(4)')) :-
	determines(CE,
		   not(interferes(discloses(CE,
					    DisasterReliefOrganization,
					    PHI),
				  informs(CE,
					  ThirdParty,
					  conditionOf(Individual))))),
	wm(s164_510b4(CE,Individual,ThirdParty,DisasterReliefOrganization,discloses(CE,DisasterReliefOrganization,PHI),PHI)),
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).
privilege(CE,
	  for(uses(CE,
		   professionalJudgement),
	      determines(CE,
			 forBestInterest(discloses(CE,ThirdParty,PHI),
					 Individual))),
	  '164.510(b)(4)') :-
	determines(CE,
		   not(interferes(discloses(CE,
					    DisasterReliefOrganization,
					    PHI),
				  informs(CE,
		                          ThirdParty,
	                                  conditionOf(Individual))))),
	wm(s164_510b4(CE,Individual,ThirdParty,DisasterReliefOrganization,discloses(CE,DisasterReliefOrganization,PHI),PHI)),
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,ThirdParty,PHI)),
		      _),
		'164.510(b)(4)')) :-
	determines(CE,
		   not(interferes(discloses(CE,
					    DisasterReliefOrganization,
					    PHI),
				  informs(CE,
		                          ThirdParty,
	                                  conditionOf(Individual))))),
	wm(s164_510b4(CE,Individual,ThirdParty,DisasterReliefOrganization,discloses(CE,DisasterReliefOrganization,PHI),PHI)),
	wm(s164_510b3(CE,Individual,ThirdParty,PHI)).

% eof
