﻿% Models section 164.512 of the HIPAA Privacy Rule

s164_512a1(CE,UsageOrDisclosure,PHI) :-
	required_by_law(CE,UsageOrDisclosure,Law),
	isCoveredEntity(CE),
	isPHI(PHI),
	limited_to_requirements_of_law(CE,UsageOrDisclosure,Law),
	inCompliance(CE,Law,UsageOrDisclosure),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	add_to_wm(s164_512a1(CE,UsageOrDisclosure,PHI)).
privilege(CE,
	  UsageOrDisclosure,
	  '164.512(a)(1)') :-
	wm(s164_512a1(CE,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(UsageOrDisclosure),
		      _),
		'164.512(a)(1)')) :-
	about(PHI,Individual),
	wm(s164_512a1(CE,UsageOrDisclosure,PHI)).

% We declare s164_512b1i_purpose to be dynamic to
% handle the "but not limited to" clause in 164.512(b)(1)(i)
:- dynamic s164_512b1i_purpose/3.
s164_512b1i(CE,PHA,Purpose,Individual,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isPublicHealthAuthority(PHA),
	about(PHI,Individual),
	s164_512b1i_purpose(PHA,Individual,Purpose),
	add_to_wm(s164_512b1i(CE,PHA,Purpose,Individual,PHI)).
s164_512b1i_purpose(PHA,_,prevents(PHA,disease(_))).
s164_512b1i_purpose(PHA,_,controls(PHA,disease(_))).
s164_512b1i_purpose(PHA,_,prevents(PHA,injury(_))).
s164_512b1i_purpose(PHA,_,controls(PHA,injury(_))).
s164_512b1i_purpose(PHA,_,prevents(PHA,disability(_))).
s164_512b1i_purpose(PHA,_,controls(PHA,disability(_))).
s164_512b1i_purpose(PHA,_,reports(PHA,_,disease)).
s164_512b1i_purpose(PHA,_,reports(PHA,_,injury)).
s164_512b1i_purpose(PHA,Individual,reports(PHA,_,birth(Individual))).
s164_512b1i_purpose(PHA,Individual,reports(PHA,_,death(Individual))).
s164_512b1i_purpose(_,_,publicHealthSurveillance).
s164_512b1i_purpose(PHA,_,investigates(PHA,_)).
s164_512b1i_purpose(_,_,publicHealthInterventions).
privilege(CE,
	  for(discloses(CE,PHA,PHI),
	      Purpose),
	  '164.512(b)(1)(i)') :-
	wm(s164_512b1i(CE,PHA,Purpose,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,PHA,PHI),
			      Purpose)),
		      _),
		'164.512(b)(1)(i)')) :-
	wm(s164_512b1i(CE,PHA,Purpose,Individual,PHI)).
privilege(CE,
	  for(discloses(CE,
			ForeignGovernmentAgency,
			PHI),
	      Purpose),
	  '164.512(b)(1)(i)') :-
	isForeignAgent(ForeignGovernmentAgency),
	collaborates(PHA,ForeignGovernmentAgency),
	atDirectionOf(CE,
		      PHA,
		      for(discloses(CE,ForeignGovernmentAgency,PHI),
			  Purpose)),
	wm(s164_512b1i(CE,PHA,Purpose,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,ForeignGovernmentAgency,PHI),
			      Purpose)),
		      _),
		'164.512(b)(1)(i)')) :-
	isForeignAgent(ForeignGovernmentAgency),
	collaborates(PHA,ForeignGovernmentAgency),
	atDirectionOf(CE,
		      PHA,
		      for(discloses(CE,ForeignGovernmentAgency,PHI),
			  Purpose)),
	wm(s164_512b1i(CE,PHA,Purpose,Individual,PHI)).

% TODO how to discover these preconditions
s164_512b1ii(CE,PHA,PHI,Child) :-
        (   authority(PHA, receives(PHA,_,abuses(_,Child))) ;
	    authority(PHA, receives(PHA,_,neglects(_,Child)))
	),
	(   isPublicHealthAuthority(PHA) ; 
	    isGovernmentEntity(PHA)
	),
	isCoveredEntity(CE),
	isPHI(PHI),
	isChild(Child),
	add_to_wm(s164_512b1ii(CE,PHA,PHI,Child)).	
privilege(CE,
	  discloses(CE,PHA,PHI),
	  '164.512(b)(1)(ii)') :-
	wm(s164_512b1ii(CE,PHA,PHI,Child)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,PHA,PHI)),
		      _),
		'164.512(b)(1)(ii)')) :-
	wm(s164_512b1ii(CE,PHA,PHI,Child)).

% We are interpreting the list in 164.512(b)(1)(iii)(A-D) to 
% be a suggestive list. Declaring is_FDA_purpose dynamic 
% ensures that other purposes can be used that are not 
% suggested in the list.
:- dynamic is_FDA_purpose/2.
s164_512b1iii(CE,FDAAgent,PHI,Purpose) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	is_FDA_purpose(FDAAgent,Purpose),
	isFDAAgent(FDAAgent),
	add_to_wm(s164_512b1iii(CE,FDAAgent,PHI,Purpose)).
privilege(CE,
	  for(discloses(CE,FDAAgent,PHI),
	      Purpose),
	  '164.512(b)(1)(iii)') :-
	wm(s164_512b1iii(CE,FDAAgent,PHI,Purpose)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,
					FDAAgent,
					PHI),
			      Purpose)),
		      _),
		'164.512(b)(1)(iii)')) :-
	wm(s164_512b1iii(CE,FDAAgent,PHI,Purpose)).

is_FDA_purpose(FDAAgent, collects(FDAAgent, productDefects(Food))) :-
	isFoodProduct(Food),
	isFDAAgent(FDAAgent).
is_FDA_purpose(FDAAgent, collects(FDAAgent, biologicalProductDeviations)) :-
	isFDAAgent(FDAAgent).
is_FDA_purpose(FDAAgent, tracks(FDAAgent, Product)) :-
	isFDAProduct(Product),
	isFDAAgent(FDAAgent).
is_FDA_purpose(FDAAgent, recalls(_,_)) :-
	isFDAAgent(FDAAgent).
is_FDA_purpose(FDAAgent, conducts(FDAAgent, postMarket(_))) :-
	isFDAAgent(FDAAgent).

s164_512b1iv(CE,Person,PHI,CommunicableDisease) :-
	permitted_by_law(CE,
			 reports(CE,
				 Person,
				 exposedTo(Person,CommunicableDisease)),
			 _),
	exposedTo(Person, CommunicableDisease),
	isCoveredEntity(CE),
	isPHI(PHI),
	isCommunicableDisease(CommunicableDisease),
	add_to_wm(s164_512b1iv(CE,Person,PHI,CommunicableDisease)).
privilege(CE,
	  discloses(CE,Person,PHI),
	  '164.512(b)(1)(iv)') :-
	wm(s164_512b1iv(CE,Person,PHI,CommunicableDisease)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,Person,PHI)),
		      _),
		'164.512(b)(1)(iv)')) :-
	wm(s164_512b1iv(CE,Person,PHI,CommunicableDisease)).

s164_512b1vA_cond1(CE,Employer,Worker,PHI) :-
	isEmployeeOf(Worker, Employer),
	isMemberOfWorkforce(CE,Employer),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Worker),
	isHealthcareProvider(CE),
	add_to_wm(s164_512b1vA_cond1(CE,Employer,Worker,PHI)).
s164_512b1vA_cond2(CE,Employer,Worker,Purpose,PHI) :-	
        for(requests(Employer, CE, treats(CE, Worker)),
	    Purpose),
	valid_s164_512b1v_purpose(Purpose),
 	isEmployeeOf(Worker, Employer),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Worker),
	isHealthcareProvider(CE),
	add_to_wm(s164_512b1vA_cond2(CE,Employer,Worker,Purpose,PHI)).
valid_s164_512b1v_purpose(surveils(CHCP, workplace(Employer))) :-
	isHealthcareProvider(CHCP).
valid_s164_512b1v_purpose(evaluates(CHCP, workplaceRelated(Injury))) :-
	isHealthcareProvider(CHCP),
	isInjury(Injury).
valid_s164_512b1v_purpose(evaluates(CHCP, workplaceRelated(Illness))) :-
	isHealthcareProvider(CHCP),
	isIllness(Illness).
privilege(CE,
	  discloses(CE,Employer,PHI),
	  '164.512(b)(1)(v)(A)') :-
        wm(s164_512b1vA_cond1(CE,Employer,Worker,PHI))
	;
	wm(s164_512b1vA_cond2(CE,Employer,Worker,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,
				    Employer,
				    PHI)),
		      _),
		'164.512(b)(1)(v)(A)')) :-
	wm(s164_512b1vA_cond1(CE,Employer,Worker,PHI))
	;
	wm(s164_512b1vA_cond2(CE,Employer,Worker,Purpose,PHI)).

s164_512b1vB_cond1(CE,Employer,Worker,PHI,Injury) :-
	about(PHI,Injury),
	workplaceRelated(Illness),
	isIllness(Illness),
	isCoveredEntity(CE),
	isEmployeeOf(Worker,Employer),
	isPHI(PHI),
	add_to_wm(s164_512b1vB_cond1(CE,Employer,Worker,PHI,Illness)).
s164_512b1vB_cond2(CE,Employer,Worker,PHI,Injury) :-
	about(PHI,Injury),
	workplaceRelated(Injury),
	isInjury(Injury),
	isCoveredEntity(CE),
	isEmployeeOf(Worker,Employer),
	isPHI(PHI),
	add_to_wm(s164_512b1vB_cond2(CE,Employer,Worker,PHI,Injury)).
s164_512b1vB_cond3(CE,Employer,Worker,PHI) :-
	about(PHI,surveils(_, workplace(Employer))),
	workplaceRelated(surveils(_, workplace(Employer))),
	isCoveredEntity(CE),
	isEmployeeOf(Worker,Employer),
	isPHI(PHI),
	add_to_wm(s164_512b1vB_cond3(CE,Employer,Worker,PHI)).
privilege(CE,
	  discloses(CE,Employer,PHI),
	  '164.512(b)(1)(v)(B)') :-
	(   s164_512b1vB_cond1(CE,Employer,Worker,PHI,Illness) ;
	    s164_512b1vB_cond2(CE,Employer,Worker,PHI,Injury) ;
	    s164_512b1vB_cond3(CE,Employer,Worker,PHI)
	).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,Employer,PHI)),
		      _),
		'164.512(b)(1)(v)(B)')) :-
	(   s164_512b1vB_cond1(CE,Employer,Worker,PHI,Illness) ;
	    s164_512b1vB_cond2(CE,Employer,Worker,PHI,Injury) ;
	    s164_512b1vB_cond3(CE,Employer,Worker,PHI)
	).

s164_512b1vC_cond1(CE,Employer,Worker,Purpose,PHI,Illness,Law) :-
	for(requires(Employer,PHI),
	    Purpose),
	s164_512b1vC_law(Law),
	s164_512b1vC_purpose(Employer,PHI,Illness,Law,Purpose),
	isIllness(Illness),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Worker),
	isEmployeeOf(Worker,Employer),
	add_to_wm(s164_512b1vC(CE,Employer,Worker,PHI,Illness)).
s164_512b1vC_cond1(CE,Employer,Worker,Purpose,PHI,Injury,Law) :-
	for(requires(Employer,PHI),
	    Purpose),
	s164_512b1vC_law(Law),
	s164_512b1vC_purpose(Employer,PHI,Injury,Law,Purpose),
	isInjury(Injury),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Worker),
	isEmployeeOf(Worker,Employer),
	add_to_wm(s164_512b1vC(CE,Employer,Worker,Purpose,PHI,Injury,Law)).
s164_512b1vC_cond2(CE,Employer,Worker,Purpose,PHI) :-
	for(requires(Employer,PHI),surveils(Employer,workplace(Employer))),
	s164_512b1vC_purpose(Employer,PHI,Injury,Law,Purpose),
	isCoveredEntity(CE),
	isPHI(PHI),
	isEmployeeOf(Worker,Employer),
	add_to_wm(s164_512b1vC(CE,Employer,Worker,Purpose,PHI)).
s164_512b1vC_law(ex_29CFR1904_through_1928).
s164_512b1vC_law(ex_30CFR50_through_90).
s164_512b1vC_law(stateLaw_with_purpose_similar_to_s164_512b1vC).
s164_512b1vC_purpose(Employer,
		     _,
		     IllnessOrInjury,
		     Law,
		     inCompliance(Employer,Law,documents(Employer,IllnessOrInjury))).
s164_512b1vC_purpose(Employer,
		     _,
		     _,
		     _,
		     surveils(Employer,workplace(Employer))).
privilege(CE,
	  for(discloses(CE,Employer,PHI),
	      Purpose),
	  '164.512(b)(1)(v)(C)') :-
	(   s164_512b1vC_cond1(CE,Employer,Worker,Purpose,PHI,IllnessOrInjury,Law) ;
	    s164_512b1vC_cond2(CE,Employer,Worker,Purpose,PHI)
	).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,
					Employer,
					PHI),
			      Purpose)),
		      _),
		'164.512(b)(1)(v)(C)')) :-
	(   s164_512b1vC_cond1(CE,Employer,Worker,Purpose,PHI,IllnessOrInjury,Law) ;
	    s164_512b1vC_cond2(CE,Employer,Worker,Purpose,PHI)
	).

s164_512b1vD(CHCP,Employer,Worker,PHI) :-
	provides(CHCP,
		 Worker,
		 written(notice)),
	contains(notice, Contents),
	s164_512b1vD_notice_contents(CHCP, Employer, PHI, Contents),
	isHealthcareProvider(CHCP),
	isEmployeeOf(Worker,Employer),
	isPHI(PHI),
	about(PHI,Worker),
	add_to_wm(s164_512b1vD(CHCP,Employer,Worker,PHI)).
s164_512b1vD_notice_contents(CHCP, Employer, PHI, discloses(CHCP,Employer,PHI)) :-
	about(PHI, Illness),
	isIllness(Illness).
s164_512b1vD_notice_contents(CHCP, Employer, PHI, discloses(CHCP,Employer,PHI)) :-
	about(PHI, Injury),
	isInjury(Injury).
s164_512b1vD_notice_contents(CHCP, Employer, PHI, discloses(CHCP,Employer,PHI)) :-
	about(PHI, surveils(_,workplace(Employer))).
s164_512b1vD1(CHCP,Worker) :-
	at(provides(CHCP,Worker,written(notice)), treats(CHCP,Worker)).
s164_512b1vD2(CHCP,Employer,Worker) :-
	at(treats(CHCP,Worker), workplace(Employer)),
	isEmployeeOf(Worker,Employer),
	prominent(displays(CHCP,written(notice))).
privilege(CHCP,
	  discloses(CHCP,Employer,PHI),
	  '164.512(b)(1)(v)(D)') :-
	s164_512b1vD(CHCP,Employer,Worker,PHI),
	(   s164_512b1vD1(CHCP,Worker) ; 
	    s164_512b1vD2(CHCP,Employer,Worker)
	).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CHCP,Employer,PHI)),
		      _),
		'164.512(b)(1)(v)(D)')) :-
	s164_512b1vD(CHCP,Employer,Worker,PHI),
	(   s164_512b1vD1(CHCP,Worker) ; 
	    s164_512b1vD2(CHCP,Employer,Worker)
	).

s164_512b2(PHA,Employer,PHI) :-
	privilege(PHA,
		  discloses(PHA,
			    Employer,
			    PHI),
		  Source),
	isSubsectionOf(Source, '164.512(b)(1)'),
	isPublicHealthAuthority(PHA),
	isPHI(PHI),
	isEmployeeOf(Worker,Employer),
	about(PHI,Worker),
	add_to_wm(s164_512b2(PHA,Employer,PHI)).
privilege(PHA,
    uses(PHA,PHI),
    '164.512(b)(2)') :-
	wm(s164_512b2(PHA,Employer,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(uses(PHA,PHI)),
		      _),
		'164.512(b)(2)')) :-
	wm(s164_512b2(PHA,Employer,PHI)).

s164_512c1(CE,GovernmentAuthority,Individual,PHI,Attacker) :-
	violentAct(Attacker,Individual),
	authority(GovernmentAuthority,
		  recieves(GovernmentAuthority,
			   CE,
			   reports(CE,
				   GovernmentAuthority,
				   violentAct(_,Individual)))),
	reasonable(believes(CE,violentAct(Attacker,Individual))),
	isCoveredEntity(CE),
	isPHI(PHI),
	isGovernmentAuthority(GovernmentAuthority),
	about(PHI,Individual),
	(   wm(s164_512c1i(CE,GovernmentAuthority,PHI)) ;
	    wm(s164_512c1ii(CE,GovernmentAuthority,PHI)) ;
	    wm(s164_512c1iii(CE,GovernmentAuthority,PHI,Attacker))
	),
	add_to_wm(s164_512c1(CE,GovernmentAuthority,Individual,PHI,Attacker)).
privilege(CE,
	  discloses(CE,
		    GovernmentAuthority,
		    PHI),
	  '164.512(c)(1)') :-
	wm(s164_512c1(CE,GovernmentAuthority,Individual,PHI,Attacker)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,GovernmentAuthority,PHI)),
		      _),
		'164.512(c)(1)')) :-
	wm(s164_512c1(CE,GovernmentAuthority,Individual,PHI,Attacker)).

s164_512c1i(CE,GovernmentAuthority,PHI) :-
	required_by_law(CE,
			discloses(CE,
				  GovernmentAuthority,
				  PHI),
		        _),
	add_to_wm(s164_512c1i(CE,GovernmentAuthority,PHI)).

s164_512c1ii(CE,GovernmentAuthority,PHI) :-
	about(PHI,Individual),
	agrees(Individual,
	       discloses(CE,
			 GovernmentAuthority,
			 PHI)),
	add_to_wm(s164_512c1ii(CE,GovernmentAuthority,PHI)).

s164_512c1iii(CE,GovernmentAuthority,PHI,Attacker) :-
	permitted_by_law(CE,
			 discloses(CE,
				   GovernmentAuthority,
				   PHI),
			 _),
	(   wm(s164_512c1iiiA(CE,GovernmentAuthority,PHI,Attacker))
	    ;
	    wm(s164_512c1iiiB(CE,GovernmentAuthority,PHI,Attacker))
	).

s164_512c1iiiA(CE,GovernmentAuthority,PHI,Attacker) :-
	inExerciseOfProfessionalJudgment(believes(CE,
						  for(requires(_,discloses(CE,
									   GovernmentAuthority,
									   PHI)),
						      prevents(_,violentAct(Attacker,Person))))),
	add_to_wm(s164_512c1iiiA(CE,GovernmentAuthority,PHI,Attacker)).

s164_512c1iiiB(CE,GovernmentAuthority,PHI,Attacker) :-
	about(PHI,Individual),
	not(able(Individual,
		 agrees(Individual,
  	                discloses(CE,
			          GovernmentAuthority,
		 	          PHI)))),
	incapacitated(Individual),
	authority(PublicOfficial,
		  recieves(PublicOfficial,
			   CE,
			   PHI)),
	represents(PublicOfficial,
		   not(intends(PublicOfficial,
			       usesAgainst(PublicOfficial,PHI,Individual)))),
	materially(adverselyAffects(waits(_,
					  not(incapacitated(Individual))),
				    LawEnforcementActivity)),
	for(requires(LawEnforcement,
		     PHI),
	    LawEnforcementActivity),
	isCoveredEntity(CE),
	isImmediate(LawEnforcementActivity),
	isLawEnforcement(LawEnforcement),
	isLawEnforcementActivity(LawEnforcementActivity),
	add_to_wm(s164_512c1iiiB(CE,GovernmentAuthority,PHI,Attacker)).
 
s164_512c2(CE,GovernmentAuthority,Individual,PHI) :-
	discloses(CE,
		  GovernmentAuthority,
	          PHI),
	privilege(CE,
	    discloses(CE,
		      GovernmentAuthority,
		      PHI),
	    Source),
	isSubsectionOf(Source, '164.512(c)(1)'),
	discloses(CE,
		  GovernmentAuthority,
		  PHI),
	about(PHI,Individual),
	isCoveredEntity(CE),
	not(s164_512c2_exception(CE,GovernmentAuthority,PHI)),
	add_to_wm(s164_512c2(CE,GovernmentAuthority,Individual,PHI)).
obligation(CE,
	   promptly(informs(CE,
			    Individual,
			    discloses(CE,
				      GovernmentAuthority,
				      PHI))),
	   '164.512(c)(2)') :-
	wm(s164_512c2(CE,GovernmentAuthority,Individual,PHI)).
implied(right(Individual,
	      promptly(informs(CE,
			       Individual,
			       discloses(CE,
					 GovernmentAuthority,
					 PHI))),
	      '164.512(c)(2)')) :-
	wm(s164_512c2(CE,GovernmentAuthority,Individual,PHI)).
privilege(CE,
	  oral(informs(CE,
		       Individual,
		       discloses(CE,
				 GovernmentAuthority,
				 PHI))),
	  '164.512(c)(2)') :-
	wm(s164_512c2(CE,GovernmentAuthority,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      written(informs(CE,
				      Individual,
				      discloses(CE,
						GovernmentAuthority,
						PHI))),
		      _),
		'164.512(c)(2)')) :-
	wm(s164_512c2(CE,GovernmentAuthority,Individual,PHI)).

s164_512c2_exception(CE,GovernmentAuthority,PHI) :-
	about(PHI,Individual),
	inExerciseOfProfessionalJudgment(determines(CE,
						    couldEndanger(discloses(CE,
									    GovernmentAuthority,
									    PHI),
								  Individual))),
	isCoveredEntity(CE).

s164_512c2_exception(CE,GovernmentAuthority,PHI) :-
	represents(Representative,Individual),
	about(PHI,Individual),
	reasonable(believes(violentAct(Representative,Individual))),
	not(inExerciseOfProfessionalJudgment(forBestInterest(informs(CE,
				                                     Representative,
								     discloses(CE,
									       GovernmentAuthority,
									       PHI)),
			                     Individual))).

s164_512d1(CE,HealthOversightAgency,Agency,PHI) :-
	for(discloses(CE,
		      HealthOversightAgency,
		      PHI),
	    oversees(HealthOversightAgency,
		     Agency)),
	not(s164_512d1_oversightException(Individual,
					  oversees(HealthOversightAgency,
						   Agency))),
        isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isHealthOversightAgency(HealthOversightAgency),
	is164_512d1_agency(Agency,Individual,PHI),
	add_to_wm(s164_512d1(CE,HealthOversightAgency,Agency,PHI)).
privilege(CE,
	  for(discloses(CE,
			HealthOversightAgency,
			PHI),
	      oversees(HealthOversightAgency,
		       Agency)),
	  '164.512(d)') :-
	wm(s164_512d1(CE,HealthOversightAgency,Agency,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,
					HealthOversightAgency,
					PHI),
			      oversees(HealthOversightAgency,
				       Agency))),
		      _),
		'164.512(d)')) :-
	wm(s164_512d1(CE,HealthOversightAgency,Agency,PHI)).
	
is164_512d1_agency(Agency,_,_) :-
	isHealthcareSystem(Agency).
is164_512d1_agency(Agency,Individual,PHI) :-
	isGovernmentBenefitProgram(Agency),
	isRelevantTo(PHI,
		     eligible(Individual,Agency)).
is164_512d1_agency(Agency,_,PHI) :-
	isSubjectToGovermentRegulatoryPrograms(Agency),
	for(requires(Agency,
		     PHI),
	    determines(_,
		       inCompliance(Agency,
   			            s164_512d1iii_regulatoryPrograms,
				    _))).
is164_512d1_agency(Agency,_,PHI) :-
	isSubjectToCivilRightsLaws(Agency),
	for(requires(Agency,
		     PHI),
	    determines(_,
		       inCompliance(Agency,
   			            s164_512d1iv_civilRightsLaws,
				    _))).

s164_512d1_oversightException(Individual,
			      oversees(HealthOversightAgency,
				       Agency)) :-
	includes(oversees(HealthOversightAgency,
			  Agency),
		 Investigation),
	subjectOf(Individual,Investigation),
	isInvestigation(Investigation).
s164_512d1_oversightException(Individual,
			      oversees(HealthOversightAgency,
				       Agency)) :-
	includes(oversees(HealthOversightAgency,
			  Agency),
		 Investigation),
	isInvestigation(Investigation),
	not(isRelatedTo(Investigation,
		        treates(_,Individual,_))).
s164_512d1_oversightException(Individual,
			      oversees(HealthOversightAgency,
			               Agency)) :-
	includes(oversees(HealthOversightAgency,
			  Agency),
		 Investigation),
	isInvestigation(Investigation),
	publicHealthBenefitsClaim(Individual).
s164_512d1_oversightException(Individual,
			      oversees(HealthOversightAgency,
				       Agency)) :-
	includes(oversees(HealthOversightAgency,
			  Agency),
		 Investigation),
	isInvestigation(Investigation),
	areIntegral(publicHealthBenefitsClaim(Individual),
		    health(Individual)).

treatAs(Investigation,
       oversees(HealthOversightAgency,
	        _)) :-
	isInvestigation(Investigation),
	subjectOf(Individual,Investigation),
	isHealthOversightAgency(HealthOversightAgency),
	not(isRelatedTo(Investigation,
		        treates(_,Individual,_))).
treatAs(oversees(HealthOversightAgency,
		 Agency,
       oversees(HealthOversightAgency,
	        Agency))) :-
	isInvestigation(Investigation),
	subjectOf(Individual,Investigation),
	isHealthOversightAgency(HealthOversightAgency),
	not(isRelatedTo(oversees(HealthOversightAgency,
				 Agency),
		        treates(_,Individual,_))).

privilege(CE,
	  for(uses(CE,PHI),
	      oversees(CE,_)),
	  '164.512(d)(4)') :-
	isHealthOversightAgency(CE),
	isCoveredEntity(CE),
	isPHI(PHI).
implied(noRight(Individual,
		right(Individual,
		      not(for(uses(CE,PHI),
			      oversees(CE,_))),
		      _),
		'164.512(d)(4)')) :-
	isHealthOversightAgency(CE),
	isCoveredEntity(CE),
	isPHI(PHI).

s164_512e1i(CE,Court,PHI) :-
	orders(Court,
	       CE,
	       discloses(CE,
			 Court,
			 PHI)),
	(   isCourt(Court)
	    ;
	    isAdministrativeTribunal(Court)
	),
	isCoveredEntity(CE),
	isPHI(PHI),
	add_to_wm(s164_512e1i(CE,Court,PHI)).
privilege(CE,
	  discloses(CE,Court,PHI),
	  '164.5012(e)(1)(i)') :-
	wm(s164_512e1i(CE,Court,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,Court,PHI)),
		      _),
		'164.5012(e)(1)(i)')) :-
	wm(s164_512e1i(CE,Court,PHI)).
obligation(CE,
	   to(minimizes(CE,
			PHI),
	      expressly(PHI,
			orders(Court,
			       CE,
			       discloses(CE,
					 Court,
					 PHI)))),
	   '164.512(e)(1)(i)') :-
	wm(s164_512e1i(CE,Court,PHI)),
	discloses(CE,Court,PHI).
implied(right(Individual,
	      to(minimizes(CE,
			   PHI),
		 expressly(PHI,
			   orders(Court,
				  CE,
				  discloses(CE,
					    Court,
					    PHI)))),
	      '164.512(e)(1)(i)')) :-
	about(PHI,Individual),
	discloses(CE,Court,PHI),
	wm(s164_512e1i(CE,Court,PHI)).

s164_512e1iiA(CE,Court,PHI) :-
	subpoenas(Court,
		  CE,
		  discloses(CE,
			    Court,
			    PHI)),
	isCoveredEntity(CE),
	isPHI(PHI),
	not(orders(Court,
	           CE,
	           discloses(CE,
			     Court,
			     PHI))),
	(   isCourt(Court)
	    ;
	    isAdministrativeTribunal(Court)
	),
	about(PHI,Individual),
	receives(CE,
		 Court,
		 satisfactory(assures(Court,
				      CE,
				      reasonable(attempts(Court,
							  notifies(Court,
								   Individual,
								   subpoenas(Court,
									     CE,
									     discloses(CE,
									               Court,
										       PHI)))))))),
	add_to_wm(s164_512e1iiA(CE,Court,PHI)).
privilege(CE,
	  discloses(CE,Court,PHI),
	  '164.5012(e)(1)(ii)(A)') :-
	wm(s164_512e1iiA(CE,Court,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,Court,PHI)),
		      _),
		'164.5012(e)(1)(ii)(A)')) :-
	wm(s164_512e1iiA(CE,Court,PHI)).
liability(Court,
	  notifies(Court,
		   Individual,
		   discloses(CE,Court,PHI)),
	  '164.512(e)(1)(ii)(A)') :-
	about(PHI,Individual),
	discloses(CE,Court,PHI),
	wm(s164_512e1iiA(CE,Court,PHI)).
% TODO what is implied power?

s164_512e1iiB(CE,Court,QualifiedProtectiveOrder,PHI) :-
	subpoenas(Court,
		  CE,
		  discloses(CE,
			    Court,
			    PHI)),
	isCoveredEntity(CE),
	isPHI(PHI),
	not(orders(Court,
	           CE,
	           discloses(CE,
			     Court,
			     PHI))),
	(   isCourt(Court)
	    ;
	    isAdministrativeTribunal(Court)
	),
	receives(CE,
		 Court,
		 satisfactory(assures(Court,
				      CE,
				      reasonable(attempts(Court,
							  obtains(Court,
								  QualifiedProtectiveOrder)))))),
	isQualifiedProtectiveOrder(QualifiedProtectiveOrder, CE, Court, PHI),
	add_to_wm(s164_512e1iiB(CE,Court,QualifiedProtectiveOrder,PHI)).
privilege(CE,
	  discloses(CE,Court,PHI),
	  '164.5012(e)(1)(ii)(B)') :-
	wm(s164_512e1iiB(CE,Court,QualifiedProtectiveOrder,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,Court,PHI)),
		      _),
		'164.5012(e)(1)(ii)(B)')) :-
	wm(s164_512e1iiB(CE,Court,QualifiedProtectiveOrder,PHI)).
liability(Court,
	  reasonable(attempts(Court,
			      obtains(Court,
				      QualifiedProtectiveOrder))),
	  '164.5012(e)(1)(ii)(B)') :-
	wm(s164_512e1iiB(CE,Court,QualifiedProtectiveOrder,PHI)).
% TODO what is the implied power

receives(CE,
	 ThirdParty,
	 satisfactory(assures(ThirdParty,
			      CE,
			      reasonable(attempts(ThirdParty,
						  notifies(ThirdParty,
							   Individual,
							   subpoenas(ThirdParty,
								     CE,
								     discloses(CE,
								               ThirdParty,
									       PHI)))))))) :-
	written(Statement),
	receives(CE,
		 ThirdParty,
		 Statement),
	demonstrates(Statement,
		     Action),
	receives(CE,
		 ThirdParty,
		 documents(ThirdParty,
			   Action)),
	is_s164_512e1iii_cond(CE, ThirdParty, PHI, Action),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual).

is_s164_512e1iii_cond(CE, ThirdParty, PHI, goodFaith(provides(ThirdParty,
		                                               Individual,
		                                               Notice))) :-
	written(Notice),
	isPHI(PHI),
	about(PHI,Individual),
	contains(Notice,
		 Information),
	about(Information,
	      CourtProceeding),
	goodFaith(provides(ThirdParty,
			   Individual,
			   Notice)),
	isCourtProceeding(CourtProceeding),
	jurisdictionOver(ThirdParty,CourtProceeding),
	sufficient(Information,
		   objects(Individual,
			   discloses(CE,
				     ThirdParty,
				     PHI))),
	(   isCourt(Court)
	    ;
	    isAdministrativeTribunal(Court)
	),
	end(timePeriod(objects(Individual,
			   discloses(CE,
				     ThirdParty,
				     PHI)))),
	(   not(objects(Individual,
			discloses(CE,
				  ThirdParty,
				  PHI)))
	    ;
	    (	resolves(ThirdParty,
			 objects(Individual,
				 discloses(CE,
					   ThirdParty,
					   PHI))),
		areConsistent(discloses(CE,
					ThirdParty,
					PHI),
			      resolves(ThirdParty,
				       objects(discloses(CE,
							 ThirdParty,
							 PHI))))
	    )
	).
is_s164_512e1iii_cond(CE, ThirdParty, PHI, to(mails(ThirdParty,
		                                     Individual,
		                                     Notice),
					      lastKnownAddress(Individual))) :-
	not(knows(ThirdParty, location(Individual))),
	written(Notice),
	isPHI(PHI),
	about(PHI,Individual),
	contains(Notice,
		 Information),
	about(Information,
	      CourtProceeding),
	isCourtProceeding(CourtProceeding),
	jurisdictionOver(ThirdParty,CourtProceeding),
	to(mails(ThirdParty,
		 Individual,
		 Notice),
	   lastKnownAddress(Individual)),
	sufficient(Information,
		   objects(Individual,
			   discloses(CE,
				     ThirdParty,
				     PHI))).

s164_512e1iiiB(Individual,CE,ThirdParty,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI, Individual),
	isHIPAAIndividual(Individual),
	(   subpoenas(ThirdParty,
		      CE,
		      discloses(CE,
				ThirdParty,
				PHI))
	    ; 
	    orders(ThirdParty,
	           CE,
	           discloses(CE,
			     ThirdParty,
			     PHI))
	),
	(   isCourt(ThirdParty)
	    ;
	    isAdministrativeTribunal(ThirdParty)
	),
	add_to_wm(s164_512e1iiiB(Individual,CE,ThirdParty,PHI)).
right(Individual,
      objects(Individual,
	      discloses(CE,
			ThirdParty,
			PHI)),
      '164.512(e)(1)(iii)(B)') :-
	wm(s164_512e1iiiB(Individual,CE,ThirdParty,PHI)).
obligation(ThirdParty,
	   permits(ThirdParty,
		   objects(Individual,
			   discloses(CE,
				     ThirdParty,
				     PHI))),
	   '164.512(e)(1)(iii)(B)') :-
	wm(s164_512e1iiiB(Individual,CE,ThirdParty,PHI)).

receives(CE,
	 ThirdParty,
	 satisfactory(assures(ThirdParty,
			      CE,
			      reasonable(attempts(ThirdParty,
						  notifies(ThirdParty,
							   Individual,
							   subpoenas(ThirdParty,
								     CE,
								     discloses(CE,
								               ThirdParty,
									       PHI)))))))) :-
	written(Statement),
	receives(CE,
		 ThirdParty,
		 Statement),
	demonstrates(Statement,
		     Action),
	receives(CE,
		 ThirdParty,
		 documents(ThirdParty,
			   Action)),
	is_s164_512e1iv_cond(CE, ThirdParty, PHI, Action),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI, Individual).
	
is_s164_512e1iv_cond(CE,
		     ThirdParty,
		     PHI,
		     (	 agrees(Party,
				QualifiedProtectiveOrder),
			 provides(Party,
				  ThirdParty,
				  QualifiedProtectiveOrder)
		     )) :-
	jurisdictionOver(ThirdParty,CourtProceeding),
	isPartyTo(Party,CourtProceeding),
	isCourtProceeding(CourtProceeding),
	isQualifiedProtectiveOrder(QualifiedProtectiveOrder, CE, ThirdParty, PHI),
	isCoveredEntity(CE),
	isPHI(PHI),
	agrees(Party,
	       QualifiedProtectiveOrder),
	provides(Party,
		 ThirdParty,
		 QualifiedProtectiveOrder),
	(   isCourt(ThirdParty)
	    ;
	    isAdministrativeTribunal(ThirdParty)
	).
is_s164_512e1iv_cond(CE,
		     ThirdParty,
		     PHI,
		     requests(ThirdParty,
			      Court,
			      QualifiedProtectiveOrder)) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	requests(ThirdParty,
		 Court,
		 QualifiedProtectiveOrder),
	isQualifiedProtectiveOrder(QualifiedProtectiveOrder, CE, ThirdParty, PHI),
	(   isCourt(Court)
	    ;
	    isAdministrativeTribunal(Court)
	).

isQualifiedProtectiveOrder(QualifiedProtectiveOrder, CE, Court, PHI) :-
	contains(QualifiedProtectiveOrder,
		 orders(Court,
			not(for(uses(Party,
				     PHI),
				Purpose)))),
	not(for(requests(Disclosee,
			 CE,
			 PHI),
		Purpose)),
	contains(QualifiedProtectiveOrder,
		 (   returns(Disclosee,
			 CE,
			 PHI)
		     ;
		     destroys(Disclosee,
			      PHI)
		 )),
	isPartyTo(Party,CourtProceeding),
	isCourtProceeding(CourtProceeding),
	jurisdictionOver(Court,CourtProceeding),
	(   isCourt(Court)
	    ;
	    isAdministrativeTribunal(Court)
	).
isQualifiedProtectiveOrder(QualifiedProtectiveOrder, CE, Court, PHI) :-
	contains(QualifiedProtectiveOrder,
		 stipulates(Party,
			    not(for(uses(Party,
					 PHI),
				    Purpose)))),
	not(for(requests(_,
			 _,
			 PHI),
		Purpose)),
	contains(QualifiedProtectiveOrder,
		 (   returns(Disclosee,
			 CE,
			 PHI)
		     ;
		     destroys(Disclosee,
			      PHI)
		 )),
	isPartyTo(Party,CourtProceeding),
	isCourtProceeding(CourtProceeding),
	(   isCourt(Court)
	    ;
	    isAdministrativeTribunal(Court)
	).

s164_512e1vi(CE,Court,Individual,PHI) :-
	not(receives(CE,
		     Court,
		     satisfactory(assures(Court,
					  CE,
					  reasonable(attempts(Court,
							      notifies(Court,
								       Individual,
								       subpoenas(Court,
										 CE,
										 discloses(CE,
											   Court,
											   PHI))))))))),
	reasonable(attempts(CE,
			    provides(CE,
				     Individual,
				     notice))),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	add_to_wm(s164_512e1vi(CE,Court,Individual,PHI)).
s164_512e1vi(CE,Court,Individual,PHI) :-
	not(receives(CE,
		     Court,
		     satisfactory(assures(Court,
					  CE,
					  reasonable(attempts(Court,
							      notifies(Court,
								       Individual,
								       subpoenas(Court,
										 CE,
										 discloses(CE,
											   Court,
											   PHI))))))))),
	reasonable(seeks(CE,
			 QualifiedProtectiveOrder)),
	isQualifiedProtectiveOrder(QualifiedProtectiveOrder, CE, Court, PHI),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	add_to_wm(s164_512e1vi(CE,Court,Individual,PHI)).
privilege(CE,
	  discloses(CE,Court,PHI),
	  '164.512(e)(1)(vi)') :-
	wm(s164_512e1vi(CE,Court,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,Court,PHI)),
		      _),
		'164.512(e)(1)(vi)')) :-
	wm(s164_512e1vi(CE,Court,Individual,PHI)).

does_not_supersede(privilege(_,_,Paragraph), privilege(_,_,Section)) :-
	isSubsectionOf(Paragraph,'164.512(e)'),
	isSubsectionOf(Section,'164.512').
does_not_supersede(obligation(_,_,Paragraph), obligation(_,_,Section)) :-
	isSubsectionOf(Paragraph,'164.512(e)'),
	isSubsectionOf(Section,'164.512').
does_not_supersede(right(_,_,Paragraph), right(_,_,Section)) :-
	isSubsectionOf(Paragraph,'164.512(e)'),
	isSubsectionOf(Section,'164.512').

s164_512f(CE,LE,PHI,Purpose) :-
	isCoveredEntity(CE),
	isLawEnforcement(LE),
	isPHI(PHI),
	for(discloses(CE,
		      LE,
		      PHI),
	    Purpose),
	isLawEnforcementPurpose(Purpose),
	(   wm(s164_512f1(CE,LE,PHI)) ;
	    wm(s164_512f2(CE,LE,Purpose,PHI)) ;
	    wm(s164_512f3(CE,LE,PHI)) ;
	    wm(s164_512f4(CE,LE,Purpose,PHI)) ;
	    wm(s164_512f5(CE,LE,PHI)) ;
	    wm(s164_512f6(CE))
	),
	add_to_wm(s164_512f(CE,LE,PHI,Purpose)).
privilege(CE,
	  for(discloses(CE,LE,PHI),
	      Purpose),
	  '164.512(f)') :-
	wm(s164_512f(CE,LE,PHI,Purpose)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,LE,PHI),
			      Purpose)),
		      _),
		'164.512(f)')) :-
	wm(s164_512f(CE,LE,PHI,Purpose)).

s164_512f1(CE,LE,PHI) :-
	wm(s164_512f1i(CE,LE,PHI)) ;
	wm(s164_512f1ii(CE,LE,PHI)).

s164_512f1i(CE,LE,PHI) :-
        isCoveredEntity(CE),
	required_by_law(CE,
		        for(discloses(CE,
				      LE,
				      PHI),
			    reports(CE,
				    _,
				    Injury)),
		       _),
	isInjury(Injury),
	isLawEnforcement(LE),
	not((  about(PHI,Child),
	       wm(s164_512b1ii(CE,PHA,PHI,Child))
	    )),
	not(wm(s164_512c1i(CE,GovernmentAuthority,PHI))),
        add_to_wm(s164_512f1i(CE,LE,PHI)).

s164_512f1ii(CE,LE,PHI) :-
	wm(s164_512f1iiA(CE,LE,CourtProceeding,PHI)) ;
	wm(s164_512f1iiB(CE,LE,GrandJury,PHI)) ;
	wm(s164_512f1iiC(CE,LE,PHI)).

s164_512f1iiA(CE,LE,CourtProceeding,PHI) :-
	inCompliance(CE,
		     CourtProceeding,
		     discloses(CE,
			       LE,
			       PHI)),
	isCoveredEntity(CE),
	isPHI(PHI),
	isCourtProceeding(CourtProceeding),
	add_to_wm(s164_512f1iiA(CE,LE,PHI)).
obligation(CE,
	   limited_to_requirements_of_law(CE,
					  discloses(CE,LE,PHI),
					  CourtProceeding),
	   '164.512(f)(1)(ii)(A)') :-
	wm(s164_512f1iiA(CE,LE,CourtProceeding,PHI)).
implied(right(Individual,
	      limited_to_requirements_of_law(CE,
					  discloses(CE,LE,PHI),
					  CourtProceeding),
	      '164.512(f)(1)(ii)(A)')) :-
	about(PHI,Individual),
	wm(s164_512f1iiA(CE,LE,CourtProceeding,PHI)).

s164_512f1iiB(CE,LE,GrandJury,PHI) :-
	subpoenas(GrandJury,
		  CE,
		  discloses(CE,
			    LE,
			    PHI)),
	isGrandJury(GrandJury),
	isCoveredEntity(CE),
	isPHI(PHI),
	add_to_wm(s164_512f1iiB(CE,LE,GrandJury,PHI)).
obligation(CE,
	   limited_to_requirements_of_law(CE,
					  discloses(CE,
						    LE,
						    PHI),
					  subpoenas(GrandJury,
						    CE,
						    discloses(CE,
							      LE,
							      PHI))),
	   '164.512(f)(1)(ii)(A)') :-
	wm(s164_512f1iiA(CE,LE,GrandJury,PHI)).
implied(right(Individual,
	      limited_to_requirements_of_law(CE,
					  discloses(CE,
						    LE,
						    PHI),
					  subpoenas(GrandJury,
						    CE,
						    discloses(CE,
							      LE,
							      PHI))),
	      '164.512(f)(1)(ii)(A)')) :-
	about(PHI,Individual),
	wm(s164_512f1iiA(CE,LE,GrandJury,PHI)).

s164_512f1iiC(CE,LE,PHI) :-
	administrativeRequest(_,
			      CE,
			      discloses(CE,
					LE,
					PHI)),
	isRelevantTo(PHI,
		     Inquiry),
	isLawEnforcementInquiry(LE,Inquiry),
	limitedToExtendReasonablyPracticable(administrativeRequest(_,
								   CE,
								   discloses(CE,
									     LE,
									     PHI))),
	not(reasonable(uses(LE,
			    DeidentifiedPHI))),
	deidentified(DeidentifiedPHI),
	isCoveredEntity(CE),
	isLawEnforcement(LE),
	isPHI(PHI),
	add_to_wm(s164_512f1iiC(CE,LE,PHI)).
	
s164_512f2(CE,
	    LE,
	    identifies(LE,
		       WantedPerson),
	    PHI) :-
	wm(s164_512f2i(CE,LE,identifies(LE,WantedPerson),PHI)).
s164_512f2i(CE,
	    LE,
	    identifies(LE,
		       WantedPerson),
	    PHI) :-
	isWantedPerson(WantedPerson),
	isCoveredEntity(CE),
	isLawEnforcement(LE),
	isPHI(PHI),
	about(PHI,WantedPerson),
	is_s164_512f2i_info(WantedPerson,PHI),
	add_to_wm(s164_512f2i(CE,LE,identifies(LE,WantedPerson),PHI)).
	
isWantedPerson(Person) :-
	isSuspect(Person).
isWantedPerson(RichardKimble) :-
	isFugitive(RichardKimble).
isWantedPerson(Person) :-
	isMaterialWitness(Person,_).
isWantedPerson(Person) :-
	isMissingPerson(Person).

is_s164_512f2i_info(Person,name(Person)).
is_s164_512f2i_info(Person,address(Person)).
is_s164_512f2i_info(Person,dob(Person)).
is_s164_512f2i_info(Person,placeOfBirth(Person)).
is_s164_512f2i_info(Person,ssn(Person)).
is_s164_512f2i_info(Person,bloodType(Person)).
is_s164_512f2i_info(Person,rhFactor(Person)).
is_s164_512f2i_info(Person,injury(Person)).
is_s164_512f2i_info(Person,date(treats(CE,Person))) :-
	treats(CE,Person),
	isCoveredEntity(CE).
is_s164_512f2i_info(Person,time(treats(CE,Person))) :-
	treats(CE,Person),
	isCoveredEntity(CE).
is_s164_512f2i_info(Person,date(death(Person))).
is_s164_512f2i_info(Person,time(death(Person))).
is_s164_512f2i_info(Person,X) :-
	distinguishingCharacteristic(Person,X).

distinguishingCharacteristic(Person,height(Person)).
distinguishingCharacteristic(Person,weight(Person)).
distinguishingCharacteristic(Person,gender(Person)).
distinguishingCharacteristic(Person,race(Person)).
distinguishingCharacteristic(Person,hairColor(Person)).
distinguishingCharacteristic(Person,eyeColor(Person)).
distinguishingCharacteristic(Person,facialHair(Person)).
distinguishingCharacteristic(Person,scar(Person)).
distinguishingCharacteristic(Person,tattoo(Person)).

s164_512f2ii(CE,LE,WantedPerson,PHI) :-
        wm(s164_512f2(CE,LE,identifies(LE,WantedPerson),PHI)),
	is_s164_512f2ii_info(WantedPerson,PHI),
	add_to_wm(s164_512f2ii(CE,LE,WantedPerson,PHI)).
obligation(CE,
	   not(discloses(CE,LE,PHI)),
	   '164.512(f)(2)(ii)') :-
	wm(s164_512f2ii(CE,LE,WantedPerson,PHI)).
implied(right(Individual,
	      not(discloses(CE,LE,PHI)),
     '164.512(f)(2)(ii)')) :-
	about(PHI,Individual),
	wm(s164_512f2ii(CE,LE,WantedPerson,PHI)).

is_s164_512f2ii_info(Person,dna(Person)).
is_s164_512f2ii_info(Person,dnaAnalysis(Person)).
is_s164_512f2ii_info(Person,dentalRecord(Person)).
is_s164_512f2ii_info(Person,bodyFluidSample(Person)).
is_s164_512f2ii_info(Person,bodyFluidTyping(Person)).
is_s164_512f2ii_info(Person,bodyFluidAnalysis(Person)).

s164_512f3(CE,LE,PHI) :-
	isCoveredEntity(CE),
	isLawEnforcement(LE),
	isPHI(PHI),
	about(PHI,Victim),
	requests(LE,CE,PHI),
	(   isCrimeVictim(Victim,Crime)
	    ;
	    suspects(_,isCrimeVictim(Victim,Crime))
	),
	(   s164_512f3i(CE,LE,PHI)
	    ;
	    s164_512f3ii(CE,LE,PHI)
	),
	add_to_wm(s164_512f3(CE,LE,PHI)).

s164_512f3i(CE,LE,PHI) :-
	agrees(Victim,
	       discloses(CE,
			 LE,
			 PHI)),
	isCoveredEntity(CE),
	isLawEnforcement(LE),
	isPHI(PHI),
	about(PHI,Victim),
	isCrimeVictim(Victim,Crime).

s164_512f3ii(CE,LE,PHI) :-
	incapacitated(Individual),
	not(able(CE,
		 obtains(CE,
			 agrees(Individual,
				discloses(CE,
					  LE,
					  PHI))))),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Victim),
	isLawEnforcement(LE),
	represents(LE,
		   for(requires(LE,
				PHI),
		       determines(LE,
				  violates(Perpetrator,
					   law)))),
	Perpetrator \= Victim,
	represents(LE,
		   not(intends(LE,
			       usesAgainst(LE,
					   PHI,
					   Individual)))),
	materially(adverselyAffects(waits(_,
					  not(incapacitated(Individual))),
				    LawEnforcementActivity)),
	for(requires(LE,
		     PHI),
	    LawEnforcementActivity),
	isImmediate(LawEnforcementActivity),
	isLawEnforcementActivity(LawEnforcementActivity),
	inExerciseOfProfessionalJudgment(determines(CE,
						    forBestInterest(discloses(CE,
									      LE,
									      PHI),
								    Victim))),
	add_to_wm(s164_512f3ii(CE,LE,PHI)).

s164_512f4(CE,
	   LE,
	   alerts(CE,
		  LE,
		  deceased(Individual)),
	   PHI) :-
	isCoveredEntity(CE),
	isLawEnforcement(LE),
	about(PHI,Individual),
	deceased(Individual),
	suspects(CE,
		 resultOf(deceased(Individual),
			  Crime)),
	isCrime(Crime),
	add_to_wm(s164_512f4(CE,LE,alerts(CE,LE,deceased(Individual)),PHI)).

s164_512f5(CE,LE,PHI) :-
	isCoveredEntity(CE),
	isLawEnforcement(LE),
	isPHI(PHI),
	goodFaith(believes(CE,
			   isEvidenceFor(PHI,
					 Crime))),
	isCrime(Crime),
	on(Crime,
	   premises(CE)),
	add_to_wm(s164_512f5(CE,LE,PHI)).
	
s164_512f5(CHCP,LE,PHI) :-
	isHealthcareProvider(CHCP),
	isLawEnforcement(LE),
	isPHI(PHI),
	about(PHI,Individual),
	isInEmergency(Individual),
	treats(CHCP,
	       Individual),
	not(on(isInEmergency(Individual),
	       premises(CHCP))),
	for(requires(LE,
		     PHI),
	    alerts(CHCP,
		   LE,
		   CrimeFacts)),
	s164_512f6i_crimeFacts(CrimeFacts),
	not(violentAct(_,Individual)),
	add_to_wm(s164_512f5(CHCP,LE,PHI)).
	
s164_512f6i_crimeFacts(Crime) :-
	isCrime(Crime).
s164_512f6i_crimeFacts(location(Crime)) :-
	isCrime(Crime).
s164_512f6i_crimeFacts(location(Victim)) :-
	isCrimeVictim(Victim).
s164_512f6i_crimeFacts(identifies(_,Perpetrator)) :-
	perpetrates(Perpetrator,
		    Crime),
	isCrime(Crime).
s164_512f6i_crimeFacts(describes(_,Perpetrator)) :-
	perpetrates(Perpetrator,
		    Crime),
	isCrime(Crime).
s164_512f6i_crimeFacts(location(Perpetrator)) :-
	perpetrates(Perpetrator,
		    Crime),
	isCrime(Crime).

s164_512g1(CE,Coroner,Purpose,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	is_s164_512g1_purpose(Coroner, Individual, Purpose),
	isUsageOrDisclosure(CE,Coroner,PHI,UsageOrDisclosure),
	isCoronerOrMedicalExaminer(Coroner),
	about(PHI, Individual),
	deceased(Individual),
	add_to_wm(s164_512g1(CE,Coroner,Purpose,UsageOrDisclosure,PHI)).
isCoronerOrMedicalExaminer(Coroner) :-
	isCoroner(Coroner).
isCoronerOrMedicalExaminer(Coroner) :-
	isMedicalExaminer(Coroner).
is_s164_512g1_purpose(Coroner, Individual, identifies(Coroner,
						      Individual)) :-
	deceased(Individual),
	isCoronerOrMedicalExaminer(Coroner).
is_s164_512g1_purpose(Coroner, Individual, determines(Coroner,
						      causes(X,
							     deceased(Individual)))) :-
	causes(X,
	       deceased(Individual)),
	deceased(Individual),
	isCoronerOrMedicalExaminer(Coroner).
is_s164_512g1_purpose(Coroner, Individual, X) :-
	authorized_by_law(Coroner,X,_),
	deceased(Individual),
	(   isCoroner(Coroner);
	    isMedicalExaminer(Coroner)
	).
privilege(CE,
	  for(UsageOrDisclosure,
	      Purpose),
	  '164.512(g)(1)') :-
	wm(s164_512g1(CE,Coroner,Purpose,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      Purpose)),
		      _),
		'164.512(g)(1)')) :-
	wm(s164_512g1(CE,Coroner,Purpose,UsageOrDisclosure,PHI)).

s164_512g2(CE,FuneralDirector,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isFuneralDirector(FuneralDirector),
	(   deceased(Individual)
	    ; 
	    reasonable(anticipates(CE,
				   deceased(Individual)))
	),
	add_to_wm(s164_512g2(CE,FuneralDirector,PHI)).
privilege(CE,
	  discloses(CE,FuneralDirector,PHI),
	  '164.512(g)(2)') :-
	wm(s164_512g2(CE,FuneralDirector,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,FuneralDirector,PHI)),
		      _), 
		'164.512(g)(2)')) :-
	wm(s164_512g2(CE,FuneralDirector,PHI)).

s164_512h(CE,OrganDonorOrganization,Organ,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	cadaveric(Organ),
	isUsageOrDisclosure(CE,OrganDonorOrganization,PHI,UsageOrDisclosure),
	isOrganProcurementOrganization(OrganDonorOrganization),
	about(PHI,Individual),
	deceased(Individual),
	add_to_wm(s164_512h(CE,OrganDonorOrganization,Organ,Individual,UsageOrDisclosure,PHI)).
privilege(CE,
	  for(UsageOrDisclosure,
	      transplants(OrganDonorOrganization,
			  Organ,
			  Individual,
			  _)),
	  '164.512(h)') :-
	wm(s164_512h(CE,OrganDonorOrganization,Organ,Individual,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      transplants(OrganDonorOrganization,
					  Organ,
					  Individual,
					  _))),
		      _), 
		'164.512(h)')) :-
	wm(s164_512h(CE,OrganDonorOrganization,Organ,Individual,UsageOrDisclosure,PHI)).

s164_512i1i(CE,IRBorPrivacyBoard,UsageOrDisclosure,Researcher,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	obtains(CE,
		waiver(authorizes(Individual,
				  CE,
				  UsageOrDisclosure))),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	isResearcher(Researcher),
	(   (   approves(IRBorPrivacyBoard,
			 waiver(Individual,authorizes(Individual,
						      CE,
						      UsageOrDisclosure))),
	        isIRB(IRBorPrivacyBoard),
		add_to_wm(s164_512i1i(CE,IRBorPrivacyBoard,UsageOrDisclosure,Researcher,PHI))

	    )
	    ; 
	    (	approves(IRBorPrivacyBoard,
			 waiver(Individual,authorizes(Individual,CE,uses(CE,PHI)))),
		isPrivacyBoard(IRBorPrivacyBoard),
		add_to_wm(s164_512i1i(CE,IRBorPrivacyBoard,UsageOrDisclosure,Researcher,PHI))
	    )
	).
obtains(CE, authorizes(Individual,CE,uses(CE,PHI))) :-
	about(PHI,Individual),
	wm(s164_512i1i(CE,IRBorPrivacyBoard,UsageOrDisclosure,Researcher,PHI)).

s164_512i1ii(CE,Researcher,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	obtains(CE,
		represents(Researcher,
			   only(for(seeks(Researcher,
					  uses(CE,
					       PHI)),
				    research)))),
	isResearcher(Researcher),
	for(requires(Researcher,
		     PHI),
	    prepares(Researcher,
		     researchProtocol)),
	obtains(CE,
		represents(Researcher,
			   not(from(removes(Researcher,
					    PHI),
				    CE)))),
	obtains(CE,
		represents(Researcher,
			   for(requires(Researcher,
					PHI),
			       research))),
	add_to_wm(s164_512i1ii(CE,Researcher,UsageOrDisclosure,PHI)).
s164_512i1ii(CE,Researcher,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	obtains(CE,
		represents(Researcher,
			   only(for(seeks(Researcher,
					  discloses(CE,
						    Researcher,
						    PHI)),
				    research)))),
	isResearcher(Researcher),
	for(requires(Researcher,
		     PHI),
	    prepares(Researcher,
		     researchProtocol)),
	obtains(CE,
		represents(Researcher,
			   not(from(removes(Researcher,
					    PHI),
				    CE)))),
	obtains(CE,
		represents(Researcher,
			   for(requires(Researcher,
					PHI),
			       research))),
	add_to_wm(s164_512i1ii(CE,Researcher,UsageOrDisclosure,PHI)).

s164_512i1iii(_,_,UsageOrDisclosure,PHI) :-
	about(PHI,Individual),
	not(deceased(Individual)).
s164_512i1iii(CE,Researcher,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	obtains(CE,
		represents(Researcher,
			   only(for(seeks(Researcher,
					  uses(CE,
					       PHI)),
				    researcher)))),
	about(PHI,Individual),
	deceased(Individual),
	isResearcher(Researcher),
	obtains(CE,
		documents(Researcher,
			  deceased(Individual))),
	obtains(CE,
		represents(Researcher,
			   for(requires(Researcher,
					PHI),
			       research))),
	add_to_wm(s164_512i1iii(CE,Researcher,UsageOrDisclosure,PHI)).
s164_512i1iii(CE,Researcher,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	obtains(CE,
		represents(Researcher,
			   only(for(seeks(Researcher,
					  discloses(CE,
						    PHI)),
				    researcher)))),
	about(PHI,Individual),
	deceased(Individual),
	isResearcher(Researcher),
	obtains(CE,
		documents(Researcher,
			  deceased(Individual))),
	obtains(CE,
		represents(Researcher,
			   for(requires(Researcher,
					PHI),
			       research))),
	add_to_wm(s164_512i1iii(CE,Researcher,UsageOrDisclosure,PHI)).
privilege(CE,
	  for(UsageOrDisclosure,
	      research),
	  '164.512') :-
	wm(s164_512i1i(CE,IRBorPrivacyBoard,UsageOrDisclosure,Researcher,PHI)),
	wm(s164_512i1ii(CE,Researcher,UsageOrDisclosure,PHI)),
	wm(s164_512i1iii(CE,Researcher,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      research)),
		      _),
		'164.512')) :-
	wm(s164_512i1i(CE,IRBorPrivacyBoard,UsageOrDisclosure,Researcher,PHI)),
	wm(s164_512i1ii(CE,Researcher,UsageOrDisclosure,PHI)),
	wm(s164_512i1iii(CE,Researcher,UsageOrDisclosure,PHI)).

s164_512i2i(CE,Researcher,IRB_or_PrivacyBoard,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isResearcher(Researcher),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	seeks(Researcher,
	      UsageOrDisclosure),
	approves(IRB_or_PrivacyBoard,
		 waiver(Individual,authorizes(Individual,
					      CE,
					      UsageOrDisclosure))),
	isIRBorPrivacyBoard(IRB_or_PrivacyBoard),
	add_to_wm(s164_512i2i(CE,Researcher,IRB_or_PrivacyBoard,Individual,UsageOrDisclosure,PHI)).
isIRBorPrivacyBoard(IRB_or_PrivacyBoard) :-
	isIRB(IRB_or_PrivacyBoard).
isIRBorPrivacyBoard(IRB_or_PrivacyBoard) :-
	isPrivacyBoard(IRB_or_PrivacyBoard).
obligation(CE,
     contains(documents(CE,
			waiver(authorizes(Individual,
					  CE,
					  UsageOrDisclosure))),
	      statement(identifies(CE,IRB_or_PrivacyBoard))),
     '164.512(i)(2)(i)') :-
	wm(s164_512i2i(CE,Researcher,IRB_or_PrivacyBoard,Individual,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      knows(Individual,IRB_or_PrivacyBoard),
	      '164.512(i)(2)(i)')) :-
	wm(s164_512i2i(CE,Researcher,IRB_or_PrivacyBoard,Individual,UsageOrDisclosure,PHI)).
obligation(CE,
	   contains(documents(CE,
			      waiver(authorizes(Individual,
						CE,
						UsageOrDisclosure))),
		    statement(identifies(CE,
					 date(approves(IRB_or_PrivacyBoard,
						       waiver(authorizes(Individual,
									 CE,
									 UsageOrDisclosure))))))),
	   '164.512(i)(2)(i)') :-
	wm(s164_512i2i(CE,Researcher,IRB_or_PrivacyBoard,Individual,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      knows(Individual,date(approves(IRB_or_PrivacyBoard,
						 waiver(authorizes(Individual,
								   CE,
								   UsageOrDisclosure))))),
	      '164.512(i)(2)(i)')) :-
	wm(s164_512i2i(CE,Researcher,IRB_or_PrivacyBoard,Individual,UsageOrDisclosure,PHI)).

s164_512i2ii(CE,Researcher,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	lessThanOrEqualTo(riskToFrom(privacy(Individual),
				     UsageOrDisclosure),
			  minimal),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	isResearcher(Researcher),
	add_to_wm(s164_512i2ii(CE,Researcher,PHI)).
obligation(CE,
	   contains(documents(CE,
			      waiver(authorizes(Individual,
						CE,
						UsageOrDisclosure))),
		    statement(lessThanOrEqualTo(riskToFrom(privacy(Individual),
							   UsageOrDisclosure),
						minimal))),
	   '164.512(i)(2)(ii)(A)') :-
	wm(s164_512i2ii(CE,Researcher,Individual,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      knows(Individual,
		    lessThanOrEqualTo(riskToFrom(privacy(Individual),
						     UsageOrDisclosure),
					  minimal)),
	      '164.512(i)(2)(ii)(A)')) :-
	wm(s164_512i2ii(CE,Researcher,Individual,UsageOrDisclosure,PHI)).

s164_512i2iiA3(CE,Researcher,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isResearcher(Researcher),
	about(PHI,Individual),
	isPHI(PHI),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	not(s164_512i2iiA3_exception(Researcher,UsageOrDisclosure,Purpose)),
	add_to_wm(s164_512i2iiA3(CE,Researcher,Individual,UsageOrDisclosure,PHI)).
s164_512i2iiA3_exception(Researcher,
			 UsageOrDisclosure,
			 required_by_law(Researcher,
					 UsageOrDisclosure,
					 _)).
s164_512i2iiA3_exception(Researcher,
			 UsageOrDisclosure,
			 oversees(ThirdParty,
				  research)) :-
	isUsageOrDisclosure(Researcher,ThirdParty,_,UsageOrDisclosure).
s164_512i2iiA3_exception(Researcher,
			 UsageOrDisclosure,
			 permitted_by_law(Researcher,
					  UsageOrDisclosure,
					  Source)).
liability(Researcher,
	  not(for(UsageOrDisclosure,
		  Purpose)),
	  '164.512(i)(2)(ii)(A)(3)') :-
	wm(s164_512i2iiA3(CE,Researcher,Individual,UsageOrDisclosure,PHI)).
implied(power(CE,
	      UsageOrDisclosure,
	      requires(CE,
		       assures(Researcher,
			       not(for(UsageOrDisclosure,
				       Purpose)))),
	      '164.512(i)(2)(ii)(A)(3)')) :-
	wm(s164_512i2iiA3(CE,Researcher,Individual,UsageOrDisclosure,PHI)).

lessThanOrEqualTo(riskToFrom(privacy(Individual),
			     UsageOrDisclosure),
		  minimal) :-
	isResearcher(Researcher),
	isCoveredEntity(CE),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	adequate(plan(protects(_,
			       identifiers))),
	(   (   adequate(plan(at(destroys(Researcher,
					  identifiers),
				 earliestOpportunity))),
		areConsistent(destroys(Researcher,
				       identifiers),
			      research)
	    )
	    ;
	    (	(  justificationFor(HealthJustification,
				    not(destroys(Researcher,
						 identifiers))),
		   isRelatedTo(HealthJustification,
			       health)
		)
	        ;
	        (   justificationFor(ResearchJustification,
				     not(destroys(Researcher,
						  identifiers))),
		    isRelatedTo(ResearchJustification,
				research)
		)
	        ;
	        required_by_law(Researcher,
				not(destroys(Researcher,
					      identifiers)),
				_)
	    )
	),
	adequate(written(assures(Researcher,
				 CE,
				 not(UsageOrDisclosureToThirdParty)))),
	not(required_by_law(Researcher,
			    UsageOrDisclosureToThirdParty,
			    _)),
	not(for(UsageOrDisclosureToThirdParty,
		oversees(ThirdParty,
			 research))),
	not(permitted_by_law(Researcher,
			     UsageOrDisclosureToThirdParty,
			     Source)),
	add_to_wm(lessThanOrEqualTo(riskToFrom(privacy(Individual),
					       UsageOrDisclosure),
				    minimal)).
	  
s164_512i2iiB(CE,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	for(requires(research,
		     waiver(authorizes(Individual,
				       CE,
				       UsageOrDisclosure))),
	    practicable(research)),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	add_to_wm(s164_512i2iiB(CE,Individual,UsageOrDisclosure,PHI)).
obligation(CE,
	   contains(documents(CE,
			      waiver(authorizes(Individual,
						CE,
						UsageOrDisclosure))),
		    statement(for(requires(research,
					   waiver(authorizes(Individual,
							     CE,
							     UsageOrDisclosure))),
				  practicable(research)))),
	   '164.512(i)(2)(ii)(B)') :-
	wm(s164_512i2iiB(CE,Individual,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      knows(Individual,
		    for(requires(research,
				     waiver(authorizes(Individual,
						       CE,
						       UsageOrDisclosure))),
			    practicable(research))),
	      '164.512(i)(2)(ii)(B)')) :-
	wm(s164_512i2iiB(CE,Individual,UsageOrDisclosure,PHI)).

s164_512i2iiC(CE,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	for(requires(UsageOrDisclosure),
	    practicable(research)),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	add_to_wm(s164_512i2iiC(CE,Individual,UsageOrDisclosure,PHI)).
obligation(CE,
	   contains(documents(CE,
			      waiver(authorizes(Individual,
						CE,
						UsageOrDisclosure))),
		    statement(for(requires(UsageOrDisclosure),
				  practicable(research)))),
	   '164.512(i)(2)(ii)(C)') :-
	wm(s164_512i2iiC(CE,Individual,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      knows(Individual,
		    for(requires(UsageOrDisclosure),
			    practicable(research))),
		          
	      '164.512(i)(2)(ii)(C)')) :-
	wm(s164_512i2iiC(CE,Individual,UsageOrDisclosure,PHI)).

s164_512i2iii(CE,Researcher,IRBorPrivacyBoard,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	isResearcher(Researcher),
	determines(IRBorPrivacyBoard,
		   for(requires(Researcher,
				PHI),
		       research)),
	isIRBorPrivacyBoard(IRBorPrivacyBoard),
	add_to_wm(s164_512i2iii(CE,Researcher,IRBorPrivacyBoard,Individual,PHI)).
obligation(CE,
	   contains(documents(CE,
			      waiver(authorizes(Individual,
						CE,
						UsageOrDisclosure))),
		    description(PHI)),
	   '164.512(i)(2)(iii)') :-
	s164_512i2iii(CE,Researcher,IRBorPrivacyBoard,Individual,UsageOrDisclosure,PHI).
implied(right(Individual,
	      description(PHI),
	      '164.512(i)(2)(iii)')) :-
	s164_512i2iii(CE,Researcher,IRBorPrivacyBoard,Individual,UsageOrDisclosure,PHI).

s164_512i2ivA(CE,Researcher,IRB,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isResearcher(Researcher),
	isPHI(PHI),
	about(PHI,Individual),
	isIRB(IRB),
	required_by_law(IRB,_,commonRule),
	add_to_wm(s164_512i2ivA(CE,Researcher,IRB,Individual,UsageOrDisclosure,PHI)).
obligation(CE,
	   contains(documents(CE,
			      waiver(authorizes(Individual,
						CE,
						UsageOrDisclosure))),
		    statement(reviews(IRB,
				      waiver(authorizes(Individual,
							CE,
							UsageOrDisclosure))))),
	   '164.512(i)(2)(iv)') :-
	s164_512i2ivA(CE,Researcher,IRB,Individual,UsageOrDisclosure,PHI).
implied(right(Individual,
	      reviews(IRB,
		      waiver(authorizes(Individual,
					CE,
					UsageOrDisclosure))),
     '164.512(i)(2)(iv)')) :-
	s164_512i2ivA(CE,Researcher,IRB,Individual,UsageOrDisclosure,PHI).
obligation(CE,
	   contains(documents(CE,
			      waiver(authorizes(Individual,
						CE,
						UsageOrDisclosure))),
		    statement(approves(IRB,
				       waiver(authorizes(Individual,
							 CE,
							 UsageOrDisclosure))))),
	   '164.512(i)(2)(iv)(A)') :-
	s164_512i2ivA(CE,Researcher,IRB,Individual,UsageOrDisclosure,PHI).
implied(right(Individual,
	      knows(Individual,
		    approves(IRB,
			     waiver(authorizes(Individual,
					       CE,
					       UsageOrDisclosure)))),
	      '164.512(i)(2)(iv)(A)')) :-
	s164_512i2ivA(CE,Researcher,IRB,Individual,UsageOrDisclosure,PHI).

s164_512i2ivB_cond1(PrivacyBoard) :-
	isPrivacyBoard(PrivacyBoard),
	not(reviews(IRB,
		    proposal(research))),
	ignore(isIRB(IRB)),
	add_to_wm(s164_512i2ivB_cond1(IRB)).
obligation(PrivacyBoard,
	   reviews(PrivacyBoard,
		   proposal(research)),
	   '164.512(i)(2)(iv)(B)') :-
	wm(s164_512i2ivB_cond1(PrivacyBoard)).
implied(right(Individual,
	      reviews(PrivacyBoard,
		      proposal(research)),
	      '164.512(i)(2)(iv)(B)')) :-
	wm(s164_512i2ivB_cond1(PrivacyBoard)).
s164_512i2ivB_cond2(CE,PrivacyBoard,Individual,UsageOrDisclosure,PHI) :-
	isPrivacyBoard(PrivacyBoard),
	isPHI(PHI),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	isResearcher(Researcher),
	not(elects(PrivacyBoard,
		   uses(PrivacyBoard,
			expeditedReviews(PrivacyBoard,
					 waiver(authorizes(Individual,
							   CE,
							   UsageOrDisclosure)))))),
	add_to_wm(s164_512i2ivB_cond2(CE,PrivacyBoard,Individual,UsageOrDisclosure,PHI)).
obligation(PrivacyBoard,
	   by(approves(PrivacyBoard,
		       waiver(authorizes(Individual,
					 CE,
					 UsageOrDisclosure))),
	      majority(PrivacyBoard)),
	   '164.512(i)(2)(iv)(B)') :-
	at(isPresent(majority(PrivacyBoard)),meeting(PrivacyBoard)),
	s164_512i2ivB_cond2(CE,PrivacyBoard,Individual,UsageOrDisclosure,PHI).
implied(right(Individual,
	      by(approves(PrivacyBoard,
			  waiver(authorizes(Individual,
					    CE,
					    UsageOrDisclosure))),
		 majority(PrivacyBoard)),
	      '164.512(i)(2)(iv)(B)')) :-
	at(isPresent(majority(PrivacyBoard)),meeting(PrivacyBoard)),
	s164_512i2ivB_cond2(CE,PrivacyBoard,Individual,UsageOrDisclosure,PHI).

s164_512i2ivC_cond1(CE,PrivacyBoard,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPrivacyBoard(PrivacyBoard),
	lessThanOrEqualTo(riskToFrom(privacy(Individual),
				     UsageOrDisclosure),
			  minimal),
	isPHI(PHI),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	isResearcher(Researcher),
	add_to_wm(s164_512i2ivC_cond1(CE,PrivacyBoard,Individual,UsageOrDisclosure,PHI)).
privilege(PrivacyBoard,
	  uses(PrivacyBoard,
	       expeditedReviews(PrivacyBoard,
				waiver(authorizes(Individual,
						  CE,
						  UsageOrDisclosure)))),
	  '164.512(i)(2)(iv)(C)') :-
	wm(s164_512i2ivC_cond1(CE,PrivacyBoard,Individual,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(uses(PrivacyBoard,
			       expeditedReviews(PrivacyBoard,
						waiver(authorizes(Individual,
								  CE,
								  UsageOrDisclosure))))),
		      _),
		'164.512(i)(2)(iv)(C)')) :-
	wm(s164_512i2ivC_cond1(CE,PrivacyBoard,Individual,UsageOrDisclosure,PHI)).

s164_512i2ivC_cond2(CE,PrivacyBoard,ChairOrDesignee,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isPrivacyBoard(PrivacyBoard),
	(   isChairOf(ChairOrDesignee,PrivacyBoard)
	    ;
	    (	designatedBy(ChairOrDesignee, Chair),
		isChairOf(Chair,PrivacyBoard)
	    )
	),
	uses(PrivacyBoard,
	     expeditedReviews(PrivacyBoard,
			      waiver(authorizes(Individual,
						CE,
						UsageOrDisclosure)))),
	isUsageOrDisclosure(CE,Researcher,PHI,UsageOrDisclosure),
	isResearcher(Researcher),
	add_to_wm(s164_512i2ivC_cond2(CE,PrivacyBoard,Individual,UsageOrDisclosure,PHI)).
privilege(ChairOrDesignee,
	  approves(ChairOrDesignee,
		   waiver(authorizes(Individual,
				     CE,
				     UsageOrDisclosure))),
	  '164.512(i)(2)(iv)(C)') :-
	wm(s164_512i2ivC_cond2(CE,PrivacyBoard,ChairOrDesignee,Individual,UsageOrDisclosure,PHI)).
implied(noRight(Individual,
		right(Individual,
		      approves(ChairOrDesignee,
			       waiver(authorizes(Individual,
						 CE,
						 UsageOrDisclosure))),
		      _),
		'164.512(i)(2)(iv)(C)')) :-
	wm(s164_512i2ivC_cond2(CE,PrivacyBoard,ChairOrDesignee,Individual,UsageOrDisclosure,PHI)).		

s164_512i2v(CE,IRBorPrivacyBoard,ChairOrDesignee,Individual,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	(   isChairOf(ChairOrDesignee,
		      IRBorPrivacyBoard)
	    ;
	    (	designatedBy(ChairOrDesignee, Chair),
		isChairOf(Chair,
			  IRBorPrivacyBoard)
	    )
	),
	isIRBorPrivacyBoard(IRBorPrivacyBoard),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	add_to_wm(s164_512i2v(CE,IRBorPrivacyBoard,Individual,UsageOrDisclosure,PHI)).
obligation(CE,
	   signs(ChairOrDesignee,
		 documents(CE,
			   waiver(authorizes(Individual,
					     CE,
					     UsageOrDisclosure))),
		 statement(reviews(IRBorPrivacyBoard,
				   waiver(authorizes(Individual,
						     CE,
						     UsageOrDisclosure))))),
	   '164.512(i)(2)(v)') :-
	wm(s164_512i2v(CE,IRBorPrivacyBoard,ChairOrDesignee,Individual,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      signs(ChairOrDesignee,
		    documents(CE,
			      waiver(authorizes(Individual,
						CE,
						UsageOrDisclosure))),
		    statement(reviews(IRBorPrivacyBoard,
				      waiver(authorizes(Individual,
							CE,
							UsageOrDisclosure))))),
	      '164.512(i)(2)(v)')) :-
	wm(s164_512i2v(CE,IRBorPrivacyBoard,ChairOrDesignee,Individual,UsageOrDisclosure,PHI)).

s164_512j1i(CE,Individual,UsageOrDisclosure,ThirdParty,Threat,StandardsOfEthicalConduct,Law,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	areConsistent(UsageOrDisclosure,
		      Law),
	applies(Law,UsageOrDisclosure),
	isLaw(Law),
	areConsistent(UsageOrDisclosure,
		      StandardsOfEthicalConduct),
	applies(StandardsOfEthicalConduct,UsageOrDisclosure),
	isStandard(StandardsOfEthicalConduct),
	goodFaith(believes(CE,
			   isNecessaryFor(UsageOrDisclosure,
					  prevents(ThirdParty,
						   Threat)))),
	(   endangers(Threat,
		      Individual)
	    ; 
	    endangers(Threat,
		      generalPublic)
	),
	reasonable(able(ThirdParty,
			prevents(ThirdParty,
				 Threat))),
	add_to_wm(s164_512j1i(CE,Individual,UsageOrDisclosure,ThirdParty,Threat,StandardsOfEthicalConduct,Law,PHI)).
privilege(CE,
	  UsageOrDisclosure,
	  '164.512(j)(1)(i)') :-
	wm(s164_512j1i(CE,Individual,UsageOrDisclosure,ThirdParty,Threat,StandardsOfEthicalConduct,Law,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(UsageOrDisclosure),
		      _),
		'164.512(j)(1)(i)')) :-
	wm(s164_512j1i(CE,Individual,UsageOrDisclosure,ThirdParty,Threat,StandardsOfEthicalConduct,Law,PHI)).

s164_512j1iiA(CE,Individual,UsageOrDisclosure,ThirdParty,StandardsOfEthicalConduct,LE,Law,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	areConsistent(UsageOrDisclosure,
		      Law),
	applies(Law,UsageOrDisclosure),
	isLaw(Law),
	areConsistent(UsageOrDisclosure,
		      StandardsOfEthicalConduct),
	applies(StandardsOfEthicalConduct,UsageOrDisclosure),
	isStandard(StandardsOfEthicalConduct),
	goodFaith(because(believes(CE,
				   isNecessaryFor(UsageOrDisclosure,
						  apprehends(LE,
							     BadGuy))),
			  admits(BadGuy,
				 violentAct(BadGuy,Victim)))),
	reasonable(believes(causes(violentAct(BadGuy,
					      Victim),
				   serious(physical(harm(Victim)))))),
	isLawEnforcement(LE),
	isHIPAAIndividual(BadGuy),
      	add_to_wm(s164_512j1iiA(CE,Individual,UsageOrDisclosure,ThirdParty,StandardsOfEthicalConduct,LE,Law,PHI)).
% TODO: backwards ref to 164.512(f)(2)(i)
privilege(CE,
	  UsageOrDisclosure,
	  '164.512(j)(1)(ii)') :-
	wm(s164_512j1iiA(CE,
			 Individual,
			 UsageOrDisclosure,
			 ThirdParty,
			 StandardsOfEthicalConduct,
			 LE,
			 Law,
			 admits(BadGuy,
				violentAct(BadGuy,
					   Victim)))),
	not(s164_512j1ii_exception(CE,
				   Individual,
				   UsageOrDisclosure,
				   ThirdParty,
				   StandardsOfEthicalConduct,
				   LE,
				   Law,
				   admits(BadGuy,
					  violentAct(BadGuy,
						     Victim)))).
implied(noRight(Individual,
		right(Individual,
		      not(UsageOrDisclosure),
		      _),
		'164.512(j)(1)(ii)')) :-
	wm(s164_512j1iiA(CE,
			 Individual,
			 UsageOrDisclosure,
			 ThirdParty,
			 StandardsOfEthicalConduct,
			 LE,
			 Law,
			 admits(BadGuy,
				violentAct(BadGuy,
					   Victim)))),
	not(s164_512j1ii_exception(CE,
				   Individual,
				   UsageOrDisclosure,
				   ThirdParty,
				   StandardsOfEthicalConduct,
				   Law,
				   admits(BadGuy,
					  violentAct(BadGuy,
						     Victim)))).

s164_512j1iiB(CE,Individual,UsageOrDisclosure,ThirdParty,StandardsOfEthicalConduct,Law,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	areConsistent(UsageOrDisclosure,
		      Law),
	applies(Law,UsageOrDisclosure),
	isLaw(Law),
	areConsistent(UsageOrDisclosure,
		      StandardsOfEthicalConduct),
	applies(StandardsOfEthicalConduct,UsageOrDisclosure),
	isStandard(StandardsOfEthicalConduct),
	(   goodFaith(because(believes(CE,
				       isNecessaryFor(UsageOrDisclosure,
						      apprehends(LE,
								 BadGuy))),
			      appears(escapes(BadGuy,
					      CorrectionalInstitution))))
	    ;
	    goodFaith(because(believes(CE,
				       isNecessaryFor(UsageOrDisclosure,
						      apprehends(LE,
								 BadGuy))),
			      appears(escapes(BadGuy,
					      lawful(inCustodyof(BadGuy,
								 LE))))))
	),
	isCorrectionalInstitution(CorrectionalInstitution),
	isLawEnforcement(LE),
	isHIPAAIndividual(BadGuy),
      	add_to_wm(s164_512j1iiB(CE,Individual,UsageOrDisclosure,ThirdParty,StandardsOfEthicalConduct,Law,PHI)).
privilege(CE,
	  UsageOrDisclosure,
	  '164.512(j)(1)(ii)') :-
	wm(s164_512j1iiB(CE,
			 Individual,
			 UsageOrDisclosure,
			 ThirdParty,
			 StandardsOfEthicalConduct,
			 Law,
			 PHI)),
	not(s164_512j1ii_exception(CE,
				   Individual,
				   UsageOrDisclosure,
				   ThirdParty,
				   StandardsOfEthicalConduct,
				   Law,
				   PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(UsageOrDisclosure),
		      _),
		'164.512(j)(1)(ii)')) :-
	wm(s164_512j1iiB(CE,
			 Individual,
			 UsageOrDisclosure,
			 ThirdParty,
			 StandardsOfEthicalConduct,
			 Law,
			 PHI)),
	not(s164_512j1ii_exception(CE,
				   Individual,
				   UsageOrDisclosure,
				   ThirdParty,
				   StandardsOfEthicalConduct,
				   Law,
				   PHI)).

s164_512j1ii_exception(CE,
		       Individual,
		       UsageOrDisclosure,
		       ThirdParty,
		       StandardsOfEthicalConduct,
		       Law,
		       PHI) :-
        wm(s164_512j2i(CE,Individual,UsageOrDisclosure,ThirdParty,Counseling,StandardsOfEthicalConduct,Law,PHI))
	;
	wm(s164_512j2ii(CE,Individual,UsageOrDisclosure,ThirdParty,Counseling,StandardsOfEthicalConduct,Law,PHI)).

s164_512j2i(CE,Individual,UsageOrDisclosure,ThirdParty,Counseling,StandardsOfEthicalConduct,Law,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	areConsistent(UsageOrDisclosure,
		      Law),
	applies(Law,UsageOrDisclosure),
	isLaw(Law),
	areConsistent(UsageOrDisclosure,
		      StandardsOfEthicalConduct),
	applies(StandardsOfEthicalConduct,UsageOrDisclosure),
	isStandard(StandardsOfEthicalConduct),
	goodFaith(because(believes(CE,
				   isNecessaryFor(UsageOrDisclosure,
						  apprehends(LE,
							     BadGuy))),
			  admits(BadGuy,
				 violentAct(BadGuy,Victim)))),
	reasonable(believes(causes(violentAct(BadGuy,
					      Victim),
				   serious(physical(harm(Victim)))))),
	isLawEnforcement(LE),
	isHIPAAIndividual(BadGuy),
	through(learns(CE,
		       admits(BadGuy,
			      violentAct(BadGuy,Victim))),
	        Counseling),
	(   isCounseling(Counseling)
	    ;
	    isTherapy(Counseling)
	    ;
	    (	isTreatment(Counseling),
		affects(Counseling,
			propensity(BadGuy,
				   violentAct(BadGuy,
					      Victim)))
	    )
	),
      	add_to_wm(s164_512j2i(CE,Individual,UsageOrDisclosure,ThirdParty,Counseling,StandardsOfEthicalConduct,Law,PHI)).
s164_512j2ii(CE,Individual,UsageOrDisclosure,ThirdParty,Counseling,StandardsOfEthicalConduct,Law,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	areConsistent(UsageOrDisclosure,
		      Law),
	applies(Law,UsageOrDisclosure),
	isLaw(Law),
	areConsistent(UsageOrDisclosure,
		      StandardsOfEthicalConduct),
	applies(StandardsOfEthicalConduct,UsageOrDisclosure),
	isStandard(StandardsOfEthicalConduct),
	goodFaith(because(believes(CE,
				   isNecessaryFor(UsageOrDisclosure,
						  apprehends(LE,
							     BadGuy))),
			  admits(BadGuy,
				 violentAct(BadGuy,Victim)))),
	reasonable(believes(causes(violentAct(BadGuy,
					      Victim),
				   serious(physical(harm(Victim)))))),
	isLawEnforcement(LE),
	isHIPAAIndividual(BadGuy),
	requests(BadGuy,
		 CE,
		 Counseling),
	(   isCounseling(Counseling)
	    ;
	    isTherapy(Counseling)
	    ;
	    (	isTreatment(Counseling),
		affects(Counseling,
			propensity(BadGuy,
				   violentAct(BadGuy,
					      Victim)))
	    )
	),
      	add_to_wm(s164_512j2ii(CE,Individual,UsageOrDisclosure,ThirdParty,Counseling,StandardsOfEthicalConduct,Law,PHI)).
privilege(CE,
	  not(UsageOrDisclosure),
	  '164.512(j)(2)(i)') :-
	wm(s164_512j2i(CE,
		       Individual,
		       UsageOrDisclosure,
		       ThirdParty,
		       Counseling,
		       StandardsOfEthicalConduct,
		       Law,
		       PHI))
	;
	wm(s164_512j2ii(CE,
			Individual,
			UsageOrDisclosure,
			ThirdParty,
			Counseling,
			StandardsOfEthicalConduct,
			Law,
			PHI)).
implied(noRight(Individual,
	        right(Individual,
		      UsageOrDisclosure,
		      _),
		'164.512(j)(2)(i)')) :-
	wm(s164_512j2i(CE,
		       Individual,
		       UsageOrDisclosure,
		       ThirdParty,
		       Counseling,
		       StandardsOfEthicalConduct,
		       Law,
		       PHI))
	;
	wm(s164_512j2ii(CE,
			Individual,
			UsageOrDisclosure,
			ThirdParty,
			Counseling,
			StandardsOfEthicalConduct,
			Law,
			PHI)).

goodFaith(because(believes(CE,
			   isNecessaryFor(UsageOrDisclosure,
					  apprehends(LE,
						     BadGuy))),
		  BasisOfBelief)) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	isLawEnforcement(LE),
	isHIPAAIndividual(BadGuy),
	knows(CE,
	      BasisOfBelief),
	add_to_wm(goodFaith(because(believes(CE,
					     isNecessaryFor(UsageOrDisclosure,
							    apprehends(LE,
								       BadGuy))),
				    BasisOfBelief))).
goodFaith(because(believes(CE,
			   isNecessaryFor(UsageOrDisclosure,
					  apprehends(LE,
						     BadGuy))),
		  BasisOfBelief)) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	isLawEnforcement(LE),
	isHIPAAIndividual(BadGuy),
	credible(represents(Person,
			    BasisOfBelief)),
	knows(Person,
	      BasisOfBelief),
	add_to_wm(goodFaith(because(believes(CE,
					     isNecessaryFor(UsageOrDisclosure,
							    apprehends(LE,
								       BadGuy))),
				    BasisOfBelief))).

s164_512k1i(CE,MilitaryCommandAuthority,Individual,ThirdParty,UsageOrDisclosure,Mission,Purpose,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	about(PHI,Individual),
	isArmedForcesPersonnel(Individual,_),
	deems(MilitaryCommandAuthority,
	      isNecessaryFor(UsageOrDisclosure,
			     execution(Mission))),
	isMilitaryCommandAuthority(MilitaryCommandAuthority),
	isMilitaryMission(Mission),
	publishes(MilitaryCommandAuthority,
		  federalRegister,
		  MilitaryCommandAuthority),
	publishes(MilitaryCommandAuthority,
		  federalRegister,
		  for(UsageOrDisclosure,
		      Purpose)),
	add_to_wm(s164_512k1i(CE,MilitaryCommandAuthority,Individual,ThirdParty,UsageOrDisclosure,Mission,Purpose,PHI)).
privilege(CE,
	  for(UsageOrDisclosure,
	      Purpose),
	  '164.512(k)(1)(i)') :-
	wm(s164_512k1i(CE,MilitaryCommandAuthority,Individual,ThirdParty,UsageOrDisclosure,Mission,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      Purpose)),
		      _),
		'164.512(k)(1)(i)')) :-
	wm(s164_512k1i(CE,MilitaryCommandAuthority,Individual,ThirdParty,UsageOrDisclosure,Mission,Purpose,PHI)).

s164_512k1ii(CE,Individual,Army,PHI) :-
	isCoveredEntity(CE),
	(   isComponentOf(CE,
			  departmentOfDefense)
	    ;
	    isComponentOf(CE,
			  departmentOfTransportation)
	),
	isPHI(PHI),
	about(PHI,Individual),
	isArmedForcesPersonnel(Individual,Army),
	isArmedForces(Army),
	(   separates(Individual,
		      Army)
	    ;
	    discharges(Army,
		       Individual)
	),
	administers(secretary(departmentOfVeteranAffairs),
		    healthBenefits(departmentOfVeteranAffairs)),
	add_to_wm(s164_512k1ii(CE,Individual,Army,PHI)).
privilege(CE,
	  for(discloses(CE,
			departmentOfVeteranAffairs,
			PHI),
	      determines(departmentOfVeteranAffairs,
			 eligible(Individual,
				  healthBenefits(departmentOfVeteranAffairs)))),
	  '164.512(k)(1)(ii)') :-
	wm(s164_512k1ii(CE,Individual,Army,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,
					departmentOfVeteranAffairs,
					PHI),
			      determines(departmentOfVeteranAffairs,
					 eligible(Individual,
						  healthBenefits(departmentOfVeteranAffairs))))),
		      _),
		'164.512(k)(1)(ii)')) :-
	wm(s164_512k1ii(CE,Individual,Army,PHI)).

s164_512k1iii(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isComponentOf(CE,departmentOfVeteranAffairs),
	add_to_wm(s164_512k1iii(CE,Individual,PHI)).
privilege(CE,
	  for(uses(CE,PHI),
	      determines(CE,
			 eligible(Individual,
				  healthBenefits(departmentOfVeteranAffairs)))),
	  '164.512(k)(1)(iii)') :-
	wm(s164_512k1iii(CE,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(uses(CE,PHI),
			      determines(CE,
					 eligible(Individual,
						  healthBenefits(departmentOfVeteranAffairs))))),
		      _),
		'164.512(k)(1)(iii)')) :-
	wm(s164_512k1iii(CE,Individual,PHI)).
privilege(CE,
	  for(discloses(CE,OtherComponent,PHI),
	      determines(OtherComponent,
			 eligible(Individual,
				  healthBenefits(departmentOfVeteranAffairs)))),
	  '164.512(k)(1)(iii)') :-
	wm(s164_512k1iii(CE,Individual,PHI)),
	isComponentOf(OtherComponent,departmentOfVeteranAffairs).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,OtherComponent,PHI),
			      determines(OtherComponent,
					 eligible(Individual,
						  healthBenefits(departmentOfVeteranAffairs))))),
		      _),
		'164.512(k)(1)(iii)')) :-
	wm(s164_512k1iii(CE,Individual,PHI)),
	isComponentOf(OtherComponent,departmentOfVeteranAffairs).

s164_512k1iv(CE,MilitaryCommandAuthority,Individual,ThirdParty,UsageOrDisclosure,Mission,Purpose,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,ThirdParty,PHI,UsageOrDisclosure),
	about(PHI,Individual),
	isForeignArmedForcesPersonnel(Individual,_),
	deems(MilitaryCommandAuthority,
	      isNecessaryFor(UsageOrDisclosure,
			     execution(Mission))),
	isForeign(isMilitaryCommandAuthority(MilitaryCommandAuthority)),
	isMilitaryMission(Mission),
	add_to_wm(s164_512k1iv(CE,MilitaryCommandAuthority,Individual,ThirdParty,UsageOrDisclosure,Mission,Purpose,PHI)).
privilege(CE,
	  for(UsageOrDisclosure,
	      Purpose),
	  '164.512(k)(1)(iv)') :-
	wm(s164_512k1iv(CE,MilitaryCommandAuthority,Individual,ThirdParty,UsageOrDisclosure,Mission,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(UsageOrDisclosure,
			      Purpose)),
		      _),
		'164.512(k)(1)(iv)')) :-
	wm(s164_512k1iv(CE,MilitaryCommandAuthority,Individual,ThirdParty,UsageOrDisclosure,Mission,Purpose,PHI)).

s164_512k2(CE,FederalAgents,IntelligenceActivities,PHI) :-
	isCoveredEntity(CE),
	isFederalAgent(FederalAgents),
	is_s164_512k2_activity(IntelligenceActivities),
	add_to_wm(s164_512k2(CE,FederalAgents,IntelligenceActivities,PHI)).
is_s164_512k2_activity(IntelligenceActivities) :-
	lawful(isIntelligence(IntelligenceActivities)).
is_s164_512k2_activity(IntelligenceActivities) :-
	lawful(isCounterIntelligence(IntelligenceActivities)).
is_s164_512k2_activity(IntelligenceActivities) :-
	authorized_by_law(_,
			  IntelligenceActivities,
			  nationalSecurityAct).
privilege(CE,
	  for(discloses(CE,FederalAgents,PHI),
	      IntelligenceActivities),
	  '164.512(k)(2)') :-
	wm(s164_512k2(CE,FederalAgents,IntelligenceActivities,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,FederalAgents,PHI),
			      IntelligenceActivities)),
		      _),
		'164.512(k)(2)')) :-
	wm(s164_512k2(CE,FederalAgents,IntelligenceActivities,PHI)).

s164_512k3(CE,FederalAgents,President,PHI) :-
	isCoveredEntity(CE),
	isFederalAgent(FederalAgents),
	isPHI(PHI),
	is_s164_512k3_person(President),
	add_to_wm(s164_512k3(CE,FederalAgents,President,PHI)).
is_s164_512k3_person(president(unitedStates)).
is_s164_512k3_person(president(_)).
is_s164_512k3_person(Person) :-
	is_18_USC_3056_person(Person).
is_s164_512k3_person(Person) :-
	is_22_USC_2709a3_person(Person).
is_s164_512k3_person(Person) :-
	is_18_USC_871_investigation(Person).
is_s164_512k3_person(Person) :-
	is_18_USC_879_investigation(Person).
privilege(CE,
	  for(discloses(CE,
			FederalAgents,
			PHI),
	      protects(FederalAgents,
		       President)),
	  '164.512(k)(3)') :-
	wm(s164_512k3(CE,FederalAgents,President,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,FederalAgents,PHI),
			      protects(FederalAgents,
				       President))),
		      _),
		'164.512(k)(3)')) :-
	wm(s164_512k3(CE,FederalAgents,President,PHI)).

s164_512k4i(CE,Individual,Purpose,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isComponentOf(CE,departmentOfState),
	is_s164_512k4_Purpose(Purpose),
	add_to_wm(s164_512k4i(CE,Individual,Purpose,PHI)).
is_s164_512k4_Purpose(executiveOrder10450_securityClearance).
is_s164_512k4_Purpose(executiveOrder12698_securityClearance).
is_s164_512k4_Purpose(foreignServiceAct_101a4).
is_s164_512k4_Purpose(foreignServiceAct_504).
is_s164_512k4_Purpose(foreignServiceAct_101b5).
is_s164_512k4_Purpose(foreignServiceAct_904).
privilege(CE,
	  for(uses(CE,PHI),
	      determines(CE,
			 medicalSuitability(Individual,
					    Purpose))),
	  '164.512(k)(4)(i)') :-
	wm(s164_512k4i(CE,Individual,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(uses(CE,PHI),
			      determines(CE,
					 medicalSuitability(Individual,
							    Purpose)))),
		      _),
		'164.512(k)(4)(i)')) :-
	wm(s164_512k4i(CE,Individual,Purpose,PHI)).

s164_512k5i(CE,Individual,CorrectionalInstitution,Purpose,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isInmate(Individual),
	(   isCorrectionalInstitution(CorrectionalInstitution)
	    ; 
	    (	isLawEnforcement(CorrectionalInstitution),
		lawful(inCustodyof(Individual,CorrectionalInstitution))
	    )
	),
	isNecessaryFor(PHI,
		       Purpose),
	is_s164_512k5_purpose(Individual,CorrectionalInstitution,Purpose),
	add_to_wm(s164_512k5i(CE,Individual,CorrectionalInstitution,Purpose,PHI)).
is_s164_512k5_purpose(Individual,
		      _,
		      provides(Unspecified,
			       Individual,
			       healthcare(Unspecified,
					  Individual))).
is_s164_512k5_purpose(Individual,
		      _,
		      health(Individual)).
is_s164_512k5_purpose(Individual,
		      _,
		      safety(Individual)).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      health(OtherInmate)) :-
	isInmate(OtherInmate),
	lawful(inCustodyof(OtherInmate,
			   CorrectionalInstitution)).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      safety(OtherInmate)) :-
	isInmate(OtherInmate),
	lawful(inCustodyof(OtherInmate,
			   CorrectionalInstitution)).
is_s164_512k5_purpose(_,
		      _,
		      health(LE)) :-
	isLawEnforcement(LE).
is_s164_512k5_purpose(_,
		      _,
		      safety(LE)) :-
	isLawEnforcement(LE).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      health(Employee)) :-
	isEmployeeOf(Employee,
		     CorrectionalInstitution).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      safety(Employee)) :-
	isEmployeeOf(Employee,
		     CorrectionalInstitution).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      health(Others)) :-
	at(Others,
	   CorrectionalInstitution).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      safety(Others)) :-
	at(Others,
	   CorrectionalInstitution).
is_s164_512k5_purpose(Individual,
		      _,
		      health(Officer)) :-
	isLawEnforcement(Officer),
	transports(Officer,
		   Individual,
		   _,
		   _).
is_s164_512k5_purpose(Individual,
		      _,
		      safety(Officer)) :-
	isLawEnforcement(Officer),
	transports(Officer,
		   Individual,
		   _,
		   _).
is_s164_512k5_purpose(Individual,
		      _,
		      health(Others)) :-
	transports(Others,
		   Individual,
		   _,
		   _).
is_s164_512k5_purpose(Individual,
		      _,
		      safety(Officer)) :-
	transports(Officer,
		   Individual,
		   _,
		   _).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      LE) :-
	at(LE,
	   CorrectionalInstitution).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      administrativeTasks(CorrectionalInstitution)).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      maintenance(CorrectionalInstitution)).
is_s164_512k5_purpose(_,
		      CorrectionalInstitution,
		      goodOrder(CorrectionalInstitution)).
privilege(CE,
	  for(discloses(CE,
			CorrectionalInstitution,
			PHI),
	      Purpose),
	  '164.512(k)(5)(i)') :-
	wm(s164_512k5i(CE,Individual,CorrectionalInstitution,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,
					CorrectionalInstitution,
					PHI),
			      Purpose)),
		      _),
		'164.512(k)(5)(i)')) :-
	wm(s164_512k5i(CE,Individual,CorrectionalInstitution,Purpose,PHI)).

s164_512k5ii(CE,Individual,Purpose,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	isInmate(Individual),
	isCorrectionalInstitution(CE),
	is_s164_512k5_purpose(Individual,CE,Purpose),
	add_to_wm(s164_512k5ii(CE,Individual,Purpose,PHI)).
privilege(CE,
	  for(uses(CE,PHI),
	      Purpose),
	  '164.512(k)(5)(ii)') :-
	wm(s164_512k5ii(CE,Individual,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(uses(CE,PHI),
			      Purpose)),
		      _),
		'164.512(k)(5)(ii)')) :-
	wm(s164_512k5ii(CE,Individual,Purpose,PHI)).

isInmate(Individual) :-
	not(on(releases(CorrectionalInstitution,
			Individual),
	       parole(Individual))),
	not(on(releases(CorrectionalInstitution,
			Individual),
	       probation(Individual))),
	not(on(releases(CorrectionalInstitution,
			Individual),
	       supervisedRelease(Individual))),
	lawful(inCustodyof(Individual,
			   _)).

s164_512k6i(HP,Agency,OtherGovernmentProgram,Individual,PHI) :-
	isHealthPlan(HP),
	isPHI(PHI),
	about(PHI,Individual),
	isGovernmentBenefitProgram(HP),
	administers(Agency,
		    OtherGovernmentProgram),
	isGovernmentBenefitProgram(OtherGovernmentProgram),
	isRelatedTo(PHI,
		    eligible(Individual,
			     HP)),
	(   required_by_law(HP,
			    shares(HP,
				   OtherGovernmentProgram,
				   in(eligible(Individual,
					       HP),
				      database)),
			    _)
	    ;
	    expressly(shares(HP,
			     OtherGovernmentProgram,
			     in(eligible(Individual,
					 HP),
				database)),
		      law)
	),
	access(HP,
	       database),
	access(OtherGovernmentProgram,
	       database),
	add_to_wm(s164_512k6i(HP,Agency,OtherGovernmentProgram,Individual,PHI)).
privilege(HP,
	  discloses(HP,Agency,PHI),
	  '164.512(k)(6)(i)') :-
	wm(s164_512k6i(HP,Agency,OtherGovernmentProgram,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(HP,Agency,PHI)),
		      _),
		'164.512(k)(6)(i)')) :-
	wm(s164_512k6i(HP,Agency,OtherGovernmentProgram,Individual,PHI)).

s164_5126kii(CE,OtherCE,HP,OtherHP,Purpose,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isGovernmentBenefitProgram(HP),
	administers(CE,
		    HP),
	isRelatedTo(PHI,
		    HP),
	isCoveredEntity(OtherCE),
	administers(OtherCE,
		    OtherHP),
	isGovernmentBenefitProgram(OtherHP),
	serveSimilarOrSamePopulations(HP,OtherHP),
	isNecessaryFor(PHI,
		       Purpose),
	is_164_512k6ii_purpose(HP,OtherHP,Purpose),
	add_to_wm(s164_5126kii(CE,OtherCE,HP,OtherHP,Purpose,PHI)).
is_164_512k6ii_purpose(HP,OtherHP,coordinates(HP,OtherHP)).
is_164_512k6ii_purpose(HP,
		       OtherHP,
		       (   improves(HP,administrativeTasks(HP)),
			   improves(OtherHP,administrativeTasks(OtherHP)))).
is_164_512k6ii_purpose(HP,
		       OtherHP,
		       (   improves(HP,management(HP)),
			   improves(OtherHP,management(OtherHP)))).
privilege(CE,
	  for(discloses(CE,OtherCE,PHI),
	      Purpose),
	  '164.512(k)(6)(ii)') :-
	wm(s164_5126kii(CE,OtherCE,HP,OtherHP,Purpose,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(for(discloses(CE,OtherCE,PHI),
			      Purpose)),
		      _),
		'164.512(k)(6)(ii)')) :-
	wm(s164_5126kii(CE,OtherCE,HP,OtherHP,Purpose,PHI)).

s164_5126l(CE,WorkersComp,WorkersCompLaw,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isWorkersComp(WorkersComp),
	authorized_by_law(CE,
			  discloses(CE,
				    WorkersComp,
				    PHI),
			  WorkersCompLaw),
	isNecessaryFor(discloses(CE,
				 WorkersComp,
				 PHI),
		       inCompliance(CE,
				    WorkersCompLaw,
				    _)),
	add_to_wm(s164_5126l(CE,WorkersComp,WorkersCompLaw,PHI)).
privilege(CE,
	  discloses(CE,WorkersComp,PHI),
	  '164.512(l)') :-
	wm(s164_5126l(CE,WorkersComp,WorkersCompLaw,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discloses(CE,WorkersComp,PHI)),
		      _),
		'164.512(l)')) :-
	wm(s164_5126l(CE,WorkersComp,WorkersCompLaw,PHI)).

% eof






