﻿% Models section 164.524 of the HIPAA Privacy Rule

s164_524a(CE,Individual,AccessOrInspects,DSR,PHI) :-
	in(PHI,DSR),
	isDesignatedRecordSet(DSR),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	accessOrInspects(Individual,PHI,AccessOrInspects),
	not(s164_524a_exceptionPHI(CE,Individual,PHI)),
	not(s164_524a2_or_a3_exception(CE,Individual,AccessOrInspects,DSR,PHI)),
	add_to_wm(s164_524a(CE,Individual,AccessOrInspects,DSR,PHI)).
accessOrInspects(Individual,PHI,access(Individual,copy(PHI))).
accessOrInspects(Individual,PHI,inspects(Individual,copy(PHI))).
s164_524a_exceptionPHI(_,Individual,arePsychotherapyNotes(Notes)) :-
	about(Notes,Individual).
s164_524a_exceptionPHI(CE,_,Info) :-
	reasonable(for(prepares(CE,
				Info),
		       Proceeding)),
	isCourtProceeding(Proceeding).
s164_524a_exceptionPHI(CE,_,PHI) :-
	maintains(CE,PHI),
	subjectToCLIA(PHI).
:- dynamic subjectToCLIA/1.
s164_524a_exceptionPHI(PHI) :-
	exemptFromCLIA(PHI).
:- dynamic exemptFromCLIA/1.
right(Individual,
      forAsLongAs(AccessOrInspects,          % TODO temporality?
		  in(PHI,DSR)),
      '164.524(a)(1)') :-
	wm(s164_524a(CE,Individual,AccessOrInspects,DSR,PHI)).
implied(obligation(CE,
		   forAsLongAs(provides(CE,
					Individual,
					AccessOrInspects),
			       in(PHI,DSR)),
		   '164.524(a)(1)')) :-
	wm(s164_524a(CE,Individual,AccessOrInspects,DSR,PHI)).

s164_524a_noRight(CE,Individual,AccessOrInspects,DSR,PHI) :-
	in(PHI,DSR),
	isDesignatedRecordSet(DSR),
	isCoveredEntity(CE),
	isPHI(PHI),
	about(PHI,Individual),
	accessOrInspects(Individual,PHI,AccessOrInspects),
	s164_524a_exceptionPHI(CE,Individual,PHI),
	not(s164_524a2_or_a3_exception(CE,Individual,AccessOrInspects,DSR,PHI)),
	add_to_wm(s164_524a_noRight(CE,Individual,AccessOrInspects,DSR,PHI)).
noRight(Individual,
	right(Individual,
	      forAsLongAs(AccessOrInspects,          % TODO temporality?
			  in(PHI,DSR)),
	      _),
	'164.524(a)(1)') :-
	wm(s164_524a_noRight(CE,Individual,AccessOrInspects,DSR,PHI)).
implied(privilege(CE,
		  not(forAsLongAs(provides(CE,
					   Individual,
					   AccessOrInspects),
				  in(PHI,DSR))),
		  '164.524(a)(1)')) :-
	wm(s164_524a_noRight(CE,Individual,AccessOrInspects,DSR,PHI)).	


s164_524a2i(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	s164_524a_exceptionPHI(CE,Individual,PHI),
	add_to_wm(s164_524a2i(CE,Individual,PHI)).
privilege(CE,
	  without(denies(CE,access(Individual,PHI)),
		  opportunity(reviews(_,denies(CE,access(Individual,PHI))))),
	  '164.524(a)(2)(i)') :-
	wm(s164_524a2i(CE,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      opportunity(reviews(_,denies(CE,access(Individual,PHI)))),
		      _),
		'164.524(a)(2)(i)')) :-
	wm(s164_524a2i(CE,Individual,PHI)).

privilege(CE,
	  without(denies(CE,access(Individual,PHI)),
		  opportunity(reviews(_,denies(CE,access(Individual,PHI))))),
	  '164.524(a)(2)(ii)') :-
	(   isCorrectionalInstitution(CE)
	    ; 
	    (	actsUnderDirectionOf(CE,CorrectionalInstitution),
		isCorrectionalInstitution(CorrectionalInstitution)
	    )
	),
	isInmate(Individual),
	jepardizes(access(Individual,PHI),
		   Attribute),
	is_s164_524a2ii_protectedAttribute(Attribute,CE,Individual,PHI),
	add_to_wm(s164_524a2ii(CE,Individual,PHI)).
	
is_s164_524a2ii_protectedAttribute(health(Person),CE,Individual,PHI) :-
	is_s164_524a2ii_protectedPerson(Person,CE,Individual,PHI).
is_s164_524a2ii_protectedAttribute(safety(Person),CE,Individual,PHI) :-
	is_s164_524a2ii_protectedPerson(Person,CE,Individual,PHI).
is_s164_524a2ii_protectedAttribute(security(Person),CE,Individual,PHI) :-
	is_s164_524a2ii_protectedPerson(Person,CE,Individual,PHI).
is_s164_524a2ii_protectedAttribute(custody(Person),CE,Individual,PHI) :-
	is_s164_524a2ii_protectedPerson(Person,CE,Individual,PHI).
is_s164_524a2ii_protectedAttribute(rehabilitation(Person),CE,Individual,PHI) :-
	is_s164_524a2ii_protectedPerson(Person,CE,Individual,PHI).
is_s164_524a2ii_protectedPerson(Individual,_,Individual,_).
is_s164_524a2ii_protectedPerson(OtherInmate,_,_,_) :-
	isInmate(OtherInmate).
is_s164_524a2ii_protectedPerson(Person,CE,_,_) :-
	isEmployeeOf(Person,CE).
is_s164_524a2ii_protectedPerson(Person,_,Individual,_) :-
	isInmate(Individual),
	isResponsible(Person,transports(Person,Individual)).

s164_524a2iii(HCP,Individual,PHI) :-
	isHealthcareProvider(HCP),
	in(CreatesOrObtains,
	   research),
	isCreatesOrObtains(HCP,_,PHI,CreatesOrObtains),
	includes(research,treatment(HCP)),
	inProgress(research),
	when(consents(Individual,
		      participates(Individual,
				   research)),
	     agrees(Individual,
		    without(denies(HCP,access(Individual,PHI)),
			    opportunity(reviews(_,denies(HCP,access(Individual,PHI))))))),
	informs(HCP,
		Individual,
		reinstates(HCP,
			   right(Individual,
				 access(Individual,copy(PHI)),
				 _))),
	add_to_wm(s164_524a2iii(HCP,Individual,PHI)).
isCreatesOrObtains(CE,_,PHI,creates(CE,PHI)).
isCreatesOrObtains(CE,ThirdParty,PHI,obtains(CE,ThirdParty,PHI)).
privilege(HCP,
	  without(denies(HCP,access(Individual,PHI)),
			opportunity(reviews(_,denies(HCP,access(Individual,PHI))))),
	  '164.524(a)(2)(iii)') :-
	wm(s164_524a2iii(HCP,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      opportunity(reviews(_,denies(HCP,access(Individual,PHI)))),
		      _),
		'164.524(a)(2)(iii)')) :-
	wm(s164_524a2iii(HCP,Individual,PHI)).

s164_524a2iv(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	subjectToThePrivacyAct(PHI),
	add_to_wm(s164_524a2iv(CE,Individual,PHI)).
:- dynamic subjectToThePrivacyAct/1.
privilege(CE,
	  without(denies(CE,access(Individual,PHI)),
			opportunity(reviews(_,denies(CE,access(Individual,PHI))))),
	  '164.524(a)(2)(iv)') :-
	wm(s164_524a2iv(CE,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      opportunity(reviews(_,denies(CE,access(Individual,PHI)))),
		      _),
		'164.524(a)(2)(iv)')) :-
	wm(s164_524a2iv(CE,Individual,PHI)).
			 
s164_524a2v(CE,ThirdParty,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	under(obtains(CE,
		      ThirdParty,
		      PHI),
	      condifdentialityPromise),
	not(isHealthcareProvider(ThirdParty)),
	reasonable(likely(reveals(access(Individual,PHI),
				  ThirdParty))),
	add_to_wm(s164_524a2v(CE,ThirdParty,Individual,PHI)).
privilege(CE,
	  without(denies(CE,access(Individual,PHI)),
			opportunity(reviews(_,denies(CE,access(Individual,PHI))))),
	  '164.524(a)(2)(v)') :-
	wm(s164_524a2v(CE,ThirdParty,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      opportunity(reviews(_,denies(CE,access(Individual,PHI)))),
		      _),
	  '164.524(a)(2)(v)')) :-
	wm(s164_524a2v(CE,ThirdParty,Individual,PHI)).

s164_524a3i(CE,LHCP,Person,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	gives(CE,
	      Individual,
	      opportunity(reviews(_,denies(CE,access(Individual,PHI))))),
	inExerciseOfProfessionalJudgment(determines(LHCP,
						    reasonable(likely(endangers(access(Individual,
										       PHI),
										Person))))),
	isLHCP(LHCP),
	isPerson(Person),
	add_to_wm(s164_524a3i(CE,LHCP,Person,Individual,PHI)).
privilege(CE,
	  denies(CE,access(Individual,PHI)),
	  '164.5245(a)(3)(i)') :-
	wm(s164_524a3i(CE,LHCP,Person,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      access(Individual,PHI),
		      _),
		'164.5245(a)(3)(i)')) :-
	wm(s164_524a3i(CE,LHCP,Person,Individual,PHI)).

s164_524a3ii(CE,LHCP,OtherPerson,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	makesReference(PHI,
		       OtherPerson),
	not(isHealthcareProvider(OtherPerson)),
	inExerciseOfProfessionalJudgment(determines(LHCP,
						    reasonable(likely(endangers(access(Individual,
										       PHI),
										OtherPerson))))),
	isLHCP(LHCP),
	add_to_wm(s164_524a3ii(CE,LHCP,OtherPerson,Individual,PHI)).
privilege(CE,
	  denies(CE,access(Individual,PHI)),
	  '164.5245(a)(3)(ii)') :-
	wm(s164_524a3ii(CE,LHCP,OtherPerson,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      access(Individual,PHI),
		      _),
		'164.5245(a)(3)(ii)')) :-
	wm(s164_524a3ii(CE,LHCP,OtherPerson,Individual,PHI)).

s164_524a3iii(CE,LHCP,Representative,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	represents(Representative,Individual),
	requests(Representative,
		 CE,
		 access(Representative,PHI)),
	inExerciseOfProfessionalJudgment(determines(LHCP,
						    reasonable(likely(endangers(access(Representative,
										       PHI),
										Individual))))),
	isLHCP(LHCP),
	add_to_wm(s164_524a3iii(CE,LHCP,Representative,Individual,PHI)).
privilege(CE,
	  denies(CE,access(Representative,PHI)),
	  '164.5245(a)(3)(iii)') :-
	wm(s164_524a3iii(CE,LHCP,Representative,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      access(Individual,PHI),
		      _),
		'164.5245(a)(3)(iii)')) :-
	wm(s164_524a3iii(CE,LHCP,Representative,Individual,PHI)).

s164_524a2_or_a3_exception(CE,Individual,AccessOrInspects,DSR,PHI).

s164_524a4(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI) :-
	isLHCP(OtherLHCP),
	LHCP \= OtherLHCP,
	(   wm(s164_524a3i(CE,LHCP,Person,Individual,PHI)) ;
	    wm(s164_524a3ii(CE,LHCP,OtherPerson,Individual,PHI)) ;
	    wm(s164_524a3iii(CE,LHCP,Representative,Individual,PHI))
	),
	add_to_wm(s164_524a4(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)).
right(Individual,
      reviews(OtherLHCP,denies(CE,access(Individual,PHI))),
      '164.524(a)(4)') :-
	wm(s164_524a4(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)).
implied(obligation(CE,
		   provides(CE,
			    Individual,
			    opportunity(reviews(OtherLHCP,denies(CE,access(Individual,PHI))))),
		   '164.524(a)(4)')) :-
	wm(s164_524a4(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)).

s164_524a4_provides(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	determines(OtherLHCP,
		   provides(CE,Individual,PHI)),
	isLHCP(OtherLHCP),
	wm(s164_524a4(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)),
	add_to_wm(s164_524a4_provides(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)).
obligation(CE,
	   provides(CE,
		    Individual,
		    PHI),
	   '164.524(a)(4)') :-
	wm(s164_524a4_provides(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)).
implied(right(Individual,
	      receives(Individual,
		       CE,
		       PHI),
	      '164.524(a)(4)')) :-
	wm(s164_524a4_provides(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)).

s164_524a4_denies(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	determines(OtherLHCP,
		   denies(CE,access(Individual,PHI))),
	isLHCP(OtherLHCP),
	wm(s164_524a4(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)),
	add_to_wm(s164_524a4_denies(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)).
obligation(CE,
	   denies(CE,access(Individual,PHI)),
	   '164.524(a)(4)') :-
	wm(s164_524a4_denies(CE,LHCP,OtherLHCP,OtherPerson,Person,OtherPerson,Representative,Individual,PHI)).
% TODO what is the implied right?

s164_524b1(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	add_to_wm(s164_524b1(CE,Individual,PHI)).
obligation(CE,
	   permits(CE,
		   requests(Individual,
			    CE,
			    access(Individual,PHI))),
	   '164.524(b)(1)') :-
	wm(s164_524b1(CE,Individual,PHI)).
implied(right(Individual,
	      requests(Individual,
			    CE,
			    access(Individual,PHI)),
	      '164.524(b)(1)')) :-
	wm(s164_524b1(CE,Individual,PHI)).
privilege(CE,
	  requires(CE,
		   written(requests(Individual,
				    CE,
				    access(Individual,PHI)))),
	  '164.524(b)(1)') :-
	wm(s164_524b1(CE,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(written(requests(Individual,
					   CE,
					   access(Individual,PHI)))),
		      _),
		'164.524(b)(1)')) :-
	wm(s164_524b1(CE,Individual,PHI)).

s164_524b2i(CE,Action,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	is_s164_524b2i_action(CE,Individual,PHI,Action),
	not(s164_524b2i_exception(CE,PHI)),
	add_to_wm(s164_524b2i(CE,Action,Individual,PHI)).
obligation(CE,
	   noLaterThan(Action,
		       day(30)),
	   '164.524(b)(2)(i)') :-
	wm(s164_524b2i(CE,Action,Individual,PHI)).
implied(right(Individual,
	      noLaterThan(Action,
		       day(30)),
	   '164.524(b)(2)(i)')) :-
	wm(s164_524b2i(CE,Action,Individual,PHI)).

is_s164_524b2i_action(CE,
		      Individual,
		      PHI,
		      informs(CE,
			      Individual,
			      grants(CE,
				     requests(Individual,CE,access(Individual,PHI))))) :-
	isCoveredEntity(CE),
        about(PHI,Individual),
	isPHI(PHI),
	grants(CE,
	       requests(Individual,CE,access(Individual,PHI))).

is_s164_524b2i_action(CE,
		      Individual,
		      PHI,
		      written(informs(CE,
				      Individual,
				      denies(CE,
					     requests(Individual,CE,access(Individual,PHI)))))) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	denies(CE,
	       requests(Individual,CE,access(Individual,PHI))).

s164_524b2ii(CE,Action,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	is_s164_524b2i_action(CE,Individual,PHI,Action),
	not(onsite(maintains(CE,PHI))),
	not(accessible(PHI,CE)),
	add_to_wm(s164_524b2ii(CE,Action,Individual,PHI)).
s164_524b2i_exception(CE,PHI) :-
	not(onsite(maintains(CE,PHI))),
	not(accessible(PHI,CE)).
obligation(CE,
	   noLaterThan(Action,
		       day(60)),
	   '164.524(b)(2)(ii)') :-
	wm(s164_524b2ii(CE,Action,Individual,PHI)).
implied(right(Individual,
	      noLaterThan(Action,
		       day(60)),
	   '164.524(b)(2)(ii)')) :-
	wm(s164_524b2ii(CE,Action,Individual,PHI)).

s164_524b2iii(CE,Action,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	within(provides(CE,
			Individual,
			written(states(CE,
				       reasons(not(Action))))),
	       day(30)),
	within(provides(CE,
			Individual,
			date(Action)),
	       day(30)),
	is_s164_524b2i_action(CE,Individual,PHI,Action),
	add_to_wm(s164_524b2iii(CE,Action,Individual,PHI)).
privilege(CE,
	  onlyOnce(extends(CE,
			   noLaterThan(Action,
				       day(30)),
			   day(30))),
	  '164.524(b)(2)(iii)') :-
	wm(s164_524b2iii(CE,Action,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(onlyOnce(extends(CE,
					   noLaterThan(Action,
						       day(30)),
					   day(30)))),
		      _),
		'164.524(b)(2)(iii)')) :-
	wm(s164_524b2iii(CE,Action,Individual,PHI)).

s164_524c1(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	in(PHI,
	   DSR),
	in(PHI,DSR),
	provides(CE,
		 Individual,
		 access(Individual,PHI)),
	in(PHI,
	   moreThanOne(location)),
	grants(CE,
	       requests(Individual,CE,access(Individual,PHI))),
	add_to_wm(s164_524c1(CE,Individual,PHI)).
privilege(CE,
	  onlyOnce(provides(CE,
			    Individual,
			    PHI)),
	  '164.524(c)(1)') :-
	wm(s164_524c1(CE,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      all(provides(CE,
				   Individual,
				   PHI)),
		      _),
		'164.524(c)(1)')) :-
	wm(s164_524c1(CE,Individual,PHI)).

s164_524c2i(CE,FormOrFormat,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	isFormOrFormat(FormOrFormat),
	grants(CE,
	       requests(Individual,CE,access(Individual,PHI))),
	add_to_wm(s164_524c2i(CE,FormOrFormat,Individual,PHI)).
isFormOrFormat(format(PHI)) :-
	isPHI(PHI).
isFormOrFormat(form(PHI)) :-
	isPHI(PHI).
obligation(CE,
	   in(provides(CE,
		       Individual,
		       access(Individual,PHI)),
	      requests(Individual,
		       CE,
		       format(PHI))),
	   '164.524(c)(2)(i)') :-
	in(readilyProducable(PHI),FormOrFormat),
	wm(s164_524c2i(CE,FormOrFormat,Individual,PHI)).
implied(right(Individual,
	      in(receives(Individual,
		          CE,
		          access(Individual,PHI)),
		 requests(Individual,
			  CE,
			  format(PHI))),
	      '164.524(c)(2)(i)')) :-
	in(readilyProducable(PHI),
	   FormOrFormat),
	wm(s164_524c2i(CE,FormOrFormat,Individual,PHI)).

s164_524c2i_alternativeFormOrFormat(CE,FormOrFormat,Individual,AlternativeFormOrFormat,PHI) :-
	not(in(readilyProducable(PHI),
	       FormOrFormat)),
	agrees(Individual,
	       AlternativeFormOrFormat),
	agrees(CE,
	       AlternativeFormOrFormat),
	is_s164_524c2i_alternativeFormOrFormat(PHI,FormOrFormat,AlternativeFormOrFormat),
	wm(s164_524c2i(CE,FormOrFormat,Individual,PHI)),
	add_to_wm(s164_524c2i_alternativeFormOrFormat(CE,FormOrFormat,Individual,AlternativeFormOrFormat,PHI)).
is_s164_524c2i_alternativeFormOrFormat(PHI,_,readable(hardCopy(PHI))).
is_s164_524c2i_alternativeFormOrFormat(PHI,form(PHI),alternative(form(PHI))).
is_s164_524c2i_alternativeFormOrFormat(PHI,format(PHI),alternative(format(PHI))).
obligation(CE,
	   in(provides(CE,
		       Individual,
		       access(Individual,PHI)),
	      AlternativeFormOrFormat),
	   '164.524(c)(2)(i)') :-
	wm(s164_524c2i_alternativeFormOrFormat(CE,FormOrFormat,Individual,AlternativeFormOrFormat,PHI)).
implied(right(Individual,
	      in(receives(Individual,
			  CE,
			  access(Individual,PHI)),
		 AlternativeFormOrFormat),
	      '164.524(c)(2)(i)')) :-
	wm(s164_524c2i_alternativeFormOrFormat(CE,FormOrFormat,Individual,AlternativeFormOrFormat,PHI)).	  

s164_524c2ii(CE,Individual,SummaryOrExplanation,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	isSummaryOrExplanation(CE,PHI,SummaryOrExplanation),
	before(agrees(Individual,
		      provides(CE,
			       Individual,
			       SummaryOrExplanation)),
	       provides(CE,
			  Individual,
			  access(Individual,PHI))),
	before(agrees(Individual,
		      from(fees,
			   provides(CE,
				    Individual,
				    SummaryOrExplanation))),
	       provides(CE,
			Individual,
			access(Individual,PHI))),
	grants(CE,
	       requests(Individual,CE,access(Individual,PHI))),
	add_to_wm(s164_524c2ii(CE,Individual,SummaryOrExplanation,PHI)).
isSummaryOrExplanation(_,PHI,summary(PHI)).
isSummaryOrExplanation(CE,PHI,explains(CE,PHI)).
privilege(CE,
	  inLieu(provides(CE,		% TODO temporality?
			  Individual,
			  SummaryOrExplanation),
		 provides(CE,
			  Individual,
			  access(Individual,PHI))),
	  '164.524(c)(2)(ii)') :-
	wm(s164_524c2ii(CE,Individual,SummaryOrExplanation,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(inLieu(provides(CE,
					  Individual,
					  SummaryOrExplanation),
				 provides(CE,
					  Individual,
					  access(Individual,PHI)))),
		      _),
		'164.524(c)(2)(ii)')) :-
	wm(s164_524c2ii(CE,Individual,SummaryOrExplanation,PHI)).

s164_524c3(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	grants(CE,
	       requests(Individual,CE,access(Individual,PHI))),
	add_to_wm(s164_524c3(CE,Individual,PHI)).
obligation(CE,
	   timely(provides(CE,
			   Individual,
			   access(Individual,PHI))),
	   '164.524(c)(3)') :-
	wm(s164_524c3(CE,Individual,PHI)).
implied(right(Individual,
	      timely(provides(CE,
			   Individual,
			   access(Individual,PHI))),
	   '164.524(c)(3)')) :-
	wm(s164_524c3(CE,Individual,PHI)).
privilege(CE,
	  discusses(CE,
		    Individual,
		    aspects(requests(Individual,
				     CE,
				     access(Individual,PHI)))),
	  '164.524(c)(3)') :-
	for(requires(CE,
		     aspects(requests(Individual,
				      CE,
				      access(Individual,PHI)))),
	    facilitates(CE,
			timely(provides(CE,
					Individual,
					access(Individual,PHI))))),
	wm(s164_524c3(CE,Individual,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(discusses(CE,
				    Individual,
				    aspects(requests(Individual,
						     CE,
						     access(Individual,PHI))))),
		      _),
		'164.524(c)(3)')) :-
	for(requires(CE,
		     aspects(requests(Individual,
				      CE,
				      access(Individual,PHI)))),
	    facilitates(CE,
			timely(provides(CE,
					Individual,
					access(Individual,PHI))))),
	wm(s164_524c3(CE,Individual,PHI)).

s164_524c4(CE,Individual,Fee,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	requestsOrAgrees(Individual,CE,PHI),
	is_s164_524c4_fee(CE,Individual,PHI,Fee),
	grants(CE,
	       requests(Individual,CE,access(Individual,PHI))),
	add_to_wm(s164_524c4(CE,Individual,Fee,PHI)).
requestsOrAgrees(Individual,CE,PHI) :-
	requests(Individual,CE,access(Individual,PHI)).
requestsOrAgrees(Individual,CE,PHI) :-
	agrees(Individual,
	       provides(CE,
			Individual,
			SummaryOrExplanation)),
	isSummaryOrExplanation(CE,PHI,SummaryOrExplanation).
is_s164_524c4_fee(_,_,PHI,cost(copy(PHI))).
is_s164_524c4_fee(CE,Individual,PHI,postage(copy(PHI))) :-
	requests(Individual,
		 CE,
		 mails(CE,
		       Individual,
		       copy(PHI))).
is_s164_524c4_fee(CE,Individual,PHI,postage(SummaryOrExplanation)) :-
	requests(Individual,
		 CE,
		 mails(CE,
		       Individual,
		       SummaryOrExplanation)),
	isSummaryOrExplanation(CE,PHI,SummaryOrExplanation).
is_s164_524c4_fee(CE,Individual,PHI,cost(prepares(CE,SummaryOrExplanation))) :-
	wm(s164_524c2ii(CE,Individual,SummaryOrExplanation,PHI)).
privilege(CE,
	  imposes(CE,
		  Individual,
		  includes(reasonable(costBased(fee)),
			   Fee)),
	  '164.524(c)(4)') :-
	wm(s164_524c4(CE,Individual,Fee,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(imposes(CE,
				  Individual,
				  includes(reasonable(costBased(fee)),
					   Fee))),
		      _),
		'164.524(c)(4)')) :-
	wm(s164_524c4(CE,Individual,Fee,PHI)).

s164_524d1(CE,Individual,OtherPHI,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	about(OtherPHI,Individual),
	isPHI(PHI),
	isPHI(OtherPHI),
	OtherPHI \= PHI,
	denies(CE,
	       requests(Individual,
			CE,
			access(Individual,PHI))),
	add_to_wm(s164_524d1(CE,Individual,OtherPHI,PHI)).
obligation(CE,
	   after(excludes(CE,
			  from(PHI,
			       OtherPHI)),
		 toTheExtentPossible(provides(CE,
					      Individual,
					      access(Individual,OtherPHI)))),
	   '164.524(d)(1)') :-
	wm(s164_524d1(CE,Individual,OtherPHI,PHI)).
implied(right(Individual,
	      after(excludes(CE,
			     from(PHI,
				  OtherPHI)),
		    toTheExtentPossible(provides(CE,
						 Individual,
						 access(Individual,OtherPHI)))),
	      '164.524(d)(1)')) :-
	wm(s164_524d1(CE,Individual,OtherPHI,PHI)).

s164_524d2(CE,Individual,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	denies(CE,
	       requests(Individual,
			CE,
			access(Individual,PHI))),
	add_to_wm(s164_524d2(CE,Individual,PHI)).
obligation(CE,
	   provides(CE,
		    Individual,
		    timely(written(denies(CE,
					  requests(Individual,
						   CE,
						   access(Individual,PHI)))))),
	   '164.524(d)(2)') :-
	wm(s164_524d2(CE,Individual,PHI)).
implied(right(Individual,
	      receives(Individual,
		       CE,
		       timely(written(inPlainLanguage(denies(CE,
							     requests(Individual,
								      CE,
								      access(Individual,PHI))))))),
	      '164.524(d)(2)')) :-
	wm(s164_524d2(CE,Individual,PHI)).

obligation(CE,
	   contains(written(denies(CE,
				   requests(Individual,
					    CE,
					    access(Individual,PHI)))),
		    DenialContents),
	   '164.524(d)(2)') :-
	is_s164_524d2_denialContents(CE,Individual,PHI,DenialContents),
	wm(s164_524d2(CE,Individual,PHI)).
implied(right(Individual,
	      contains(written(denies(CE,
				   requests(Individual,
					    CE,
					    access(Individual,PHI)))),
		       DenialContents),
	      '164.524(d)(2)')) :-
	is_s164_524d2_denialContents(CE,Individual,PHI,DenialContents),
	wm(s164_524d2(CE,Individual,PHI)).
is_s164_524d2_denialContents(CE,Individual,PHI,basis(denies(CE,
							    requests(Individual,
								     CE,
								     access(Individual,PHI))))).
is_s164_524d2_denialContents(CE,
			     Individual,
			     PHI,
			     statement(right(Individual,
					     reviews(OtherLHCP,denies(CE,access(Individual,PHI))),
					     '164.524(a)(4)'))) :-
	right(Individual,
	      reviews(OtherLHCP,denies(CE,access(Individual,PHI))),
	      '164.524(a)(4)').
is_s164_524d2_denialContents(CE,
			     Individual,
			     PHI,
			     statement(description(how(exercises(Individual,
								 right(Individual,
								       reviews(OtherLHCP,
									       denies(CE,access(Individual,PHI))),
								       '164.524(a)(4)')))))) :-
	right(Individual,
	      reviews(OtherLHCP,denies(CE,access(Individual,PHI))),
	      '164.524(a)(4)').

is_s164_524d2_denialContents(CE,Individual,PHI,Statement) :-
	is_s160_306_compliantProcedure(CE,Individual,PHI,Statement).
:- dynamic is_s160_306_compliantProcedure/4.

is_s164_524d2_denialContents(CE,
			     Individual,
			     _,
			     statement(process(Compliant))) :-
	is_164_530d1_complaint(CE,Individual,_,Compliant).

is_s164_524d2_denialContents(CE,
			     Individual,
			     _,
			     statement(PersonOrOffice)) :-
	wm(s164_530a1ii(CE,PersonOrOffice,Individual,_,_)).

s164_524d3(CE,Individual,MaintainerOfPHI,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	denies(CE,
	       requests(Individual,
			CE,
			access(Individual,PHI))),
	not(maintains(CE,PHI)),
	knows(CE,maintains(MaintainerOfPHI,PHI)),
	add_to_wm(s164_524d3(CE,Individual,MaintainerOfPHI,PHI)).
obligation(CE,
	   informs(CE,
		   Individual,
		   to(directs(Individual,
			      requests(Individual,
				       CE,
				       access(Individual,PHI))),
		      MaintainerOfPHI)),
	   '164.524(d)(3)') :-
	wm(s164_524d3(CE,Individual,MaintainerOfPHI,PHI)).
implied(right(Individual,
	      informs(CE,
		      Individual,
		      to(directs(Individual,
				 requests(Individual,
					  CE,
					  access(Individual,PHI))),
			 MaintainerOfPHI)),
	      '164.524(d)(3)')) :-
	wm(s164_524d3(CE,Individual,MaintainerOfPHI,PHI)).

s164_524d4(CE,Individual,OtherLHCP,PHI) :-
	isCoveredEntity(CE),
	about(PHI,Individual),
	isPHI(PHI),
	denies(CE,
	       requests(Individual,
			CE,
			access(Individual,PHI))),
	requests(Individual,
		 CE,
		 reviews(OtherLHCP,denies(CE,access(Individual,PHI)))),
	not(directly(involved(OtherLHCP,
			      denies(CE,access(Individual,PHI))))),
	add_to_wm(s164_524d4(CE,Individual,OtherLHCP,PHI)).
obligation(CE,
	   to(designates(CE,
			 OtherLHCP),
	      reviews(OtherLHCP,denies(CE,access(Individual,PHI)))),
	   '164.524(d)(4)') :-
	wm(s164_524d4(CE,Individual,OtherLHCP,PHI)).
% TODO what is the implied right?

obligation(CE,
	   promptly(refers(CE,
			   OtherLHCP,
			   requests(Individual,
				    CE,
				    reviews(OtherLHCP,denies(CE,access(Individual,PHI)))))),
	   '164.524(d)(4)') :-
	wm(s164_524d4(CE,Individual,OtherLHCP,PHI)).
% TODO what is the implied right?

obligation(OtherLHCP,
	   within(determines(OtherLHCP,
			     reviews(OtherLHCP,denies(CE,access(Individual,PHI)))),
		  reasonable(timePeriod(_))),
	   '164.524(d)(4)') :-
	wm(s164_524d4(CE,Individual,OtherLHCP,PHI)).
% TODO what is the implied right?

obligation(CE,
	   provides(CE,
		    Individual,
		    written(notice(determines(OtherLHCP,
					      reviews(OtherLHCP,denies(CE,access(Individual,PHI))))))),
	   '164.524(d)(4)') :-
	wm(s164_524d4(CE,Individual,OtherLHCP,PHI)).
implied(right(Individual,
	      receives(Individual,
		       CE,
		       written(notice(determines(OtherLHCP,
					      reviews(OtherLHCP,denies(CE,access(Individual,PHI))))))),
	   '164.524(d)(4)')) :-
	wm(s164_524d4(CE,Individual,OtherLHCP,PHI)).

s164_524e1(CE,Individual,DSR) :-
	isCoveredEntity(CE),
	isDesignatedRecordSet(DSR),
	subject(DSR,
		access(Individual,DSR)),
	about(DSR,Individual),
	add_to_wm(s164_524e1(CE,Individual,DSR)).
obligation(CE,
	   documents(CE,DSR),
	   '164.524(e)(1)') :-
	wm(s164_524e1(CE,Individual,DSR)).
% TODO what is the implied right?

s164_524e2(CE,Agent,Individual,PHI) :-
	isCoveredEntity(CE),
	isPersonOrOffice(Agent),
	isResponsible(Agent,
		      receives(Agent,
			       Individual,
			       requests(Individual,
					CE,
					access(Individual,PHI)))),
	add_to_wm(s164_524e2(CE,Agent,Individual,PHI)).
obligation(CE,
	   documents(CE,title(Agent)),
	   '164.524(e)(2)') :-
	wm(s164_524e2(CE,Agent,Individual,PHI)).
% TODO what is the implied right?

% eof







