% Models section 164.530 of the HIPAA Privacy Rule

s164_530a1i(CE,PrivacyOfficial,PolicyOrProcedure) :-
	isCoveredEntity(CE),
	isPrivacyOfficial(PrivacyOfficial),
	isResponsible(PrivacyOfficial,
		      develops(PrivacyOfficial,
			       PolicyOrProcedure)),
	isResponsible(PrivacyOfficial,
		      implements(PrivacyOfficial,
				 PolicyOrProcedure)),
	isProceduresOrPolicies(CE,PolicyOrProcedure),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530a1i(CE,PrivacyOfficial,PolicyOrProcedure)).
obligation(CE,
	   designates(CE,PrivacyOfficial),
	   '164.530(a)(1)(i)') :-
	wm(s164_530a1i(CE,PrivacyOfficial,PolicyOrProcedure)).
% TODO what is the implied right?

s164_530a1ii(CE,PersonOrOffice,Individual,Contents,Section) :-
	isCoveredEntity(CE),
	isPersonOrOffice(PersonOrOffice),
	isResponsible(PersonOrOffice,
		      receives(PersonOrOffice,
			       Individual,
			       complains(Individual,_))),
	isResponsible(PersonOrOffice,
		      able(provides(PersonOrOffice,
				    Individual,
				    Contents))),
	obligation(CE,
		   contains(notice(_),
			    Contents),
		   Section),
	isSubsectionOf(Section,'164.520'),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530a1ii(CE,PersonOrOffice,Individual,Contents,Section)).
obligation(CE,
	   designates(CE,PersonOrOffice),
	   '164.530(a)(1)(ii)') :-
	wm(s164_530a1ii(CE,PersonOrOffice,Individual,Contents,Section)).
% TODO what is the implied right?

s164_530a2(CE,X,Section) :-
	isCoveredEntity(CE),
	obligation(CE,designates(CE,X),Section),
	isSubsectionOf(Section,'164.530(a)(1)'),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530a2(CE,X,Section)).
obligation(CE,
	   documents(CE,X),
	   '164.530(j)') :-
	wm(s164_530a2(CE,X,Section)).
% TODO what is the implied right?

s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure) :-
	isCoveredEntity(CE),
	isMemberOfWorkforce(WorkforceMember,CE),
	isProceduresOrPolicies(CE,PolicyOrProcedure),
	withRespectTo(PolicyOrProcedure,PHI),
	isPHI(PHI),
	isNecessaryFor(trains(CE,
			      WorkforceMember,
			      PolicyOrProcedure),
		       carriesOut(WorkforceMember,Function)),
	appropriate(for(trains(CE,
			       WorkforceMember,
			       PolicyOrProcedure),
			carriesOut(WorkforceMember,Function))),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).
obligation(CE,
	   trains(CE,WorkforceMember,PolicyOrProcedure),
	   '164.530(b)(1)') :-
	wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).
implied(right(WorkforceMember,
	      trains(CE,WorkforceMember,PolicyOrProcedure),
	      '164.530(b)(1)')) :-
	wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).

obligation(CE,
	   noLaterThan(trains(CE,WorkforceMember,PolicyOrProcedure),
		       complianceDate(CE)),
	   '164.530(b)(2)(i)(A)') :-
	wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).
implied(right(WorkforceMember,
	      noLaterThan(trains(CE,WorkforceMember,PolicyOrProcedure),
		       complianceDate(CE)),
	      '164.530(b)(2)(i)(A)')) :-
	wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).

obligation(CE,
	   reasonable(after(trains(CE,WorkforceMember,PolicyOrProcedure),
			    joins(WorkforceMember,
				  workforce(CE)))),
	   '164.530(b)(2)(i)(B)') :-
	wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).
implied(right(WorkforceMember,
	      reasonable(after(trains(CE,WorkforceMember,PolicyOrProcedure),
			    joins(WorkforceMember,
				  workforce(CE)))),
	      '164.530(b)(2)(i)(B)')) :-
	wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).

obligation(CE,
	   trains(CE,WorkforceMember,PolicyOrProcedure),
	   '164.530(b)(2)(i)(C)') :-
	affects(materially(changes(hipaa,PolicyOrProcedure)),
		Function),
	wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).
implied(right(WorkforceMember,
	       trains(CE,WorkforceMember,PolicyOrProcedure),
	      '164.530(b)(2)(i)(C)')) :-
	affects(materially(changes(hipaa,PolicyOrProcedure)),
		Function),
	wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).
	      
obligation(CE,
	   documents(CE,trains(CE,WorkforceMember,PolicyOrProcedure)),
	   '164.530(b)(2)(ii)') :-
	wm(s164_530b1(CE,WorkforceMember,Function,PolicyOrProcedure)).
% TODO what is the implied right?

s164_530c1(CE,Safeguards,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	is_164_530c1_safeguards(CE,PHI,Safeguards),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530c1(CE,Safeguards,PHI)).
is_164_530c1_safeguards(CE,PHI,administrative(safeguards(CE,privacy(PHI)))).
is_164_530c1_safeguards(CE,PHI,technical(safeguards(CE,privacy(PHI)))).
is_164_530c1_safeguards(CE,PHI,physical(safeguards(CE,privacy(PHI)))).
obligation(CE,
	   hasInPlace(CE,
		      appropriate(Safeguards)),
	   '164.530(c)(1)') :-
	wm(s164_530c1(CE,Safeguards,PHI)).
implied(right(Individual,
	      privacy(PHI),
	      '164.530(c)(1)')) :-
	about(PHI,Individual),
	wm(s164_530c1(CE,Safeguards,PHI)).

s164_530c2i(CE,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	violates(UsageOrDisclosure,hipaa),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530c2i(CE,UsageOrDisclosure,PHI)).
obligation(CE,
	   reasonable(from(safeguards(CE,PHI),
			   intentional(UsageOrDisclosure))),
	   '164.530(c)(2)(i)') :-
	wm(s164_530c2i(CE,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      reasonable(from(safeguards(CE,PHI),
			      intentional(UsageOrDisclosure))),
	      '164.530(c)(2)(i)')) :-
	about(PHI,Individual),
	wm(s164_530c2i(CE,UsageOrDisclosure,PHI)).
obligation(CE,
	   reasonable(from(safeguards(CE,PHI),
			   unintentional(UsageOrDisclosure))),
	   '164.530(c)(2)(i)') :-
	wm(s164_530c2i(CE,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      reasonable(from(safeguards(CE,PHI),
			      unintentional(UsageOrDisclosure))),
	      '164.530(c)(2)(i)')) :-
	about(PHI,Individual),
	wm(s164_530c2i(CE,UsageOrDisclosure,PHI)).

s164_530c2ii(CE,AllowedUsageOrDisclosure,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	pursuantTo(UsageOrDisclosure,AllowedUsageOrDisclosure),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	isUsageOrDisclosure(CE,_,PHI,AllowedUsageOrDisclosure),
	obligation(CE,AllowedUsageOrDisclosure,PHI),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530c2ii(CE,AllowedUsageOrDisclosure,UsageOrDisclosure,PHI)).
s164_530c2ii(CE,AllowedUsageOrDisclosure,UsageOrDisclosure,PHI) :-
	isCoveredEntity(CE),
	isPHI(PHI),
	pursuantTo(UsageOrDisclosure,AllowedUsageOrDisclosure),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	isUsageOrDisclosure(CE,_,PHI,AllowedUsageOrDisclosure),
	privilege(CE,AllowedUsageOrDisclosure,PHI),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530c2ii(CE,AllowedUsageOrDisclosure,UsageOrDisclosure,PHI)).
obligation(CE,
	   limits(reasonable(safeguards(CE,PHI)),
		  incidental(UsageOrDisclosure)),
	   '164.530(c)(1)(ii)') :-
	wm(s164_530c2ii(CE,AllowedUsageOrDisclosure,UsageOrDisclosure,PHI)).
implied(right(Individual,
	      limits(reasonable(safeguards(CE,PHI)),
		  incidental(UsageOrDisclosure)),
	   '164.530(c)(1)(ii)')) :-
	about(PHI,Individual),
	wm(s164_530c2ii(CE,AllowedUsageOrDisclosure,UsageOrDisclosure,PHI)).

s164_530d1(CE,Individual,PolicyOrProcedure,Compliant) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PolicyOrProcedure),
	is_164_530d1_complaint(CE,Individual,PolicyOrProcedure,Compliant),
	obligation(CE,PolicyOrProcedure,_),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530d1(CE,Individual,PolicyOrProcedure,Compliant)).
is_164_530d1_complaint(_,Individual,PolicyOrProcedure,complains(Individual,PolicyOrProcedure)).
is_164_530d1_complaint(CE,Individual,PolicyOrProcedure,complains(Individual,
								 complies(CE,PolicyOrProcedure))).
obligation(CE,
	   provides(CE,
		    Individual,
		    process(Compliant)),
	   '164.530(d)(1)') :-
	wm(s164_530d1(CE,Individual,PolicyOrProcedure,Compliant)).
implied(right(Individual,
	      Compliant,
	      '164.530(d)(1)')) :-
	wm(s164_530d1(CE,Individual,PolicyOrProcedure,Compliant)).

obligation(CE,
	   documents(CE,complains(Individual,_)),
	   '164.530(d)(2)') :-
	isCoveredEntity(CE),
	complains(Individual,_).
% TODO what is the implied right?
obligation(CE,
	   documents(CE,disposition(complains(Individual,_))),
	   '164.530(d)(2)') :-
	isCoveredEntity(CE),
	complains(Individual,_).
% TODO what is the implied right?

s164_530e1(CE,WorkforceMember,PolicyOrProcedure) :-
	isCoveredEntity(CE),
	isMemberOfWorkforce(WorkforceMember,CE),
        fails(complies(WorkforceMember,PolicyOrProcedure)),
	isProceduresOrPolicies(CE,PolicyOrProcedure),
	not(s164_530e1_exception(CE,WorkforceMember)),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530e1(CE,WorkforceMember,PolicyOrProcedure)).
s164_530e1_exception(CE,WorkforceMember) :-
	s164_530g2(CE,WorkforceMember).
s164_530e1_exception(CE,WhistleBlower) :-
	(   wm(s164_502j1i(CE,WhistleBlower,Agency,PHI)) ;
	    wm(s164_502j1iiA(CE,WhistleBlower,Agency,PHI)) ;
	    wm(s164_502j1iiB(CE,WhistleBlower,_,PHI)) ;
	    wm(s164_502j2i(CE,_,_,_,PHI))
	).
obligation(CE,
	   applies(CE,sanctions,WorkforceMember),
	   '164.530(e)(1)') :-
	wm(s164_530e1(CE,WorkforceMember,PolicyOrProcedure)).
% TODO what is the implied right?

obligation(CE,
	   documents(CE,applies(CE,sanctions,WorkforceMember)),
	   '164.530(e)(2)') :-
	isCoveredEntity(CE),
	isMemberOfWorkforce(WorkforceMember,CE),
	applies(CE,sanctions,WorkforceMember),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)).%
% TODO what is the implied right?

s164_530f(CE,UsageOrDisclosure,PolicyOrProcedure,PHI) :-
	isCoveredEntity(CE),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	isPHI(PHI),
	violates(UsageOrDisclosure,PolicyOrProcedure),
	isProceduresOrPolicies(CE,PolicyOrProcedure),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530f(CE,UsageOrDisclosure,PolicyOrProcedure,PHI)).
s164_530f(CE,UsageOrDisclosure,PolicyOrProcedure,PHI) :-
	isCoveredEntity(CE),
	isUsageOrDisclosure(CE,_,PHI,UsageOrDisclosure),
	isPHI(PHI),
	violates(UsageOrDisclosure,hipaa), % TODO requirements vs obligations
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530f(CE,UsageOrDisclosure,PolicyOrProcedure,PHI)).
obligation(CE,
	   mitigates(CE,harmfulEffects(UsageOrDisclosure)),
	   '164.530(f)') :-
	wm(s164_530f(CE,UsageOrDisclosure,PolicyOrProcedure,PHI)).
implied(right(Individual,
	      mitigates(CE,harmfulEffects(UsageOrDisclosure)),
	      '164.530(f)')) :-
	about(PHI,Individual),
	wm(s164_530f(CE,UsageOrDisclosure,PolicyOrProcedure,PHI)).

s164_530g1(CE,Individual,Action,ThreateningAct) :-
	isCoveredEntity(CE),
	isThreateningAct(CE,Individual,ThreateningAct),
	is_164_530g1_action(CE,Individual,Action),
	add_to_wm(s164_530g1(CE,Individual,Action,ThreateningAct)).
is_164_530g1_action(CE,Individual,right(Individual,_,_)).
is_164_530g1_action(_,Individual,Process) :- % TODO What does "process" mean?
	provides(hipaa,
		 Individual,
		 Process).
is_164_530g1_action(_,Individual,complains(Individual,_)).
obligation(CE,
	   not(for(ThreateningAct,
		   Action)),
	   '164.530(g)(1)') :-
	wm(s164_530g1(CE,Individual,Action,ThreateningAct)).
implied(right(Individual,
	      not(for(ThreateningAct,
		      Action)),
	      '164.530(g)(1)')) :-
	wm(s164_530g1(CE,Individual,Action,ThreateningAct)).

s164_530g2(CE,WorkforceMember) :-
	isCoveredEntity(CE),
	isMemberOfWorkforce(WorkforceMember,CE),
	is_160_316_forbiddenAction(intimidates(CE,WorkforceMember)),
	add_to_wm(s164_530g2(CE,WorkforceMember)).
:- dynamic is_160_316_forbiddenAction/1.
obligation(CE,
	   not(intimidates(CE,WorkforceMember)),
	   '164.530(g)(2)') :-
	wm(s164_530g2(CE,WorkforceMember)).
implied(right(WorkforceMember,
	      not(intimidates(CE,WorkforceMember)),
	      '164.530(g)(2)')) :-
	wm(s164_530g2(CE,WorkforceMember)).
obligation(CE,
	   not(retaliatoryAction(CE,WorkforceMember)),
	   '164.530(g)(2)') :-
	wm(s164_530g2(CE,WorkforceMember)).
implied(right(WorkforceMember,
	      not(retaliatoryAction(CE,WorkforceMember)),
	      '164.530(g)(2)')) :-
	wm(s164_530g2(CE,WorkforceMember)).

is_164_530h_benefits(CE,Individual,treats(CE,Individual)).
is_164_530h_benefits(HP,Individual,enrolls(Individual,HP)) :-
	isHealthPlan(HP).
is_164_530h_benefits(CE,Individual,eligible(Individual,healthBenefits(CE))).
obligation(CE,
	   not(conditionOf(requires(CE,
				    Individual,
				    waives(Individual,right(Individual,_,_))),
			   provides(CE,
				    Individual,
				    Benefits))),
	   '164.530(h)') :-
	isCoveredEntity(CE),
	is_164_530h_benefits(CE,Individual,Benefits).
implied(right(Individual,
	      not(conditionOf(requires(CE,
				    Individual,
				    waives(Individual,right(Individual,_,_))),
			   provides(CE,
				    Individual,
				    Benefits))),
	   '164.530(h)')) :-
	isCoveredEntity(CE),
	is_164_530h_benefits(CE,Individual,Benefits).

s164_530i1(CE,PolicyOrProcedure,PHI) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PolicyOrProcedure),
	designed(PolicyOrProcedure,complies(CE,hipaa)),
	isPHI(PHI),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),%
	add_to_wm(s164_530i1(CE,PolicyOrProcedure,PHI)).
obligation(CE,
	   implements(withRespectTo(PolicyOrProcedure,PHI)),
	   '164.530(i)(1)') :-
	wm(s164_530i1(CE,PolicyOrProcedure,PHI)).
implied(right(Individual,
	      implements(withRespectTo(PolicyOrProcedure,PHI)),
	      '164.530(i)(1)')) :-
	about(PHI,Individual),
	wm(s164_530i1(CE,PolicyOrProcedure,PHI)).
obligation(CE,
	   takesIntoAccount(reasonable(designed(PolicyOrProcedure,complies(CE,hipaa))),
			    Activity),
	   '164.530(i)(1)') :-
	is_164_530i1_activity(CE,Activity),
	wm(s164_530i1(CE,PolicyOrProcedure,PHI)).
is_164_530i1_activity(CE,size(activities(CE))).
is_164_530i1_activity(CE,typeOf(activities(CE))).
implied(right(Individual,
	      takesIntoAccount(reasonable(designed(PolicyOrProcedure,complies(CE,hipaa))),
			    Activity),
	   '164.530(i)(1)')) :-
	is_164_530i1_activity(CE,Activity),
	about(PHI,Individual),
	wm(s164_530i1(CE,PolicyOrProcedure,PHI)).

obligation(CE,
	   not(construes(CE,
			 X,
			 permits(PolicyOrProcedure,violates(CE,hipaa)))),
	   '164.530(i)(1)_3') :-
	is_164_530i1_action(CE,PolicyOrProcedure,PHI,X),
	wm(s164_530i1(CE,PolicyOrProcedure,PHI)).
% TODO what is the implied right?
is_164_530i1_action(CE,
		    PolicyOrProcedure,
		    _,
		    takesIntoAccount(reasonable(designed(PolicyOrProcedure,complies(CE,hipaa))),
				     Activity)).
is_164_530i1_action(_,
		    PolicyOrProcedure,
		    PHI,
		    implements(withRespectTo(PolicyOrProcedure,PHI))).

obligation(CE,
	   asNecessary(CE,
		       appropriate(to(changes(CE,
					      PolicyOrProcedure),
				      complies(CE,hipaa)))),
	   '164.530(i)(2)(i)') :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PolicyOrProcedure).
% TODO what is the implied right?

s164_530i2ii(CE,Individual,PrivacyPractices,CreatesOrReceives,PHI) :-
	isCoveredEntity(CE),
	isPrivacyPractice(PrivacyPractices),
	isPHI(PHI),
	before(CreatesOrReceives,%
	       effectiveDate(changes(CE,PrivacyPractices))),%
	createsOrReceives(CE,_,PHI,CreatesOrReceives),
	includes(notice(_),
		 statement(reserves(CE,
				    right(CE,
					  changes(CE,PrivacyPractices),
					  _)))),
	about(PHI,Individual),
	ensures(CE,
		complies(revises(CE,PrivacyPractices),
			 hipaa)),
	documents(CE,revises(CE,PrivacyPractices)),
	not(before(implements(CE,
			      changes(CE,PrivacyPractices)),
		   effectiveDate(revises(CE,notice(_))))),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),
	add_to_wm(s164_530i2ii(CE,Individual,PrivacyPractices,CreatesOrReceives,PHI)).
privilege(CE,
	  makesEffective(CE,
			 changes(CE,PrivacyPractices),
			 PHI),
	  '164.530(i)(2)(ii)') :-
	wm(s164_530i2ii(CE,Individual,PrivacyPractices,CreatesOrReceives,PHI)).
implied(noRight(Individual,
		right(Individual,
		      not(makesEffective(CE,
					 changes(CE,PrivacyPractices),
					 PHI)),
		      _),
		'164.530(i)(2)(ii)')) :-
	wm(s164_530i2ii(CE,Individual,PrivacyPractices,CreatesOrReceives,PHI)).

s164_530i3(CE,Law,PolicyOrProcedure) :-
	isCoveredEntity(CE),
	changes(_,Law),
	isLaw(Law),
	necessitates(changes(_,Law),
		     changes(CE,PolicyOrProcedure)),
	isProceduresOrPolicies(CE,PolicyOrProcedure),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),
	add_to_wm(s164_530i3(CE,Law,PolicyOrProcedure)).
obligation(CE,
	   promptly(CE,
		    (	documents(CE,changes(CE,PolicyOrProcedure)),
			implements(CE,changes(CE,PolicyOrProcedure))
		    )),
	   '164.503(i)(3)') :-
	wm(s164_530i3(CE,Law,PolicyOrProcedure)).
implied(right(Individual,
	      promptly(CE,
		    (	documents(CE,changes(CE,PolicyOrProcedure)),
			implements(CE,changes(CE,PolicyOrProcedure))
		    )),
	      '164.503(i)(3)')) :-
	wm(s164_530i3(CE,Law,PolicyOrProcedure)).
% TODO how to connect Individual to the implied right 164.530(i)(3)

obligation(CE,
	   promptly(appropriate(revises(CE,notice(_)))),
	   '164.530(i)(3)') :-
	materially(affects(changes(_,Law),notice(_))),
	wm(s164_530i3(CE,Law,PolicyOrProcedure)).
implied(right(Individual,
	      promptly(appropriate(revises(CE,notice(_)))),
	      '164.530(i)(3)')) :-
	materially(affects(changes(_,Law),notice(_))),
	wm(s164_530i3(CE,Law,PolicyOrProcedure)).
% TODO how to connect Individual to the implied right 164.530(i)(3)

% TODO need recursive document model to handle the phrase "Nothing in
% this paragraph..." in 164.530(i)(3)

s164_530i4iA(CE,PrivacyPractices) :-
	isCoveredEntity(CE),
	states(notice(_),PrivacyPractices),
	isPrivacyPractice(PrivacyPractices),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),
	add_to_wm(s164_530i4iA(CE,PrivacyPractices)).
obligation(CE,
	   ensures(CE,
		   complies(revises(CE,PrivacyPractices),
			    hipaa)),
	   '164.530(i)(4)(i)(A)') :-
	wm(s164_530i4iA(CE,PrivacyPractices)).
implied(right(Individual,
	      ensures(CE,
		      complies(revises(CE,PrivacyPractices),
			       hipaa)),
	      '164.530(i)(4)(i)(A)')) :-
	wm(s164_530i4iA(CE,PrivacyPractices)).
% TODO how to connect Individual to the implied right 164.530(i)(4)(i)(A)

obligation(CE,
	   documents(CE,revises(CE,PrivacyPractices)),
	   '164.530(i)(4)(i)(B)') :-
	isCoveredEntity(CE),
	revises(CE,PrivacyPractices),
	isPrivacyPractice(PrivacyPractices).
% TODO what is the implied right?

s164_530i4iC(CE,PrivacyPractices) :-
	isCoveredEntity(CE),
	isPrivacyPractice(PrivacyPractices),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),
	add_to_wm(s164_530i4iC(CE,PrivacyPractices)).
obligation(CE,
	   not(before(implements(CE,
				 changes(CE,PrivacyPractices)),
		      effectiveDate(revises(CE,notice(_))))),
	   '164.530(i)(4)(i)(C)') :-
	wm(s164_530i4iC(CE,PrivacyPractices)).
implied(right(Individual,
	      not(before(implements(CE,
				    changes(CE,PrivacyPractices)),
			 effectiveDate(revises(CE,notice(_))))),
	      '164.530(i)(4)(i)(C)')) :-
	wm(s164_530i4iC(CE,PrivacyPractices)).
% TODO how to connect Individual to the implied right 164.530(i)(4)(i)(C)

s164_530i4i(CE,PrivacyPractices,notice(X)) :-
	not(reserves(CE,
		     right(CE,
			   changes(CE,PrivacyPractices),
			   _))),
	isCoveredEntity(CE),
	isPrivacyPractice(PrivacyPractices),
	states(notice(X),PrivacyPractices),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),
	add_to_wm(s164_530i4i(CE,PrivacyPractices,notice(X))).
obligation(CE,
	   isBound(CE,PrivacyPractices),
	   '164.530(i)(4)(ii)') :-
	wm(s164_530i4i(CE,PrivacyPractices,notice(_))).
implied(right(Individual,
	      isBound(CE,PrivacyPractices),
	      '164.530(i)(4)(ii)')) :-
	wm(s164_530i4i(CE,PrivacyPractices,notice(_))).
% TODO how to connect Individual to the implied right 164.530(i)(4)(ii)

privilege(CE,
	  changes(CE,PrivacyPractices),
	  '164.530(i)(4)(ii)') :-
	ensures(CE,
		complies(revises(CE,PrivacyPractices),
			 hipaa)),
	documents(CE,revises(CE,PrivacyPractices)),
	not(before(implements(CE,
			      changes(CE,PrivacyPractices)),
		   effectiveDate(revises(CE,notice(_))))),
	wm(s164_530i4i(CE,PrivacyPractices,notice(_))).
implied(noRight(Individual,
		right(Individual,
		      not(changes(CE,PrivacyPractices)),
		      _),
		'164.530(i)(4)(ii)')) :-
	ensures(CE,
		complies(revises(CE,PrivacyPractices),
			 hipaa)),
	documents(CE,revises(CE,PrivacyPractices)),
	not(before(implements(CE,
			      changes(CE,PrivacyPractices)),
		   effectiveDate(revises(CE,notice(_))))),
	wm(s164_530i4i(CE,PrivacyPractices,notice(_))).

obligation(CE,
	   effective(changes(CE,PrivacyPractices),
		     PHI),
	   '164.530(i)(4)(ii)(B)') :-
	after(CreatesOrReceives,effectiveDate(notice(X))),
	createsOrReceives(CE,_,PHI,CreatesOrReceives),
	wm(s164_530i4i(CE,PrivacyPractices,notice(X))).
implied(right(Individual,
	      effective(changes(CE,PrivacyPractices),
			PHI),
	      '164.530(i)(4)(ii)(B)')) :-
	about(PHI,Individual),
	after(CreatesOrReceives,effectiveDate(notice(X))),
	createsOrReceives(CE,_,PHI,CreatesOrReceives),
	wm(s164_530i4i(CE,PrivacyPractices,notice(X))).

s164_530i5(CE,PolicyOrProcedure) :-
	isCoveredEntity(CE),
	isProceduresOrPolicies(CE,PolicyOrProcedure),
	not(materially(affects(changes(CE,PolicyOrProcedure),
			       notice(_)))),
	complies(revises(CE,PolicyOrProcedure),
		 hipaa),
	documents(CE,PolicyOrProcedure),
	not(groupHealthPlanException(CE,ThirdParty,Individual,CreatesOrReceives,PHI)),
	add_to_wm(s164_530i5(CE,PolicyOrProcedure)).
privilege(CE,
	  changes(CE,PolicyOrProcedure),
	  '164.530(i)(5)') :-
	wm(s164_530i5(CE,PolicyOrProcedure)).
implied(noRight(Individual,
		right(Individual,
		      not(changes(CE,PolicyOrProcedure)),
		      _),
		'164.530(i)(5)')) :-
	wm(s164_530i5(CE,PolicyOrProcedure)).

obligation(CE,
	   maintains(CE,PolicyOrProcedure),
	   '164.530(j)(1)') :-
	inWrittenOrElectronicForm(PolicyOrProcedure),
	isCoveredEntity(CE).
% TODO what is the implied right?

obligation(CE,
	   from(retains(documents(CE,X),year(6)),
	        date(creates(CE,X))),
	   '164.530(j)(2)') :-
	isCoveredEntity(CE),
	after(date(creates(CE,X)),
	      date(last(effective(X,_)))),
	obligation(CE,documents(CE,X),_).
implied(right(Individual,
	      from(retains(documents(CE,X),year(6)),
		   date(creates(CE,X))),
	      '164.530(j)(2)')) :-
	isCoveredEntity(CE),
	after(date(creates(CE,X)),
	      date(last(effective(X,_)))),
	obligation(CE,documents(CE,X),_).
% TODO how to connect Individual to the implied right 164.530(j)(2)

obligation(CE,
	   from(retains(documents(CE,X),year(6)),
	        date(last(effective(CE,X)))),
	   '164.530(j)(2)') :-
	isCoveredEntity(CE),
	after(date(last(effective(X,_))),
	      date(creates(CE,X))),
	obligation(CE,documents(CE,X),_).
implied(right(Individual,
	      from(retains(documents(CE,X),year(6)),
		   date(last(effective(CE,X)))),
	      '164.530(j)(2)')) :-
	isCoveredEntity(CE),
	after(date(last(effective(X,_))),
	      date(creates(CE,X))),
	obligation(CE,documents(CE,X),_).
% TODO how to connect Individual to the implied right 164.530(j)(2)

% TODO privilege "is not subject to" for 164.530(k)

groupHealthPlanException(GHP,HIIorHMO,Individual,CreatesOrReceives,PHI) :-
	wm(s164_530k1(GHP,HIIorHMO,Individual,CreatesOrReceives,PHI)).
s164_530k1(GHP,HIIorHMO,Individual,CreatesOrReceives,PHI) :-
	isGroupHealthPlan(GHP),
	solely(through(provides(GHP,Individual,healthBenefits(GHP)),
		       HIIorHMO)),
	isHIIorHMO(HIIorHMO),
	not(CreatesOrReceives),
	createsOrReceives(GHP,_,PHI,CreatesOrReceives),
	isPHI(PHI),
	not(allowed_164_530k1_information(HIIorHMO,PHI)),
	add_to_wm(s164_530k1(GHP,HIIorHMO,Individual,CreatesOrReceives,PHI)).
isHIIorHMO(X) :-
	isHealthInsuranceIssuer(X).
isHIIorHMO(X) :-
	isHMO(X).
allowed_164_530k1_information(_,summary(PHI)) :-
	isPHI(PHI).
allowed_164_530k1_information(HIIorHMO,PHI) :-
	about(PHI,
	      enrolled(Individual,HIIorHMO)),
	about(PHI,Individual).
allowed_164_530k1_information(HIIorHMO,PHI) :-
	about(PHI,
	      disenrolled(Individual,HIIorHMO)),
	about(PHI,Individual).

% eof
